#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1 
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {} 
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; } 
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; } 
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr; 
  size_t sz0, sz1; 
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {} 
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; } 
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T> 
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a > r && b > r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow; 
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && (((a ^ b) >= 0 && a > std::numeric_limits<T>::max() / b) || ((a ^ b) < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow; 
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _151,    std::shared_ptr< monty::ndarray< long long,1 > > _152,    int _153,    int _154,    int _155,    std::shared_ptr< monty::ndarray< long long,1 > > _156) { mosek::fusion::p_Sort::argTransposeSort(_151,_152,_153,_154,_155,_156); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156){
  _checked_ptr_1<long long> _ptr__151(_151 ? _151->raw() : nullptr, _151 ? _151->size(0) : 0);
  _checked_ptr_1<long long> _ptr__152(_152 ? _152->raw() : nullptr, _152 ? _152->size(0) : 0);
  _checked_ptr_1<long long> _ptr__156(_156 ? _156->raw() : nullptr, _156 ? _156->size(0) : 0);
  int _6657 = (int)0;
  int _6658 = safe_add( safe_mul( _153,_155 ),(int)1 );
  for (int _157 = _6657; _157 < _6658; ++_157)
  {
    {
      _ptr__152[_157] = (int)0;
    }
  }
  int _6659 = (int)0;
  int _6660 = (int)((_156)->size(0));
  for (int _158 = _6659; _158 < _6660; ++_158)
  {
    {
      ++ _ptr__152[safe_add( safe_add( safe_mul( (_ptr__156[_ptr__151[_158]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__151[_158]] % _155) ),(int)1 )];
    }
  }
  int _6661 = (int)0;
  int _6662 = safe_mul( _153,_155 );
  for (int _159 = _6661; _159 < _6662; ++_159)
  {
    {
      _ptr__152[safe_add( _159,(int)1 )] = safe_add( _ptr__152[safe_add( _159,(int)1 )],_ptr__152[_159] );
    }
  }
  std::vector<long long> _6663;
  for (int _161 = (int)0, _6664 = (int)((_151)->size(0)); _161 < _6664 ; ++_161)
  {
    _6663.push_back(_ptr__151[_161]);
  }
  auto _6665 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6663.size()),_6663.begin(),_6663.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _160 = _6665;
  _checked_ptr_1<long long> _ptr__160(_160 ? _160->raw() : nullptr,_160 ? _160->size(0) : 0);
  long long _6666 = (long long)0;
  long long _6667 = (long long)((_156)->size(0));
  for (long long _162 = _6666; _162 < _6667; ++_162)
  {
    {
      long long _163 = safe_add( safe_mul( (_ptr__156[_ptr__160[_162]] / safe_mul( _154,_155 )),_155 ),(_ptr__156[_ptr__160[_162]] % _155) );
      _ptr__151[_ptr__152[_163]] = _ptr__160[_162];
      ++ _ptr__152[_163];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _164,    std::shared_ptr< monty::ndarray< long long,1 > > _165) { mosek::fusion::p_Sort::argsort(_164,_165); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165){
  _checked_ptr_1<long long> _ptr__164(_164 ? _164->raw() : nullptr, _164 ? _164->size(0) : 0);
  _checked_ptr_1<long long> _ptr__165(_165 ? _165->raw() : nullptr, _165 ? _165->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_164,_165,(long long)((int)0),(long long)((int)((_164)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _166,    std::shared_ptr< monty::ndarray< int,1 > > _167) { mosek::fusion::p_Sort::argsort(_166,_167); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167){
  _checked_ptr_1<long long> _ptr__166(_166 ? _166->raw() : nullptr, _166 ? _166->size(0) : 0);
  _checked_ptr_1<int> _ptr__167(_167 ? _167->raw() : nullptr, _167 ? _167->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_166,_167,(long long)((int)0),(long long)((int)((_166)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _168,    std::shared_ptr< monty::ndarray< long long,1 > > _169,    std::shared_ptr< monty::ndarray< long long,1 > > _170) { mosek::fusion::p_Sort::argsort(_168,_169,_170); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170){
  _checked_ptr_1<long long> _ptr__168(_168 ? _168->raw() : nullptr, _168 ? _168->size(0) : 0);
  _checked_ptr_1<long long> _ptr__169(_169 ? _169->raw() : nullptr, _169 ? _169->size(0) : 0);
  _checked_ptr_1<long long> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_168,_169,_170,(long long)((int)0),(long long)((int)((_168)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _171,    std::shared_ptr< monty::ndarray< int,1 > > _172,    std::shared_ptr< monty::ndarray< int,1 > > _173) { mosek::fusion::p_Sort::argsort(_171,_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173){
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  _checked_ptr_1<int> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<int> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_171,_172,_173,(long long)((int)0),(long long)((int)((_171)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< long long,1 > > _175,    long long _176,    long long _177) { mosek::fusion::p_Sort::argsort(_174,_175,_176,_177); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<long long> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,_177,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _178,    std::shared_ptr< monty::ndarray< int,1 > > _179,    long long _180,    long long _181) { mosek::fusion::p_Sort::argsort(_178,_179,_180,_181); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181){
  _checked_ptr_1<long long> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  _checked_ptr_1<int> _ptr__179(_179 ? _179->raw() : nullptr, _179 ? _179->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_178,_179,_180,_181,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _182,    std::shared_ptr< monty::ndarray< long long,1 > > _183,    std::shared_ptr< monty::ndarray< long long,1 > > _184,    long long _185,    long long _186) { mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186){
  _checked_ptr_1<long long> _ptr__182(_182 ? _182->raw() : nullptr, _182 ? _182->size(0) : 0);
  _checked_ptr_1<long long> _ptr__183(_183 ? _183->raw() : nullptr, _183 ? _183->size(0) : 0);
  _checked_ptr_1<long long> _ptr__184(_184 ? _184->raw() : nullptr, _184 ? _184->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_182,_183,_184,_185,_186,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _187,    std::shared_ptr< monty::ndarray< int,1 > > _188,    std::shared_ptr< monty::ndarray< int,1 > > _189,    long long _190,    long long _191) { mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191){
  _checked_ptr_1<long long> _ptr__187(_187 ? _187->raw() : nullptr, _187 ? _187->size(0) : 0);
  _checked_ptr_1<int> _ptr__188(_188 ? _188->raw() : nullptr, _188 ? _188->size(0) : 0);
  _checked_ptr_1<int> _ptr__189(_189 ? _189->raw() : nullptr, _189 ? _189->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_187,_188,_189,_190,_191,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _192,    std::shared_ptr< monty::ndarray< long long,1 > > _193,    long long _194,    long long _195,    bool _196) { mosek::fusion::p_Sort::argsort(_192,_193,_194,_195,_196); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196){
  _checked_ptr_1<long long> _ptr__192(_192 ? _192->raw() : nullptr, _192 ? _192->size(0) : 0);
  _checked_ptr_1<long long> _ptr__193(_193 ? _193->raw() : nullptr, _193 ? _193->size(0) : 0);
  if (((!_196) || ((_195 - _194) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_192,_193,_194,_195,_196)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _197 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__197(_197 ? _197->raw() : nullptr,_197 ? _197->size(0) : 0);
      int _198 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_192,_193,nullptr,_194,_195,_197);
      if (((_ptr__197[(int)1] - _ptr__197[(int)0]) < safe_mul( _198,(_195 - _194) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_192,_193,_194,_195,_ptr__197[(int)0],_ptr__197[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_192,_193,_194,_195);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _199,    std::shared_ptr< monty::ndarray< int,1 > > _200,    long long _201,    long long _202,    bool _203) { mosek::fusion::p_Sort::argsort(_199,_200,_201,_202,_203); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203){
  _checked_ptr_1<long long> _ptr__199(_199 ? _199->raw() : nullptr, _199 ? _199->size(0) : 0);
  _checked_ptr_1<int> _ptr__200(_200 ? _200->raw() : nullptr, _200 ? _200->size(0) : 0);
  if (((!_203) || ((_202 - _201) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_199,_200,_201,_202,_203)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _204 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__204(_204 ? _204->raw() : nullptr,_204 ? _204->size(0) : 0);
      int _205 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_199,_200,nullptr,_201,_202,_204);
      if (((_ptr__204[(int)1] - _ptr__204[(int)0]) < safe_mul( _205,(_202 - _201) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_199,_200,_201,_202,_ptr__204[(int)0],_ptr__204[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_199,_200,_201,_202);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _206,    std::shared_ptr< monty::ndarray< long long,1 > > _207,    std::shared_ptr< monty::ndarray< long long,1 > > _208,    long long _209,    long long _210,    bool _211) { mosek::fusion::p_Sort::argsort(_206,_207,_208,_209,_210,_211); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211){
  _checked_ptr_1<long long> _ptr__206(_206 ? _206->raw() : nullptr, _206 ? _206->size(0) : 0);
  _checked_ptr_1<long long> _ptr__207(_207 ? _207->raw() : nullptr, _207 ? _207->size(0) : 0);
  _checked_ptr_1<long long> _ptr__208(_208 ? _208->raw() : nullptr, _208 ? _208->size(0) : 0);
  if (((!_211) || ((_210 - _209) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_206,_207,_208,_209,_210,_211)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _212 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__212(_212 ? _212->raw() : nullptr,_212 ? _212->size(0) : 0);
      int _213 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_206,_207,_208,_209,_210,_212);
      if ((((_ptr__212[(int)1] - _ptr__212[(int)0]) < safe_mul( _213,(_210 - _209) )) && ((_ptr__212[(int)3] - _ptr__212[(int)2]) < safe_mul( _213,(_210 - _209) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_206,_208,_209,_210,_ptr__212[(int)2],_ptr__212[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_206,_207,_209,_210,_ptr__212[(int)0],_ptr__212[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_206,_207,_208,_209,_210);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _214,    std::shared_ptr< monty::ndarray< int,1 > > _215,    std::shared_ptr< monty::ndarray< int,1 > > _216,    long long _217,    long long _218,    bool _219) { mosek::fusion::p_Sort::argsort(_214,_215,_216,_217,_218,_219); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219){
  _checked_ptr_1<long long> _ptr__214(_214 ? _214->raw() : nullptr, _214 ? _214->size(0) : 0);
  _checked_ptr_1<int> _ptr__215(_215 ? _215->raw() : nullptr, _215 ? _215->size(0) : 0);
  _checked_ptr_1<int> _ptr__216(_216 ? _216->raw() : nullptr, _216 ? _216->size(0) : 0);
  if (((!_219) || ((_218 - _217) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_214,_215,_216,_217,_218,_219)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__220(_220 ? _220->raw() : nullptr,_220 ? _220->size(0) : 0);
      int _221 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_214,_215,_216,_217,_218,_220);
      if ((((_ptr__220[(int)1] - _ptr__220[(int)0]) < safe_mul( _221,(_218 - _217) )) && ((_ptr__220[(int)3] - _ptr__220[(int)2]) < safe_mul( _221,(_218 - _217) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_214,_216,_217,_218,_ptr__220[(int)2],_ptr__220[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_214,_215,_217,_218,_ptr__220[(int)0],_ptr__220[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_214,_215,_216,_217,_218);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _222,    std::shared_ptr< monty::ndarray< long long,1 > > _223,    long long _224,    long long _225,    long long _226,    long long _227) { mosek::fusion::p_Sort::argbucketsort(_222,_223,_224,_225,_226,_227); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227){
  _checked_ptr_1<long long> _ptr__222(_222 ? _222->raw() : nullptr, _222 ? _222->size(0) : 0);
  _checked_ptr_1<long long> _ptr__223(_223 ? _223->raw() : nullptr, _223 ? _223->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_222,_224,_225,_223,_226,_227);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _228,    std::shared_ptr< monty::ndarray< int,1 > > _229,    long long _230,    long long _231,    int _232,    int _233) { mosek::fusion::p_Sort::argbucketsort(_228,_229,_230,_231,_232,_233); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233){
  _checked_ptr_1<long long> _ptr__228(_228 ? _228->raw() : nullptr, _228 ? _228->size(0) : 0);
  _checked_ptr_1<int> _ptr__229(_229 ? _229->raw() : nullptr, _229 ? _229->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_228,_230,_231,_229,_232,_233);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _234,    std::shared_ptr< monty::ndarray< long long,1 > > _235,    std::shared_ptr< monty::ndarray< long long,1 > > _236,    long long _237,    long long _238,    std::shared_ptr< monty::ndarray< long long,1 > > _239) { mosek::fusion::p_Sort::getminmax(_234,_235,_236,_237,_238,_239); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239){
  _checked_ptr_1<long long> _ptr__234(_234 ? _234->raw() : nullptr, _234 ? _234->size(0) : 0);
  _checked_ptr_1<long long> _ptr__235(_235 ? _235->raw() : nullptr, _235 ? _235->size(0) : 0);
  _checked_ptr_1<long long> _ptr__236(_236 ? _236->raw() : nullptr, _236 ? _236->size(0) : 0);
  _checked_ptr_1<long long> _ptr__239(_239 ? _239->raw() : nullptr, _239 ? _239->size(0) : 0);
  _ptr__239[(int)0] = _ptr__235[_ptr__234[_237]];
  _ptr__239[(int)1] = _ptr__235[_ptr__234[_237]];
  long long _6668 = safe_add( _237,(int)1 );
  long long _6669 = _238;
  for (long long _240 = _6668; _240 < _6669; ++_240)
  {
    {
      if ((_ptr__239[(int)0] > _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)0] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
      if ((_ptr__239[(int)1] < _ptr__235[_ptr__234[_240]]))
      {
        {
          _ptr__239[(int)1] = _ptr__235[_ptr__234[_240]];
        }
      }
      {}
    }
  }
  if ((NULL != _236.get()))
  {
    {
      _ptr__239[(int)2] = _ptr__236[_ptr__234[_237]];
      _ptr__239[(int)3] = _ptr__236[_ptr__234[_237]];
      long long _6670 = safe_add( _237,(int)1 );
      long long _6671 = _238;
      for (long long _241 = _6670; _241 < _6671; ++_241)
      {
        {
          if ((_ptr__239[(int)2] > _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)2] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
          if ((_ptr__239[(int)3] < _ptr__236[_ptr__234[_241]]))
          {
            {
              _ptr__239[(int)3] = _ptr__236[_ptr__234[_241]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _242,    std::shared_ptr< monty::ndarray< int,1 > > _243,    std::shared_ptr< monty::ndarray< int,1 > > _244,    long long _245,    long long _246,    std::shared_ptr< monty::ndarray< int,1 > > _247) { mosek::fusion::p_Sort::getminmax(_242,_243,_244,_245,_246,_247); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247){
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _checked_ptr_1<int> _ptr__243(_243 ? _243->raw() : nullptr, _243 ? _243->size(0) : 0);
  _checked_ptr_1<int> _ptr__244(_244 ? _244->raw() : nullptr, _244 ? _244->size(0) : 0);
  _checked_ptr_1<int> _ptr__247(_247 ? _247->raw() : nullptr, _247 ? _247->size(0) : 0);
  _ptr__247[(int)0] = _ptr__243[_ptr__242[_245]];
  _ptr__247[(int)1] = _ptr__243[_ptr__242[_245]];
  long long _6672 = safe_add( _245,(int)1 );
  long long _6673 = _246;
  for (long long _248 = _6672; _248 < _6673; ++_248)
  {
    {
      if ((_ptr__247[(int)0] > _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)0] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
      if ((_ptr__247[(int)1] < _ptr__243[_ptr__242[_248]]))
      {
        {
          _ptr__247[(int)1] = _ptr__243[_ptr__242[_248]];
        }
      }
      {}
    }
  }
  if ((NULL != _244.get()))
  {
    {
      _ptr__247[(int)2] = _ptr__244[_ptr__242[_245]];
      _ptr__247[(int)3] = _ptr__244[_ptr__242[_245]];
      long long _6674 = safe_add( _245,(int)1 );
      long long _6675 = _246;
      for (long long _249 = _6674; _249 < _6675; ++_249)
      {
        {
          if ((_ptr__247[(int)2] > _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)2] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
          if ((_ptr__247[(int)3] < _ptr__244[_ptr__242[_249]]))
          {
            {
              _ptr__247[(int)3] = _ptr__244[_ptr__242[_249]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _250,    std::shared_ptr< monty::ndarray< long long,1 > > _251,    long long _252,    long long _253,    bool _254) { return mosek::fusion::p_Sort::issorted(_250,_251,_252,_253,_254); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254){
  _checked_ptr_1<long long> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _checked_ptr_1<long long> _ptr__251(_251 ? _251->raw() : nullptr, _251 ? _251->size(0) : 0);
  long long _6676 = _252;
  long long _6677 = (_253 - (int)1);
  for (long long _255 = _6676; _255 < _6677; ++_255)
  {
    {
      if ((_ptr__251[_ptr__250[_255]] > _ptr__251[_ptr__250[safe_add( _255,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _256,    std::shared_ptr< monty::ndarray< int,1 > > _257,    long long _258,    long long _259,    bool _260) { return mosek::fusion::p_Sort::issorted(_256,_257,_258,_259,_260); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260){
  _checked_ptr_1<long long> _ptr__256(_256 ? _256->raw() : nullptr, _256 ? _256->size(0) : 0);
  _checked_ptr_1<int> _ptr__257(_257 ? _257->raw() : nullptr, _257 ? _257->size(0) : 0);
  long long _6678 = _258;
  long long _6679 = (_259 - (int)1);
  for (long long _261 = _6678; _261 < _6679; ++_261)
  {
    {
      if ((_ptr__257[_ptr__256[_261]] > _ptr__257[_ptr__256[safe_add( _261,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _262,    std::shared_ptr< monty::ndarray< long long,1 > > _263,    std::shared_ptr< monty::ndarray< long long,1 > > _264,    long long _265,    long long _266,    bool _267) { return mosek::fusion::p_Sort::issorted(_262,_263,_264,_265,_266,_267); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267){
  _checked_ptr_1<long long> _ptr__262(_262 ? _262->raw() : nullptr, _262 ? _262->size(0) : 0);
  _checked_ptr_1<long long> _ptr__263(_263 ? _263->raw() : nullptr, _263 ? _263->size(0) : 0);
  _checked_ptr_1<long long> _ptr__264(_264 ? _264->raw() : nullptr, _264 ? _264->size(0) : 0);
  long long _6680 = _265;
  long long _6681 = (_266 - (int)1);
  for (long long _268 = _6680; _268 < _6681; ++_268)
  {
    {
      if (((_ptr__263[_ptr__262[_268]] > _ptr__263[_ptr__262[safe_add( _268,(int)1 )]]) || ((_ptr__263[_ptr__262[safe_add( _268,(int)1 )]] == _ptr__263[_ptr__262[_268]]) && (_ptr__264[_ptr__262[_268]] > _ptr__264[_ptr__262[safe_add( _268,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _269,    std::shared_ptr< monty::ndarray< int,1 > > _270,    std::shared_ptr< monty::ndarray< int,1 > > _271,    long long _272,    long long _273,    bool _274) { return mosek::fusion::p_Sort::issorted(_269,_270,_271,_272,_273,_274); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274){
  _checked_ptr_1<long long> _ptr__269(_269 ? _269->raw() : nullptr, _269 ? _269->size(0) : 0);
  _checked_ptr_1<int> _ptr__270(_270 ? _270->raw() : nullptr, _270 ? _270->size(0) : 0);
  _checked_ptr_1<int> _ptr__271(_271 ? _271->raw() : nullptr, _271 ? _271->size(0) : 0);
  long long _6682 = _272;
  long long _6683 = (_273 - (int)1);
  for (long long _275 = _6682; _275 < _6683; ++_275)
  {
    {
      if (((_ptr__270[_ptr__269[_275]] > _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) || ((_ptr__270[_ptr__269[_275]] == _ptr__270[_ptr__269[safe_add( _275,(int)1 )]]) && (_ptr__271[_ptr__269[_275]] > _ptr__271[_ptr__269[safe_add( _275,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276){ return new mosek::fusion::IndexCounter(_276); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _276) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_276); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _276){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__276(_276 ? _276->raw() : nullptr, _276 ? _276->size(0) : 0);
    n = (int)((_276)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_276);
    std::vector<int> _6684;
    for (int _277 = (int)0, _6685 = (int)((_276)->size(0)); _277 < _6685 ; ++_277)
    {
      _6684.push_back(_ptr__276[_277]);
    }
    auto _6686 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6684.size()),_6684.begin(),_6684.end()));
    dims = _6686;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){ return new mosek::fusion::IndexCounter(_278,_279,_280); }mosek::fusion::IndexCounter::IndexCounter  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_278,_279,_280); }void mosek::fusion::p_IndexCounter::_initialize  (long long _278,    std::shared_ptr< monty::ndarray< int,1 > > _279,    std::shared_ptr< monty::ndarray< int,1 > > _280){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__279(_279 ? _279->raw() : nullptr, _279 ? _279->size(0) : 0);
    _checked_ptr_1<int> _ptr__280(_280 ? _280->raw() : nullptr, _280 ? _280->size(0) : 0);
    int _281 = (int)((_280)->size(0));
    n = (int)((_279)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6687 = (int)0;
    int _6688 = n;
    for (int _282 = _6687; _282 < _6688; ++_282)
    {
      {
        ((*st)(_282)) = _278;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_280);
    dims = _279;
    start = _278;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){ return new mosek::fusion::IndexCounter(_283,_284,_285); }mosek::fusion::IndexCounter::IndexCounter  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_283,_284,_285); }void mosek::fusion::p_IndexCounter::_initialize  (long long _283,    std::shared_ptr< monty::ndarray< int,1 > > _284,    std::shared_ptr< monty::ndarray< long long,1 > > _285){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__284(_284 ? _284->raw() : nullptr, _284 ? _284->size(0) : 0);
    _checked_ptr_1<long long> _ptr__285(_285 ? _285->raw() : nullptr, _285 ? _285->size(0) : 0);
    n = (int)((_284)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _6689 = (int)0;
    int _6690 = n;
    for (int _286 = _6689; _286 < _6690; ++_286)
    {
      {
        ((*st)(_286)) = _283;
      }
    }
    strides = _285;
    dims = _284;
    start = _283;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _287 = _pubthis->get();
  _pubthis->inc();
  return _287;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _288;
  {
    _288 = (int)0;
    for(;((_288 < (n - (int)1)) && (((*ii)(_288)) == ((*dims)(((n - _288) - (int)1)))));++ _288)
    {
      {
        ((*ii)(_288)) = (int)0;
        ++ ((*ii)(safe_add( _288,(int)1 )));
        ((*st)(safe_add( _288,(int)1 ))) = safe_add( ((*st)(safe_add( _288,(int)1 ))),((*strides)(((n - _288) - (int)2))) );
      }
    }
  }
  int _6691 = (int)0;
  int _6692 = _288;
  for (int _289 = _6691; _289 < _6692; ++_289)
  {
    {
      ((*st)(_289)) = ((*st)(_288));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _6693 = (int)0;
  int _6694 = n;
  for (int _290 = _6693; _290 < _6694; ++_290)
  {
    {
      ((*st)(_290)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _291,    int _292) { return mosek::fusion::p_CommonTools::resize(_291,_292); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292){
  _checked_ptr_1<long long> _ptr__291(_291 ? _291->raw() : nullptr, _291 ? _291->size(0) : 0);
  if ((_292 == (int)((_291)->size(0))))
  {
    {
      return _291;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_292)));
      _checked_ptr_1<long long> _ptr__293(_293 ? _293->raw() : nullptr,_293 ? _293->size(0) : 0);
      if ((_292 > (int)((_291)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,(int)((_291)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_291,(int)0,_293,(int)0,_292);
        }
      }
      return _293;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _294,    int _295) { return mosek::fusion::p_CommonTools::resize(_294,_295); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295){
  _checked_ptr_1<int> _ptr__294(_294 ? _294->raw() : nullptr, _294 ? _294->size(0) : 0);
  if ((_295 == (int)((_294)->size(0))))
  {
    {
      return _294;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _296 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_295)));
      _checked_ptr_1<int> _ptr__296(_296 ? _296->raw() : nullptr,_296 ? _296->size(0) : 0);
      if ((_295 > (int)((_294)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,(int)((_294)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_294,(int)0,_296,(int)0,_295);
        }
      }
      return _296;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298){
  _checked_ptr_1<double> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _299 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_298)));
      _checked_ptr_1<double> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::binarySearch(_300,_301); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301){
  _checked_ptr_1<int> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  int _302 = (int)0;
  int _303 = (int)((_300)->size(0));
  if ((_ptr__300[_302] == _301))
  {
    {
      return _302;
    }
  }
  else if((_ptr__300[(_303 - (int)1)] == _301))
  {
    {
      return (_303 - (int)1);
    }
  }
  {}
  while ( (_302 < (_303 - (int)1)) )
  {
    {
      int _304 = ((_303 - _302) / (int)2);
      if ((_301 < _ptr__300[_304]))
      {
        {
          _302 = safe_add( _304,(int)1 );
        }
      }
      else if((_301 > _ptr__300[_304]))
      {
        {
          _303 = _304;
        }
      }
      else
      {
        {
          return _304;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _305,    long long _306) { return mosek::fusion::p_CommonTools::binarySearch(_305,_306); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306){
  _checked_ptr_1<long long> _ptr__305(_305 ? _305->raw() : nullptr, _305 ? _305->size(0) : 0);
  int _307 = ::mosek::fusion::p_CommonTools::binarySearchL(_305,_306);
  if (((_307 < (int)((_305)->size(0))) && (_ptr__305[_307] == _306)))
  {
    {
      return _307;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _308,    long long _309) { return mosek::fusion::p_CommonTools::binarySearchR(_308,_309); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309){
  _checked_ptr_1<long long> _ptr__308(_308 ? _308->raw() : nullptr, _308 ? _308->size(0) : 0);
  int _310 = (int)0;
  int _311 = (int)((_308)->size(0));
  if ((_ptr__308[_310] > _309))
  {
    {
      return _310;
    }
  }
  {}
  while ( (_310 < (_311 - (int)1)) )
  {
    {
      int _312 = (safe_add( _311,_310 ) / (int)2);
      if ((_309 >= _ptr__308[_312]))
      {
        {
          _310 = _312;
        }
      }
      else
      {
        {
          _311 = _312;
        }
      }
    }
  }
  return _311;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _313,    long long _314) { return mosek::fusion::p_CommonTools::binarySearchL(_313,_314); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314){
  _checked_ptr_1<long long> _ptr__313(_313 ? _313->raw() : nullptr, _313 ? _313->size(0) : 0);
  int _315 = (int)0;
  int _316 = (int)((_313)->size(0));
  if ((_314 <= _ptr__313[_315]))
  {
    {
      return _315;
    }
  }
  {}
  while ( (_315 < (_316 - (int)1)) )
  {
    {
      int _317 = (safe_add( _316,_315 ) / (int)2);
      if ((_ptr__313[_317] < _314))
      {
        {
          _315 = _317;
        }
      }
      else
      {
        {
          _316 = _317;
        }
      }
    }
  }
  return _316;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _318,    std::shared_ptr< monty::ndarray< int,1 > > _319,    std::shared_ptr< monty::ndarray< int,1 > > _320) { mosek::fusion::p_CommonTools::ndIncr(_318,_319,_320); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320){
  _checked_ptr_1<int> _ptr__318(_318 ? _318->raw() : nullptr, _318 ? _318->size(0) : 0);
  _checked_ptr_1<int> _ptr__319(_319 ? _319->raw() : nullptr, _319 ? _319->size(0) : 0);
  _checked_ptr_1<int> _ptr__320(_320 ? _320->raw() : nullptr, _320 ? _320->size(0) : 0);
  int _321 = ((int)((_318)->size(0)) - (int)1);
  ++ _ptr__318[_321];
  while ( ((_321 > (int)0) && (_ptr__318[_321] >= _ptr__320[_321])) )
  {
    {
      _ptr__318[_321] = _ptr__319[_321];
      ++ _ptr__318[(_321 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _322,    std::shared_ptr< monty::ndarray< int,1 > > _323,    std::shared_ptr< monty::ndarray< double,1 > > _324,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,    long long _328,    int _329,    int _330) { mosek::fusion::p_CommonTools::transposeTriplets(_322,_323,_324,_325,_326,_327,_328,_329,_330); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330){
  _checked_ptr_1<int> _ptr__322(_322 ? _322->raw() : nullptr, _322 ? _322->size(0) : 0);
  _checked_ptr_1<int> _ptr__323(_323 ? _323->raw() : nullptr, _323 ? _323->size(0) : 0);
  _checked_ptr_1<double> _ptr__324(_324 ? _324->raw() : nullptr, _324 ? _324->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _329,(int)2 ))));
  _checked_ptr_1<long long> _ptr__331(_331 ? _331->raw() : nullptr,_331 ? _331->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _330,(int)2 ))));
  _checked_ptr_1<long long> _ptr__332(_332 ? _332->raw() : nullptr,_332 ? _332->size(0) : 0);
  {
    long long _333 = (long long)0;
    for(;(_333 < _328);++ _333)
    {
      {
        _ptr__332[safe_add( _ptr__323[_333],(int)2 )] = safe_add( _ptr__332[safe_add( _ptr__323[_333],(int)2 )],(int)1 );
        _ptr__331[safe_add( _ptr__322[_333],(int)2 )] = safe_add( _ptr__331[safe_add( _ptr__322[_333],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _334 = (int)1;
    for(;(_334 < _329);++ _334)
    {
      {
        _ptr__331[safe_add( _334,(int)1 )] = safe_add( _ptr__331[safe_add( _334,(int)1 )],_ptr__331[_334] );
      }
    }
  }
  {
    int _335 = (int)1;
    for(;(_335 < _330);++ _335)
    {
      {
        _ptr__332[safe_add( _335,(int)1 )] = safe_add( _ptr__332[safe_add( _335,(int)1 )],_ptr__332[_335] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__336(_336 ? _336->raw() : nullptr,_336 ? _336->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _337 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_328)));
  _checked_ptr_1<long long> _ptr__337(_337 ? _337->raw() : nullptr,_337 ? _337->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_328)));
  _checked_ptr_1<double> _ptr__338(_338 ? _338->raw() : nullptr,_338 ? _338->size(0) : 0);
  int _6695 = (int)0;
  int _6696 = _329;
  for (int _339 = _6695; _339 < _6696; ++_339)
  {
    {
      {
        long long _340 = _ptr__331[_339];
        for(;(_340 < _ptr__331[safe_add( _339,(int)1 )]);++ _340)
        {
          {
            int _341 = _ptr__323[_340];
            long long _342 = _ptr__332[_341];
            _ptr__336[_342] = _339;
            _ptr__337[_342] = _341;
            _ptr__338[_342] = _ptr__324[_340];
            _ptr__332[_341] = safe_add( _342,(int)1 );
          }
        }
      }
    }
  }
  ((*_325)((int)0)) = _337;
  ((*_326)((int)0)) = _336;
  ((*_327)((int)0)) = _338;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _343,    std::shared_ptr< monty::ndarray< int,1 > > _344,    std::shared_ptr< monty::ndarray< double,1 > > _345,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,    long long _349,    int _350,    int _351) { mosek::fusion::p_CommonTools::transposeTriplets(_343,_344,_345,_346,_347,_348,_349,_350,_351); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351){
  _checked_ptr_1<int> _ptr__343(_343 ? _343->raw() : nullptr, _343 ? _343->size(0) : 0);
  _checked_ptr_1<int> _ptr__344(_344 ? _344->raw() : nullptr, _344 ? _344->size(0) : 0);
  _checked_ptr_1<double> _ptr__345(_345 ? _345->raw() : nullptr, _345 ? _345->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _352 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _350,(int)2 ))));
  _checked_ptr_1<long long> _ptr__352(_352 ? _352->raw() : nullptr,_352 ? _352->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _353 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _351,(int)2 ))));
  _checked_ptr_1<long long> _ptr__353(_353 ? _353->raw() : nullptr,_353 ? _353->size(0) : 0);
  {
    long long _354 = (long long)0;
    for(;(_354 < _349);++ _354)
    {
      {
        _ptr__353[safe_add( _ptr__344[_354],(int)2 )] = safe_add( _ptr__353[safe_add( _ptr__344[_354],(int)2 )],(int)1 );
        _ptr__352[safe_add( _ptr__343[_354],(int)2 )] = safe_add( _ptr__352[safe_add( _ptr__343[_354],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _355 = (int)1;
    for(;(_355 < _350);++ _355)
    {
      {
        _ptr__352[safe_add( _355,(int)1 )] = safe_add( _ptr__352[safe_add( _355,(int)1 )],_ptr__352[_355] );
      }
    }
  }
  {
    int _356 = (int)1;
    for(;(_356 < _351);++ _356)
    {
      {
        _ptr__353[safe_add( _356,(int)1 )] = safe_add( _ptr__353[safe_add( _356,(int)1 )],_ptr__353[_356] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _357 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__357(_357 ? _357->raw() : nullptr,_357 ? _357->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_349)));
  _checked_ptr_1<int> _ptr__358(_358 ? _358->raw() : nullptr,_358 ? _358->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _359 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_349)));
  _checked_ptr_1<double> _ptr__359(_359 ? _359->raw() : nullptr,_359 ? _359->size(0) : 0);
  {
    int _360 = (int)0;
    for(;(_360 < _350);++ _360)
    {
      {
        long long _6697 = _ptr__352[_360];
        long long _6698 = _ptr__352[safe_add( _360,(int)1 )];
        for (long long _361 = _6697; _361 < _6698; ++_361)
        {
          {
            int _362 = _ptr__344[_361];
            long long _363 = _ptr__353[_362];
            _ptr__357[_363] = _360;
            _ptr__358[_363] = _362;
            _ptr__359[_363] = _ptr__345[_361];
            _ptr__353[_362] = safe_add( _363,(int)1 );
          }
        }
      }
    }
  }
  ((*_346)((int)0)) = _358;
  ((*_347)((int)0)) = _357;
  ((*_348)((int)0)) = _359;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _364,    std::shared_ptr< monty::ndarray< int,1 > > _365,    std::shared_ptr< monty::ndarray< double,1 > > _366,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,    long long _370,    int _371,    int _372) { mosek::fusion::p_CommonTools::tripletSort(_364,_365,_366,_367,_368,_369,_370,_371,_372); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372){
  _checked_ptr_1<int> _ptr__364(_364 ? _364->raw() : nullptr, _364 ? _364->size(0) : 0);
  _checked_ptr_1<int> _ptr__365(_365 ? _365->raw() : nullptr, _365 ? _365->size(0) : 0);
  _checked_ptr_1<double> _ptr__366(_366 ? _366->raw() : nullptr, _366 ? _366->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__373(_373 ? _373->raw() : nullptr,_373 ? _373->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _374 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _372,(int)2 ))));
  _checked_ptr_1<long long> _ptr__374(_374 ? _374->raw() : nullptr,_374 ? _374->size(0) : 0);
  long long _6699 = (long long)0;
  long long _6700 = _370;
  for (long long _375 = _6699; _375 < _6700; ++_375)
  {
    {
      _ptr__374[safe_add( _ptr__365[_375],(int)2 )] = safe_add( _ptr__374[safe_add( _ptr__365[_375],(int)2 )],(int)1 );
    }
  }
  int _6701 = (int)1;
  int _6702 = _372;
  for (int _376 = _6701; _376 < _6702; ++_376)
  {
    {
      _ptr__374[safe_add( _376,(int)1 )] = safe_add( _ptr__374[safe_add( _376,(int)1 )],_ptr__374[_376] );
    }
  }
  int _6703 = (int)0;
  int _6704 = (int)_370;
  for (int _377 = _6703; _377 < _6704; ++_377)
  {
    {
      int _378 = _ptr__365[_377];
      _ptr__373[_ptr__374[safe_add( _378,(int)1 )]] = _377;
      _ptr__374[safe_add( _378,(int)1 )] = safe_add( _ptr__374[safe_add( _378,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _379 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _371,(int)2 ))));
  _checked_ptr_1<long long> _ptr__379(_379 ? _379->raw() : nullptr,_379 ? _379->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _380 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_370)));
  _checked_ptr_1<int> _ptr__380(_380 ? _380->raw() : nullptr,_380 ? _380->size(0) : 0);
  {
    int _381 = (int)0;
    for(;(_381 < _370);++ _381)
    {
      {
        _ptr__379[safe_add( _ptr__364[_381],(int)2 )] = safe_add( _ptr__379[safe_add( _ptr__364[_381],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _382 = (int)1;
    for(;(_382 < _371);++ _382)
    {
      {
        _ptr__379[safe_add( _382,(int)1 )] = safe_add( _ptr__379[safe_add( _382,(int)1 )],_ptr__379[_382] );
      }
    }
  }
  {
    int _383 = (int)0;
    for(;(_383 < _372);++ _383)
    {
      {
        {
          long long _384 = _ptr__374[_383];
          for(;(_384 < _ptr__374[safe_add( _383,(int)1 )]);++ _384)
          {
            {
              int _385 = _ptr__364[_ptr__373[_384]];
              _ptr__380[_ptr__379[safe_add( _385,(int)1 )]] = _ptr__373[_384];
              _ptr__379[safe_add( _385,(int)1 )] = safe_add( _ptr__379[safe_add( _385,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _386 = (int)1;
  {
    int _387 = _ptr__364[_ptr__380[(int)0]];
    int _388 = _ptr__365[_ptr__380[(int)0]];
    {
      int _389 = (int)1;
      for(;(_389 < _370);++ _389)
      {
        {
          int _390 = _ptr__380[_389];
          if (((_387 != _ptr__364[_390]) || (_388 != _ptr__365[_390])))
          {
            {
              _387 = _ptr__364[_390];
              _388 = _ptr__365[_390];
              ++ _386;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__391(_391 ? _391->raw() : nullptr,_391 ? _391->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_386)));
  _checked_ptr_1<int> _ptr__392(_392 ? _392->raw() : nullptr,_392 ? _392->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _393 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_386)));
  _checked_ptr_1<double> _ptr__393(_393 ? _393->raw() : nullptr,_393 ? _393->size(0) : 0);
  {
    int _394 = _ptr__380[(int)0];
    _ptr__391[(int)0] = _ptr__364[_394];
    _ptr__392[(int)0] = _ptr__365[_394];
    _ptr__393[(int)0] = _ptr__366[_394];
  }
  int _395 = (int)1;
  int _6705 = (int)1;
  long long _6706 = _370;
  for (long long _396 = _6705; _396 < _6706; ++_396)
  {
    {
      int _397 = _ptr__380[_396];
      if (((_ptr__391[(_395 - (int)1)] == _ptr__364[_397]) && (_ptr__392[(_395 - (int)1)] == _ptr__365[_397])))
      {
        {
          _ptr__393[(_395 - (int)1)] = (_ptr__393[(_395 - (int)1)] + _ptr__366[_397]);
        }
      }
      else
      {
        {
          _ptr__391[_395] = _ptr__364[_397];
          _ptr__392[_395] = _ptr__365[_397];
          _ptr__393[_395] = _ptr__366[_397];
          ++ _395;
        }
      }
    }
  }
  ((*_367)((int)0)) = _391;
  ((*_368)((int)0)) = _392;
  ((*_369)((int)0)) = _393;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _398,    std::shared_ptr< monty::ndarray< int,1 > > _399) { mosek::fusion::p_CommonTools::argMSort(_398,_399); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399){
  _checked_ptr_1<int> _ptr__398(_398 ? _398->raw() : nullptr, _398 ? _398->size(0) : 0);
  _checked_ptr_1<int> _ptr__399(_399 ? _399->raw() : nullptr, _399 ? _399->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_398)->size(0)))));
  _checked_ptr_1<int> _ptr__400(_400 ? _400->raw() : nullptr,_400 ? _400->size(0) : 0);
  bool _401 = false;
  {
    int _402 = (int)1;
    for(;(_402 < (int)((_398)->size(0)));_402 *= (int)2)
    {
      {
        _401 = (!_401);
        int _6707 = (int)0;
        int _6708 = (int)((_398)->size(0));
        int _6709 = safe_mul( _402,(int)2 );
        for (int _403 = _6707; _403 < _6708; _403 += _6709)
        {
          {
            if (_401)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_398,_400,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_400,_398,_399,_403,safe_add( _403,_402 ),safe_add( _403,safe_mul( (int)2,_402 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_401)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_400,(int)0,_398,(int)0,(int)((_398)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409){
  _checked_ptr_1<int> _ptr__404(_404 ? _404->raw() : nullptr, _404 ? _404->size(0) : 0);
  _checked_ptr_1<int> _ptr__405(_405 ? _405->raw() : nullptr, _405 ? _405->size(0) : 0);
  _checked_ptr_1<int> _ptr__406(_406 ? _406->raw() : nullptr, _406 ? _406->size(0) : 0);
  int _6710;
  bool _6711 = (_409 > (int)((_404)->size(0)));
  if (_6711)
  {
    _6710 = (int)((_404)->size(0));
  }
  else
  {
    _6710 = _409;
  }
  int _410 = _6710;
  int _6712;
  bool _6713 = (_408 > _410);
  if (_6713)
  {
    _6712 = _410;
  }
  else
  {
    _6712 = _408;
  }
  int _411 = _6712;
  if ((_411 == _410))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_404,_407,_405,_407,(_411 - _407));
    }
  }
  else
  {
    {
      int _412 = _407;
      int _413 = _411;
      int _414;
      {
        _414 = _407;
        for(;((_412 < _411) && (_413 < _410));++ _414)
        {
          {
            if ((_ptr__406[_ptr__404[_412]] < _ptr__406[_ptr__404[_413]]))
            {
              {
                _ptr__405[_414] = _ptr__404[_412];
                ++ _412;
              }
            }
            else
            {
              {
                _ptr__405[_414] = _ptr__404[_413];
                ++ _413;
              }
            }
          }
        }
      }
      while ( (_412 < _411) )
      {
        {
          _ptr__405[_414] = _ptr__404[_412];
          ++ _412;
          ++ _414;
        }
      }
      while ( (_413 < _410) )
      {
        {
          _ptr__405[_414] = _ptr__404[_413];
          ++ _413;
          ++ _414;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _415,    std::shared_ptr< monty::ndarray< long long,1 > > _416,    std::shared_ptr< monty::ndarray< long long,1 > > _417,    long long _418,    long long _419) { mosek::fusion::p_CommonTools::argQsort(_415,_416,_417,_418,_419); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419){
  _checked_ptr_1<long long> _ptr__415(_415 ? _415->raw() : nullptr, _415 ? _415->size(0) : 0);
  _checked_ptr_1<long long> _ptr__416(_416 ? _416->raw() : nullptr, _416 ? _416->size(0) : 0);
  _checked_ptr_1<long long> _ptr__417(_417 ? _417->raw() : nullptr, _417 ? _417->size(0) : 0);
  if ((NULL == _417.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_418,_419);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_415,_416,_417,_418,_419);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _420,    std::shared_ptr< monty::ndarray< int,1 > > _421,    std::shared_ptr< monty::ndarray< int,1 > > _422,    long long _423,    long long _424) { mosek::fusion::p_CommonTools::argQsort(_420,_421,_422,_423,_424); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424){
  _checked_ptr_1<long long> _ptr__420(_420 ? _420->raw() : nullptr, _420 ? _420->size(0) : 0);
  _checked_ptr_1<int> _ptr__421(_421 ? _421->raw() : nullptr, _421 ? _421->size(0) : 0);
  _checked_ptr_1<int> _ptr__422(_422 ? _422->raw() : nullptr, _422 ? _422->size(0) : 0);
  if ((NULL == _422.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_423,_424);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_420,_421,_422,_423,_424);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _425,    int _426,    int _427,    int _428){ return new mosek::fusion::SolutionStruct(_425,_426,_427,_428); }mosek::fusion::SolutionStruct::SolutionStruct  (int _425,    int _426,    int _427,    int _428) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_425,_426,_427,_428); }void mosek::fusion::p_SolutionStruct::_initialize  (int _425,    int _426,    int _427,    int _428){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _425;
    sol_numcon = _426;
    sol_numcone = _427;
    sol_numbarvar = _428;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_425 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
    if ((_428 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_428)));
      }
    }
    {}
    if ((_426 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_426)));
      }
    }
    {}
    if ((_427 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_425)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){ return new mosek::fusion::SolutionStruct(_429); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_429); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_429)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_429)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_429)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _6714;
    bool _6715 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc.get());
    if (_6715)
    {
      _6714 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xc);
    }
    else
    {
      _6714 = nullptr;
    }
    xc = _6714;
    std::shared_ptr< monty::ndarray< double,1 > > _6716;
    bool _6717 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx.get());
    if (_6717)
    {
      _6716 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->xx);
    }
    else
    {
      _6716 = nullptr;
    }
    xx = _6716;
    std::shared_ptr< monty::ndarray< double,1 > > _6718;
    bool _6719 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx.get());
    if (_6719)
    {
      _6718 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->yx);
    }
    else
    {
      _6718 = nullptr;
    }
    yx = _6718;
    std::shared_ptr< monty::ndarray< double,1 > > _6720;
    bool _6721 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slc.get());
    if (_6721)
    {
      _6720 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6720 = nullptr;
    }
    slc = _6720;
    std::shared_ptr< monty::ndarray< double,1 > > _6722;
    bool _6723 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->suc.get());
    if (_6723)
    {
      _6722 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6722 = nullptr;
    }
    suc = _6722;
    std::shared_ptr< monty::ndarray< double,1 > > _6724;
    bool _6725 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->y.get());
    if (_6725)
    {
      _6724 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->y);
    }
    else
    {
      _6724 = nullptr;
    }
    y = _6724;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _6726;
    bool _6727 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx.get());
    if (_6727)
    {
      _6726 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->slx);
    }
    else
    {
      _6726 = nullptr;
    }
    slx = _6726;
    std::shared_ptr< monty::ndarray< double,1 > > _6728;
    bool _6729 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux.get());
    if (_6729)
    {
      _6728 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->sux);
    }
    else
    {
      _6728 = nullptr;
    }
    sux = _6728;
    std::shared_ptr< monty::ndarray< double,1 > > _6730;
    bool _6731 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx.get());
    if (_6731)
    {
      _6730 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_429)->snx);
    }
    else
    {
      _6730 = nullptr;
    }
    snx = _6730;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _430,int _431,int _432,int _433) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_430,_431,_432,_433); }void mosek::fusion::p_SolutionStruct::resize(int _430,int _431,int _432,int _433){
  if ((_433 < (int)0))
  {
    {
    }
  }
  else if((_433 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _433;
    }
  }
  else if((_433 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _434;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _433,(int)100 )))
      {
        {
          _434 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _434 = safe_add( _433,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_434);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_434);
      sol_numbarvar = _434;
    }
  }
  if ((_430 < (int)0))
  {
    {
    }
  }
  else if((_430 <= sol_numvar))
  {
    {
      sol_numvar = _430;
    }
  }
  else if((_430 <= (int)((xx)->size(0))))
  {
    {
      int _6732 = sol_numvar;
      int _6733 = _430;
      for (int _435 = _6732; _435 < _6733; ++_435)
      {
        {
          ((*slx)(_435)) = 0.0;
          ((*sux)(_435)) = 0.0;
          ((*xx)(_435)) = 0.0;
          ((*yx)(_435)) = 0.0;
        }
      }
      sol_numvar = _430;
    }
  }
  else
  {
    {
      int _436;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _430,(int)100 )))
      {
        {
          _436 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _436 = safe_add( _430,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _437 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__437(_437 ? _437->raw() : nullptr,_437 ? _437->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_437,(int)0,(int)((slx)->size(0)));
      slx = _437;
      std::shared_ptr< monty::ndarray< double,1 > > _438 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__438(_438 ? _438->raw() : nullptr,_438 ? _438->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_438,(int)0,(int)((sux)->size(0)));
      sux = _438;
      std::shared_ptr< monty::ndarray< double,1 > > _439 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__439(_439 ? _439->raw() : nullptr,_439 ? _439->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_439,(int)0,(int)((xx)->size(0)));
      xx = _439;
      std::shared_ptr< monty::ndarray< double,1 > > _440 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_436)));
      _checked_ptr_1<double> _ptr__440(_440 ? _440->raw() : nullptr,_440 ? _440->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_440,(int)0,(int)((yx)->size(0)));
      yx = _440;
      {
        int _441 = sol_numvar;
        for(;(_441 < _430);++ _441)
        {
          {
            ((*slx)(_441)) = 0.0;
            ((*sux)(_441)) = 0.0;
            ((*xx)(_441)) = 0.0;
          }
        }
      }
      sol_numvar = _430;
    }
  }
  if ((_431 < (int)0))
  {
    {
    }
  }
  else if((_431 <= sol_numcon))
  {
    {
      sol_numcon = _431;
    }
  }
  else if((_431 <= (int)((xx)->size(0))))
  {
    {
      int _6734 = sol_numcon;
      int _6735 = _431;
      for (int _442 = _6734; _442 < _6735; ++_442)
      {
        {
          ((*slc)(_442)) = 0.0;
          ((*suc)(_442)) = 0.0;
          ((*xc)(_442)) = 0.0;
          ((*y)(_442)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  else
  {
    {
      int _443;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _431,(int)100 )))
      {
        {
          _443 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _443 = safe_add( _431,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _444 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__444(_444 ? _444->raw() : nullptr,_444 ? _444->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_444,(int)0,(int)((slc)->size(0)));
      slc = _444;
      std::shared_ptr< monty::ndarray< double,1 > > _445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__445(_445 ? _445->raw() : nullptr,_445 ? _445->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_445,(int)0,(int)((suc)->size(0)));
      suc = _445;
      std::shared_ptr< monty::ndarray< double,1 > > _446 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__446(_446 ? _446->raw() : nullptr,_446 ? _446->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_446,(int)0,(int)((xc)->size(0)));
      xc = _446;
      std::shared_ptr< monty::ndarray< double,1 > > _447 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_443)));
      _checked_ptr_1<double> _ptr__447(_447 ? _447->raw() : nullptr,_447 ? _447->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_447,(int)0,(int)((y)->size(0)));
      y = _447;
      int _6736 = sol_numcon;
      int _6737 = _431;
      for (int _448 = _6736; _448 < _6737; ++_448)
      {
        {
          ((*slc)(_448)) = 0.0;
          ((*suc)(_448)) = 0.0;
          ((*xc)(_448)) = 0.0;
          ((*y)(_448)) = 0.0;
        }
      }
      sol_numcon = _431;
    }
  }
  if ((_432 < (int)0))
  {
    {
    }
  }
  else if((_432 <= sol_numcone))
  {
    {
      sol_numcone = _432;
    }
  }
  else if((_432 <= (int)((xx)->size(0))))
  {
    {
      int _6738 = sol_numcone;
      int _6739 = _432;
      for (int _449 = _6738; _449 < _6739; ++_449)
      {
        {
          ((*snx)(_449)) = 0.0;
        }
      }
      sol_numcone = _432;
    }
  }
  else
  {
    {
      int _450;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _432,(int)100 )))
      {
        {
          _450 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _450 = safe_add( _432,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _451 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_450)));
      _checked_ptr_1<double> _ptr__451(_451 ? _451->raw() : nullptr,_451 ? _451->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_451,(int)0,(int)((snx)->size(0)));
      snx = _451;
      {
        int _452 = sol_numcone;
        for(;(_452 < _432);++ _452)
        {
          {
            ((*snx)(_452)) = 0.0;
          }
        }
      }
      sol_numcone = _432;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _453) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_453); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _453){
  return isAcceptable(dstatus,_453);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_454); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454){
  return isAcceptable(pstatus,_454);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456){
  if ((_456 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_455 == ::mosek::fusion::SolutionStatus::Optimal) || (_455 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_456 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_455 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){ return new mosek::fusion::ConNZStruct(_457,_458,_459,_460,_461,_462,_463); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_457,_458,_459,_460,_461,_462,_463); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _457,    std::shared_ptr< monty::ndarray< int,1 > > _458,    std::shared_ptr< monty::ndarray< double,1 > > _459,    std::shared_ptr< monty::ndarray< double,1 > > _460,    std::shared_ptr< monty::ndarray< int,1 > > _461,    std::shared_ptr< monty::ndarray< int,1 > > _462,    std::shared_ptr< monty::ndarray< int,1 > > _463){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__457(_457 ? _457->raw() : nullptr, _457 ? _457->size(0) : 0);
    _checked_ptr_1<int> _ptr__458(_458 ? _458->raw() : nullptr, _458 ? _458->size(0) : 0);
    _checked_ptr_1<double> _ptr__459(_459 ? _459->raw() : nullptr, _459 ? _459->size(0) : 0);
    _checked_ptr_1<double> _ptr__460(_460 ? _460->raw() : nullptr, _460 ? _460->size(0) : 0);
    _checked_ptr_1<int> _ptr__461(_461 ? _461->raw() : nullptr, _461 ? _461->size(0) : 0);
    _checked_ptr_1<int> _ptr__462(_462 ? _462->raw() : nullptr, _462 ? _462->size(0) : 0);
    _checked_ptr_1<int> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    ptrb = _457;
    subj = _458;
    cof = _459;
    bfix = _460;
    barsubi = _461;
    barsubj = _462;
    barmidx = _463;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _464){ return new mosek::fusion::Model(_464); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _464) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_464); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _464){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_464);
    monty::rc_ptr< ::mosek::fusion::Model > _465 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_464)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_464)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_464)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6740;
    for (int _466 = (int)0, _6741 = (int)((mosek::fusion::p_Model::_get_impl(_464)->vars)->size(0)); _466 < _6741 ; ++_466)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6742;
      bool _6743 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get());
      if (_6743)
      {
        _6742 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->vars)(_466)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6742 = nullptr;
      }
      _6740.push_back(_6742);
    }
    auto _6744 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6740.size()),_6740.begin(),_6740.end()));
    vars = _6744;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_464)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6745;
    for (int _467 = (int)0, _6746 = (int)((mosek::fusion::p_Model::_get_impl(_464)->barvars)->size(0)); _467 < _6746 ; ++_467)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _6747;
      bool _6748 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get());
      if (_6748)
      {
        _6747 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->barvars)(_467)).get())->__mosek_2fusion_2ModelVariable__clone(_465);
      }
      else
      {
        _6747 = nullptr;
      }
      _6745.push_back(_6747);
    }
    auto _6749 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6745.size()),_6745.begin(),_6745.end()));
    barvars = _6749;
    var_map = mosek::fusion::p_Model::_get_impl(_464)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_type);
    natconmap_efix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_efix);
    natconmap_lb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_lb);
    natconmap_ub = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_464)->natconmap_ub);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_464)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6750;
    for (int _468 = (int)0, _6751 = (int)((mosek::fusion::p_Model::_get_impl(_464)->cons)->size(0)); _468 < _6751 ; ++_468)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _6752;
      bool _6753 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get());
      if (_6753)
      {
        _6752 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_464)->cons)(_468)).get())->__mosek_2fusion_2ModelConstraint__clone(_465);
      }
      else
      {
        _6752 = nullptr;
      }
      _6750.push_back(_6752);
    }
    auto _6754 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6750.size()),_6750.begin(),_6750.end()));
    cons = _6754;
    con_map = mosek::fusion::p_Model::_get_impl(_464)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    bfixidx = mosek::fusion::p_Model::_get_impl(_464)->bfixidx;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _469){ return new mosek::fusion::Model(_469); }mosek::fusion::Model::Model  (const std::string &  _469) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_469); }void mosek::fusion::p_Model::_initialize  (const std::string &  _469){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_469,std::string (""));
    model_name = _469;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _6755;
    for (int _470 = (int)0, _6756 = (int)1024; _470 < _6756 ; ++_470)
    {
      _6755.push_back(nullptr);
    }
    auto _6757 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_6755.size()),_6755.begin(),_6755.end()));
    vars = _6757;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_efix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_lb = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_ub = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _6758;
    for (int _471 = (int)0, _6759 = (int)1024; _471 < _6759 ; ++_471)
    {
      _6758.push_back(nullptr);
    }
    auto _6760 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_6758.size()),_6758.begin(),_6758.end()));
    cons = _6760;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    bfixidx = natvarmap_alloc((int)1);
    task_var_putboundlist_fx(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(bfixidx)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}));
    task_var_name(bfixidx,std::string ("1.0"));
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474){
  _checked_ptr_1<int> _ptr__473(_473 ? _473->raw() : nullptr, _473 ? _473->size(0) : 0);
  _checked_ptr_1<int> _ptr__474(_474 ? _474->raw() : nullptr, _474 ? _474->size(0) : 0);
  return _472;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string & _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478){
  _checked_ptr_1<int> _ptr__475(_475 ? _475->raw() : nullptr, _475 ? _475->size(0) : 0);
  _checked_ptr_1<int> _ptr__477(_477 ? _477->raw() : nullptr, _477 ? _477->size(0) : 0);
  _checked_ptr_1<long long> _ptr__478(_478 ? _478->raw() : nullptr, _478 ? _478->size(0) : 0);
  task_format_con_names(_475,_476,_477,_478);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string & _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482){
  _checked_ptr_1<int> _ptr__479(_479 ? _479->raw() : nullptr, _479 ? _479->size(0) : 0);
  _checked_ptr_1<int> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  _checked_ptr_1<long long> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  task_format_var_names(_479,_480,_481,_482);
}
void mosek::fusion::p_Model::varname(int _483,const std::string & _484){
  task_var_name(_483,_484);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486){
  _checked_ptr_1<int> _ptr__486(_486 ? _486->raw() : nullptr, _486 ? _486->size(0) : 0);
  int _487 = ((*natbarvarmap_ptr)(_485));
  int _488 = ((*natbarvarmap_num)(_485));
  int _6761 = (int)0;
  int _6762 = _488;
  for (int _489 = _6761; _489 < _6762; ++_489)
  {
    {
      _ptr__486[_489] = safe_add( _487,_489 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491){
  _checked_ptr_1<long long> _ptr__491(_491 ? _491->raw() : nullptr, _491 ? _491->size(0) : 0);
  int _492 = ((*natbarvarmap_ptr)(_490));
  int _493 = ((*natbarvarmap_num)(_490));
  int _494 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_490))));
  int _495 = (safe_mul( safe_mul( _493,_494 ),safe_add( _494,(int)1 ) ) / (int)2);
  long long _496 = ((*natbarvar_ptr)(_492));
  int _6763 = (int)0;
  int _6764 = _495;
  for (int _497 = _6763; _497 < _6764; ++_497)
  {
    {
      _ptr__491[_497] = safe_add( _496,_497 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _498,int _499){
  int _500 = (int)((natbarvar_idx)->size(0));
  int _501 = task_numbarvar();
  int _502 = (safe_mul( _499,safe_add( _499,(int)1 ) ) / (int)2);
  int _503 = safe_mul( _498,_502 );
  if ((safe_add( natbarvar_numbarvarelm,_503 ) >= _500))
  {
    {
      if ((_503 < _500))
      {
        {
          _503 = _500;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _500,_503 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _500,_503 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _500,_503 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _6765;
      bool _6766 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_6766)
      {
        _6765 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _6765 = (int)32;
      }
      int _504 = _6765;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_504);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _504,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _505 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_504)));
      int _6767 = (int)0;
      int _6768 = (int)((barvars)->size(0));
      for (int _506 = _6767; _506 < _6768; ++_506)
      {
        {
          ((*_505)(_506)) = ((*barvars)(_506));
        }
      }
      barvars = _505;
    }
  }
  {}
  if ((safe_add( _501,_498 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _6769;
      bool _6770 = (safe_add( _501,_498 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_6770)
      {
        _6769 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _6769 = safe_add( _501,_498 );
      }
      int _507 = _6769;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_507);
    }
  }
  {}
  if ((safe_add( _501,_498 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _6771;
      bool _6772 = (_498 > (int)((natbarvar_ptr)->size(0)));
      if (_6772)
      {
        _6771 = _498;
      }
      else
      {
        _6771 = (int)((natbarvar_ptr)->size(0));
      }
      int _508 = _6771;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_508 ),(int)1 ));
    }
  }
  {}
  int _6773 = (int)0;
  int _6774 = _498;
  for (int _509 = _6773; _509 < _6774; ++_509)
  {
    {
      ((*natbarvar_dim)(safe_add( _501,_509 ))) = _499;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _498;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_498 );
  int _510 = task_append_barvar(_499,_498);
  int _511 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _512 = ((*natbarvar_ptr)(_501));
    int _6775 = (int)0;
    int _6776 = _499;
    for (int _513 = _6775; _513 < _6776; ++_513)
    {
      {
        int _6777 = _513;
        int _6778 = _499;
        for (int _514 = _6777; _514 < _6778; ++_514)
        {
          {
            int _6779 = (int)0;
            int _6780 = _498;
            for (int _515 = _6779; _515 < _6780; ++_515)
            {
              {
                ((*natbarvar_idx)(safe_add( _512,safe_mul( _515,_502 ) ))) = safe_add( _511,_515 );
                ((*natbarvar_i)(safe_add( _512,safe_mul( _515,_502 ) ))) = _514;
                ((*natbarvar_j)(safe_add( _512,safe_mul( _515,_502 ) ))) = _513;
              }
            }
            ++ _512;
          }
        }
      }
    }
    int _6781 = (int)0;
    int _6782 = _498;
    for (int _516 = _6781; _516 < _6782; ++_516)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _511,_516 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _511,_516 ))),_502 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _498,_502 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _517){
  int _518 = natvarmap->alloc(_517);
  int _519 = safe_add( natvarmap->maxidx(_518),(int)1 );
  int _520 = natvarmap->capacity();
  int _521 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _520))
  {
    {
      int _522 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_520);
      int _6783 = _522;
      int _6784 = _520;
      for (int _523 = _6783; _523 < _6784; ++_523)
      {
        {
          ((*natvarmap_idx)(_523)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_520);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _521))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_521);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _524 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_521)));
      int _6785 = (int)0;
      int _6786 = (int)((vars)->size(0));
      for (int _525 = _6785; _525 < _6786; ++_525)
      {
        {
          ((*_524)(_525)) = ((*vars)(_525));
        }
      }
      int _6787 = (int)((vars)->size(0));
      int _6788 = (int)((_524)->size(0));
      for (int _526 = _6787; _526 < _6788; ++_526)
      {
        {
          ((*_524)(_526)) = nullptr;
        }
      }
      vars = _524;
    }
  }
  {}
  if ((task_numvar() < _519))
  {
    {
      task_append_var((_519 - task_numvar()));
    }
  }
  {}
  return _518;
}
int mosek::fusion::p_Model::natconmap_alloc(int _527){
  int _528 = natconmap->alloc(_527);
  int _529 = safe_add( natconmap->maxidx(_528),(int)1 );
  int _530 = natconmap->capacity();
  int _531 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _530))
  {
    {
      int _532 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_530);
      int _6789 = _532;
      int _6790 = _530;
      for (int _533 = _6789; _533 < _6790; ++_533)
      {
        {
          ((*natconmap_idx)(_533)) = (-(int)1);
        }
      }
      natconmap_efix = ::mosek::fusion::p_CommonTools::resize(natconmap_efix,_530);
      natconmap_lb = ::mosek::fusion::p_CommonTools::resize(natconmap_lb,_530);
      natconmap_ub = ::mosek::fusion::p_CommonTools::resize(natconmap_ub,_530);
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_530);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_530);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _531))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_531);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _534 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_531)));
      int _6791 = (int)0;
      int _6792 = (int)((cons)->size(0));
      for (int _535 = _6791; _535 < _6792; ++_535)
      {
        {
          ((*_534)(_535)) = ((*cons)(_535));
        }
      }
      int _6793 = (int)((cons)->size(0));
      int _6794 = _531;
      for (int _536 = _6793; _536 < _6794; ++_536)
      {
        {
          ((*_534)(_536)) = nullptr;
        }
      }
      cons = _534;
    }
  }
  {}
  if ((_529 > task_numcon()))
  {
    {
      task_append_con((_529 - task_numcon()));
    }
  }
  {}
  return _528;
}
int mosek::fusion::p_Model::natconemap_alloc(int _537){
  int _538 = natconemap->alloc(_537);
  int _539 = safe_add( natconemap->maxidx(_538),(int)1 );
  if ((_539 > task_numcone()))
  {
    {
      task_append_zerocones((_539 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _538;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540){
  _checked_ptr_1<long long> _ptr__540(_540 ? _540->raw() : nullptr, _540 ? _540->size(0) : 0);
  int _541 = (int)0;
  int _6795 = (int)0;
  int _6796 = (int)((_540)->size(0));
  for (int _542 = _6795; _542 < _6796; ++_542)
  {
    {
      if ((_ptr__540[_542] > (int)0))
      {
        {
          ++ _541;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _543 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_541)));
  _checked_ptr_1<int> _ptr__543(_543 ? _543->raw() : nullptr,_543 ? _543->size(0) : 0);
  int _544 = (int)0;
  int _6797 = (int)0;
  int _6798 = (int)((_540)->size(0));
  for (int _545 = _6797; _545 < _6798; ++_545)
  {
    {
      if ((_ptr__540[_545] > (int)0))
      {
        {
          _ptr__543[_544] = (int)(_ptr__540[_545] - (int)1);
          ++ _544;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_543);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546){
  _checked_ptr_1<long long> _ptr__546(_546 ? _546->raw() : nullptr, _546 ? _546->size(0) : 0);
  int _547 = (int)0;
  int _6799 = (int)0;
  int _6800 = (int)((_546)->size(0));
  for (int _548 = _6799; _548 < _6800; ++_548)
  {
    {
      if ((_ptr__546[_548] > (int)0))
      {
        {
          ++ _547;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _549 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_547)));
  _checked_ptr_1<int> _ptr__549(_549 ? _549->raw() : nullptr,_549 ? _549->size(0) : 0);
  int _550 = (int)0;
  int _6801 = (int)0;
  int _6802 = (int)((_546)->size(0));
  for (int _551 = _6801; _551 < _6802; ++_551)
  {
    {
      if ((_ptr__546[_551] > (int)0))
      {
        {
          _ptr__549[_550] = (int)(_ptr__546[_551] - (int)1);
          ++ _550;
        }
      }
      {}
    }
  }
  task_var_putintlist(_549);
}
void mosek::fusion::Model::putlicensewait  ( bool _552) { mosek::fusion::p_Model::putlicensewait(_552); }void mosek::fusion::p_Model::putlicensewait(bool _552){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_552);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _553) { mosek::fusion::p_Model::putlicensepath(_553); }void mosek::fusion::p_Model::putlicensepath(const std::string & _553){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_553);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _554) { mosek::fusion::p_Model::putlicensecode(_554); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554){
  _checked_ptr_1<int> _ptr__554(_554 ? _554->raw() : nullptr, _554 ? _554->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_554);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _6803 = (int)0;
  int _6804 = (int)((vars)->size(0));
  for (int _555 = _6803; _555 < _6804; ++_555)
  {
    {
      ((*vars)(_555)) = nullptr;
    }
  }
  int _6805 = (int)0;
  int _6806 = (int)((cons)->size(0));
  for (int _556 = _6805; _556 < _6806; ++_556)
  {
    {
      ((*cons)(_556)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558){
  if (((_557 < (int)0) || ((_557 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_557)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_557))))->elementName((long long)(((*natvarmap_idx)(_557))),_558);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_559,_560,_561,_562); }void mosek::fusion::p_Model::getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562){
  _checked_ptr_1<int> _ptr__560(_560 ? _560->raw() : nullptr, _560 ? _560->size(0) : 0);
  _checked_ptr_1<double> _ptr__561(_561 ? _561->raw() : nullptr, _561 ? _561->size(0) : 0);
  int _563 = (int)((_560)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6807;
  bool _6808 = _559;
  if (_6808)
  {
    _6807 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6807 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _564 = _6807;
  _checked_ptr_1<double> _ptr__564(_564 ? _564->raw() : nullptr,_564 ? _564->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6809;
  bool _6810 = _559;
  if (_6810)
  {
    _6809 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6809 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _565 = _6809;
  _checked_ptr_1<double> _ptr__565(_565 ? _565->raw() : nullptr,_565 ? _565->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6811;
  bool _6812 = _559;
  if (_6812)
  {
    _6811 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6811 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _566 = _6811;
  _checked_ptr_1<double> _ptr__566(_566 ? _566->raw() : nullptr,_566 ? _566->size(0) : 0);
  int _6813 = (int)0;
  int _6814 = _563;
  for (int _567 = _6813; _567 < _6814; ++_567)
  {
    {
      long long _568 = ((*natconmap_slackidx)(_ptr__560[_567]));
      if ((_568 < (int)0))
      {
        {
          long long _569 = (-safe_add( _568,(int)1 ));
          _ptr__561[safe_add( _562,_567 )] = _ptr__565[_569];
        }
      }
      else if((_568 > (int)0))
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__564[(_568 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__561[safe_add( _562,_567 )] = _ptr__566[_ptr__560[_567]];
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_570,_571,_572,_573); }void mosek::fusion::p_Model::getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573){
  _checked_ptr_1<long long> _ptr__571(_571 ? _571->raw() : nullptr, _571 ? _571->size(0) : 0);
  _checked_ptr_1<double> _ptr__572(_572 ? _572->raw() : nullptr, _572 ? _572->size(0) : 0);
  int _574 = (int)((_571)->size(0));
  if (_570)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _575 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__575(_575 ? _575->raw() : nullptr,_575 ? _575->size(0) : 0);
      int _6815 = (int)0;
      int _6816 = _574;
      for (int _576 = _6815; _576 < _6816; ++_576)
      {
        {
          if ((_ptr__571[_576] > (int)0))
          {
            {
              _ptr__572[safe_add( _573,_576 )] = _ptr__575[(_ptr__571[_576] - (int)1)];
            }
          }
          else
          {
            {
              _ptr__572[safe_add( _573,_576 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _577 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__577(_577 ? _577->raw() : nullptr,_577 ? _577->size(0) : 0);
      int _6817 = (int)0;
      int _6818 = _574;
      for (int _578 = _6817; _578 < _6818; ++_578)
      {
        {
          if ((_ptr__571[_578] > (int)0))
          {
            {
              _ptr__572[safe_add( _573,_578 )] = (-_ptr__577[(_ptr__571[_578] - (int)1)]);
            }
          }
          else
          {
            {
              _ptr__572[safe_add( _573,_578 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_579,_580,_581,_582); }void mosek::fusion::p_Model::getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582){
  _checked_ptr_1<long long> _ptr__580(_580 ? _580->raw() : nullptr, _580 ? _580->size(0) : 0);
  _checked_ptr_1<double> _ptr__581(_581 ? _581->raw() : nullptr, _581 ? _581->size(0) : 0);
  int _583 = (int)((_580)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _6819;
  bool _6820 = _579;
  if (_6820)
  {
    _6819 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _6819 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _584 = _6819;
  _checked_ptr_1<double> _ptr__584(_584 ? _584->raw() : nullptr,_584 ? _584->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6821;
  bool _6822 = (natbarvar_numbarvarelm > (int)0);
  if (_6822)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _6823;
    bool _6824 = _579;
    if (_6824)
    {
      _6823 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _6823 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _6821 = _6823;
  }
  else
  {
    _6821 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _585 = _6821;
  _checked_ptr_1<double> _ptr__585(_585 ? _585->raw() : nullptr,_585 ? _585->size(0) : 0);
  int _6825 = (int)0;
  int _6826 = _583;
  for (int _586 = _6825; _586 < _6826; ++_586)
  {
    {
      if ((_ptr__580[_586] > (int)0))
      {
        {
          _ptr__581[safe_add( _582,_586 )] = _ptr__584[(_ptr__580[_586] - (int)1)];
        }
      }
      else if((_ptr__580[_586] < (int)0))
      {
        {
          long long _587 = (-safe_add( _ptr__580[_586],(int)1 ));
          _ptr__581[safe_add( _582,_586 )] = _ptr__585[_587];
        }
      }
      else
      {
        {
          _ptr__581[safe_add( _582,_586 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_588,_589,_590); }void mosek::fusion::p_Model::setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590){
  _checked_ptr_1<long long> _ptr__589(_589 ? _589->raw() : nullptr, _589 ? _589->size(0) : 0);
  _checked_ptr_1<double> _ptr__590(_590 ? _590->raw() : nullptr, _590 ? _590->size(0) : 0);
  if (_588)
  {
    {
      int _591 = (int)0;
      int _6827 = (int)0;
      int _6828 = (int)((_589)->size(0));
      for (int _592 = _6827; _592 < _6828; ++_592)
      {
        {
          if ((_ptr__589[_592] >= (int)0))
          {
            {
              ++ _591;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _593 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_591)));
      _checked_ptr_1<int> _ptr__593(_593 ? _593->raw() : nullptr,_593 ? _593->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6829;
      bool _6830 = (_591 == (int)((_589)->size(0)));
      if (_6830)
      {
        _6829 = _590;
      }
      else
      {
        _6829 = _590;
      }
      std::shared_ptr< monty::ndarray< double,1 > > _594 = _6829;
      _checked_ptr_1<double> _ptr__594(_594 ? _594->raw() : nullptr,_594 ? _594->size(0) : 0);
      int _595 = (int)0;
      int _6831 = (int)0;
      int _6832 = (int)((_589)->size(0));
      for (int _596 = _6831; _596 < _6832; ++_596)
      {
        {
          if ((_ptr__589[_596] > (int)0))
          {
            {
              _ptr__593[_595] = (int)(_ptr__589[_596] - (int)1);
              ++ _595;
            }
          }
          {}
        }
      }
      setSolution_xx(_593,_594);
    }
  }
  else
  {
    {
    }
  }
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _6833 = (int)0;
  int _6834 = (int)((vars)->size(0));
  for (int _597 = _6833; _597 < _6834; ++_597)
  {
    {
      if ((NULL != ((*vars)(_597)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_597)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6835 = (int)0;
  int _6836 = (int)((barvars)->size(0));
  for (int _598 = _6835; _598 < _6836; ++_598)
  {
    {
      if ((NULL != ((*barvars)(_598)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_598)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _6837 = (int)0;
  int _6838 = (int)((cons)->size(0));
  for (int _599 = _6837; _599 < _6838; ++_599)
  {
    {
      if ((NULL != ((*cons)(_599)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_599)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTask(const std::string & _600) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_600); }void mosek::fusion::p_Model::writeTask(const std::string & _600){
  _pubthis->flushNames();
  task_write(_600);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _601) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_601); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _601){
  return task_get_liinf(_601);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _602) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_602); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _602){
  return task_get_iinf(_602);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _603) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_603); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _603){
  return task_get_dinf(_603);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _604) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_604); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _604){
  task_setCallbackHandler(_604);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _605) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_605); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _605){
  task_setDataCallbackHandler(_605);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _606) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_606); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _606){
  task_setLogHandler(_606);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _607,double _608) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_607,_608); }void mosek::fusion::p_Model::setSolverParam(const std::string & _607,double _608){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_607,_608);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _609,int _610) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_609,_610); }void mosek::fusion::p_Model::setSolverParam(const std::string & _609,int _610){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_609,_610);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _611,const std::string & _612) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_611,_612); }void mosek::fusion::p_Model::setSolverParam(const std::string & _611,const std::string & _612){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_611,_612);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
  task_solve();
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _613){
  if ((NULL != initsol_xx.get()))
  {
    {
      int _614 = task_numvar();
      std::shared_ptr< monty::ndarray< double,1 > > _615 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_614)));
      _checked_ptr_1<double> _ptr__615(_615 ? _615->raw() : nullptr,_615 ? _615->size(0) : 0);
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _617 = __mosek_2fusion_2Model__get_sol_cache(_613,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx.get()))
          {
            {
              int _6839;
              bool _6840 = ((int)((mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx)->size(0)) <= _614);
              if (_6840)
              {
                _6839 = (int)((mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx)->size(0));
              }
              else
              {
                _6839 = _614;
              }
              ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_617)->xx,(int)0,_615,(int)0,_6839);
            }
          }
          {}
        }
      }
      catch (mosek::fusion::SolutionError _616)
      {
        {
        }
      }
      int _6841;
      bool _6842 = ((int)((initsol_xx)->size(0)) <= _614);
      if (_6842)
      {
        _6841 = (int)((initsol_xx)->size(0));
      }
      else
      {
        _6841 = _614;
      }
      int _618 = _6841;
      int _6843 = (int)0;
      int _6844 = _618;
      for (int _619 = _6843; _619 < _6844; ++_619)
      {
        {
          if (((*initsol_xx_flag)(_619)))
          {
            {
              _ptr__615[_619] = ((*initsol_xx)(_619));
            }
          }
          {}
        }
      }
      task_putxx_slice(_613,(int)0,_614,_615);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _620,bool _621,bool _622){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _623 = nullptr;
  mosek::fusion::SolutionType _624 = _620;
  if ((_624 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _624 = solutionptr;
    }
  }
  {}
  if ((_624 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _623 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _623 = sol_bas;
        }
      }
      else
      {
        {
          _623 = sol_itr;
        }
      }
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _623 = sol_itr;
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _623 = sol_bas;
    }
  }
  else if((_624 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _623 = sol_itg;
    }
  }
  {}
  if ((NULL == _623.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_622 || ((_621 && _623->isPrimalAcceptable(acceptable_sol)) || ((!_621) && _623->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _623;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _625 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _626 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->pstatus;
          if ((!_621))
          {
            {
              _626 = mosek::fusion::p_SolutionStruct::_get_impl(_623)->dstatus;
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_626 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_626 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but at least "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _625->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected"));
          throw ::mosek::fusion::SolutionError(_625->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _627,bool _628){
  return __mosek_2fusion_2Model__get_sol_cache(_627,_628,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _629,std::shared_ptr< monty::ndarray< double,1 > > _630){
  _checked_ptr_1<int> _ptr__629(_629 ? _629->raw() : nullptr, _629 ? _629->size(0) : 0);
  _checked_ptr_1<double> _ptr__630(_630 ? _630->raw() : nullptr, _630 ? _630->size(0) : 0);
  ensure_initsol_xx();
  int _6845 = (int)0;
  int _6846 = (int)((_629)->size(0));
  for (int _631 = _6845; _631 < _6846; ++_631)
  {
    {
      ((*initsol_xx)(_ptr__629[_631])) = _ptr__630[_631];
      ((*initsol_xx_flag)(_ptr__629[_631])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _632 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_632)));
      std::vector<bool> _6847;
      for (int _633 = (int)0, _6848 = _632; _633 < _6848 ; ++_633)
      {
        _6847.push_back(false);
      }
      auto _6849 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6847.size()),_6847.begin(),_6847.end()));
      initsol_xx_flag = _6849;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _632))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _634 = initsol_xx;
      _checked_ptr_1<double> _ptr__634(_634 ? _634->raw() : nullptr,_634 ? _634->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _635 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_632)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_632)));
      ::mosek::fusion::Utils::Tools::arraycopy(_634,(int)0,initsol_xx,(int)0,_632);
      int _6850 = (int)0;
      int _6851 = _632;
      for (int _636 = _6850; _636 < _6851; ++_636)
      {
        {
          ((*initsol_xx_flag)(_636)) = ((*_635)(_636));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _637){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_637,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _638){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_638,false))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _639){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_639,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _640){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_640,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _641){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_641,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _642){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_642,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _643){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_643,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _644){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_644,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _645){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_645,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _646){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_646,true))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _647){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_647,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _648) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_648); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _648){
  solutionptr = _648;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _649) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_649); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _649){
  acceptable_sol = _649;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _650) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_650); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _650){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _651 = nullptr;
  if ((_650 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _651 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _651 = sol_bas;
        }
      }
      else
      {
        {
          _651 = sol_itr;
        }
      }
    }
  }
  else if((_650 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _651 = sol_itr;
    }
  }
  else if((_650 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _651 = sol_bas;
    }
  }
  else if((_650 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _651 = sol_itg;
    }
  }
  {}
  if ((NULL == _651.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_651)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _652) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_652); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _652){
  return getSolutionStatus(_652,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _653) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_653); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _653){
  return getSolutionStatus(_653,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _654,bool _655){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _657 = __mosek_2fusion_2Model__get_sol_cache(_654,_655,true);
      if (_655)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_657)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_657)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _656)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _658,monty::rc_ptr< ::mosek::fusion::Expression > _659){
  _checked_ptr_1<int> _ptr__658(_658 ? _658->raw() : nullptr, _658 ? _658->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_659)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _660 = ws->popi32();
  int _661 = ws->popi32(_660);
  int _662 = ws->popi32();
  int _663 = ws->popi32();
  bool _664 = ((int)0 != ws->popi32());
  int _665 = ws->popi32(safe_add( _662,(int)1 ));
  int _6852;
  bool _6853 = _664;
  if (_6853)
  {
    _6852 = ws->popi64(_662);
  }
  else
  {
    _6852 = (int)0;
  }
  int _666 = _6852;
  int _667 = ws->popi64(_663);
  int _668 = ws->popf64(_662);
  int _669 = ws->popf64(_663);
  std::shared_ptr< monty::ndarray< int,1 > > _670 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__670(_670 ? _670->raw() : nullptr,_670 ? _670->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _671 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__671(_671 ? _671->raw() : nullptr,_671 ? _671->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _672 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__672(_672 ? _672->raw() : nullptr,_672 ? _672->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _673 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _662,(int)1 ))));
  _checked_ptr_1<long long> _ptr__673(_673 ? _673->raw() : nullptr,_673 ? _673->size(0) : 0);
  int _6854 = (int)0;
  int _6855 = _662;
  for (int _674 = _6854; _674 < _6855; ++_674)
  {
    {
      int _6856 = _ptr__670[safe_add( _665,_674 )];
      int _6857 = _ptr__670[safe_add( safe_add( _665,_674 ),(int)1 )];
      for (int _675 = _6856; _675 < _6857; ++_675)
      {
        {
          if ((_ptr__671[safe_add( _667,_675 )] > (int)0))
          {
            {
              ++ _ptr__673[safe_add( _674,(int)1 )];
            }
          }
          {}
        }
      }
    }
  }
  int _6858 = (int)0;
  int _6859 = _662;
  for (int _676 = _6858; _676 < _6859; ++_676)
  {
    {
      _ptr__673[safe_add( _676,(int)1 )] += _ptr__673[_676];
    }
  }
  long long _677 = _ptr__673[_662];
  std::shared_ptr< monty::ndarray< int,1 > > _678 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_677)));
  _checked_ptr_1<int> _ptr__678(_678 ? _678->raw() : nullptr,_678 ? _678->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _679 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_677)));
  _checked_ptr_1<double> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
  int _680 = (int)0;
  int _6860 = (int)0;
  int _6861 = _662;
  for (int _681 = _6860; _681 < _6861; ++_681)
  {
    {
      int _6862 = _ptr__670[safe_add( _665,_681 )];
      int _6863 = _ptr__670[safe_add( safe_add( _665,_681 ),(int)1 )];
      for (int _682 = _6862; _682 < _6863; ++_682)
      {
        {
          if ((_ptr__671[safe_add( _667,_682 )] > (int)0))
          {
            {
              _ptr__678[_680] = (int)(_ptr__671[safe_add( _667,_682 )] - (int)1);
              _ptr__679[_680] = _ptr__672[safe_add( _669,_682 )];
              ++ _680;
            }
          }
          {}
        }
      }
    }
  }
  task_putarowlist(_658,_673,_678,_679);
  std::vector<int> _6864;
  for (int _683 = (int)0, _6865 = _662; _683 < _6865 ; ++_683)
  {
    _6864.push_back(bfixidx);
  }
  auto _6866 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6864.size()),_6864.begin(),_6864.end()));
  std::vector<double> _6867;
  for (int _684 = (int)0, _6868 = _662; _684 < _6868 ; ++_684)
  {
    _6867.push_back(_ptr__672[safe_add( _668,_684 )]);
  }
  auto _6869 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6867.size()),_6867.begin(),_6867.end()));
  task_putaijlist(_658,_6866,_6869,(long long)(_662));
  int _685 = (int)0;
  int _6870 = (int)0;
  int _6871 = _662;
  for (int _686 = _6870; _686 < _6871; ++_686)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__658[_686])) > (int)0))
      {
        {
          ++ _685;
        }
      }
      {}
    }
  }
  if ((_685 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _687 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_685)));
      _checked_ptr_1<int> _ptr__687(_687 ? _687->raw() : nullptr,_687 ? _687->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _688 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_685)));
      _checked_ptr_1<int> _ptr__688(_688 ? _688->raw() : nullptr,_688 ? _688->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _689 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_685)));
      _checked_ptr_1<double> _ptr__689(_689 ? _689->raw() : nullptr,_689 ? _689->size(0) : 0);
      int _690 = (int)0;
      int _6872 = (int)0;
      int _6873 = _662;
      for (int _691 = _6872; _691 < _6873; ++_691)
      {
        {
          if ((((*natconmap_slackidx)(_ptr__658[_691])) > (int)0))
          {
            {
              _ptr__687[_690] = _ptr__658[_691];
              _ptr__688[_690] = (int)(((*natconmap_slackidx)(_ptr__658[_691])) - (int)1);
              _ptr__689[_690] = (-1.0);
              ++ _690;
            }
          }
          {}
        }
      }
      task_putaijlist(_687,_688,_689,(long long)(_685));
    }
  }
  {}
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _692,monty::rc_ptr< ::mosek::fusion::Expression > _693,std::shared_ptr< monty::ndarray< int,1 > > _694,bool _695){
  _checked_ptr_1<int> _ptr__692(_692 ? _692->raw() : nullptr, _692 ? _692->size(0) : 0);
  _checked_ptr_1<int> _ptr__694(_694 ? _694->raw() : nullptr, _694 ? _694->size(0) : 0);
  int _696 = safe_mul( (int)((_692)->size(0)),(int)((_694)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _697 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_696)));
  _checked_ptr_1<double> _ptr__697(_697 ? _697->raw() : nullptr,_697 ? _697->size(0) : 0);
  std::vector<int> _6874;
  for (int _699 = (int)0, _6875 = (int)((_692)->size(0)); _699 < _6875 ; ++_699)
  {
    for (int _700 = (int)0, _6876 = (int)((_694)->size(0)); _700 < _6876 ; ++_700)
    {
      _6874.push_back(_ptr__692[_699]);
    }
  }
  auto _6877 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6874.size()),_6874.begin(),_6874.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _698 = _6877;
  _checked_ptr_1<int> _ptr__698(_698 ? _698->raw() : nullptr,_698 ? _698->size(0) : 0);
  std::vector<int> _6878;
  for (int _702 = (int)0, _6879 = (int)((_692)->size(0)); _702 < _6879 ; ++_702)
  {
    for (int _703 = (int)0, _6880 = (int)((_694)->size(0)); _703 < _6880 ; ++_703)
    {
      _6878.push_back(_ptr__694[_703]);
    }
  }
  auto _6881 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6878.size()),_6878.begin(),_6878.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _701 = _6881;
  _checked_ptr_1<int> _ptr__701(_701 ? _701->raw() : nullptr,_701 ? _701->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_693)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _704 = ws->popi32();
  int _705 = ws->popi32(_704);
  int _706 = ws->popi32();
  int _707 = ws->popi32();
  bool _708 = ((int)0 != ws->popi32());
  int _709 = ws->popi32(safe_add( _706,(int)1 ));
  int _6882;
  bool _6883 = _708;
  if (_6883)
  {
    _6882 = ws->popi64(_706);
  }
  else
  {
    _6882 = (int)0;
  }
  int _710 = _6882;
  int _711 = ws->popi64(_707);
  int _712 = ws->popf64(_706);
  int _713 = ws->popf64(_707);
  std::shared_ptr< monty::ndarray< int,1 > > _714 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__714(_714 ? _714->raw() : nullptr,_714 ? _714->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _715 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__715(_715 ? _715->raw() : nullptr,_715 ? _715->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _716 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__716(_716 ? _716->raw() : nullptr,_716 ? _716->size(0) : 0);
  int _717 = (int)0;
  int _6884 = (int)0;
  int _6885 = _706;
  for (int _718 = _6884; _718 < _6885; ++_718)
  {
    {
      int _719 = _ptr__714[safe_add( _709,_718 )];
      int _720 = _ptr__714[safe_add( safe_add( _709,_718 ),(int)1 )];
      int _721 = _719;
      int _722 = (int)0;
      while ( ((_722 < (int)((_694)->size(0))) && (_721 < _720)) )
      {
        {
          if ((_ptr__694[_722] < (_ptr__715[safe_add( _711,_721 )] - (int)1)))
          {
            {
              ++ _722;
            }
          }
          else if((_ptr__694[_722] > (_ptr__715[safe_add( _711,_721 )] - (int)1)))
          {
            {
              ++ _721;
            }
          }
          else
          {
            {
              _ptr__697[safe_add( _717,_722 )] = _ptr__716[safe_add( _713,_721 )];
              ++ _722;
              ++ _721;
            }
          }
        }
      }
      _717 += (int)((_694)->size(0));
    }
  }
  task_putaijlist(_698,_701,_697,(long long)(_696));
  if (_695)
  {
    {
      std::vector<int> _6886;
      for (int _723 = (int)0, _6887 = _706; _723 < _6887 ; ++_723)
      {
        _6886.push_back(bfixidx);
      }
      auto _6888 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6886.size()),_6886.begin(),_6886.end()));
      std::vector<double> _6889;
      for (int _724 = (int)0, _6890 = _706; _724 < _6890 ; ++_724)
      {
        _6889.push_back(_ptr__716[safe_add( _712,_724 )]);
      }
      auto _6891 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6889.size()),_6889.begin(),_6889.end()));
      task_putaijlist(_692,_6888,_6891,(long long)(_706));
    }
  }
  {}
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _725,monty::rc_ptr< ::mosek::fusion::Variable > _726) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_725,_726); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _725,monty::rc_ptr< ::mosek::fusion::Variable > _726){
  if ((_725->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _727 = _726->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _728 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_727)));
  _checked_ptr_1<long long> _ptr__728(_728 ? _728->raw() : nullptr,_728 ? _728->size(0) : 0);
  if ((_727 < _726->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _729 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_727)));
      _checked_ptr_1<long long> _ptr__729(_729 ? _729->raw() : nullptr,_729 ? _729->size(0) : 0);
      _726->inst((int)0,_729,(int)0,_728);
    }
  }
  else
  {
    {
      _726->inst((int)0,_728);
    }
  }
  int _6892 = (int)0;
  int _6893 = _727;
  for (int _730 = _6892; _730 < _6893; ++_730)
  {
    {
      if ((_ptr__728[_730] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _731 = true;
  int _6894 = (int)0;
  int _6895 = (_727 - (int)1);
  for (int _732 = _6894; _732 < _6895; ++_732)
  {
    {
      _731 = (_731 && (_ptr__728[_732] < _ptr__728[(_732 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _733 = nullptr;
  _checked_ptr_1<int> _ptr__733(_733 ? _733->raw() : nullptr,_733 ? _733->size(0) : 0);
  if (_731)
  {
    {
      std::vector<int> _6896;
      for (int _734 = (int)0, _6897 = _727; _734 < _6897 ; ++_734)
      {
        _6896.push_back((int)(_ptr__728[_734] - (int)1));
      }
      auto _6898 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6896.size()),_6896.begin(),_6896.end()));
      _733 = _6898;
      _ptr__733.update(_733 ? _733->raw() : nullptr, _733 ? _733->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _6899;
      for (int _736 = (-(int)1), _6900 = _727; _736 < _6900 ; ++_736)
      {
        _6899.push_back(_736);
      }
      auto _6901 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6899.size()),_6899.begin(),_6899.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _735 = _6901;
      _checked_ptr_1<long long> _ptr__735(_735 ? _735->raw() : nullptr,_735 ? _735->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_735,_728,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_727));
      std::vector<int> _6902;
      for (int _737 = (int)0, _6903 = _727; _737 < _6903 ; ++_737)
      {
        _6902.push_back((int)(_ptr__728[_ptr__735[_737]] - (int)1));
      }
      auto _6904 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6902.size()),_6902.begin(),_6902.end()));
      _733 = _6904;
      _ptr__733.update(_733 ? _733->raw() : nullptr, _733 ? _733->size(0) : 0);
    }
  }
  int _738 = (int)((_733)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _739 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_738)));
  _checked_ptr_1<double> _ptr__739(_739 ? _739->raw() : nullptr,_739 ? _739->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _740 = _733;
  _checked_ptr_1<int> _ptr__740(_740 ? _740->raw() : nullptr,_740 ? _740->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_725)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  int _741 = ws->popi32();
  int _742 = ws->popi32(_741);
  int _743 = ws->popi32();
  int _744 = ws->popi32();
  bool _745 = ((int)0 != ws->popi32());
  int _746 = ws->popi32(safe_add( _743,(int)1 ));
  int _6905;
  bool _6906 = _745;
  if (_6906)
  {
    _6905 = ws->popi64(_743);
  }
  else
  {
    _6905 = (int)0;
  }
  int _747 = _6905;
  int _748 = ws->popi64(_744);
  int _749 = ws->popf64(_743);
  int _750 = ws->popf64(_744);
  std::shared_ptr< monty::ndarray< int,1 > > _751 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__751(_751 ? _751->raw() : nullptr,_751 ? _751->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _752 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__752(_752 ? _752->raw() : nullptr,_752 ? _752->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _753 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__753(_753 ? _753->raw() : nullptr,_753 ? _753->size(0) : 0);
  int _754 = (int)0;
  int _6907 = (int)0;
  int _6908 = _743;
  for (int _755 = _6907; _755 < _6908; ++_755)
  {
    {
      int _756 = _ptr__751[safe_add( _746,_755 )];
      int _757 = _ptr__751[safe_add( safe_add( _746,_755 ),(int)1 )];
      int _758 = _756;
      int _759 = (int)0;
      while ( ((_759 < (int)((_733)->size(0))) && (_758 < _757)) )
      {
        {
          if ((_ptr__733[_759] < (_ptr__752[safe_add( _748,_758 )] - (int)1)))
          {
            {
              ++ _759;
            }
          }
          else if((_ptr__733[_759] > (_ptr__752[safe_add( _748,_758 )] - (int)1)))
          {
            {
              ++ _758;
            }
          }
          else
          {
            {
              _ptr__739[safe_add( _754,_759 )] = _ptr__753[safe_add( _750,_758 )];
              ++ _759;
              ++ _758;
            }
          }
        }
      }
      _754 += (int)((_733)->size(0));
    }
  }
  task_putclist(_740,_739);
}
void mosek::fusion::p_Model::objective_(const std::string & _760,mosek::fusion::ObjectiveSense _761,monty::rc_ptr< ::mosek::fusion::Expression > _762){
  task_putobjectivename(_760);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _763 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _764 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_762)).as<::mosek::fusion::Expression>())->eval(_763,_764,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _765 = mosek::fusion::p_WorkStack::_get_impl(_763)->i32;
  _checked_ptr_1<int> _ptr__765(_765 ? _765->raw() : nullptr,_765 ? _765->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _766 = mosek::fusion::p_WorkStack::_get_impl(_763)->i64;
  _checked_ptr_1<long long> _ptr__766(_766 ? _766->raw() : nullptr,_766 ? _766->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _767 = mosek::fusion::p_WorkStack::_get_impl(_763)->f64;
  _checked_ptr_1<double> _ptr__767(_767 ? _767->raw() : nullptr,_767 ? _767->size(0) : 0);
  int _768 = _763->popi32();
  int _769 = (int)1;
  int _6909 = (int)0;
  int _6910 = _768;
  for (int _770 = _6909; _770 < _6910; ++_770)
  {
    {
      _768 *= _763->popi32();
    }
  }
  if ((_769 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  int _771 = _763->popi32();
  if ((_771 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _772 = _763->popi32();
  bool _773 = (_763->popi32() != (int)0);
  int _774 = _763->popi32(safe_add( _771,(int)1 ));
  int _775 = _763->popi64(_772);
  int _776 = _763->popf64(_771);
  int _777 = _763->popf64(_772);
  int _778 = (int)0;
  int _779 = (int)0;
  int _6911 = (int)0;
  int _6912 = _772;
  for (int _780 = _6911; _780 < _6912; ++_780)
  {
    {
      if ((_ptr__766[safe_add( _775,_780 )] < (int)0))
      {
        {
          ++ _779;
        }
      }
      else if((_ptr__766[safe_add( _775,_780 )] > (int)0))
      {
        {
          ++ _778;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _781 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_778)));
  _checked_ptr_1<int> _ptr__781(_781 ? _781->raw() : nullptr,_781 ? _781->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _782 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_778)));
  _checked_ptr_1<double> _ptr__782(_782 ? _782->raw() : nullptr,_782 ? _782->size(0) : 0);
  {
    int _783 = (int)0;
    int _6913 = (int)0;
    int _6914 = _772;
    for (int _784 = _6913; _784 < _6914; ++_784)
    {
      {
        if ((_ptr__766[safe_add( _775,_784 )] > (int)0))
        {
          {
            _ptr__781[_783] = (int)(_ptr__766[safe_add( _775,_784 )] - (int)1);
            _ptr__782[_783] = _ptr__767[safe_add( _777,_784 )];
            ++ _783;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_761 == ::mosek::fusion::ObjectiveSense::Maximize),_781,_782,_ptr__767[_776]);
  if ((_779 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _785 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
      _checked_ptr_1<int> _ptr__785(_785 ? _785->raw() : nullptr,_785 ? _785->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _786 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
      _checked_ptr_1<int> _ptr__786(_786 ? _786->raw() : nullptr,_786 ? _786->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _787 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_779)));
      _checked_ptr_1<int> _ptr__787(_787 ? _787->raw() : nullptr,_787 ? _787->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _788 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_779)));
      _checked_ptr_1<double> _ptr__788(_788 ? _788->raw() : nullptr,_788 ? _788->size(0) : 0);
      int _6915 = (int)0;
      int _6916 = _779;
      for (int _789 = _6915; _789 < _6916; ++_789)
      {
        {
          long long _790 = (-safe_add( _ptr__766[safe_add( _775,_789 )],(int)1 ));
          _ptr__785[_789] = ((*natbarvar_idx)(_790));
          _ptr__786[_789] = ((*natbarvar_i)(_790));
          _ptr__787[_789] = ((*natbarvar_j)(_790));
          double _6917;
          bool _6918 = (_ptr__786[_789] == _ptr__787[_789]);
          if (_6918)
          {
            _6917 = _ptr__767[safe_add( _777,_789 )];
          }
          else
          {
            _6917 = (0.5 * _ptr__767[safe_add( _777,_789 )]);
          }
          _ptr__788[_789] = _6917;
        }
      }
      task_putbarc(_785,_786,_787,_788);
    }
  }
  {}
}
void mosek::fusion::Model :: objective(double _791) { mosek::fusion::p_Model::_get_impl(this)->objective(_791); }void mosek::fusion::p_Model::objective(double _791){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_791));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _792,double _793) { mosek::fusion::p_Model::_get_impl(this)->objective(_792,_793); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _792,double _793){
  objective_(std::string (""),_792,::mosek::fusion::p_Expr::constTerm(_793));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _794,monty::rc_ptr< ::mosek::fusion::Expression > _795) { mosek::fusion::p_Model::_get_impl(this)->objective(_794,_795); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _794,monty::rc_ptr< ::mosek::fusion::Expression > _795){
  objective_(std::string (""),_794,_795);
}
void mosek::fusion::Model :: objective(const std::string & _796,double _797) { mosek::fusion::p_Model::_get_impl(this)->objective(_796,_797); }void mosek::fusion::p_Model::objective(const std::string & _796,double _797){
  objective_(_796,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_797));
}
void mosek::fusion::Model :: objective(const std::string & _798,mosek::fusion::ObjectiveSense _799,double _800) { mosek::fusion::p_Model::_get_impl(this)->objective(_798,_799,_800); }void mosek::fusion::p_Model::objective(const std::string & _798,mosek::fusion::ObjectiveSense _799,double _800){
  objective_(_798,_799,::mosek::fusion::p_Expr::constTerm(_800));
}
void mosek::fusion::Model :: objective(const std::string & _801,mosek::fusion::ObjectiveSense _802,monty::rc_ptr< ::mosek::fusion::Expression > _803) { mosek::fusion::p_Model::_get_impl(this)->objective(_801,_802,_803); }void mosek::fusion::p_Model::objective(const std::string & _801,mosek::fusion::ObjectiveSense _802,monty::rc_ptr< ::mosek::fusion::Expression > _803){
  objective_(_801,_802,_803);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_804,_805); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805) { return __mosek_2fusion_2Model__constraint(_804,_805); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_804,_805);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_806,_807,_808); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808) { return __mosek_2fusion_2Model__constraint(_806,_807,_808); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808){
  return __mosek_2fusion_2Model__constraint_(_806,_807,_808);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_809,_810); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810) { return __mosek_2fusion_2Model__constraint(_809,_810); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_809,_810);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_811,_812,_813); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813) { return __mosek_2fusion_2Model__constraint(_811,_812,_813); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813){
  return __mosek_2fusion_2Model__constraint_(_811,_812,_813);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_814,_815); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815) { return __mosek_2fusion_2Model__constraint(_814,_815); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_814,_815);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_816,_817,_818); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818) { return __mosek_2fusion_2Model__constraint(_816,_817,_818); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818){
  return __mosek_2fusion_2Model__constraint_(_816,_817,_818);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_819,_820); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820) { return __mosek_2fusion_2Model__constraint(_819,_820); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_819,_820);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_821,_822,_823); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) { return __mosek_2fusion_2Model__constraint(_821,_822,_823); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823){
  return __mosek_2fusion_2Model__constraint_(_821,_822,_823);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_824,_825); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825) { return __mosek_2fusion_2Model__constraint(_824,_825); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_824,_825);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_826,_827,_828); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828) { return __mosek_2fusion_2Model__constraint(_826,_827,_828); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828){
  return __mosek_2fusion_2Model__constraint_(_826,_827,_828);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_829); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) { return __mosek_2fusion_2Model__variable(_829); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_829)->shape,_829);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_830,_831,_832); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) { return __mosek_2fusion_2Model__variable(_830,_831,_832); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_830),(int)(_830),(int)(_831)}),_832);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_833,_834); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834) { return __mosek_2fusion_2Model__variable(_833,_834); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_833),(int)(_833)}),_834);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_835,_836); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836) { return __mosek_2fusion_2Model__variable(_835,_836); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836){
  return __mosek_2fusion_2Model__variable_(_835,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_836);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_837,_838,_839,_840); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) { return __mosek_2fusion_2Model__variable(_837,_838,_839,_840); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840){
  return __mosek_2fusion_2Model__variable_(_837,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_838),(int)(_838),(int)(_839)}),_840);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_841,_842,_843); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843) { return __mosek_2fusion_2Model__variable(_841,_842,_843); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843){
  return __mosek_2fusion_2Model__variable_(_841,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_842),(int)(_842)}),_843);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_844,_845,_846); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) { return __mosek_2fusion_2Model__variable(_844,_845,_846); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846){
  _checked_ptr_1<int> _ptr__845(_845 ? _845->raw() : nullptr, _845 ? _845->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_844,_845,_846);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_847); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) { return __mosek_2fusion_2Model__variable(_847); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_847)->shape,_847)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_848,_849,_850); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) { return __mosek_2fusion_2Model__variable(_848,_849,_850); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_848),(int)(_848),(int)(_849)}),_850)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_851,_852); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852) { return __mosek_2fusion_2Model__variable(_851,_852); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_851),(int)(_851)}),_852)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_853,_854); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854) { return __mosek_2fusion_2Model__variable(_853,_854); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854){
  return (__mosek_2fusion_2Model__variable_(_853,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_854)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_855,_856,_857,_858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) { return __mosek_2fusion_2Model__variable(_855,_856,_857,_858); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858){
  return (__mosek_2fusion_2Model__variable_(_855,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_856),(int)(_856),(int)(_857)}),_858)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_859,_860,_861); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861) { return __mosek_2fusion_2Model__variable(_859,_860,_861); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861){
  return (__mosek_2fusion_2Model__variable_(_859,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_860),(int)(_860)}),_861)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_862,_863,_864); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) { return __mosek_2fusion_2Model__variable(_862,_863,_864); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864){
  _checked_ptr_1<int> _ptr__863(_863 ? _863->raw() : nullptr, _863 ? _863->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_862,_863,_864)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_865); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) { return __mosek_2fusion_2Model__variable(_865); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_865);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_866); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866) { return __mosek_2fusion_2Model__variable(_866); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_866);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_867); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867) { return __mosek_2fusion_2Model__variable(_867); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_867);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_868,_869); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869) { return __mosek_2fusion_2Model__variable(_868,_869); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869){
  _checked_ptr_1<int> _ptr__868(_868 ? _868->raw() : nullptr, _868 ? _868->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_868,_869);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_870,_871); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871) { return __mosek_2fusion_2Model__variable(_870,_871); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871){
  _checked_ptr_1<int> _ptr__870(_870 ? _870->raw() : nullptr, _870 ? _870->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_870,_871);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_872,_873); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) { return __mosek_2fusion_2Model__variable(_872,_873); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873){
  _checked_ptr_1<int> _ptr__872(_872 ? _872->raw() : nullptr, _872 ? _872->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_872,_873);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_874); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _874) { return __mosek_2fusion_2Model__variable(_874); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874){
  _checked_ptr_1<int> _ptr__874(_874 ? _874->raw() : nullptr, _874 ? _874->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_874,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_875,_876); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876) { return __mosek_2fusion_2Model__variable(_875,_876); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_875)}),_876);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_877,_878); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878) { return __mosek_2fusion_2Model__variable(_877,_878); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_877)}),_878);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_879,_880); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880) { return __mosek_2fusion_2Model__variable(_879,_880); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_879)}),_880);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _881) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_881); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _881) { return __mosek_2fusion_2Model__variable(_881); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _881){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_881)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_882,_883); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883) { return __mosek_2fusion_2Model__variable(_882,_883); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883){
  return __mosek_2fusion_2Model__variable_(_882,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_883);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_884,_885); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885) { return __mosek_2fusion_2Model__variable(_884,_885); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885){
  return __mosek_2fusion_2Model__ranged_variable(_884,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_885);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_886,_887); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887) { return __mosek_2fusion_2Model__variable(_886,_887); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887){
  return __mosek_2fusion_2Model__variable_(_886,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_887);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_888,_889,_890); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) { return __mosek_2fusion_2Model__variable(_888,_889,_890); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890){
  _checked_ptr_1<int> _ptr__889(_889 ? _889->raw() : nullptr, _889 ? _889->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_888,_889,_890);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_891,_892,_893); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) { return __mosek_2fusion_2Model__variable(_891,_892,_893); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893){
  _checked_ptr_1<int> _ptr__892(_892 ? _892->raw() : nullptr, _892 ? _892->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_891,_892,_893);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_894,_895,_896); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) { return __mosek_2fusion_2Model__variable(_894,_895,_896); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896){
  _checked_ptr_1<int> _ptr__895(_895 ? _895->raw() : nullptr, _895 ? _895->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_894,_895,_896);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _897,std::shared_ptr< monty::ndarray< int,1 > > _898) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_897,_898); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _897,std::shared_ptr< monty::ndarray< int,1 > > _898) { return __mosek_2fusion_2Model__variable(_897,_898); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _897,std::shared_ptr< monty::ndarray< int,1 > > _898){
  _checked_ptr_1<int> _ptr__898(_898 ? _898->raw() : nullptr, _898 ? _898->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_897,_898,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_899,_900,_901); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901) { return __mosek_2fusion_2Model__variable(_899,_900,_901); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901){
  return __mosek_2fusion_2Model__variable_(_899,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_900)}),_901);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_902,_903,_904); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904) { return __mosek_2fusion_2Model__variable(_902,_903,_904); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904){
  return __mosek_2fusion_2Model__ranged_variable(_902,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_903)}),_904);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_905,_906,_907); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907) { return __mosek_2fusion_2Model__variable(_905,_906,_907); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907){
  return __mosek_2fusion_2Model__variable_(_905,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_906)}),_907);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _908,int _909) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_908,_909); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _908,int _909) { return __mosek_2fusion_2Model__variable(_908,_909); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _908,int _909){
  return __mosek_2fusion_2Model__variable_(_908,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_909)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _910) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_910); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _910) { return __mosek_2fusion_2Model__variable(_910); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _910){
  return __mosek_2fusion_2Model__variable_(_910,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _911,std::shared_ptr< monty::ndarray< int,1 > > _912,monty::rc_ptr< ::mosek::fusion::RangeDomain > _913){
  _checked_ptr_1<int> _ptr__912(_912 ? _912->raw() : nullptr, _912 ? _912->size(0) : 0);
  if ((((int)((_911).size()) > (int)0) && hasVariable(_911)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_911)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6919;
  bool _6920 = (NULL != _912.get());
  if (_6920)
  {
    _6919 = _912;
  }
  else
  {
    _6919 = mosek::fusion::p_RangeDomain::_get_impl(_913)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _914 = _6919;
  _checked_ptr_1<int> _ptr__914(_914 ? _914->raw() : nullptr,_914 ? _914->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_913)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_913)->shape,_914))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _914.get()))
  {
    {
      _914 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__914.update(_914 ? _914->raw() : nullptr, _914 ? _914->size(0) : 0);
    }
  }
  {}
  int _915 = (int)((_914)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _916 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_915)));
  _checked_ptr_1<int> _ptr__916(_916 ? _916->raw() : nullptr,_916 ? _916->size(0) : 0);
  if ((_915 > (int)0))
  {
    {
      _ptr__916[(_915 - (int)1)] = (int)1;
      int _6921 = (int)1;
      int _6922 = _915;
      for (int _917 = _6921; _917 < _6922; ++_917)
      {
        {
          _ptr__916[((_915 - _917) - (int)1)] = safe_mul( _ptr__916[(_915 - _917)],_ptr__914[(_915 - _917)] );
        }
      }
    }
  }
  {}
  int _918 = (int)1;
  int _6923 = (int)0;
  int _6924 = (int)((_914)->size(0));
  for (int _919 = _6923; _919 < _6924; ++_919)
  {
    {
      _918 *= _ptr__914[_919];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _920 = nullptr;
  _checked_ptr_1<long long> _ptr__920(_920 ? _920->raw() : nullptr,_920 ? _920->size(0) : 0);
  if ((NULL != _920.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(1)) != _915))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _920 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(0)))));
      _ptr__920.update(_920 ? _920->raw() : nullptr, _920 ? _920->size(0) : 0);
      int _6925 = (int)0;
      int _6926 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(0));
      for (int _921 = _6925; _921 < _6926; ++_921)
      {
        {
          int _6927 = (int)0;
          int _6928 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(1));
          for (int _922 = _6927; _922 < _6928; ++_922)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)(_921,_922)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)(_921,_922)) >= _ptr__914[_922])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _923 = (int)0;
          int _6929 = (int)0;
          int _6930 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)->size(1));
          for (int _924 = _6929; _924 < _6930; ++_924)
          {
            {
              _923 += safe_mul( _ptr__916[_924],((*mosek::fusion::p_RangeDomain::_get_impl(_913)->sparsity)(_921,_924)) );
            }
          }
          _ptr__920[_921] = _923;
        }
      }
    }
  }
  {}
  int _6931;
  bool _6932 = (NULL != _920.get());
  if (_6932)
  {
    _6931 = (int)((_920)->size(0));
  }
  else
  {
    _6931 = _918;
  }
  int _925 = _6931;
  std::shared_ptr< monty::ndarray< double,1 > > _926;
  _checked_ptr_1<double> _ptr__926(_926 ? _926->raw() : nullptr,_926 ? _926->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _927;
  _checked_ptr_1<double> _ptr__927(_927 ? _927->raw() : nullptr,_927 ? _927->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_913)->scalable)
  {
    {
      std::vector<double> _6933;
      for (int _928 = (int)0, _6934 = _925; _928 < _6934 ; ++_928)
      {
        _6933.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_913)->lb)((int)0)));
      }
      auto _6935 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6933.size()),_6933.begin(),_6933.end()));
      _926 = _6935;
      _ptr__926.update(_926 ? _926->raw() : nullptr, _926 ? _926->size(0) : 0);
      std::vector<double> _6936;
      for (int _929 = (int)0, _6937 = _925; _929 < _6937 ; ++_929)
      {
        _6936.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_913)->ub)((int)0)));
      }
      auto _6938 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6936.size()),_6936.begin(),_6936.end()));
      _927 = _6938;
      _ptr__927.update(_927 ? _927->raw() : nullptr, _927 ? _927->size(0) : 0);
    }
  }
  else
  {
    {
      _926 = mosek::fusion::p_RangeDomain::_get_impl(_913)->lb;
      _ptr__926.update(_926 ? _926->raw() : nullptr, _926 ? _926->size(0) : 0);
      _927 = mosek::fusion::p_RangeDomain::_get_impl(_913)->ub;
      _ptr__927.update(_927 ? _927->raw() : nullptr, _927 ? _927->size(0) : 0);
    }
  }
  int _930 = natvarmap_alloc(_925);
  std::shared_ptr< monty::ndarray< int,1 > > _931 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_930))));
  _checked_ptr_1<int> _ptr__931(_931 ? _931->raw() : nullptr,_931 ? _931->size(0) : 0);
  natvarmap->get(_930,_931,(int)0);
  int _6939 = (int)0;
  int _6940 = _925;
  for (int _932 = _6939; _932 < _6940; ++_932)
  {
    {
      ((*natvarmap_idx)(_ptr__931[_932])) = _930;
    }
  }
  task_var_putboundlist_ra(_931,_926,_927);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _933 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_911,(long long)(_930),_914,_920,_931);
  if (mosek::fusion::p_RangeDomain::_get_impl(_913)->cardinal_flag)
  {
    {
      task_var_putintlist(_931);
    }
  }
  {}
  ((*vars)(_930)) = (_933).as<::mosek::fusion::ModelVariable>();
  if (((int)((_911).size()) > (int)0))
  {
    {
      var_map->setItem(_911,_930);
    }
  }
  {}
  return (_933).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _934,std::shared_ptr< monty::ndarray< int,1 > > _935,monty::rc_ptr< ::mosek::fusion::ConeDomain > _936){
  _checked_ptr_1<int> _ptr__935(_935 ? _935->raw() : nullptr, _935 ? _935->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6941;
  bool _6942 = (NULL != _935.get());
  if (_6942)
  {
    _6941 = _935;
  }
  else
  {
    _6941 = mosek::fusion::p_ConeDomain::_get_impl(_936)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _937 = _6941;
  _checked_ptr_1<int> _ptr__937(_937 ? _937->raw() : nullptr,_937 ? _937->size(0) : 0);
  if ((((int)((_934).size()) > (int)0) && hasVariable(_934)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_934)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _937.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_936)->shape.get()) && (!::mosek::fusion::p_Set::match(_937,mosek::fusion::p_ConeDomain::_get_impl(_936)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_936->getAxis() >= (int)((_937)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _6943;
  bool _6944 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_936)->shape.get());
  if (_6944)
  {
    _6943 = _936->getAxis();
  }
  else
  {
    _6943 = ((int)((_937)->size(0)) - (int)1);
  }
  int _938 = _6943;
  int _939 = _ptr__937[_938];
  int _940 = (int)((_937)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _941 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_940)));
  _checked_ptr_1<int> _ptr__941(_941 ? _941->raw() : nullptr,_941 ? _941->size(0) : 0);
  _ptr__941[(_940 - (int)1)] = (int)1;
  int _6945 = (int)1;
  int _6946 = _940;
  for (int _942 = _6945; _942 < _6946; ++_942)
  {
    {
      _ptr__941[((_940 - _942) - (int)1)] = safe_mul( _ptr__941[(_940 - _942)],_ptr__937[(_940 - _942)] );
    }
  }
  int _943 = _ptr__937[(int)0];
  int _6947 = (int)1;
  int _6948 = (int)((_937)->size(0));
  for (int _944 = _6947; _944 < _6948; ++_944)
  {
    {
      _943 *= _ptr__937[_944];
    }
  }
  int _945 = (int)1;
  int _6949 = (int)0;
  int _6950 = _938;
  for (int _946 = _6949; _946 < _6950; ++_946)
  {
    {
      _945 *= _ptr__937[_946];
    }
  }
  int _947 = (int)1;
  int _6951 = safe_add( _938,(int)1 );
  int _6952 = _940;
  for (int _948 = _6951; _948 < _6952; ++_948)
  {
    {
      _947 *= _ptr__937[_948];
    }
  }
  int _949 = safe_mul( _945,_947 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InQCone) && (_939 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_939 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_939 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_939 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_939 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_939 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _950 = natvarmap_alloc(_943);
  int _951 = natconemap_alloc(_949);
  ((*natvarmap_type)(_950)) = safe_add( _951,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _952 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_950))));
  _checked_ptr_1<int> _ptr__952(_952 ? _952->raw() : nullptr,_952 ? _952->size(0) : 0);
  natvarmap->get(_950,_952,(int)0);
  int _6953 = (int)0;
  int _6954 = _943;
  for (int _953 = _6953; _953 < _6954; ++_953)
  {
    {
      ((*natvarmap_idx)(_ptr__952[_953])) = _950;
    }
  }
  task_var_putboundlist_fr(_952);
  if (mosek::fusion::p_ConeDomain::_get_impl(_936)->int_flag)
  {
    {
      task_var_putintlist(_952);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _954 = _952;
  _checked_ptr_1<int> _ptr__954(_954 ? _954->raw() : nullptr,_954 ? _954->size(0) : 0);
  if ((_938 < ((int)((_937)->size(0)) - (int)1)))
  {
    {
      _954 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_952)->size(0)))));
      _ptr__954.update(_954 ? _954->raw() : nullptr, _954 ? _954->size(0) : 0);
      int _955 = (int)0;
      int _6955 = (int)0;
      int _6956 = _945;
      for (int _956 = _6955; _956 < _6956; ++_956)
      {
        {
          int _6957 = (int)0;
          int _6958 = _947;
          for (int _957 = _6957; _957 < _6958; ++_957)
          {
            {
              int _6959 = (int)0;
              int _6960 = _939;
              for (int _958 = _6959; _958 < _6960; ++_958)
              {
                {
                  _ptr__954[_955] = _ptr__952[safe_add( safe_mul( safe_add( safe_mul( _956,_939 ),_958 ),_947 ),_957 )];
                  ++ _955;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _959 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_949)));
  _checked_ptr_1<int> _ptr__959(_959 ? _959->raw() : nullptr,_959 ? _959->size(0) : 0);
  natconemap->get(_951,_959,(int)0);
  ((*natconemap_dim)(_951)) = _939;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_959,_939,_949,_954);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_959,_939,_949,_954);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_959,_939,_949,_954);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _6961;
                  for (int _960 = (int)0, _6962 = _949; _960 < _6962 ; ++_960)
                  {
                    _6961.push_back(mosek::fusion::p_ConeDomain::_get_impl(_936)->alpha);
                  }
                  auto _6963 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6961.size()),_6961.begin(),_6961.end()));
                  task_put_ppowcones(_959,_939,_949,_954,_6963);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_959,_939,_949,_954);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_936)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _6964;
                          for (int _961 = (int)0, _6965 = _949; _961 < _6965 ; ++_961)
                          {
                            _6964.push_back(mosek::fusion::p_ConeDomain::_get_impl(_936)->alpha);
                          }
                          auto _6966 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6964.size()),_6964.begin(),_6964.end()));
                          task_put_dpowcones(_959,_939,_949,_954,_6966);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _6967 = (int)0;
  int _6968 = (int)((_959)->size(0));
  for (int _962 = _6967; _962 < _6968; ++_962)
  {
    {
      task_cone_name(_ptr__959[_962],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__959[_962])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _963 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_934,_950,_937,_952);
  ((*vars)(_950)) = (_963).as<::mosek::fusion::ModelVariable>();
  if (((int)((_934).size()) > (int)0))
  {
    {
      var_map->setItem(_934,_950);
    }
  }
  {}
  return (_963).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _964,std::shared_ptr< monty::ndarray< int,1 > > _965,monty::rc_ptr< ::mosek::fusion::LinearDomain > _966){
  _checked_ptr_1<int> _ptr__965(_965 ? _965->raw() : nullptr, _965 ? _965->size(0) : 0);
  if ((((int)((_964).size()) > (int)0) && hasVariable(_964)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_964)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6969;
  bool _6970 = (NULL != _965.get());
  if (_6970)
  {
    _6969 = _965;
  }
  else
  {
    _6969 = mosek::fusion::p_LinearDomain::_get_impl(_966)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _967 = _6969;
  _checked_ptr_1<int> _ptr__967(_967 ? _967->raw() : nullptr,_967 ? _967->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_966)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_966)->shape,_967))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _967.get()))
  {
    {
      _967 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__967.update(_967 ? _967->raw() : nullptr, _967 ? _967->size(0) : 0);
    }
  }
  {}
  int _968 = (int)((_967)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _969 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_968)));
  _checked_ptr_1<int> _ptr__969(_969 ? _969->raw() : nullptr,_969 ? _969->size(0) : 0);
  if ((_968 > (int)0))
  {
    {
      _ptr__969[(_968 - (int)1)] = (int)1;
      int _6971 = (int)1;
      int _6972 = _968;
      for (int _970 = _6971; _970 < _6972; ++_970)
      {
        {
          _ptr__969[((_968 - _970) - (int)1)] = safe_mul( _ptr__969[(_968 - _970)],_ptr__967[(_968 - _970)] );
        }
      }
    }
  }
  {}
  int _971 = (int)1;
  int _6973 = (int)0;
  int _6974 = (int)((_967)->size(0));
  for (int _972 = _6973; _972 < _6974; ++_972)
  {
    {
      _971 *= _ptr__967[_972];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _973 = nullptr;
  _checked_ptr_1<long long> _ptr__973(_973 ? _973->raw() : nullptr,_973 ? _973->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _974 = nullptr;
  _checked_ptr_1<int> _ptr__974(_974 ? _974->raw() : nullptr,_974 ? _974->size(0) : 0);
  if (mosek::fusion::p_LinearDomain::_get_impl(_966)->empty)
  {
    {
      _973 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
      _ptr__973.update(_973 ? _973->raw() : nullptr, _973 ? _973->size(0) : 0);
    }
  }
  else if((NULL != mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)->size(1)) != _968))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _975 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)->size(0));
      _973 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_975)));
      _ptr__973.update(_973 ? _973->raw() : nullptr, _973 ? _973->size(0) : 0);
      int _6975 = (int)0;
      int _6976 = _975;
      for (int _976 = _6975; _976 < _6976; ++_976)
      {
        {
          int _6977 = (int)0;
          int _6978 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)->size(1));
          for (int _977 = _6977; _977 < _6978; ++_977)
          {
            {
              if (((((*mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)(_976,_977)) < (int)0) || (((*mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)(_976,_977)) >= _ptr__967[_977])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is out of bounds"));
                }
              }
              {}
            }
          }
          long long _978 = (int)0;
          int _6979 = (int)0;
          int _6980 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)->size(1));
          for (int _979 = _6979; _979 < _6980; ++_979)
          {
            {
              _978 += safe_mul( _ptr__969[_979],((*mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity)(_976,_979)) );
            }
          }
          _ptr__973[_976] = _978;
        }
      }
      std::shared_ptr< monty::ndarray< int,2 > > _980 = mosek::fusion::p_LinearDomain::_get_impl(_966)->sparsity;
      int _981 = (int)0;
      int _6981 = (int)0;
      int _6982 = _968;
      for (int _982 = _6981; _982 < _6982; ++_982)
      {
        {
          if ((_981 < _ptr__967[_982]))
          {
            {
              _981 = _ptr__967[_982];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _983 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_975)));
      _checked_ptr_1<int> _ptr__983(_983 ? _983->raw() : nullptr,_983 ? _983->size(0) : 0);
      int _6983 = (int)0;
      int _6984 = _975;
      for (int _984 = _6983; _984 < _6984; ++_984)
      {
        {
          _ptr__983[_984] = _984;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _985 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_975)));
      _checked_ptr_1<int> _ptr__985(_985 ? _985->raw() : nullptr,_985 ? _985->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _986 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _981,(int)1 ))));
      _checked_ptr_1<int> _ptr__986(_986 ? _986->raw() : nullptr,_986 ? _986->size(0) : 0);
      int _6985 = (int)0;
      int _6986 = _968;
      for (int _987 = _6985; _987 < _6986; ++_987)
      {
        {
          int _988 = ((_968 - _987) - (int)1);
          int _6987 = (int)0;
          int _6988 = safe_add( _ptr__967[_988],(int)1 );
          for (int _989 = _6987; _989 < _6988; ++_989)
          {
            {
              _ptr__986[_989] = (int)0;
            }
          }
          int _6989 = (int)0;
          int _6990 = _975;
          for (int _990 = _6989; _990 < _6990; ++_990)
          {
            {
              ++ _ptr__986[safe_add( ((*_980)(_990,_988)),(int)1 )];
            }
          }
          int _6991 = (int)0;
          int _6992 = _ptr__967[_988];
          for (int _991 = _6991; _991 < _6992; ++_991)
          {
            {
              _ptr__986[safe_add( _991,(int)1 )] += _ptr__986[_991];
            }
          }
          int _6993 = (int)0;
          int _6994 = _975;
          for (int _992 = _6993; _992 < _6994; ++_992)
          {
            {
              int _993 = _ptr__983[_992];
              _ptr__985[_ptr__986[((*_980)(_993,_988))]] = _993;
              ++ _ptr__986[((*_980)(_993,_988))];
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _994 = _983;
          _checked_ptr_1<int> _ptr__994(_994 ? _994->raw() : nullptr,_994 ? _994->size(0) : 0);
          _983 = _985;
          _ptr__983.update(_983 ? _983->raw() : nullptr, _983 ? _983->size(0) : 0);
          _985 = _994;
          _ptr__985.update(_985 ? _985->raw() : nullptr, _985 ? _985->size(0) : 0);
        }
      }
      int _6995 = (int)0;
      int _6996 = _975;
      for (int _995 = _6995; _995 < _6996; ++_995)
      {
        {
          int _996 = _ptr__983[_995];
          long long _997 = (int)0;
          int _6997 = (int)0;
          int _6998 = _968;
          for (int _998 = _6997; _998 < _6998; ++_998)
          {
            {
              _997 += safe_mul( _ptr__969[_998],((*_980)(_996,_998)) );
            }
          }
          _ptr__973[_995] = _997;
        }
      }
    }
  }
  {}
  int _6999;
  bool _7000 = (NULL != _973.get());
  if (_7000)
  {
    _6999 = (int)((_973)->size(0));
  }
  else
  {
    _6999 = _971;
  }
  int _999 = _6999;
  std::shared_ptr< monty::ndarray< double,1 > > _1000 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_999)));
  _checked_ptr_1<double> _ptr__1000(_1000 ? _1000->raw() : nullptr,_1000 ? _1000->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd)->size(0)) == (int)1))
      {
        {
          int _7001 = (int)0;
          int _7002 = _999;
          for (int _1001 = _7001; _1001 < _7002; ++_1001)
          {
            {
              _ptr__1000[_1001] = ((*mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd)->size(0)) == _999))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_966)->bnd,(int)0,_1000,(int)0,_999);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _1002 = natvarmap_alloc(_999);
  std::shared_ptr< monty::ndarray< int,1 > > _1003 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1002))));
  _checked_ptr_1<int> _ptr__1003(_1003 ? _1003->raw() : nullptr,_1003 ? _1003->size(0) : 0);
  natvarmap->get(_1002,_1003,(int)0);
  int _7003 = (int)0;
  int _7004 = _999;
  for (int _1004 = _7003; _1004 < _7004; ++_1004)
  {
    {
      ((*natvarmap_idx)(_ptr__1003[_1004])) = _1002;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_1003);
      ((*natvarmap_type)(_1002)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_1003,_1000);
      ((*natvarmap_type)(_1002)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_1003,_1000);
      ((*natvarmap_type)(_1002)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_966)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_1003,_1000);
      ((*natvarmap_type)(_1002)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _1005 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_964,(long long)(_1002),_967,_973,_1003);
  if (mosek::fusion::p_LinearDomain::_get_impl(_966)->cardinal_flag)
  {
    {
      task_var_putintlist(_1003);
    }
  }
  {}
  ((*vars)(_1002)) = (_1005).as<::mosek::fusion::ModelVariable>();
  if (((int)((_964).size()) > (int)0))
  {
    {
      var_map->setItem(_964,_1002);
    }
  }
  {}
  return (_1005).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1006,std::shared_ptr< monty::ndarray< int,1 > > _1007,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1008){
  _checked_ptr_1<int> _ptr__1007(_1007 ? _1007->raw() : nullptr, _1007 ? _1007->size(0) : 0);
  if ((((int)((_1006).size()) > (int)0) && hasVariable(_1006)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1006)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7005;
  bool _7006 = (NULL != _1007.get());
  if (_7006)
  {
    _7005 = _1007;
  }
  else
  {
    _7005 = mosek::fusion::p_LinPSDDomain::_get_impl(_1008)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1009 = _7005;
  _checked_ptr_1<int> _ptr__1009(_1009 ? _1009->raw() : nullptr,_1009 ? _1009->size(0) : 0);
  if ((NULL == _1009.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if((!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_1008)->shape,_1009)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _1010 = (int)((_1009)->size(0));
  int _1011 = mosek::fusion::p_LinPSDDomain::_get_impl(_1008)->conedim;
  if (((_1011 < (int)0) || (_1011 >= _1010)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1012 = _ptr__1009[_1011];
  int _1013 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1012 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1013,safe_add( _1013,(int)1 ) ) / (int)2) != _1012))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1014 = (int)1;
  int _1015 = _ptr__1009[_1011];
  int _1016 = (int)1;
  int _7007 = (int)0;
  int _7008 = _1011;
  for (int _1017 = _7007; _1017 < _7008; ++_1017)
  {
    {
      _1016 *= _ptr__1009[_1017];
    }
  }
  int _7009 = safe_add( _1011,(int)1 );
  int _7010 = _1010;
  for (int _1018 = _7009; _1018 < _7010; ++_1018)
  {
    {
      _1014 *= _ptr__1009[_1018];
    }
  }
  int _1019 = safe_mul( _1016,_1014 );
  int _1020 = safe_mul( _1019,_1012 );
  int _1021 = natbarvarmap_alloc(_1019,_1013);
  std::shared_ptr< monty::ndarray< int,1 > > _1022 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1020)));
  _checked_ptr_1<int> _ptr__1022(_1022 ? _1022->raw() : nullptr,_1022 ? _1022->size(0) : 0);
  natbarvarmap_get(_1021,_1022);
  std::shared_ptr< monty::ndarray< long long,1 > > _1023 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1019,_1015 ))));
  _checked_ptr_1<long long> _ptr__1023(_1023 ? _1023->raw() : nullptr,_1023 ? _1023->size(0) : 0);
  {
    int _1024 = (int)0;
    int _7011 = (int)0;
    int _7012 = _1016;
    for (int _1025 = _7011; _1025 < _7012; ++_1025)
    {
      {
        int _7013 = (int)0;
        int _7014 = _1015;
        for (int _1026 = _7013; _1026 < _7014; ++_1026)
        {
          {
            int _7015 = (int)0;
            int _7016 = safe_add( _1026,(int)1 );
            for (int _1027 = _7015; _1027 < _7016; ++_1027)
            {
              {
                int _7017 = (int)0;
                int _7018 = _1014;
                for (int _1028 = _7017; _1028 < _7018; ++_1028)
                {
                  {
                    _ptr__1023[_1024] = safe_add( ((*natbarvar_ptr)(safe_add( safe_mul( _1025,_1014 ),_1028 ))),safe_add( (safe_mul( _1026,((safe_mul( (int)2,_1013 ) - _1026) - (int)1) ) / (int)2),_1027 ) );
                    ++ _1024;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1029 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_1006,_1021,_1009,_1011,_1023);
  ((*barvars)(_1021)) = (_1029).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1006).size()) > (int)0))
  {
    {
      var_map->setItem(_1006,(-safe_add( _1021,(int)1 )));
    }
  }
  {}
  return (_1029).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1030,std::shared_ptr< monty::ndarray< int,1 > > _1031,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1032){
  _checked_ptr_1<int> _ptr__1031(_1031 ? _1031->raw() : nullptr, _1031 ? _1031->size(0) : 0);
  if ((((int)((_1030).size()) > (int)0) && hasVariable(_1030)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1030)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1033 = _1031;
  _checked_ptr_1<int> _ptr__1033(_1033 ? _1033->raw() : nullptr,_1033 ? _1033->size(0) : 0);
  if ((NULL == _1033.get()))
  {
    {
      _1033 = mosek::fusion::p_PSDDomain::_get_impl(_1032)->shape;
      _ptr__1033.update(_1033 ? _1033->raw() : nullptr, _1033 ? _1033->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1033.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1034 = mosek::fusion::p_PSDDomain::_get_impl(_1032)->conedim1;
  int _1035 = mosek::fusion::p_PSDDomain::_get_impl(_1032)->conedim2;
  int _1036 = (int)((_1033)->size(0));
  int _1037 = _ptr__1033[_1034];
  if ((_1034 > _1035))
  {
    {
      int _1038 = _1034;
      _1034 = _1035;
      _1035 = _1038;
    }
  }
  {}
  if (((_1034 == _1035) || ((_1034 < (int)0) || (_1035 >= _1036))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1033[_1034] != _ptr__1033[_1035]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1039 = (int)1;
  int _7019 = (int)0;
  int _7020 = _1034;
  for (int _1040 = _7019; _1040 < _7020; ++_1040)
  {
    {
      _1039 *= _ptr__1033[_1040];
    }
  }
  int _7021 = safe_add( _1034,(int)1 );
  int _7022 = _1035;
  for (int _1041 = _7021; _1041 < _7022; ++_1041)
  {
    {
      _1039 *= _ptr__1033[_1041];
    }
  }
  int _7023 = safe_add( _1035,(int)1 );
  int _7024 = _1036;
  for (int _1042 = _7023; _1042 < _7024; ++_1042)
  {
    {
      _1039 *= _ptr__1033[_1042];
    }
  }
  int _1043 = (safe_mul( safe_mul( _1039,_1037 ),safe_add( _1037,(int)1 ) ) / (int)2);
  int _1044 = natbarvarmap_alloc(_1039,_1037);
  std::shared_ptr< monty::ndarray< long long,1 > > _1045 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1043)));
  _checked_ptr_1<long long> _ptr__1045(_1045 ? _1045->raw() : nullptr,_1045 ? _1045->size(0) : 0);
  natbarvar_get(_1044,_1045);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1046 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1030,_1044,_1033,mosek::fusion::p_PSDDomain::_get_impl(_1032)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1032)->conedim2,_1045);
  ((*barvars)(_1044)) = (_1046).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1030).size()) > (int)0))
  {
    {
      var_map->setItem(_1030,(-safe_add( _1044,(int)1 )));
    }
  }
  {}
  return (_1046).as<::mosek::fusion::SymmetricVariable>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1047,monty::rc_ptr< ::mosek::fusion::Expression > _1048,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1049){
  if ((((int)((_1047).size()) > (int)0) && hasConstraint(_1047)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1047)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_RangeDomain::_get_impl(_1049)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1050 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1048)).as<::mosek::fusion::Expression>());
  _1050->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1051 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1051(_1051 ? _1051->raw() : nullptr,_1051 ? _1051->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1052 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1052(_1052 ? _1052->raw() : nullptr,_1052 ? _1052->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1053 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1053(_1053 ? _1053->raw() : nullptr,_1053 ? _1053->size(0) : 0);
  int _1054 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1055 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1056 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1057 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1058 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1059 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1060 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1061 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1062 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1049)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1049)->shape)->size(0)) != _1054))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _7025 = (int)0;
          int _7026 = _1054;
          for (int _1063 = _7025; _1063 < _7026; ++_1063)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1049)->shape)(_1063)) != _ptr__1051[safe_add( _1055,_1063 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1064 = (int)1;
  int _7027 = (int)0;
  int _7028 = _1054;
  for (int _1065 = _7027; _1065 < _7028; ++_1065)
  {
    {
      _1064 *= _ptr__1051[safe_add( _1055,_1065 )];
    }
  }
  int _1066 = natconmap_alloc(_1064);
  std::shared_ptr< monty::ndarray< int,1 > > _1067 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1064)));
  _checked_ptr_1<int> _ptr__1067(_1067 ? _1067->raw() : nullptr,_1067 ? _1067->size(0) : 0);
  natconmap->get(_1066,_1067,(int)0);
  int _7029 = (int)0;
  int _7030 = _1064;
  for (int _1068 = _7029; _1068 < _7030; ++_1068)
  {
    {
      ((*natconmap_idx)(_ptr__1067[_1068])) = _1066;
      ((*natconmap_slackidx)(_ptr__1067[_1068])) = (int)0;
    }
  }
  ((*natconmap_type)(_1066)) = (int)4;
  putarows(_1067,rs,_1056,_1057,_1059,_1060,_1062);
  std::vector<int> _7031;
  for (int _1069 = (int)0, _7032 = _1056; _1069 < _7032 ; ++_1069)
  {
    _7031.push_back(bfixidx);
  }
  auto _7033 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7031.size()),_7031.begin(),_7031.end()));
  std::vector<double> _7034;
  for (int _1070 = (int)0, _7035 = _1056; _1070 < _7035 ; ++_1070)
  {
    _7034.push_back(_ptr__1053[safe_add( _1061,_1070 )]);
  }
  auto _7036 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7034.size()),_7034.begin(),_7034.end()));
  task_putaijlist(_1067,_7033,_7036,(long long)(_1056));
  std::shared_ptr< monty::ndarray< double,1 > > _1071 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1064)));
  _checked_ptr_1<double> _ptr__1071(_1071 ? _1071->raw() : nullptr,_1071 ? _1071->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1072 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1064)));
  _checked_ptr_1<double> _ptr__1072(_1072 ? _1072->raw() : nullptr,_1072 ? _1072->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1073 = natconmap_efix;
  _checked_ptr_1<double> _ptr__1073(_1073 ? _1073->raw() : nullptr,_1073 ? _1073->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1074 = mosek::fusion::p_RangeDomain::_get_impl(_1049)->lb;
  _checked_ptr_1<double> _ptr__1074(_1074 ? _1074->raw() : nullptr,_1074 ? _1074->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1075 = mosek::fusion::p_RangeDomain::_get_impl(_1049)->ub;
  _checked_ptr_1<double> _ptr__1075(_1075 ? _1075->raw() : nullptr,_1075 ? _1075->size(0) : 0);
  bool _1076 = mosek::fusion::p_RangeDomain::_get_impl(_1049)->empty;
  bool _1077 = mosek::fusion::p_RangeDomain::_get_impl(_1049)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1078 = mosek::fusion::p_RangeDomain::_get_impl(_1049)->sparsity;
  {
    int _7037 = (int)0;
    int _7038 = _1056;
    for (int _1079 = _7037; _1079 < _7038; ++_1079)
    {
      {
        _ptr__1073[_ptr__1067[_1079]] = _ptr__1053[safe_add( _1061,_1079 )];
      }
    }
    if (_1077)
    {
      {
        int _7039 = (int)0;
        int _7040 = _1064;
        for (int _1080 = _7039; _1080 < _7040; ++_1080)
        {
          {
            _ptr__1071[_1080] = ((*mosek::fusion::p_RangeDomain::_get_impl(_1049)->lb)((int)0));
            _ptr__1072[_1080] = ((*mosek::fusion::p_RangeDomain::_get_impl(_1049)->ub)((int)0));
          }
        }
      }
    }
    else if(_1076)
    {
      {
      }
    }
    else if((NULL != _1078.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1081 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1054)));
        _checked_ptr_1<int> _ptr__1081(_1081 ? _1081->raw() : nullptr,_1081 ? _1081->size(0) : 0);
        _ptr__1081[(_1054 - (int)1)] = (int)1;
        int _7041 = (int)1;
        int _7042 = _1054;
        for (int _1082 = _7041; _1082 < _7042; ++_1082)
        {
          {
            _ptr__1081[((_1054 - _1082) - (int)1)] = safe_mul( _ptr__1081[(_1054 - _1082)],_ptr__1051[(safe_add( _1055,_1054 ) - _1082)] );
          }
        }
        int _7043 = (int)0;
        int _7044 = (int)((_1074)->size(0));
        for (int _1083 = _7043; _1083 < _7044; ++_1083)
        {
          {
            int _1084 = (int)0;
            int _7045 = (int)0;
            int _7046 = _1054;
            for (int _1085 = _7045; _1085 < _7046; ++_1085)
            {
              {
                _1084 += safe_mul( _ptr__1081[_1085],((*_1078)(_1083,_1085)) );
              }
            }
            _ptr__1071[_1084] = _ptr__1074[_1083];
            _ptr__1072[_1084] = _ptr__1075[_1083];
          }
        }
      }
    }
    else
    {
      {
        int _7047 = (int)0;
        int _7048 = _1064;
        for (int _1086 = _7047; _1086 < _7048; ++_1086)
        {
          {
            _ptr__1071[_1086] = _ptr__1074[_1086];
            _ptr__1072[_1086] = _ptr__1075[_1086];
          }
        }
      }
    }
  }
  task_con_putboundlist_ra(_1067,_1071,_1072);
  std::vector<int> _7049;
  for (int _1088 = (int)0, _7050 = _1054; _1088 < _7050 ; ++_1088)
  {
    _7049.push_back(_ptr__1051[safe_add( _1055,_1088 )]);
  }
  auto _7051 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7049.size()),_7049.begin(),_7049.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1087 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1047,_7051,_1067);
  ((*cons)(_1066)) = (_1087).as<::mosek::fusion::ModelConstraint>();
  return (_1087).as<::mosek::fusion::Constraint>();
}
void mosek::fusion::p_Model::update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1089,std::shared_ptr< monty::ndarray< double,1 > > _1090){
  _checked_ptr_1<int> _ptr__1089(_1089 ? _1089->raw() : nullptr, _1089 ? _1089->size(0) : 0);
  _checked_ptr_1<double> _ptr__1090(_1090 ? _1090->raw() : nullptr, _1090 ? _1090->size(0) : 0);
  std::vector<int> _7052;
  for (int _1091 = (int)0, _7053 = (int)((_1089)->size(0)); _1091 < _7053 ; ++_1091)
  {
    _7052.push_back((int)0);
  }
  auto _7054 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7052.size()),_7052.begin(),_7052.end()));
  task_putaijlist(_1089,_7054,_1090,(long long)((int)((_1089)->size(0))));
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1092,monty::rc_ptr< ::mosek::fusion::WorkStack > _1093,int _1094,int _1095,int _1096,int _1097,int _1098){
  _checked_ptr_1<int> _ptr__1092(_1092 ? _1092->raw() : nullptr, _1092 ? _1092->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1099 = mosek::fusion::p_WorkStack::_get_impl(_1093)->i32;
  _checked_ptr_1<int> _ptr__1099(_1099 ? _1099->raw() : nullptr,_1099 ? _1099->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1100 = mosek::fusion::p_WorkStack::_get_impl(_1093)->i64;
  _checked_ptr_1<long long> _ptr__1100(_1100 ? _1100->raw() : nullptr,_1100 ? _1100->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1101 = mosek::fusion::p_WorkStack::_get_impl(_1093)->f64;
  _checked_ptr_1<double> _ptr__1101(_1101 ? _1101->raw() : nullptr,_1101 ? _1101->size(0) : 0);
  int _1102 = (int)0;
  int _1103 = (int)0;
  int _1104 = (int)0;
  int _7055 = (int)0;
  int _7056 = _1094;
  for (int _1105 = _7055; _1105 < _7056; ++_1105)
  {
    {
      int _1106 = _ptr__1099[safe_add( _1096,_1105 )];
      int _1107 = _ptr__1099[safe_add( safe_add( _1096,_1105 ),(int)1 )];
      int _1108 = _1106;
      while ( ((_1108 < _1107) && (_ptr__1100[safe_add( _1097,_1108 )] < (int)0)) )
      {
        {
          int _1109 = ((*natbarvar_idx)((-safe_add( _ptr__1100[safe_add( _1097,_1108 )],(int)1 ))));
          int _1110 = _1108;
          ++ _1108;
          while ( ((_1108 < _1107) && ((_ptr__1100[safe_add( _1097,_1108 )] < (int)0) && (_1109 == ((*natbarvar_idx)((-safe_add( _ptr__1100[safe_add( _1097,_1108 )],(int)1 ))))))) )
          {
            {
              ++ _1108;
            }
          }
          ++ _1103;
        }
      }
      _1104 += (_1108 - _1106);
      _1102 += (_1107 - _1108);
    }
  }
  int _1111 = (int)((_1092)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1112 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1111,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1112(_1112 ? _1112->raw() : nullptr,_1112 ? _1112->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1113 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1102)));
  _checked_ptr_1<int> _ptr__1113(_1113 ? _1113->raw() : nullptr,_1113 ? _1113->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1114 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1102)));
  _checked_ptr_1<double> _ptr__1114(_1114 ? _1114->raw() : nullptr,_1114 ? _1114->size(0) : 0);
  {
    int _1115 = (int)0;
    int _7057 = (int)0;
    int _7058 = _1094;
    for (int _1116 = _7057; _1116 < _7058; ++_1116)
    {
      {
        int _1117 = (int)0;
        int _7059 = _ptr__1099[safe_add( _1096,_1116 )];
        int _7060 = _ptr__1099[safe_add( safe_add( _1096,_1116 ),(int)1 )];
        for (int _1118 = _7059; _1118 < _7060; ++_1118)
        {
          {
            if ((_ptr__1100[safe_add( _1097,_1118 )] > (int)0))
            {
              {
                _ptr__1113[safe_add( _1115,_1117 )] = (int)(_ptr__1100[safe_add( _1097,_1118 )] - (int)1);
                _ptr__1114[safe_add( _1115,_1117 )] = _ptr__1101[safe_add( _1098,_1118 )];
                ++ _1117;
              }
            }
            {}
          }
        }
        _ptr__1112[safe_add( _1116,(int)1 )] = safe_add( _ptr__1112[_1116],_1117 );
        _1115 += _1117;
      }
    }
  }
  task_putarowlist(_1092,_1112,_1113,_1114);
  if ((_1103 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1119 = _1092;
      _checked_ptr_1<int> _ptr__1119(_1119 ? _1119->raw() : nullptr,_1119 ? _1119->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1120 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1111,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1120(_1120 ? _1120->raw() : nullptr,_1120 ? _1120->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1121 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1103)));
      _checked_ptr_1<int> _ptr__1121(_1121 ? _1121->raw() : nullptr,_1121 ? _1121->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1122 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1103)));
      _checked_ptr_1<int> _ptr__1122(_1122 ? _1122->raw() : nullptr,_1122 ? _1122->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1123 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1103)));
      _checked_ptr_1<long long> _ptr__1123(_1123 ? _1123->raw() : nullptr,_1123 ? _1123->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1124 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1104)));
      _checked_ptr_1<int> _ptr__1124(_1124 ? _1124->raw() : nullptr,_1124 ? _1124->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1125 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1104)));
      _checked_ptr_1<int> _ptr__1125(_1125 ? _1125->raw() : nullptr,_1125 ? _1125->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1126 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1104)));
      _checked_ptr_1<double> _ptr__1126(_1126 ? _1126->raw() : nullptr,_1126 ? _1126->size(0) : 0);
      int _1127 = (int)0;
      int _1128 = (int)0;
      int _7061 = (int)0;
      int _7062 = _1111;
      for (int _1129 = _7061; _1129 < _7062; ++_1129)
      {
        {
          int _1130 = _ptr__1099[safe_add( _1096,_1129 )];
          int _1131 = _ptr__1099[safe_add( safe_add( _1096,_1129 ),(int)1 )];
          while ( ((_1130 < _1131) && (_ptr__1100[safe_add( _1097,_1130 )] < (int)0)) )
          {
            {
              int _1132 = _1130;
              int _1133 = ((*natbarvar_idx)((-safe_add( _ptr__1100[safe_add( _1097,_1130 )],(int)1 ))));
              while ( ((_1130 < _1131) && ((_ptr__1100[safe_add( _1097,_1130 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1100[safe_add( _1097,_1130 )],(int)1 )))) == _1133))) )
              {
                {
                  _ptr__1124[_1128] = ((*natbarvar_i)((-safe_add( _ptr__1100[safe_add( _1097,_1130 )],(int)1 ))));
                  _ptr__1125[_1128] = ((*natbarvar_j)((-safe_add( _ptr__1100[safe_add( _1097,_1130 )],(int)1 ))));
                  if ((_ptr__1124[_1128] == _ptr__1125[_1128]))
                  {
                    {
                      _ptr__1126[_1128] = _ptr__1101[safe_add( _1098,_1130 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1126[_1128] = (0.5 * _ptr__1101[safe_add( _1098,_1130 )]);
                    }
                  }
                  ++ _1128;
                  ++ _1130;
                }
              }
              _ptr__1121[_1127] = _1133;
              _ptr__1122[_1127] = ((*natbarvar_dim)(_1133));
              _ptr__1123[_1127] = (_1130 - _1132);
              ++ _1127;
            }
          }
          _1130 = _1131;
          _ptr__1120[safe_add( _1129,(int)1 )] = _1127;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1134 = task_appendsymmatlist(_1122,_1123,_1124,_1125,_1126);
      _checked_ptr_1<long long> _ptr__1134(_1134 ? _1134->raw() : nullptr,_1134 ? _1134->size(0) : 0);
      task_putbararowlist(_1119,_1120,_1121,_1134);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1135,monty::rc_ptr< ::mosek::fusion::Expression > _1136,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1137){
  std::shared_ptr< monty::ndarray< int,1 > > _1138 = _1136->getShape();
  _checked_ptr_1<int> _ptr__1138(_1138 ? _1138->raw() : nullptr,_1138 ? _1138->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1137)->shape.get()) && (!::mosek::fusion::p_Set::match(_1138,mosek::fusion::p_PSDDomain::_get_impl(_1137)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1139;
  int _1140;
  int _1141;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1137)->axisIsSet)
  {
    {
      _1139 = (mosek::fusion::p_PSDDomain::_get_impl(_1137)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1137)->conedim2);
      int _7063;
      bool _7064 = _1139;
      if (_7064)
      {
        _7063 = mosek::fusion::p_PSDDomain::_get_impl(_1137)->conedim1;
      }
      else
      {
        _7063 = mosek::fusion::p_PSDDomain::_get_impl(_1137)->conedim2;
      }
      _1141 = _7063;
      int _7065;
      bool _7066 = _1139;
      if (_7066)
      {
        _7065 = mosek::fusion::p_PSDDomain::_get_impl(_1137)->conedim2;
      }
      else
      {
        _7065 = mosek::fusion::p_PSDDomain::_get_impl(_1137)->conedim1;
      }
      _1140 = _7065;
    }
  }
  else
  {
    {
      _1139 = true;
      _1141 = ((int)((_1138)->size(0)) - (int)2);
      _1140 = ((int)((_1138)->size(0)) - (int)1);
    }
  }
  if (((_1140 >= (int)((_1138)->size(0))) || (_ptr__1138[_1141] != _ptr__1138[_1140])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _7067;
  bool _7068 = (mosek::fusion::p_PSDDomain::_get_impl(_1137)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_7068)
  {
    _7067 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1141,_1140,_1136).as<::mosek::fusion::Expression>();
  }
  else
  {
    _7067 = _1136;
  }
  monty::rc_ptr< ::mosek::fusion::ExprCompress > _1142 = ::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1141,_1140,_7067)).as<::mosek::fusion::Expression>());
  _1142->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1143 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1143(_1143 ? _1143->raw() : nullptr,_1143 ? _1143->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1144 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1144(_1144 ? _1144->raw() : nullptr,_1144 ? _1144->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1145 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1145(_1145 ? _1145->raw() : nullptr,_1145 ? _1145->size(0) : 0);
  int _1146 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1147 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1146)));
  _checked_ptr_1<int> _ptr__1147(_1147 ? _1147->raw() : nullptr,_1147 ? _1147->size(0) : 0);
  rs->popi32(_1146,_1147,(int)0);
  int _1148 = rs->popi32();
  int _1149 = rs->popi32();
  bool _1150 = (rs->popi32() != (int)0);
  int _1151 = rs->popi32(safe_add( _1148,(int)1 ));
  int _7069;
  bool _7070 = _1150;
  if (_7070)
  {
    _7069 = rs->popi64(_1148);
  }
  else
  {
    _7069 = (-(int)99999);
  }
  int _1152 = _7069;
  int _1153 = rs->popi64(_1149);
  int _1154 = rs->popf64(_1148);
  int _1155 = rs->popf64(_1149);
  int _1156 = _ptr__1147[_1140];
  int _1157 = (safe_mul( _1156,safe_add( _1156,(int)1 ) ) / (int)2);
  int _7071 = (int)0;
  int _7072 = _1146;
  for (int _1158 = _7071; _1158 < _7072; ++_1158)
  {
    {
      if (((_1158 != _1141) && (_1158 != _1140)))
      {
        {
          _1157 *= _ptr__1147[_1158];
        }
      }
      {}
    }
  }
  int _1159 = natconmap_alloc(_1157);
  std::shared_ptr< monty::ndarray< int,1 > > _1160 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1157)));
  _checked_ptr_1<int> _ptr__1160(_1160 ? _1160->raw() : nullptr,_1160 ? _1160->size(0) : 0);
  natconmap->get(_1159,_1160,(int)0);
  putarows(_1160,rs,_1148,_1149,_1151,_1153,_1155);
  std::vector<int> _7073;
  for (int _1161 = (int)0, _7074 = _1148; _1161 < _7074 ; ++_1161)
  {
    _7073.push_back(bfixidx);
  }
  auto _7075 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7073.size()),_7073.begin(),_7073.end()));
  std::vector<double> _7076;
  for (int _1162 = (int)0, _7077 = _1148; _1162 < _7077 ; ++_1162)
  {
    _7076.push_back(_ptr__1145[safe_add( _1154,_1162 )]);
  }
  auto _7078 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7076.size()),_7076.begin(),_7076.end()));
  task_putaijlist(_1160,_7075,_7078,(long long)(_1148));
  std::shared_ptr< monty::ndarray< int,1 > > _1163 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1163(_1163 ? _1163->raw() : nullptr,_1163 ? _1163->size(0) : 0);
  int _7079 = (int)0;
  int _7080 = _1141;
  for (int _1164 = _7079; _1164 < _7080; ++_1164)
  {
    {
      _ptr__1163[(int)0] *= _ptr__1147[_1164];
    }
  }
  _ptr__1163[(int)1] = _ptr__1147[_1141];
  int _7081 = safe_add( _1141,(int)1 );
  int _7082 = _1140;
  for (int _1165 = _7081; _1165 < _7082; ++_1165)
  {
    {
      _ptr__1163[(int)2] *= _ptr__1147[_1165];
    }
  }
  _ptr__1163[(int)3] = _ptr__1147[_1140];
  int _7083 = safe_add( _1140,(int)1 );
  int _7084 = _1146;
  for (int _1166 = _7083; _1166 < _7084; ++_1166)
  {
    {
      _ptr__1163[(int)4] *= _ptr__1147[_1166];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1167 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1167(_1167 ? _1167->raw() : nullptr,_1167 ? _1167->size(0) : 0);
  _ptr__1167[(int)4] = (int)1;
  int _7085 = (int)1;
  int _7086 = (int)5;
  for (int _1168 = _7085; _1168 < _7086; ++_1168)
  {
    {
      _ptr__1167[(((int)5 - _1168) - (int)1)] = safe_mul( _ptr__1167[((int)5 - _1168)],_ptr__1163[((int)5 - _1168)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1169 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1157)));
  _checked_ptr_1<double> _ptr__1169(_1169 ? _1169->raw() : nullptr,_1169 ? _1169->size(0) : 0);
  if ((_1152 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _7087 = (int)0;
      int _7088 = _1148;
      for (int _1170 = _7087; _1170 < _7088; ++_1170)
      {
        {
          ((*natconmap_efix)(_ptr__1160[_1170])) = _ptr__1145[safe_add( _1154,_1170 )];
          ((*natconmap_lb)(_ptr__1160[_1170])) = (int)0;
          ((*natconmap_ub)(_ptr__1160[_1170])) = (int)0;
          _ptr__1169[_1170] = 0.0;
        }
      }
    }
  }
  task_con_putboundlist_fx(_1160,_1169);
  int _1171 = safe_mul( safe_mul( _ptr__1163[(int)0],_ptr__1163[(int)2] ),_ptr__1163[(int)4] );
  int _1172 = _ptr__1163[(int)1];
  int _1173 = natbarvarmap_alloc(_1171,_1172);
  std::shared_ptr< monty::ndarray< int,1 > > _1174 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1171)));
  _checked_ptr_1<int> _ptr__1174(_1174 ? _1174->raw() : nullptr,_1174 ? _1174->size(0) : 0);
  natbarvarmap_get(_1173,_1174);
  std::vector<int> _7089;
  for (int _1176 = (int)0, _7090 = (safe_mul( _1172,safe_add( _1172,(int)1 ) ) / (int)2); _1176 < _7090 ; ++_1176)
  {
    _7089.push_back(_1172);
  }
  auto _7091 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7089.size()),_7089.begin(),_7089.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1175 = _7091;
  _checked_ptr_1<int> _ptr__1175(_1175 ? _1175->raw() : nullptr,_1175 ? _1175->size(0) : 0);
  std::vector<long long> _7092;
  for (int _1178 = (int)0, _7093 = (safe_mul( _1172,safe_add( _1172,(int)1 ) ) / (int)2); _1178 < _7093 ; ++_1178)
  {
    _7092.push_back((int)1);
  }
  auto _7094 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7092.size()),_7092.begin(),_7092.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1177 = _7094;
  _checked_ptr_1<long long> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1179 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1172,safe_add( _1172,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1179(_1179 ? _1179->raw() : nullptr,_1179 ? _1179->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1180 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1172,safe_add( _1172,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1180(_1180 ? _1180->raw() : nullptr,_1180 ? _1180->size(0) : 0);
  std::vector<double> _7095;
  for (int _1182 = (int)0, _7096 = (safe_mul( _1172,safe_add( _1172,(int)1 ) ) / (int)2); _1182 < _7096 ; ++_1182)
  {
    _7095.push_back((-1.0));
  }
  auto _7097 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7095.size()),_7095.begin(),_7095.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1181 = _7097;
  _checked_ptr_1<double> _ptr__1181(_1181 ? _1181->raw() : nullptr,_1181 ? _1181->size(0) : 0);
  {
    int _1183 = (int)0;
    int _7098 = (int)0;
    int _7099 = _1172;
    for (int _1184 = _7098; _1184 < _7099; ++_1184)
    {
      {
        int _7100 = (int)0;
        int _7101 = safe_add( _1184,(int)1 );
        for (int _1185 = _7100; _1185 < _7101; ++_1185)
        {
          {
            _ptr__1179[_1183] = _1184;
            _ptr__1180[_1183] = _1185;
            ++ _1183;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1186 = task_appendsymmatlist(_1175,_1177,_1179,_1180,_1181);
  _checked_ptr_1<long long> _ptr__1186(_1186 ? _1186->raw() : nullptr,_1186 ? _1186->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1187 = _1160;
  _checked_ptr_1<int> _ptr__1187(_1187 ? _1187->raw() : nullptr,_1187 ? _1187->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1188 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1157)));
  _checked_ptr_1<int> _ptr__1188(_1188 ? _1188->raw() : nullptr,_1188 ? _1188->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1189 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1157)));
  _checked_ptr_1<long long> _ptr__1189(_1189 ? _1189->raw() : nullptr,_1189 ? _1189->size(0) : 0);
  {
    int _1190 = (int)0;
    if (_1139)
    {
      {
        int _7102 = (int)0;
        int _7103 = _ptr__1163[(int)0];
        for (int _1191 = _7102; _1191 < _7103; ++_1191)
        {
          {
            int _7104 = (int)0;
            int _7105 = _ptr__1163[(int)1];
            for (int _1192 = _7104; _1192 < _7105; ++_1192)
            {
              {
                int _7106 = (int)0;
                int _7107 = _ptr__1163[(int)2];
                for (int _1193 = _7106; _1193 < _7107; ++_1193)
                {
                  {
                    int _7108 = (int)0;
                    int _7109 = safe_add( _1192,(int)1 );
                    for (int _1194 = _7108; _1194 < _7109; ++_1194)
                    {
                      {
                        int _7110 = (int)0;
                        int _7111 = _ptr__1163[(int)4];
                        for (int _1195 = _7110; _1195 < _7111; ++_1195)
                        {
                          {
                            _ptr__1189[_1190] = _ptr__1186[safe_add( (safe_mul( _1192,safe_add( _1192,(int)1 ) ) / (int)2),_1194 )];
                            _ptr__1188[_1190] = _ptr__1174[safe_add( safe_mul( safe_add( safe_mul( _1191,_ptr__1163[(int)2] ),_1193 ),_ptr__1163[(int)4] ),_1195 )];
                            ((*natconmap_slackidx)(_ptr__1160[_1190])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1188[_1190])),(safe_mul( _1194,((safe_mul( (int)2,_ptr__1163[(int)1] ) - _1194) - (int)1) ) / (int)2) ),_1192 );
                            ++ _1190;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _7112 = (int)0;
        int _7113 = _ptr__1163[(int)0];
        for (int _1196 = _7112; _1196 < _7113; ++_1196)
        {
          {
            int _7114 = (int)0;
            int _7115 = _ptr__1163[(int)1];
            for (int _1197 = _7114; _1197 < _7115; ++_1197)
            {
              {
                int _7116 = (int)0;
                int _7117 = _ptr__1163[(int)2];
                for (int _1198 = _7116; _1198 < _7117; ++_1198)
                {
                  {
                    int _7118 = _1197;
                    int _7119 = _ptr__1163[(int)1];
                    for (int _1199 = _7118; _1199 < _7119; ++_1199)
                    {
                      {
                        int _7120 = (int)0;
                        int _7121 = _ptr__1163[(int)4];
                        for (int _1200 = _7120; _1200 < _7121; ++_1200)
                        {
                          {
                            _ptr__1189[_1190] = _ptr__1186[safe_add( (safe_mul( _1199,safe_add( _1199,(int)1 ) ) / (int)2),_1197 )];
                            _ptr__1188[_1190] = _ptr__1174[safe_add( safe_mul( safe_add( safe_mul( _1196,_ptr__1163[(int)2] ),_1198 ),_ptr__1163[(int)4] ),_1200 )];
                            ((*natconmap_slackidx)(_ptr__1160[_1190])) = safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1188[_1190])),(safe_mul( _1197,((safe_mul( (int)2,_ptr__1163[(int)1] ) - _1197) - (int)1) ) / (int)2) ),_1199 );
                            ++ _1190;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1187,_1188,_1189);
  ((*natconmap_type)(_1159)) = (-safe_add( _1173,(int)1 ));
  std::vector<long long> _7122;
  for (int _1202 = (int)0, _7123 = _1157; _1202 < _7123 ; ++_1202)
  {
    _7122.push_back(((*natconmap_slackidx)(_ptr__1160[_1202])));
  }
  auto _7124 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7122.size()),_7122.begin(),_7122.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1201 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1135,_1159,_1147,_1141,_1140,_7124,_1160);
  ((*cons)(_1159)) = (_1201).as<::mosek::fusion::ModelConstraint>();
  return (_1201).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1203,monty::rc_ptr< ::mosek::fusion::Expression > _1204,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1205){
  if ((((int)((_1203).size()) > (int)0) && hasConstraint(_1203)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1203)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1203).size()) > (int)0) && hasConstraint(_1203)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1203)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1206 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1204)).as<::mosek::fusion::Expression>());
  _1206->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1207 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1207(_1207 ? _1207->raw() : nullptr,_1207 ? _1207->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1208 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1208(_1208 ? _1208->raw() : nullptr,_1208 ? _1208->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1209 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1209(_1209 ? _1209->raw() : nullptr,_1209 ? _1209->size(0) : 0);
  int _1210 = rs->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _1211 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1210)));
  _checked_ptr_1<int> _ptr__1211(_1211 ? _1211->raw() : nullptr,_1211 ? _1211->size(0) : 0);
  rs->popi32(_1210,_1211,(int)0);
  int _1212 = rs->popi32();
  int _1213 = rs->popi32();
  bool _1214 = (rs->popi32() != (int)0);
  int _1215 = rs->popi32(safe_add( _1212,(int)1 ));
  int _1216 = rs->popi64(_1213);
  int _1217 = rs->popf64(_1212);
  int _1218 = rs->popf64(_1213);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1205)->shape.get()) && (!::mosek::fusion::p_Set::match(_1211,mosek::fusion::p_LinPSDDomain::_get_impl(_1205)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1219 = (int)1;
  int _7125 = (int)0;
  int _7126 = _1210;
  for (int _1220 = _7125; _1220 < _7126; ++_1220)
  {
    {
      _1219 *= _ptr__1211[_1220];
    }
  }
  int _1221 = mosek::fusion::p_LinPSDDomain::_get_impl(_1205)->conedim;
  int _1222 = _ptr__1211[_1221];
  int _1223 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1222 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1223,safe_add( _1223,(int)1 ) ) / (int)2) != _1222))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1224 = (int)1;
  int _7127 = (int)0;
  int _7128 = _1221;
  for (int _1225 = _7127; _1225 < _7128; ++_1225)
  {
    {
      _1224 *= _ptr__1211[_1225];
    }
  }
  int _1226 = (int)1;
  int _7129 = safe_add( _1221,(int)1 );
  int _7130 = _1210;
  for (int _1227 = _7129; _1227 < _7130; ++_1227)
  {
    {
      _1226 *= _ptr__1211[_1227];
    }
  }
  int _1228 = safe_mul( _1224,_1226 );
  int _1229 = natconmap_alloc(_1219);
  std::shared_ptr< monty::ndarray< int,1 > > _1230 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1219)));
  _checked_ptr_1<int> _ptr__1230(_1230 ? _1230->raw() : nullptr,_1230 ? _1230->size(0) : 0);
  natconmap->get(_1229,_1230,(int)0);
  putarows(_1230,rs,_1212,_1213,_1215,_1216,_1218);
  std::vector<int> _7131;
  for (int _1231 = (int)0, _7132 = _1212; _1231 < _7132 ; ++_1231)
  {
    _7131.push_back(bfixidx);
  }
  auto _7133 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7131.size()),_7131.begin(),_7131.end()));
  std::vector<double> _7134;
  for (int _1232 = (int)0, _7135 = _1212; _1232 < _7135 ; ++_1232)
  {
    _7134.push_back(_ptr__1209[safe_add( _1217,_1232 )]);
  }
  auto _7136 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7134.size()),_7134.begin(),_7134.end()));
  task_putaijlist(_1230,_7133,_7136,(long long)(_1212));
  int _1233 = natbarvarmap_alloc(_1228,_1223);
  std::shared_ptr< monty::ndarray< int,1 > > _1234 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1228)));
  _checked_ptr_1<int> _ptr__1234(_1234 ? _1234->raw() : nullptr,_1234 ? _1234->size(0) : 0);
  natbarvarmap_get(_1233,_1234);
  ((*barvars)(_1233)) = nullptr;
  int _1235 = safe_mul( safe_mul( _1222,_1224 ),_1226 );
  std::vector<int> _7137;
  for (int _1237 = (int)0, _7138 = _1222; _1237 < _7138 ; ++_1237)
  {
    _7137.push_back(_1237);
  }
  auto _7139 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7137.size()),_7137.begin(),_7137.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1236 = _7139;
  _checked_ptr_1<int> _ptr__1236(_1236 ? _1236->raw() : nullptr,_1236 ? _1236->size(0) : 0);
  std::vector<long long> _7140;
  for (int _1239 = (int)0, _7141 = _1222; _1239 < _7141 ; ++_1239)
  {
    _7140.push_back((int)1);
  }
  auto _7142 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7140.size()),_7140.begin(),_7140.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1238 = _7142;
  _checked_ptr_1<long long> _ptr__1238(_1238 ? _1238->raw() : nullptr,_1238 ? _1238->size(0) : 0);
  std::vector<double> _7143;
  for (int _1241 = (int)0, _7144 = _1222; _1241 < _7144 ; ++_1241)
  {
    _7143.push_back((-1.0));
  }
  auto _7145 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7143.size()),_7143.begin(),_7143.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1240 = _7145;
  _checked_ptr_1<double> _ptr__1240(_1240 ? _1240->raw() : nullptr,_1240 ? _1240->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1242 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1222)));
  _checked_ptr_1<int> _ptr__1242(_1242 ? _1242->raw() : nullptr,_1242 ? _1242->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1243 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1222)));
  _checked_ptr_1<int> _ptr__1243(_1243 ? _1243->raw() : nullptr,_1243 ? _1243->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1244 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1235)));
  _checked_ptr_1<int> _ptr__1244(_1244 ? _1244->raw() : nullptr,_1244 ? _1244->size(0) : 0);
  {
    int _1245 = (int)0;
    int _7146 = (int)0;
    int _7147 = _1224;
    for (int _1246 = _7146; _1246 < _7147; ++_1246)
    {
      {
        int _7148 = (int)0;
        int _7149 = _1223;
        for (int _1247 = _7148; _1247 < _7149; ++_1247)
        {
          {
            int _7150 = (int)0;
            int _7151 = safe_add( _1247,(int)1 );
            for (int _1248 = _7150; _1248 < _7151; ++_1248)
            {
              {
                int _7152 = (int)0;
                int _7153 = _1226;
                for (int _1249 = _7152; _1249 < _7153; ++_1249)
                {
                  {
                    _ptr__1244[_1245] = safe_add( safe_mul( _1246,_1226 ),_1249 );
                    _ptr__1242[_1245] = _1247;
                    _ptr__1243[_1245] = _1248;
                    ++ _1245;
                  }
                }
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1229)) = (-safe_add( _1233,(int)1 ));
    int _7154 = (int)0;
    int _7155 = _1219;
    for (int _1250 = _7154; _1250 < _7155; ++_1250)
    {
      {
        ((*natconmap_blockid)(_ptr__1230[_1250])) = _1229;
        ((*natconmap_idx)(_ptr__1230[_1250])) = _1250;
        ((*natconmap_efix)(_ptr__1230[_1250])) = _ptr__1209[safe_add( _1217,_1250 )];
        ((*natconmap_lb)(_ptr__1230[_1250])) = (int)0;
        ((*natconmap_ub)(_ptr__1230[_1250])) = (int)0;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1251 = task_appendsymmatlist(_1236,_1238,_1242,_1243,_1240);
  _checked_ptr_1<long long> _ptr__1251(_1251 ? _1251->raw() : nullptr,_1251 ? _1251->size(0) : 0);
  task_putbaraijlist(_1230,_1244,_1251);
  std::vector<double> _7156;
  for (int _1253 = (int)0, _7157 = _1219; _1253 < _7157 ; ++_1253)
  {
    _7156.push_back(0.0);
  }
  auto _7158 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7156.size()),_7156.begin(),_7156.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1252 = _7158;
  _checked_ptr_1<double> _ptr__1252(_1252 ? _1252->raw() : nullptr,_1252 ? _1252->size(0) : 0);
  task_con_putboundlist_fx(_1230,_1252);
  std::vector<long long> _7159;
  for (int _1255 = (int)0, _7160 = _1219; _1255 < _7160 ; ++_1255)
  {
    _7159.push_back(((*natconmap_slackidx)(_ptr__1230[_1255])));
  }
  auto _7161 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7159.size()),_7159.begin(),_7159.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1254 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1203,_1229,_1211,_1221,_1230,_7161);
  ((*cons)(_1229)) = (_1254).as<::mosek::fusion::ModelConstraint>();
  return (_1254).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1256,monty::rc_ptr< ::mosek::fusion::Expression > _1257,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1258){
  if ((((int)((_1256).size()) > (int)0) && hasConstraint(_1256)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1256)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1256).size()) > (int)0) && hasConstraint(_1256)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1256)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_ConeDomain::_get_impl(_1258)->int_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1259 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1257)).as<::mosek::fusion::Expression>());
  _1259->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1260 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1260(_1260 ? _1260->raw() : nullptr,_1260 ? _1260->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1261 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1261(_1261 ? _1261->raw() : nullptr,_1261 ? _1261->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1262 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1262(_1262 ? _1262->raw() : nullptr,_1262 ? _1262->size(0) : 0);
  int _1263 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1264 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1265 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1266 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1267 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1268 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1269 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1270 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1271 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7162;
  for (int _1273 = (int)0, _7163 = _1263; _1273 < _7163 ; ++_1273)
  {
    _7162.push_back(_ptr__1260[safe_add( _1264,_1273 )]);
  }
  auto _7164 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7162.size()),_7162.begin(),_7162.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1272 = _7164;
  _checked_ptr_1<int> _ptr__1272(_1272 ? _1272->raw() : nullptr,_1272 ? _1272->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1258)->shape.get()) && (!::mosek::fusion::p_Set::match(_1272,mosek::fusion::p_ConeDomain::_get_impl(_1258)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _7165;
  bool _7166 = _1258->axisIsSet();
  if (_7166)
  {
    _7165 = _1258->getAxis();
  }
  else
  {
    _7165 = (_1263 - (int)1);
  }
  int _1274 = _7165;
  int _1275 = _ptr__1272[_1274];
  int _1276 = (int)1;
  int _1277 = (int)1;
  int _1278 = (int)1;
  {
    int _7167 = (int)0;
    int _7168 = _1263;
    for (int _1279 = _7167; _1279 < _7168; ++_1279)
    {
      {
        _1278 *= _ptr__1272[_1279];
      }
    }
    int _7169 = (int)0;
    int _7170 = _1274;
    for (int _1280 = _7169; _1280 < _7170; ++_1280)
    {
      {
        _1277 *= _ptr__1272[_1280];
      }
    }
    int _7171 = safe_add( _1274,(int)1 );
    int _7172 = _1263;
    for (int _1281 = _7171; _1281 < _7172; ++_1281)
    {
      {
        _1276 *= _ptr__1272[_1281];
      }
    }
  }
  int _1282 = safe_mul( _1277,_1276 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InQCone) && (_1275 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1275)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1275 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1275)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1275 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1275)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1275 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1275)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1275 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1275)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1275 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1275)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1283 = natvarmap_alloc(_1278);
  std::shared_ptr< monty::ndarray< int,1 > > _1284 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1278)));
  _checked_ptr_1<int> _ptr__1284(_1284 ? _1284->raw() : nullptr,_1284 ? _1284->size(0) : 0);
  natvarmap->get(_1283,_1284,(int)0);
  int _1285 = natconemap_alloc(_1282);
  int _7173 = (int)0;
  int _7174 = _1278;
  for (int _1286 = _7173; _1286 < _7174; ++_1286)
  {
    {
      ((*natvarmap_idx)(_ptr__1284[_1286])) = _1283;
    }
  }
  task_var_putboundlist_fr(_1284);
  std::shared_ptr< monty::ndarray< int,1 > > _7175;
  bool _7176 = (_1274 < ((int)((_1272)->size(0)) - (int)1));
  if (_7176)
  {
    _7175 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1284)->size(0)))));
  }
  else
  {
    _7175 = _1284;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1287 = _7175;
  _checked_ptr_1<int> _ptr__1287(_1287 ? _1287->raw() : nullptr,_1287 ? _1287->size(0) : 0);
  if ((_1274 < ((int)((_1272)->size(0)) - (int)1)))
  {
    {
      int _1288 = (int)0;
      int _7177 = (int)0;
      int _7178 = _1277;
      for (int _1289 = _7177; _1289 < _7178; ++_1289)
      {
        {
          int _7179 = (int)0;
          int _7180 = _1276;
          for (int _1290 = _7179; _1290 < _7180; ++_1290)
          {
            {
              int _7181 = (int)0;
              int _7182 = _1275;
              for (int _1291 = _7181; _1291 < _7182; ++_1291)
              {
                {
                  _ptr__1287[_1288] = _ptr__1284[safe_add( safe_mul( safe_add( safe_mul( _1289,_1275 ),_1291 ),_1276 ),_1290 )];
                  ++ _1288;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1292 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1282)));
  _checked_ptr_1<int> _ptr__1292(_1292 ? _1292->raw() : nullptr,_1292 ? _1292->size(0) : 0);
  natconemap->get(_1285,_1292,(int)0);
  ((*natconemap_dim)(_1285)) = _1275;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1292,_1275,_1282,_1287);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1292,_1275,_1282,_1287);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1292,_1275,_1282,_1287);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _7183;
      for (int _1293 = (int)0, _7184 = _1282; _1293 < _7184 ; ++_1293)
      {
        _7183.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1258)->alpha);
      }
      auto _7185 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7183.size()),_7183.begin(),_7183.end()));
      task_put_ppowcones(_1292,_1275,_1282,_1287,_7185);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1292,_1275,_1282,_1287);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1258)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _7186;
      for (int _1294 = (int)0, _7187 = _1282; _1294 < _7187 ; ++_1294)
      {
        _7186.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1258)->alpha);
      }
      auto _7188 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7186.size()),_7186.begin(),_7186.end()));
      task_put_dpowcones(_1292,_1275,_1282,_1287,_7188);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1283)) = nullptr;
  std::shared_ptr< monty::ndarray< double,1 > > _1295 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1278)));
  _checked_ptr_1<double> _ptr__1295(_1295 ? _1295->raw() : nullptr,_1295 ? _1295->size(0) : 0);
  int _1296 = natconmap_alloc(_1278);
  std::shared_ptr< monty::ndarray< int,1 > > _1297 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1278)));
  _checked_ptr_1<int> _ptr__1297(_1297 ? _1297->raw() : nullptr,_1297 ? _1297->size(0) : 0);
  natconmap->get(_1296,_1297,(int)0);
  ((*natconmap_type)(_1296)) = safe_add( _1283,(int)6 );
  {
    int _7189 = (int)0;
    int _7190 = _1278;
    for (int _1298 = _7189; _1298 < _7190; ++_1298)
    {
      {
        ((*natconmap_efix)(_ptr__1297[_1298])) = _ptr__1262[safe_add( _1270,_1298 )];
      }
    }
    int _7191 = (int)0;
    int _7192 = _1278;
    for (int _1299 = _7191; _1299 < _7192; ++_1299)
    {
      {
        ((*natconmap_lb)(_ptr__1297[_1299])) = (int)0;
      }
    }
    int _7193 = (int)0;
    int _7194 = _1278;
    for (int _1300 = _7193; _1300 < _7194; ++_1300)
    {
      {
        ((*natconmap_ub)(_ptr__1297[_1300])) = (int)0;
      }
    }
    int _7195 = (int)0;
    int _7196 = _1278;
    for (int _1301 = _7195; _1301 < _7196; ++_1301)
    {
      {
        ((*natconmap_slackidx)(_ptr__1297[_1301])) = safe_add( _ptr__1284[_1301],(int)1 );
      }
    }
    int _7197 = (int)0;
    int _7198 = _1278;
    for (int _1302 = _7197; _1302 < _7198; ++_1302)
    {
      {
        ((*natconmap_blockid)(_ptr__1297[_1302])) = _1296;
      }
    }
    int _7199 = (int)0;
    int _7200 = _1278;
    for (int _1303 = _7199; _1303 < _7200; ++_1303)
    {
      {
        ((*natconmap_idx)(_ptr__1297[_1303])) = _1303;
      }
    }
  }
  putarows(_1297,rs,_1265,_1266,_1268,_1269,_1271);
  task_con_putboundlist_fx(_1297,_1295);
  std::vector<double> _7201;
  for (int _1304 = (int)0, _7202 = (int)((_1297)->size(0)); _1304 < _7202 ; ++_1304)
  {
    _7201.push_back((-1.0));
  }
  auto _7203 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7201.size()),_7201.begin(),_7201.end()));
  task_putaijlist(_1297,_1284,_7203,(long long)((int)((_1297)->size(0))));
  std::vector<int> _7204;
  for (int _1305 = (int)0, _7205 = _1265; _1305 < _7205 ; ++_1305)
  {
    _7204.push_back(bfixidx);
  }
  auto _7206 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7204.size()),_7204.begin(),_7204.end()));
  std::vector<double> _7207;
  for (int _1306 = (int)0, _7208 = _1265; _1306 < _7208 ; ++_1306)
  {
    _7207.push_back(_ptr__1262[safe_add( _1270,_1306 )]);
  }
  auto _7209 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7207.size()),_7207.begin(),_7207.end()));
  task_putaijlist(_1297,_7206,_7209,(long long)(_1265));
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1307 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1256,_1258,_1272,_1296,_1297,_1284);
  ((*cons)(_1296)) = (_1307).as<::mosek::fusion::ModelConstraint>();
  return (_1307).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1308,monty::rc_ptr< ::mosek::fusion::Expression > _1309,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1310){
  if ((((int)((_1308).size()) > (int)0) && hasConstraint(_1308)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1308)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_LinearDomain::_get_impl(_1310)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1311 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1309)).as<::mosek::fusion::Expression>());
  _1311->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1312 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1312(_1312 ? _1312->raw() : nullptr,_1312 ? _1312->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1313 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1313(_1313 ? _1313->raw() : nullptr,_1313 ? _1313->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1314 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1314(_1314 ? _1314->raw() : nullptr,_1314 ? _1314->size(0) : 0);
  int _1315 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1316 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1317 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1318 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1319 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1320 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1321 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1322 = mosek::fusion::p_WorkStack::_get_impl(rs)->bfix_base;
  int _1323 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  std::vector<int> _7210;
  for (int _1325 = (int)0, _7211 = _1315; _1325 < _7211 ; ++_1325)
  {
    _7210.push_back(_ptr__1312[safe_add( _1316,_1325 )]);
  }
  auto _7212 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7210.size()),_7210.begin(),_7210.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1324 = _7212;
  _checked_ptr_1<int> _ptr__1324(_1324 ? _1324->raw() : nullptr,_1324 ? _1324->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1310)->shape.get()) && (!::mosek::fusion::p_Set::match(_1324,mosek::fusion::p_LinearDomain::_get_impl(_1310)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1326 = (int)1;
  int _7213 = (int)0;
  int _7214 = _1315;
  for (int _1327 = _7213; _1327 < _7214; ++_1327)
  {
    {
      _1326 *= _ptr__1324[_1327];
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1328;
  _checked_ptr_1<double> _ptr__1328(_1328 ? _1328->raw() : nullptr,_1328 ? _1328->size(0) : 0);
  int _1329 = natconmap_alloc(_1326);
  std::shared_ptr< monty::ndarray< int,1 > > _1330 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1326)));
  _checked_ptr_1<int> _ptr__1330(_1330 ? _1330->raw() : nullptr,_1330 ? _1330->size(0) : 0);
  natconmap->get(_1329,_1330,(int)0);
  putarows(_1330,rs,_1317,_1318,_1320,_1321,_1323);
  std::vector<int> _7215;
  for (int _1331 = (int)0, _7216 = _1317; _1331 < _7216 ; ++_1331)
  {
    _7215.push_back(bfixidx);
  }
  auto _7217 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7215.size()),_7215.begin(),_7215.end()));
  std::vector<double> _7218;
  for (int _1332 = (int)0, _7219 = _1317; _1332 < _7219 ; ++_1332)
  {
    _7218.push_back(_ptr__1314[safe_add( _1322,_1332 )]);
  }
  auto _7220 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7218.size()),_7218.begin(),_7218.end()));
  task_putaijlist(_1330,_7217,_7220,(long long)(_1317));
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1333 = mosek::fusion::p_LinearDomain::_get_impl(_1310)->sparsity;
    bool _1334 = mosek::fusion::p_LinearDomain::_get_impl(_1310)->empty;
    std::shared_ptr< monty::ndarray< double,1 > > _1335 = mosek::fusion::p_LinearDomain::_get_impl(_1310)->bnd;
    _checked_ptr_1<double> _ptr__1335(_1335 ? _1335->raw() : nullptr,_1335 ? _1335->size(0) : 0);
    bool _1336 = mosek::fusion::p_LinearDomain::_get_impl(_1310)->scalable;
    std::shared_ptr< monty::ndarray< double,1 > > _1337 = natconmap_efix;
    _checked_ptr_1<double> _ptr__1337(_1337 ? _1337->raw() : nullptr,_1337 ? _1337->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1338 = natconmap_lb;
    _checked_ptr_1<double> _ptr__1338(_1338 ? _1338->raw() : nullptr,_1338 ? _1338->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _1339 = natconmap_ub;
    _checked_ptr_1<double> _ptr__1339(_1339 ? _1339->raw() : nullptr,_1339 ? _1339->size(0) : 0);
    {
      int _7221 = (int)0;
      int _7222 = _1317;
      for (int _1340 = _7221; _1340 < _7222; ++_1340)
      {
        {
          _ptr__1337[_ptr__1330[_1340]] = _ptr__1314[safe_add( _1322,_1340 )];
        }
      }
      if ((NULL == _1335.get()))
      {
        {
          int _7223 = (int)0;
          int _7224 = _1317;
          for (int _1341 = _7223; _1341 < _7224; ++_1341)
          {
            {
              _ptr__1338[_ptr__1330[_1341]] = (int)0;
              _ptr__1339[_ptr__1330[_1341]] = (int)0;
            }
          }
        }
      }
      else if(_1336)
      {
        {
          int _7225 = (int)0;
          int _7226 = _1317;
          for (int _1342 = _7225; _1342 < _7226; ++_1342)
          {
            {
              _ptr__1338[_ptr__1330[_1342]] = _ptr__1335[(int)0];
              _ptr__1339[_ptr__1330[_1342]] = _ptr__1335[(int)0];
            }
          }
        }
      }
      else if((NULL != _1333.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1343 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1315)));
          _checked_ptr_1<int> _ptr__1343(_1343 ? _1343->raw() : nullptr,_1343 ? _1343->size(0) : 0);
          _ptr__1343[(_1315 - (int)1)] = (int)1;
          int _7227 = (int)1;
          int _7228 = _1315;
          for (int _1344 = _7227; _1344 < _7228; ++_1344)
          {
            {
              _ptr__1343[((_1315 - _1344) - (int)1)] = safe_mul( _ptr__1343[(_1315 - _1344)],_ptr__1324[(_1315 - _1344)] );
            }
          }
          int _7229 = (int)0;
          int _7230 = (int)((_1333)->size(0));
          for (int _1345 = _7229; _1345 < _7230; ++_1345)
          {
            {
              int _1346 = (int)0;
              int _7231 = (int)0;
              int _7232 = _1315;
              for (int _1347 = _7231; _1347 < _7232; ++_1347)
              {
                {
                  _1346 += safe_mul( _ptr__1343[_1347],((*_1333)(_1345,_1347)) );
                }
              }
              _ptr__1338[_ptr__1330[_1346]] = _ptr__1335[_1345];
              _ptr__1339[_ptr__1330[_1346]] = _ptr__1335[_1345];
            }
          }
        }
      }
      else if(_1334)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1348 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1315)));
          _checked_ptr_1<int> _ptr__1348(_1348 ? _1348->raw() : nullptr,_1348 ? _1348->size(0) : 0);
          _ptr__1348[(_1315 - (int)1)] = (int)1;
          int _7233 = (int)1;
          int _7234 = _1315;
          for (int _1349 = _7233; _1349 < _7234; ++_1349)
          {
            {
              _ptr__1348[((_1315 - _1349) - (int)1)] = safe_mul( _ptr__1348[(_1315 - _1349)],_ptr__1324[(_1315 - _1349)] );
            }
          }
          int _7235 = (int)0;
          int _7236 = (int)((_1333)->size(0));
          for (int _1350 = _7235; _1350 < _7236; ++_1350)
          {
            {
              int _1351 = (int)0;
              int _7237 = (int)0;
              int _7238 = _1315;
              for (int _1352 = _7237; _1352 < _7238; ++_1352)
              {
                {
                  _1351 += safe_mul( _ptr__1348[_1352],((*_1333)(_1350,_1352)) );
                }
              }
              _ptr__1338[_ptr__1330[_1351]] = (int)0;
              _ptr__1339[_ptr__1330[_1351]] = (int)0;
            }
          }
        }
      }
      else
      {
        {
          int _7239 = (int)0;
          int _7240 = _1317;
          for (int _1353 = _7239; _1353 < _7240; ++_1353)
          {
            {
              _ptr__1338[_ptr__1330[_1353]] = _ptr__1335[_1353];
              _ptr__1339[_ptr__1330[_1353]] = _ptr__1335[_1353];
            }
          }
        }
      }
    }
    std::vector<double> _7241;
    for (int _1354 = (int)0, _7242 = (int)((_1330)->size(0)); _1354 < _7242 ; ++_1354)
    {
      _7241.push_back(_ptr__1338[_ptr__1330[_1354]]);
    }
    auto _7243 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7241.size()),_7241.begin(),_7241.end()));
    _1328 = _7243;
    _ptr__1328.update(_1328 ? _1328->raw() : nullptr, _1328 ? _1328->size(0) : 0);
  }
  int _7244 = (int)0;
  int _7245 = _1326;
  for (int _1355 = _7244; _1355 < _7245; ++_1355)
  {
    {
      ((*natconmap_idx)(_ptr__1330[_1355])) = _1329;
      ((*natconmap_slackidx)(_ptr__1330[_1355])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1310)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1329)) = (int)1;
      task_con_putboundlist_fr(_1330);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1310)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1329)) = (int)3;
      task_con_putboundlist_up(_1330,_1328);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1310)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1329)) = (int)2;
      task_con_putboundlist_lo(_1330,_1328);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1310)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1329)) = (int)5;
      task_con_putboundlist_fx(_1330,_1328);
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1356 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1308,_1329,_1324,_1330);
  ((*cons)(_1329)) = (_1356).as<::mosek::fusion::ModelConstraint>();
  return (_1356).as<::mosek::fusion::Constraint>();
}
std::string mosek::fusion::Model::getVersion  ( ) { return mosek::fusion::p_Model::getVersion(); }std::string mosek::fusion::p_Model::getVersion(){
  return ::mosek::fusion::p_BaseModel::env_getversion();
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1357) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1357); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1357){
  return con_map->hasItem(_1357);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1358) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1358); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1358){
  return var_map->hasItem(_1358);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1359) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1359); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1359) { return __mosek_2fusion_2Model__getConstraint(_1359); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1359){
  return (((*cons)(_1359))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1360) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1360); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1360) { return __mosek_2fusion_2Model__getConstraint(_1360); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1360){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _7246;
  bool _7247 = con_map->hasItem(_1360);
  if (_7247)
  {
    _7246 = ((*cons)(con_map->getItem(_1360)));
  }
  else
  {
    _7246 = nullptr;
  }
  return (_7246).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1361) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1361); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1361) { return __mosek_2fusion_2Model__getVariable(_1361); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1361){
  return (((*vars)(_1361))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1362) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1362); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1362) { return __mosek_2fusion_2Model__getVariable(_1362); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1362){
  if (var_map->hasItem(_1362))
  {
    {
      int _1363 = var_map->getItem(_1362);
      if ((_1363 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1363,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1363))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_type.reset();natconmap_ub.reset();natconmap_lb.reset();natconmap_efix.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1364,    std::shared_ptr< monty::ndarray< int,1 > > _1365,    std::shared_ptr< monty::ndarray< long long,1 > > _1366,    std::shared_ptr< monty::ndarray< long long,1 > > _1367){ return new mosek::fusion::SliceVariable(_1364,_1365,_1366,_1367); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1364,    std::shared_ptr< monty::ndarray< int,1 > > _1365,    std::shared_ptr< monty::ndarray< long long,1 > > _1366,    std::shared_ptr< monty::ndarray< long long,1 > > _1367) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1364,_1365,_1366,_1367); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1364,    std::shared_ptr< monty::ndarray< int,1 > > _1365,    std::shared_ptr< monty::ndarray< long long,1 > > _1366,    std::shared_ptr< monty::ndarray< long long,1 > > _1367){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1365(_1365 ? _1365->raw() : nullptr, _1365 ? _1365->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1366(_1366 ? _1366->raw() : nullptr, _1366 ? _1366->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1367(_1367 ? _1367->raw() : nullptr, _1367 ? _1367->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1364,_1365,_1366,_1367);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1367;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1366;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1365;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1368,    monty::rc_ptr< ::mosek::fusion::Model > _1369){ return new mosek::fusion::SymRangedVariable(_1368,_1369); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1368,    monty::rc_ptr< ::mosek::fusion::Model > _1369) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1368,_1369); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1368,    monty::rc_ptr< ::mosek::fusion::Model > _1369){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1368,_1369);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1368)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1368)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1368)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1368)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1368)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1370,    const std::string &  _1371,    long long _1372,    int _1373,    std::shared_ptr< monty::ndarray< long long,1 > > _1374,    std::shared_ptr< monty::ndarray< int,1 > > _1375){ return new mosek::fusion::SymRangedVariable(_1370,_1371,_1372,_1373,_1374,_1375); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1370,    const std::string &  _1371,    long long _1372,    int _1373,    std::shared_ptr< monty::ndarray< long long,1 > > _1374,    std::shared_ptr< monty::ndarray< int,1 > > _1375) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1370,_1371,_1372,_1373,_1374,_1375); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1370,    const std::string &  _1371,    long long _1372,    int _1373,    std::shared_ptr< monty::ndarray< long long,1 > > _1374,    std::shared_ptr< monty::ndarray< int,1 > > _1375){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1374(_1374 ? _1374->raw() : nullptr, _1374 ? _1374->size(0) : 0);
    _checked_ptr_1<int> _ptr__1375(_1375 ? _1375->raw() : nullptr, _1375 ? _1375->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1370,_1371,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1373),(int)(_1373)}),_1372,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1373,_1374),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1373,_1374,_1375));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1371;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1375;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1374;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1373;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1376,std::shared_ptr< monty::ndarray< double,1 > > _1377){
  _checked_ptr_1<double> _ptr__1377(_1377 ? _1377->raw() : nullptr, _1377 ? _1377->size(0) : 0);
  dual_lu(_1376,_1377,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1378,std::shared_ptr< monty::ndarray< double,1 > > _1379){
  _checked_ptr_1<double> _ptr__1379(_1379 ? _1379->raw() : nullptr, _1379 ? _1379->size(0) : 0);
  dual_lu(_1378,_1379,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1380 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7248 = (int)0;
          int _7249 = (int)((nativeidxs)->size(0));
          for (int _1381 = _7248; _1381 < _7249; ++_1381)
          {
            {
              std::string _7250;
              bool _7251 = ((int)((name).size()) == (int)0);
              if (_7251)
              {
                _7250 = std::string ("");
              }
              else
              {
                _7250 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1381 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1381 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1380.get())->varname(((*nativeidxs)(_1381)),_7250);
            }
          }
        }
      }
      else
      {
        {
          int _7252 = (int)0;
          int _7253 = (int)((sparsity)->size(0));
          for (int _1382 = _7252; _1382 < _7253; ++_1382)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1380.get())->varname(((*nativeidxs)(_1382)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1382)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1382)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1383){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1383)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1384,std::shared_ptr< monty::ndarray< long long,1 > > _1385,std::shared_ptr< monty::ndarray< int,1 > > _1386){
  _checked_ptr_1<long long> _ptr__1385(_1385 ? _1385->raw() : nullptr, _1385 ? _1385->size(0) : 0);
  _checked_ptr_1<int> _ptr__1386(_1386 ? _1386->raw() : nullptr, _1386 ? _1386->size(0) : 0);
  if ((NULL == _1385.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1387 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1384,_1384 ))));
      _checked_ptr_1<long long> _ptr__1387(_1387 ? _1387->raw() : nullptr,_1387 ? _1387->size(0) : 0);
      int _1388 = (int)0;
      {
        int _7254 = (int)0;
        int _7255 = _1384;
        for (int _1389 = _7254; _1389 < _7255; ++_1389)
        {
          {
            _ptr__1387[safe_add( safe_mul( _1389,_1384 ),_1389 )] = safe_add( _ptr__1386[_1388],(int)1 );
            ++ _1388;
            int _7256 = safe_add( _1389,(int)1 );
            int _7257 = _1384;
            for (int _1390 = _7256; _1390 < _7257; ++_1390)
            {
              {
                _ptr__1387[safe_add( safe_mul( _1389,_1384 ),_1390 )] = safe_add( _ptr__1386[_1388],(int)1 );
                _ptr__1387[safe_add( safe_mul( _1390,_1384 ),_1389 )] = safe_add( _ptr__1386[_1388],(int)1 );
                ++ _1388;
              }
            }
          }
        }
      }
      return _1387;
    }
  }
  else
  {
    {
      int _1391 = (int)0;
      {
        int _7258 = (int)0;
        int _7259 = (int)((_1385)->size(0));
        for (int _1392 = _7258; _1392 < _7259; ++_1392)
        {
          {
            int _7260;
            bool _7261 = ((_ptr__1385[_1392] % safe_add( _1384,(int)1 )) == (int)0);
            if (_7261)
            {
              _7260 = (int)1;
            }
            else
            {
              _7260 = (int)2;
            }
            _1391 += _7260;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1393 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1391)));
      _checked_ptr_1<long long> _ptr__1393(_1393 ? _1393->raw() : nullptr,_1393 ? _1393->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1394 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1391)));
      _checked_ptr_1<long long> _ptr__1394(_1394 ? _1394->raw() : nullptr,_1394 ? _1394->size(0) : 0);
      {
        int _1395 = (int)0;
        int _7262 = (int)0;
        int _7263 = (int)((_1385)->size(0));
        for (int _1396 = _7262; _1396 < _7263; ++_1396)
        {
          {
            long long _1397 = (_ptr__1385[_1396] / _1384);
            long long _1398 = (_ptr__1385[_1396] % _1384);
            _ptr__1393[_1395] = _ptr__1385[_1396];
            _ptr__1394[_1395] = safe_add( _ptr__1386[_1396],(int)1 );
            ++ _1395;
            if ((_1397 != _1398))
            {
              {
                _ptr__1393[_1395] = safe_add( safe_mul( _1398,_1384 ),_1397 );
                _ptr__1394[_1395] = safe_add( _ptr__1386[_1396],(int)1 );
                ++ _1395;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7264;
      for (int _1400 = (int)0, _7265 = _1391; _1400 < _7265 ; ++_1400)
      {
        _7264.push_back(_1400);
      }
      auto _7266 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7264.size()),_7264.begin(),_7264.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1399 = _7266;
      _checked_ptr_1<long long> _ptr__1399(_1399 ? _1399->raw() : nullptr,_1399 ? _1399->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1399,_1393,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1391));
      std::vector<long long> _7267;
      for (int _1401 = (int)0, _7268 = _1391; _1401 < _7268 ; ++_1401)
      {
        _7267.push_back(_ptr__1394[_ptr__1399[_1401]]);
      }
      auto _7269 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7267.size()),_7267.begin(),_7267.end()));
      return _7269;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1402,std::shared_ptr< monty::ndarray< long long,1 > > _1403){
  _checked_ptr_1<long long> _ptr__1403(_1403 ? _1403->raw() : nullptr, _1403 ? _1403->size(0) : 0);
  if ((NULL == _1403.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1404 = (int)0;
      {
        int _7270 = (int)0;
        int _7271 = (int)((_1403)->size(0));
        for (int _1405 = _7270; _1405 < _7271; ++_1405)
        {
          {
            int _7272;
            bool _7273 = ((_ptr__1403[_1405] % safe_add( _1402,(int)1 )) == (int)0);
            if (_7273)
            {
              _7272 = (int)1;
            }
            else
            {
              _7272 = (int)2;
            }
            _1404 += _7272;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1406 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1404)));
      _checked_ptr_1<long long> _ptr__1406(_1406 ? _1406->raw() : nullptr,_1406 ? _1406->size(0) : 0);
      {
        int _1407 = (int)0;
        int _7274 = (int)0;
        int _7275 = (int)((_1403)->size(0));
        for (int _1408 = _7274; _1408 < _7275; ++_1408)
        {
          {
            long long _1409 = (_ptr__1403[_1408] / _1402);
            long long _1410 = (_ptr__1403[_1408] % _1402);
            _ptr__1406[_1407] = _ptr__1403[_1408];
            ++ _1407;
            if ((_1409 != _1410))
            {
              {
                _ptr__1406[_1407] = safe_add( safe_mul( _1410,_1402 ),_1409 );
                ++ _1407;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7276;
      for (int _1412 = (int)0, _7277 = _1404; _1412 < _7277 ; ++_1412)
      {
        _7276.push_back(_1412);
      }
      auto _7278 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7276.size()),_7276.begin(),_7276.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1411 = _7278;
      _checked_ptr_1<long long> _ptr__1411(_1411 ? _1411->raw() : nullptr,_1411 ? _1411->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1411,_1406,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1404));
      std::vector<long long> _7279;
      for (int _1413 = (int)0, _7280 = _1404; _1413 < _7280 ; ++_1413)
      {
        _7279.push_back(_ptr__1406[_ptr__1411[_1413]]);
      }
      auto _7281 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7279.size()),_7279.begin(),_7279.end()));
      return _7281;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1414,    monty::rc_ptr< ::mosek::fusion::Model > _1415){ return new mosek::fusion::RangedVariable(_1414,_1415); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1414,    monty::rc_ptr< ::mosek::fusion::Model > _1415) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1414,_1415); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1414,    monty::rc_ptr< ::mosek::fusion::Model > _1415){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1414,_1415);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1414)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1414)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1414)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1414)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1414)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1416,    const std::string &  _1417,    long long _1418,    std::shared_ptr< monty::ndarray< int,1 > > _1419,    std::shared_ptr< monty::ndarray< long long,1 > > _1420,    std::shared_ptr< monty::ndarray< int,1 > > _1421){ return new mosek::fusion::RangedVariable(_1416,_1417,_1418,_1419,_1420,_1421); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1416,    const std::string &  _1417,    long long _1418,    std::shared_ptr< monty::ndarray< int,1 > > _1419,    std::shared_ptr< monty::ndarray< long long,1 > > _1420,    std::shared_ptr< monty::ndarray< int,1 > > _1421) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1416,_1417,_1418,_1419,_1420,_1421); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1416,    const std::string &  _1417,    long long _1418,    std::shared_ptr< monty::ndarray< int,1 > > _1419,    std::shared_ptr< monty::ndarray< long long,1 > > _1420,    std::shared_ptr< monty::ndarray< int,1 > > _1421){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1419(_1419 ? _1419->raw() : nullptr, _1419 ? _1419->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1420(_1420 ? _1420->raw() : nullptr, _1420 ? _1420->size(0) : 0);
    _checked_ptr_1<int> _ptr__1421(_1421 ? _1421->raw() : nullptr, _1421 ? _1421->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1416,_1417,_1419,_1418,_1420,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1421));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1421;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1420;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1417;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1419;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1422,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1423) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1422,_1423); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1422,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1423) { return __mosek_2fusion_2RangedVariable__elementDesc(_1422,_1423); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1422,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1423){
  _pubthis->elementName(_1422,_1423);
  _1423->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1423;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1424 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1425 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1425->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1425->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7282 = (int)1;
          int _7283 = _pubthis->getND();
          for (int _1426 = _7282; _1426 < _7283; ++_1426)
          {
            {
              _1425->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1426);
            }
          }
        }
      }
      {}
      _1425->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1424.get())->varnames(nativeidxs,_1425->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1427,std::shared_ptr< monty::ndarray< double,1 > > _1428){
  _checked_ptr_1<double> _ptr__1428(_1428 ? _1428->raw() : nullptr, _1428 ? _1428->size(0) : 0);
  dual_lu(_1427,_1428,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1429,std::shared_ptr< monty::ndarray< double,1 > > _1430){
  _checked_ptr_1<double> _ptr__1430(_1430 ? _1430->raw() : nullptr, _1430 ? _1430->size(0) : 0);
  dual_lu(_1429,_1430,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1431){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1431)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1432){
  _checked_ptr_1<int> _ptr__1432(_1432 ? _1432->raw() : nullptr, _1432 ? _1432->size(0) : 0);
  std::vector<long long> _7284;
  for (int _1433 = (int)0, _7285 = (int)((_1432)->size(0)); _1433 < _7285 ; ++_1433)
  {
    _7284.push_back(safe_add( _ptr__1432[_1433],(int)1 ));
  }
  auto _7286 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7284.size()),_7284.begin(),_7284.end()));
  return _7286;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1434,    monty::rc_ptr< ::mosek::fusion::Model > _1435){ return new mosek::fusion::LinearPSDVariable(_1434,_1435); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1434,    monty::rc_ptr< ::mosek::fusion::Model > _1435) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1434,_1435); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1434,    monty::rc_ptr< ::mosek::fusion::Model > _1435){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1434,_1435);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1434)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1434)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1434)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1434)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1434)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1436,    const std::string &  _1437,    int _1438,    std::shared_ptr< monty::ndarray< int,1 > > _1439,    int _1440,    std::shared_ptr< monty::ndarray< long long,1 > > _1441){ return new mosek::fusion::LinearPSDVariable(_1436,_1437,_1438,_1439,_1440,_1441); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1436,    const std::string &  _1437,    int _1438,    std::shared_ptr< monty::ndarray< int,1 > > _1439,    int _1440,    std::shared_ptr< monty::ndarray< long long,1 > > _1441) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1436,_1437,_1438,_1439,_1440,_1441); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1436,    const std::string &  _1437,    int _1438,    std::shared_ptr< monty::ndarray< int,1 > > _1439,    int _1440,    std::shared_ptr< monty::ndarray< long long,1 > > _1441){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1439(_1439 ? _1439->raw() : nullptr, _1439 ? _1439->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1441(_1441 ? _1441->raw() : nullptr, _1441 ? _1441->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1436,_1437,_1439,_1438,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1441));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1437;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1440;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1438;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1439;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1441;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1442 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1442->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1442->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1442->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7287 = (int)1;
  int _7288 = (int)((shape)->size(0));
  for (int _1443 = _7287; _1443 < _7288; ++_1443)
  {
    {
      _1442->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1443)));
    }
  }
  _1442->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1442->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1444) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1444); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1444){
  _checked_ptr_1<long long> _ptr__1444(_1444 ? _1444->raw() : nullptr, _1444 ? _1444->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1445) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1445); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1445){
  _checked_ptr_1<long long> _ptr__1445(_1445 ? _1445->raw() : nullptr, _1445 ? _1445->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1446){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1446)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1447){
  _checked_ptr_1<long long> _ptr__1447(_1447 ? _1447->raw() : nullptr, _1447 ? _1447->size(0) : 0);
  std::vector<long long> _7289;
  for (int _1448 = (int)0, _7290 = (int)((_1447)->size(0)); _1448 < _7290 ; ++_1448)
  {
    _7289.push_back((-safe_add( _ptr__1447[_1448],(int)1 )));
  }
  auto _7291 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7289.size()),_7289.begin(),_7289.end()));
  return _7291;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1449,    monty::rc_ptr< ::mosek::fusion::Model > _1450){ return new mosek::fusion::PSDVariable(_1449,_1450); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1449,    monty::rc_ptr< ::mosek::fusion::Model > _1450) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1449,_1450); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1449,    monty::rc_ptr< ::mosek::fusion::Model > _1450){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1449,_1450);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1449)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1449)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1449)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1449)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1449)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1449)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1451,    const std::string &  _1452,    int _1453,    std::shared_ptr< monty::ndarray< int,1 > > _1454,    int _1455,    int _1456,    std::shared_ptr< monty::ndarray< long long,1 > > _1457){ return new mosek::fusion::PSDVariable(_1451,_1452,_1453,_1454,_1455,_1456,_1457); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1451,    const std::string &  _1452,    int _1453,    std::shared_ptr< monty::ndarray< int,1 > > _1454,    int _1455,    int _1456,    std::shared_ptr< monty::ndarray< long long,1 > > _1457) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1451,_1452,_1453,_1454,_1455,_1456,_1457); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1451,    const std::string &  _1452,    int _1453,    std::shared_ptr< monty::ndarray< int,1 > > _1454,    int _1455,    int _1456,    std::shared_ptr< monty::ndarray< long long,1 > > _1457){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1454(_1454 ? _1454->raw() : nullptr, _1454 ? _1454->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1457(_1457 ? _1457->raw() : nullptr, _1457 ? _1457->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1451,_1452,_1454,_1453,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1454,_1455,_1456,_1457));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1453;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1457;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1452;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1454;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1455;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1456;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1458 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1458->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1458->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1458->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7292 = (int)1;
  int _7293 = (int)((shape)->size(0));
  for (int _1459 = _7292; _1459 < _7293; ++_1459)
  {
    {
      _1458->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1459)));
    }
  }
  _1458->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1458->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1460,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1461) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1460,_1461); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1460,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1461) { return __mosek_2fusion_2PSDVariable__elementDesc(_1460,_1461); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1460,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1461){
  _pubthis->elementName(_1460,_1461);
  _1461->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1461;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1462){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1462)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1463,int _1464,int _1465,std::shared_ptr< monty::ndarray< long long,1 > > _1466){
  _checked_ptr_1<int> _ptr__1463(_1463 ? _1463->raw() : nullptr, _1463 ? _1463->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1466(_1466 ? _1466->raw() : nullptr, _1466 ? _1466->size(0) : 0);
  int _1467 = (int)((_1463)->size(0));
  bool _1468 = (_1464 < _1465);
  int _7294;
  bool _7295 = _1468;
  if (_7295)
  {
    _7294 = _1464;
  }
  else
  {
    _7294 = _1465;
  }
  int _1469 = _7294;
  int _7296;
  bool _7297 = (!_1468);
  if (_7297)
  {
    _7296 = _1464;
  }
  else
  {
    _7296 = _1465;
  }
  int _1470 = _7296;
  int _1471 = (int)1;
  int _7298 = (int)0;
  int _7299 = _1469;
  for (int _1472 = _7298; _1472 < _7299; ++_1472)
  {
    {
      _1471 *= _ptr__1463[_1472];
    }
  }
  int _1473 = _ptr__1463[_1469];
  int _1474 = (int)1;
  int _7300 = safe_add( _1469,(int)1 );
  int _7301 = _1470;
  for (int _1475 = _7300; _1475 < _7301; ++_1475)
  {
    {
      _1474 *= _ptr__1463[_1475];
    }
  }
  int _1476 = _ptr__1463[_1470];
  int _1477 = (int)1;
  int _7302 = safe_add( _1470,(int)1 );
  int _7303 = _1467;
  for (int _1478 = _7302; _1478 < _7303; ++_1478)
  {
    {
      _1477 *= _ptr__1463[_1478];
    }
  }
  int _1479 = safe_mul( safe_mul( safe_mul( safe_mul( _1471,_1473 ),_1474 ),_1476 ),_1477 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1480 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1479)));
  _checked_ptr_1<long long> _ptr__1480(_1480 ? _1480->raw() : nullptr,_1480 ? _1480->size(0) : 0);
  int _1481 = _1477;
  int _1482 = safe_mul( _1481,_1476 );
  int _1483 = safe_mul( _1482,_1474 );
  int _1484 = safe_mul( _1483,_1483 );
  {
    int _1485 = (int)0;
    int _7304 = (int)0;
    int _7305 = _1471;
    for (int _1486 = _7304; _1486 < _7305; ++_1486)
    {
      {
        int _7306 = (int)0;
        int _7307 = _1476;
        for (int _1487 = _7306; _1487 < _7307; ++_1487)
        {
          {
            int _7308 = (int)0;
            int _7309 = _1474;
            for (int _1488 = _7308; _1488 < _7309; ++_1488)
            {
              {
                int _7310 = _1487;
                int _7311 = _1473;
                for (int _1489 = _7310; _1489 < _7311; ++_1489)
                {
                  {
                    int _7312 = (int)0;
                    int _7313 = _1477;
                    for (int _1490 = _7312; _1490 < _7313; ++_1490)
                    {
                      {
                        _ptr__1480[safe_add( safe_add( safe_add( safe_add( safe_mul( _1486,_1484 ),safe_mul( _1489,_1483 ) ),safe_mul( _1488,_1482 ) ),safe_mul( _1487,_1481 ) ),_1490 )] = (-safe_add( _ptr__1466[_1485],(int)1 ));
                        _ptr__1480[safe_add( safe_add( safe_add( safe_add( safe_mul( _1486,_1484 ),safe_mul( _1487,_1483 ) ),safe_mul( _1488,_1482 ) ),safe_mul( _1489,_1481 ) ),_1490 )] = (-safe_add( _ptr__1466[_1485],(int)1 ));
                        ++ _1485;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1480;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1491,    monty::rc_ptr< ::mosek::fusion::Model > _1492){ return new mosek::fusion::SymLinearVariable(_1491,_1492); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1491,    monty::rc_ptr< ::mosek::fusion::Model > _1492) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1491,_1492); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1491,    monty::rc_ptr< ::mosek::fusion::Model > _1492){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1491,_1492);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1491)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1491)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1491)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1491)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1491)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1493,    const std::string &  _1494,    long long _1495,    int _1496,    std::shared_ptr< monty::ndarray< long long,1 > > _1497,    std::shared_ptr< monty::ndarray< int,1 > > _1498){ return new mosek::fusion::SymLinearVariable(_1493,_1494,_1495,_1496,_1497,_1498); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1493,    const std::string &  _1494,    long long _1495,    int _1496,    std::shared_ptr< monty::ndarray< long long,1 > > _1497,    std::shared_ptr< monty::ndarray< int,1 > > _1498) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1493,_1494,_1495,_1496,_1497,_1498); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1493,    const std::string &  _1494,    long long _1495,    int _1496,    std::shared_ptr< monty::ndarray< long long,1 > > _1497,    std::shared_ptr< monty::ndarray< int,1 > > _1498){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1497(_1497 ? _1497->raw() : nullptr, _1497 ? _1497->size(0) : 0);
    _checked_ptr_1<int> _ptr__1498(_1498 ? _1498->raw() : nullptr, _1498 ? _1498->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1493,_1494,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1496),(int)(_1496)}),_1495,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1496,_1497),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1496,_1497,_1498));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1494;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1498;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1497;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1496;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1499 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _7314 = (int)0;
          int _7315 = (int)((nativeidxs)->size(0));
          for (int _1500 = _7314; _1500 < _7315; ++_1500)
          {
            {
              std::string _7316;
              bool _7317 = ((int)((name).size()) == (int)0);
              if (_7317)
              {
                _7316 = std::string ("");
              }
              else
              {
                _7316 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1500 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1500 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1499.get())->varname(((*nativeidxs)(_1500)),_7316);
            }
          }
        }
      }
      else
      {
        {
          int _7318 = (int)0;
          int _7319 = (int)((sparsity)->size(0));
          for (int _1501 = _7318; _1501 < _7319; ++_1501)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1499.get())->varname(((*nativeidxs)(_1501)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1501)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1501)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1502){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1502)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1503,std::shared_ptr< monty::ndarray< long long,1 > > _1504,std::shared_ptr< monty::ndarray< int,1 > > _1505){
  _checked_ptr_1<long long> _ptr__1504(_1504 ? _1504->raw() : nullptr, _1504 ? _1504->size(0) : 0);
  _checked_ptr_1<int> _ptr__1505(_1505 ? _1505->raw() : nullptr, _1505 ? _1505->size(0) : 0);
  if ((NULL == _1504.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1506 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1503,_1503 ))));
      _checked_ptr_1<long long> _ptr__1506(_1506 ? _1506->raw() : nullptr,_1506 ? _1506->size(0) : 0);
      int _1507 = (int)0;
      {
        int _7320 = (int)0;
        int _7321 = _1503;
        for (int _1508 = _7320; _1508 < _7321; ++_1508)
        {
          {
            _ptr__1506[safe_add( safe_mul( _1508,_1503 ),_1508 )] = safe_add( _ptr__1505[_1507],(int)1 );
            ++ _1507;
            int _7322 = safe_add( _1508,(int)1 );
            int _7323 = _1503;
            for (int _1509 = _7322; _1509 < _7323; ++_1509)
            {
              {
                _ptr__1506[safe_add( safe_mul( _1508,_1503 ),_1509 )] = safe_add( _ptr__1505[_1507],(int)1 );
                _ptr__1506[safe_add( safe_mul( _1509,_1503 ),_1508 )] = safe_add( _ptr__1505[_1507],(int)1 );
                ++ _1507;
              }
            }
          }
        }
      }
      return _1506;
    }
  }
  else
  {
    {
      int _1510 = (int)0;
      {
        int _7324 = (int)0;
        int _7325 = (int)((_1504)->size(0));
        for (int _1511 = _7324; _1511 < _7325; ++_1511)
        {
          {
            int _7326;
            bool _7327 = ((_ptr__1504[_1511] % safe_add( _1503,(int)1 )) == (int)0);
            if (_7327)
            {
              _7326 = (int)1;
            }
            else
            {
              _7326 = (int)2;
            }
            _1510 += _7326;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1512 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1510)));
      _checked_ptr_1<long long> _ptr__1512(_1512 ? _1512->raw() : nullptr,_1512 ? _1512->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1513 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1510)));
      _checked_ptr_1<long long> _ptr__1513(_1513 ? _1513->raw() : nullptr,_1513 ? _1513->size(0) : 0);
      {
        int _1514 = (int)0;
        int _7328 = (int)0;
        int _7329 = (int)((_1504)->size(0));
        for (int _1515 = _7328; _1515 < _7329; ++_1515)
        {
          {
            long long _1516 = (_ptr__1504[_1515] / _1503);
            long long _1517 = (_ptr__1504[_1515] % _1503);
            _ptr__1512[_1514] = _ptr__1504[_1515];
            _ptr__1513[_1514] = safe_add( _ptr__1505[_1515],(int)1 );
            ++ _1514;
            if ((_1516 != _1517))
            {
              {
                _ptr__1512[_1514] = safe_add( safe_mul( _1517,_1503 ),_1516 );
                _ptr__1513[_1514] = safe_add( _ptr__1505[_1515],(int)1 );
                ++ _1514;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7330;
      for (int _1519 = (int)0, _7331 = _1510; _1519 < _7331 ; ++_1519)
      {
        _7330.push_back(_1519);
      }
      auto _7332 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7330.size()),_7330.begin(),_7330.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1518 = _7332;
      _checked_ptr_1<long long> _ptr__1518(_1518 ? _1518->raw() : nullptr,_1518 ? _1518->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1518,_1512,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1510));
      std::vector<long long> _7333;
      for (int _1520 = (int)0, _7334 = _1510; _1520 < _7334 ; ++_1520)
      {
        _7333.push_back(_ptr__1513[_ptr__1518[_1520]]);
      }
      auto _7335 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7333.size()),_7333.begin(),_7333.end()));
      return _7335;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1521,std::shared_ptr< monty::ndarray< long long,1 > > _1522){
  _checked_ptr_1<long long> _ptr__1522(_1522 ? _1522->raw() : nullptr, _1522 ? _1522->size(0) : 0);
  if ((NULL == _1522.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1523 = (int)0;
      {
        int _7336 = (int)0;
        int _7337 = (int)((_1522)->size(0));
        for (int _1524 = _7336; _1524 < _7337; ++_1524)
        {
          {
            int _7338;
            bool _7339 = ((_ptr__1522[_1524] % safe_add( _1521,(int)1 )) == (int)0);
            if (_7339)
            {
              _7338 = (int)1;
            }
            else
            {
              _7338 = (int)2;
            }
            _1523 += _7338;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1525 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1523)));
      _checked_ptr_1<long long> _ptr__1525(_1525 ? _1525->raw() : nullptr,_1525 ? _1525->size(0) : 0);
      {
        int _1526 = (int)0;
        int _7340 = (int)0;
        int _7341 = (int)((_1522)->size(0));
        for (int _1527 = _7340; _1527 < _7341; ++_1527)
        {
          {
            long long _1528 = (_ptr__1522[_1527] / _1521);
            long long _1529 = (_ptr__1522[_1527] % _1521);
            _ptr__1525[_1526] = _ptr__1522[_1527];
            ++ _1526;
            if ((_1528 != _1529))
            {
              {
                _ptr__1525[_1526] = safe_add( safe_mul( _1529,_1521 ),_1528 );
                ++ _1526;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _7342;
      for (int _1531 = (int)0, _7343 = _1523; _1531 < _7343 ; ++_1531)
      {
        _7342.push_back(_1531);
      }
      auto _7344 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7342.size()),_7342.begin(),_7342.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1530 = _7344;
      _checked_ptr_1<long long> _ptr__1530(_1530 ? _1530->raw() : nullptr,_1530 ? _1530->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1530,_1525,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1523));
      std::vector<long long> _7345;
      for (int _1532 = (int)0, _7346 = _1523; _1532 < _7346 ; ++_1532)
      {
        _7345.push_back(_ptr__1525[_ptr__1530[_1532]]);
      }
      auto _7347 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7345.size()),_7345.begin(),_7345.end()));
      return _7347;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1533,    monty::rc_ptr< ::mosek::fusion::Model > _1534){ return new mosek::fusion::LinearVariable(_1533,_1534); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1533,    monty::rc_ptr< ::mosek::fusion::Model > _1534) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1533,_1534); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1533,    monty::rc_ptr< ::mosek::fusion::Model > _1534){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1533,_1534);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1533)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1533)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1533)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1533)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1533)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1535,    const std::string &  _1536,    long long _1537,    std::shared_ptr< monty::ndarray< int,1 > > _1538,    std::shared_ptr< monty::ndarray< long long,1 > > _1539,    std::shared_ptr< monty::ndarray< int,1 > > _1540){ return new mosek::fusion::LinearVariable(_1535,_1536,_1537,_1538,_1539,_1540); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1535,    const std::string &  _1536,    long long _1537,    std::shared_ptr< monty::ndarray< int,1 > > _1538,    std::shared_ptr< monty::ndarray< long long,1 > > _1539,    std::shared_ptr< monty::ndarray< int,1 > > _1540) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1535,_1536,_1537,_1538,_1539,_1540); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1535,    const std::string &  _1536,    long long _1537,    std::shared_ptr< monty::ndarray< int,1 > > _1538,    std::shared_ptr< monty::ndarray< long long,1 > > _1539,    std::shared_ptr< monty::ndarray< int,1 > > _1540){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1538(_1538 ? _1538->raw() : nullptr, _1538 ? _1538->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1539(_1539 ? _1539->raw() : nullptr, _1539 ? _1539->size(0) : 0);
    _checked_ptr_1<int> _ptr__1540(_1540 ? _1540->raw() : nullptr, _1540 ? _1540->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1535,_1536,_1538,_1537,_1539,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1540));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1536;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1540;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1539;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1538;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1541 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1541->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1541->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7348 = (int)1;
      int _7349 = (int)((shape)->size(0));
      for (int _1542 = _7348; _1542 < _7349; ++_1542)
      {
        {
          _1541->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1542)));
        }
      }
    }
  }
  {}
  _1541->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1541->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1543 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1544 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1544->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1544->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _7350 = (int)1;
          int _7351 = _pubthis->getND();
          for (int _1545 = _7350; _1545 < _7351; ++_1545)
          {
            {
              _1544->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1545);
            }
          }
        }
      }
      {}
      _1544->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7352;
      bool _7353 = (_pubthis->getND() > (int)0);
      if (_7353)
      {
        _7352 = _pubthis->getShape();
      }
      else
      {
        _7352 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1543.get())->varnames(nativeidxs,_1544->toString(),_7352,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1546){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1546)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1547){
  _checked_ptr_1<int> _ptr__1547(_1547 ? _1547->raw() : nullptr, _1547 ? _1547->size(0) : 0);
  std::vector<long long> _7354;
  for (int _1548 = (int)0, _7355 = (int)((_1547)->size(0)); _1548 < _7355 ; ++_1548)
  {
    _7354.push_back(safe_add( _ptr__1547[_1548],(int)1 ));
  }
  auto _7356 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7354.size()),_7354.begin(),_7354.end()));
  return _7356;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1549,    monty::rc_ptr< ::mosek::fusion::Model > _1550){ return new mosek::fusion::ConicVariable(_1549,_1550); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1549,    monty::rc_ptr< ::mosek::fusion::Model > _1550) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1549,_1550); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1549,    monty::rc_ptr< ::mosek::fusion::Model > _1550){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1549,_1550);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1549)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1549)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1549)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1549)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1549)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1549)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1551,    const std::string &  _1552,    int _1553,    std::shared_ptr< monty::ndarray< int,1 > > _1554,    std::shared_ptr< monty::ndarray< int,1 > > _1555){ return new mosek::fusion::ConicVariable(_1551,_1552,_1553,_1554,_1555); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1551,    const std::string &  _1552,    int _1553,    std::shared_ptr< monty::ndarray< int,1 > > _1554,    std::shared_ptr< monty::ndarray< int,1 > > _1555) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1551,_1552,_1553,_1554,_1555); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1551,    const std::string &  _1552,    int _1553,    std::shared_ptr< monty::ndarray< int,1 > > _1554,    std::shared_ptr< monty::ndarray< int,1 > > _1555){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1554(_1554 ? _1554->raw() : nullptr, _1554 ? _1554->size(0) : 0);
    _checked_ptr_1<int> _ptr__1555(_1555 ? _1555->raw() : nullptr, _1555 ? _1555->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1551,_1552,_1554,_1553,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1555));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1552;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1553;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1554;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1555;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1556 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1556->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1556->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1556->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1556->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7357 = (int)1;
  int _7358 = (int)((shape)->size(0));
  for (int _1557 = _7357; _1557 < _7358; ++_1557)
  {
    {
      _1556->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1557)));
    }
  }
  _1556->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1556->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1558 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1559 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1559->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _7359 = (int)1;
      int _7360 = _pubthis->getND();
      for (int _1560 = _7359; _1560 < _7360; ++_1560)
      {
        {
          _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1560);
        }
      }
      _1559->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _7361;
      bool _7362 = (_pubthis->getND() > (int)0);
      if (_7362)
      {
        _7361 = _pubthis->getShape();
      }
      else
      {
        _7361 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1558.get())->varnames(nativeidxs,_1559->toString(),_7361,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1561){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1561)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1562){
  _checked_ptr_1<int> _ptr__1562(_1562 ? _1562->raw() : nullptr, _1562 ? _1562->size(0) : 0);
  std::vector<long long> _7363;
  for (int _1563 = (int)0, _7364 = (int)((_1562)->size(0)); _1563 < _7364 ; ++_1563)
  {
    _7363.push_back(safe_add( _ptr__1562[_1563],(int)1 ));
  }
  auto _7365 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7363.size()),_7363.begin(),_7363.end()));
  return _7365;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1564,    monty::rc_ptr< ::mosek::fusion::Model > _1565){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1564,_1565);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1564)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1564)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1564)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1564)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1564)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1566,    const std::string &  _1567,    std::shared_ptr< monty::ndarray< int,1 > > _1568,    long long _1569,    std::shared_ptr< monty::ndarray< long long,1 > > _1570,    std::shared_ptr< monty::ndarray< long long,1 > > _1571){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1568(_1568 ? _1568->raw() : nullptr, _1568 ? _1568->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1570(_1570 ? _1570->raw() : nullptr, _1570 ? _1570->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1571(_1571 ? _1571->raw() : nullptr, _1571 ? _1571->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1566,_1568,_1570,_1571);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1567;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1569;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1568;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1570;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1571;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1572,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1573) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1572,_1573); }void mosek::fusion::p_ModelVariable::elementName(long long _1572,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1573){
  std::string _7366;
  bool _7367 = ((int)((name).size()) == (int)0);
  if (_7367)
  {
    _7366 = std::string ("_");
  }
  else
  {
    _7366 = name;
  }
  _1573->__mosek_2fusion_2Utils_2StringBuffer__a(_7366)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1572))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1575){ return new mosek::fusion::NilVariable(_1575); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1575) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1575); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1575){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1575(_1575 ? _1575->raw() : nullptr, _1575 ? _1575->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1575),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _7368;
    for (int _1576 = (int)0, _7369 = (int)((_1575)->size(0)); _1576 < _7369 ; ++_1576)
    {
      _7368.push_back(_ptr__1575[_1576]);
    }
    auto _7370 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7368.size()),_7368.begin(),_7368.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _7370;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)}));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1577,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1578) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1577,_1578); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1577,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1578) { return __mosek_2fusion_2NilVariable__elementDesc(_1577,_1578); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1577,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1578){
  return _1578;
}
void mosek::fusion::NilVariable :: elementName(long long _1579,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1580) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1579,_1580); }void mosek::fusion::p_NilVariable::elementName(long long _1579,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1580){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1581,std::shared_ptr< monty::ndarray< long long,1 > > _1582,std::shared_ptr< monty::ndarray< long long,1 > > _1583) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1581,_1582,_1583); }int mosek::fusion::p_NilVariable::inst(int _1581,std::shared_ptr< monty::ndarray< long long,1 > > _1582,std::shared_ptr< monty::ndarray< long long,1 > > _1583){
  _checked_ptr_1<long long> _ptr__1582(_1582 ? _1582->raw() : nullptr, _1582 ? _1582->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1583(_1583 ? _1583->raw() : nullptr, _1583 ? _1583->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1584,_1585); }void mosek::fusion::p_NilVariable::inst(int _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585){
  _checked_ptr_1<long long> _ptr__1585(_1585 ? _1585->raw() : nullptr, _1585 ? _1585->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1586,bool _1587) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1586,_1587); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1586,bool _1587){
  _checked_ptr_1<double> _ptr__1586(_1586 ? _1586->raw() : nullptr, _1586 ? _1586->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1588,std::shared_ptr< monty::ndarray< double,1 > > _1589,bool _1590) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1588,_1589,_1590); }void mosek::fusion::p_NilVariable::values(int _1588,std::shared_ptr< monty::ndarray< double,1 > > _1589,bool _1590){
  _checked_ptr_1<double> _ptr__1589(_1589 ? _1589->raw() : nullptr, _1589 ? _1589->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1591); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1591) { return __mosek_2fusion_2NilVariable__index(_1591); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591) { return __mosek_2fusion_2NilVariable__index(_1591); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591) { return __mosek_2fusion_2NilVariable__index(_1591); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591){
  _checked_ptr_1<int> _ptr__1591(_1591 ? _1591->raw() : nullptr, _1591 ? _1591->size(0) : 0);
  std::vector<int> _7371;
  for (int _1592 = (int)0, _7372 = (int)((shape)->size(0)); _1592 < _7372 ; ++_1592)
  {
    _7371.push_back((int)1);
  }
  auto _7373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7371.size()),_7371.begin(),_7371.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7373)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1593) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1593); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1593) { return __mosek_2fusion_2NilVariable__index(_1593); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1593) { return __mosek_2fusion_2NilVariable__index(_1593); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1593) { return __mosek_2fusion_2NilVariable__index(_1593); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1593){
  std::vector<int> _7374;
  for (int _1594 = (int)0, _7375 = (int)((shape)->size(0)); _1594 < _7375 ; ++_1594)
  {
    _7374.push_back((int)1);
  }
  auto _7376 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7374.size()),_7374.begin(),_7374.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7376)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1595,_1596); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) { return __mosek_2fusion_2NilVariable__slice(_1595,_1596); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) { return __mosek_2fusion_2NilVariable__slice(_1595,_1596); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) { return __mosek_2fusion_2NilVariable__slice(_1595,_1596); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596){
  _checked_ptr_1<int> _ptr__1595(_1595 ? _1595->raw() : nullptr, _1595 ? _1595->size(0) : 0);
  _checked_ptr_1<int> _ptr__1596(_1596 ? _1596->raw() : nullptr, _1596 ? _1596->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1595)->size(0))) || ((int)((shape)->size(0)) != (int)((_1596)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _7377 = (int)0;
  int _7378 = (int)((_1595)->size(0));
  for (int _1597 = _7377; _1597 < _7378; ++_1597)
  {
    {
      if (((_ptr__1596[_1597] > _ptr__1595[_1597]) || ((_ptr__1595[_1597] < (int)0) || (_ptr__1596[_1597] >= ((*shape)(_1597))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _7379;
  for (int _1598 = (int)0, _7380 = (int)((shape)->size(0)); _1598 < _7380 ; ++_1598)
  {
    _7379.push_back((_ptr__1596[_1598] - _ptr__1595[_1598]));
  }
  auto _7381 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7379.size()),_7379.begin(),_7379.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_7381)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1599,int _1600) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1599,_1600); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1599,int _1600) { return __mosek_2fusion_2NilVariable__slice(_1599,_1600); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1599,int _1600) { return __mosek_2fusion_2NilVariable__slice(_1599,_1600); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1599,int _1600) { return __mosek_2fusion_2NilVariable__slice(_1599,_1600); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1599,int _1600){
  if (((_1600 > _1599) || ((_1599 < (int)0) || (_1600 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1600 - _1599))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1601,    monty::rc_ptr< ::mosek::fusion::Model > _1602){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1602;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1601)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1601)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1601)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1603,    std::shared_ptr< monty::ndarray< int,1 > > _1604,    std::shared_ptr< monty::ndarray< long long,1 > > _1605,    std::shared_ptr< monty::ndarray< long long,1 > > _1606){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1604(_1604 ? _1604->raw() : nullptr, _1604 ? _1604->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1605(_1605 ? _1605->raw() : nullptr, _1605 ? _1605->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1606(_1606 ? _1606->raw() : nullptr, _1606 ? _1606->size(0) : 0);
    model = _1603;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1604;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1605;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1606;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1607 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1607->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1607->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _7382 = (int)1;
      int _7383 = (int)((shape)->size(0));
      for (int _1608 = _7382; _1608 < _7383; ++_1608)
      {
        {
          _1607->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1608)));
        }
      }
    }
  }
  {}
  _1607->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1607->toString();
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__eval() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::eval() { return __mosek_2fusion_2BaseVariable__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseVariable::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__eval(){
  return _pubthis->__mosek_2fusion_2BaseVariable__asExpr()->__mosek_2fusion_2Expression__eval();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1609,monty::rc_ptr< ::mosek::fusion::WorkStack > _1610,monty::rc_ptr< ::mosek::fusion::WorkStack > _1611) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1609,_1610,_1611); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1609,monty::rc_ptr< ::mosek::fusion::WorkStack > _1610,monty::rc_ptr< ::mosek::fusion::WorkStack > _1611){
  int _1612 = (int)((nativeidxs)->size(0));
  int _1613 = _1612;
  int _1614 = (int)((shape)->size(0));
  bool _1615 = (NULL != sparsity.get());
  _1609->alloc_expr(_1614,_1613,_1612,_1615);
  int _1616 = mosek::fusion::p_WorkStack::_get_impl(_1609)->ptr_base;
  int _1617 = mosek::fusion::p_WorkStack::_get_impl(_1609)->nidxs_base;
  int _1618 = mosek::fusion::p_WorkStack::_get_impl(_1609)->sp_base;
  int _1619 = mosek::fusion::p_WorkStack::_get_impl(_1609)->cof_base;
  int _1620 = mosek::fusion::p_WorkStack::_get_impl(_1609)->bfix_base;
  int _1621 = mosek::fusion::p_WorkStack::_get_impl(_1609)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1622 = mosek::fusion::p_WorkStack::_get_impl(_1609)->i32;
  _checked_ptr_1<int> _ptr__1622(_1622 ? _1622->raw() : nullptr,_1622 ? _1622->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1623 = mosek::fusion::p_WorkStack::_get_impl(_1609)->i64;
  _checked_ptr_1<long long> _ptr__1623(_1623 ? _1623->raw() : nullptr,_1623 ? _1623->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1624 = mosek::fusion::p_WorkStack::_get_impl(_1609)->f64;
  _checked_ptr_1<double> _ptr__1624(_1624 ? _1624->raw() : nullptr,_1624 ? _1624->size(0) : 0);
  int _7384 = (int)0;
  int _7385 = _1614;
  for (int _1625 = _7384; _1625 < _7385; ++_1625)
  {
    {
      _ptr__1622[safe_add( _1621,_1625 )] = ((*shape)(_1625));
    }
  }
  {
    int _7386 = (int)0;
    int _7387 = safe_add( _1612,(int)1 );
    for (int _1626 = _7386; _1626 < _7387; ++_1626)
    {
      {
        _ptr__1622[safe_add( _1616,_1626 )] = _1626;
      }
    }
    int _7388 = (int)0;
    int _7389 = _1612;
    for (int _1627 = _7388; _1627 < _7389; ++_1627)
    {
      {
        _ptr__1623[safe_add( _1617,_1627 )] = ((*nativeidxs)(_1627));
      }
    }
    if (_1615)
    {
      {
        int _7390 = (int)0;
        int _7391 = _1612;
        for (int _1628 = _7390; _1628 < _7391; ++_1628)
        {
          {
            _ptr__1623[safe_add( _1618,_1628 )] = ((*sparsity)(_1628));
          }
        }
      }
    }
    {}
    int _7392 = (int)0;
    int _7393 = _1612;
    for (int _1629 = _7392; _1629 < _7393; ++_1629)
    {
      {
        _ptr__1624[safe_add( _1619,_1629 )] = 1.0;
      }
    }
    int _7394 = (int)0;
    int _7395 = _1612;
    for (int _1630 = _7394; _1630 < _7395; ++_1630)
    {
      {
        _ptr__1624[safe_add( _1620,_1630 )] = 0.0;
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1631) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_1631); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1631) { return __mosek_2fusion_2BaseVariable__reshape(_1631); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1631) { return __mosek_2fusion_2BaseVariable__reshape(_1631); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1631){
  _checked_ptr_1<int> _ptr__1631(_1631 ? _1631->raw() : nullptr, _1631 ? _1631->size(0) : 0);
  long long _1632 = (int)1;
  int _7396 = (int)0;
  int _7397 = (int)((_1631)->size(0));
  for (int _1633 = _7396; _1633 < _7397; ++_1633)
  {
    {
      if ((_ptr__1631[_1633] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _1632 *= _ptr__1631[_1633];
    }
  }
  if ((_1632 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _7398;
  for (int _1634 = (int)0, _7399 = (int)((_1631)->size(0)); _1634 < _7399 ; ++_1634)
  {
    _7398.push_back(_ptr__1631[_1634]);
  }
  auto _7400 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7398.size()),_7398.begin(),_7398.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_7400,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1635) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_1635); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1635){
  _checked_ptr_1<double> _ptr__1635(_1635 ? _1635->raw() : nullptr, _1635 ? _1635->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_1635)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_1635);
    }
  }
  else
  {
    {
      if (((int)((_1635)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _7401;
      for (int _1637 = (int)0, _7402 = (int)((nativeidxs)->size(0)); _1637 < _7402 ; ++_1637)
      {
        _7401.push_back(_ptr__1635[((*sparsity)(_1637))]);
      }
      auto _7403 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7401.size()),_7401.begin(),_7401.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _1636 = _7403;
      _checked_ptr_1<double> _ptr__1636(_1636 ? _1636->raw() : nullptr,_1636 ? _1636->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_1636);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _1638) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_1638); }int mosek::fusion::p_BaseVariable::getDim(int _1638){
  return ((*shape)(_1638));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _1639 = (long long)1;
  int _7404 = (int)0;
  int _7405 = (int)((shape)->size(0));
  for (int _1640 = _7404; _1640 < _7405; ++_1640)
  {
    {
      _1639 *= ((*shape)(_1640));
    }
  }
  return _1639;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1641 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1641(_1641 ? _1641->raw() : nullptr,_1641 ? _1641->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_1641,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1642 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1642(_1642 ? _1642->raw() : nullptr,_1642 ? _1642->size(0) : 0);
      int _7406 = (int)0;
      int _7407 = (int)((nativeidxs)->size(0));
      for (int _1643 = _7406; _1643 < _7407; ++_1643)
      {
        {
          _ptr__1642[((*sparsity)(_1643))] = _ptr__1641[_1643];
        }
      }
      _1641 = _1642;
      _ptr__1641.update(_1641 ? _1641->raw() : nullptr, _1641 ? _1641->size(0) : 0);
    }
  }
  {}
  return _1641;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _1644 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__1644(_1644 ? _1644->raw() : nullptr,_1644 ? _1644->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_1644,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _1645 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__1645(_1645 ? _1645->raw() : nullptr,_1645 ? _1645->size(0) : 0);
      int _7408 = (int)0;
      int _7409 = (int)((nativeidxs)->size(0));
      for (int _1646 = _7408; _1646 < _7409; ++_1646)
      {
        {
          _ptr__1645[((*sparsity)(_1646))] = _ptr__1644[_1646];
        }
      }
      _1644 = _1645;
      _ptr__1644.update(_1644 ? _1644->raw() : nullptr, _1644 ? _1644->size(0) : 0);
    }
  }
  {}
  return _1644;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1647 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__1647(_1647 ? _1647->raw() : nullptr,_1647 ? _1647->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _7410;
      bool _7411 = (NULL == sparsity.get());
      if (_7411)
      {
        _7410 = nullptr;
      }
      else
      {
        _7410 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1648 = _7410;
      _checked_ptr_1<long long> _ptr__1648(_1648 ? _1648->raw() : nullptr,_1648 ? _1648->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _1649 = (int)0;
          int _7412 = (int)0;
          int _7413 = ((*shape)((int)1));
          for (int _1650 = _7412; _1650 < _7413; ++_1650)
          {
            {
              int _7414 = (int)0;
              int _7415 = ((*shape)((int)0));
              for (int _1651 = _7414; _1651 < _7415; ++_1651)
              {
                {
                  _ptr__1647[_1649] = ((*nativeidxs)(safe_add( safe_mul( _1651,((*shape)((int)1)) ),_1650 )));
                  ++ _1649;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1652 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__1652(_1652 ? _1652->raw() : nullptr,_1652 ? _1652->size(0) : 0);
          int _1653 = ((*shape)((int)0));
          int _1654 = ((*shape)((int)1));
          int _7416 = (int)0;
          int _7417 = (int)((sparsity)->size(0));
          for (int _1655 = _7416; _1655 < _7417; ++_1655)
          {
            {
              ++ _ptr__1652[safe_add( (((*sparsity)(_1655)) % _1654),(int)1 )];
            }
          }
          int _7418 = (int)0;
          int _7419 = _1654;
          for (int _1656 = _7418; _1656 < _7419; ++_1656)
          {
            {
              _ptr__1652[safe_add( _1656,(int)1 )] += _ptr__1652[_1656];
            }
          }
          int _7420 = (int)0;
          int _7421 = (int)((sparsity)->size(0));
          for (int _1657 = _7420; _1657 < _7421; ++_1657)
          {
            {
              long long _1658 = (((*sparsity)(_1657)) % _1654);
              _ptr__1647[_ptr__1652[_1658]] = ((*nativeidxs)(_1657));
              _ptr__1648[_ptr__1652[_1658]] = safe_add( (((*sparsity)(_1657)) / _1654),safe_mul( (((*sparsity)(_1657)) % _1654),_1653 ) );
              ++ _ptr__1652[_1658];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_1648,_1647)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1659,int _1660,int _1661) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1659,_1660,_1661); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1659,int _1660,int _1661) { return __mosek_2fusion_2BaseVariable__index(_1659,_1660,_1661); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1659,int _1660,int _1661) { return __mosek_2fusion_2BaseVariable__index(_1659,_1660,_1661); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1659,int _1660,int _1661){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1659),(int)(_1660),(int)(_1661)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1662,int _1663) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1662,_1663); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1662,int _1663) { return __mosek_2fusion_2BaseVariable__index(_1662,_1663); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1662,int _1663) { return __mosek_2fusion_2BaseVariable__index(_1662,_1663); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1662,int _1663){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1662),(int)(_1663)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1664) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1664); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1664) { return __mosek_2fusion_2BaseVariable__index(_1664); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1664) { return __mosek_2fusion_2BaseVariable__index(_1664); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1664){
  _checked_ptr_1<int> _ptr__1664(_1664 ? _1664->raw() : nullptr, _1664 ? _1664->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _1665 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_1664)->size(0)))));
  int _7422 = (int)0;
  int _7423 = (int)((_1664)->size(0));
  for (int _1666 = _7422; _1666 < _7423; ++_1666)
  {
    {
      ((*_1665)((int)0,_1666)) = _ptr__1664[_1666];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1665)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _1667) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_1667); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _1667) { return __mosek_2fusion_2BaseVariable__index(_1667); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _1667) { return __mosek_2fusion_2BaseVariable__index(_1667); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _1667){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1667)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1668,std::shared_ptr< monty::ndarray< int,1 > > _1669,std::shared_ptr< monty::ndarray< int,1 > > _1670) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1668,_1669,_1670); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1668,std::shared_ptr< monty::ndarray< int,1 > > _1669,std::shared_ptr< monty::ndarray< int,1 > > _1670) { return __mosek_2fusion_2BaseVariable__pick(_1668,_1669,_1670); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1668,std::shared_ptr< monty::ndarray< int,1 > > _1669,std::shared_ptr< monty::ndarray< int,1 > > _1670) { return __mosek_2fusion_2BaseVariable__pick(_1668,_1669,_1670); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1668,std::shared_ptr< monty::ndarray< int,1 > > _1669,std::shared_ptr< monty::ndarray< int,1 > > _1670){
  _checked_ptr_1<int> _ptr__1668(_1668 ? _1668->raw() : nullptr, _1668 ? _1668->size(0) : 0);
  _checked_ptr_1<int> _ptr__1669(_1669 ? _1669->raw() : nullptr, _1669 ? _1669->size(0) : 0);
  _checked_ptr_1<int> _ptr__1670(_1670 ? _1670->raw() : nullptr, _1670 ? _1670->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_1668)->size(0)) != (int)((_1669)->size(0))) || ((int)((_1668)->size(0)) != (int)((_1670)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1671 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1668)->size(0)),(int)3)));
  int _7424 = (int)0;
  int _7425 = (int)((_1668)->size(0));
  for (int _1672 = _7424; _1672 < _7425; ++_1672)
  {
    {
      ((*_1671)(_1672,(int)0)) = _ptr__1668[_1672];
      ((*_1671)(_1672,(int)1)) = _ptr__1669[_1672];
      ((*_1671)(_1672,(int)2)) = _ptr__1670[_1672];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1671);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1673,std::shared_ptr< monty::ndarray< int,1 > > _1674) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1673,_1674); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1673,std::shared_ptr< monty::ndarray< int,1 > > _1674) { return __mosek_2fusion_2BaseVariable__pick(_1673,_1674); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1673,std::shared_ptr< monty::ndarray< int,1 > > _1674) { return __mosek_2fusion_2BaseVariable__pick(_1673,_1674); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1673,std::shared_ptr< monty::ndarray< int,1 > > _1674){
  _checked_ptr_1<int> _ptr__1673(_1673 ? _1673->raw() : nullptr, _1673 ? _1673->size(0) : 0);
  _checked_ptr_1<int> _ptr__1674(_1674 ? _1674->raw() : nullptr, _1674 ? _1674->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_1673)->size(0)) != (int)((_1674)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _1675 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_1673)->size(0)),(int)2)));
  int _7426 = (int)0;
  int _7427 = (int)((_1673)->size(0));
  for (int _1676 = _7426; _1676 < _7427; ++_1676)
  {
    {
      ((*_1675)(_1676,(int)0)) = _ptr__1673[_1676];
      ((*_1675)(_1676,(int)1)) = _ptr__1674[_1676];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_1675);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1677) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1677); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1677) { return __mosek_2fusion_2BaseVariable__pick(_1677); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1677) { return __mosek_2fusion_2BaseVariable__pick(_1677); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1677){
  if (((int)((shape)->size(0)) != (int)((_1677)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7428 = (int)0;
  int _7429 = (int)((_1677)->size(0));
  for (int _1678 = _7428; _1678 < _7429; ++_1678)
  {
    {
      int _7430 = (int)0;
      int _7431 = (int)((_1677)->size(1));
      for (int _1679 = _7430; _1679 < _7431; ++_1679)
      {
        {
          if (((((*_1677)(_1678,_1679)) < (int)0) || (((*_1677)(_1678,_1679)) >= ((*shape)(_1679)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
            }
          }
          {}
        }
      }
    }
  }
  int _1680 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1681 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1680)));
  _checked_ptr_1<long long> _ptr__1681(_1681 ? _1681->raw() : nullptr,_1681 ? _1681->size(0) : 0);
  _ptr__1681[(_1680 - (int)1)] = (int)1;
  int _7432 = (int)1;
  int _7433 = _1680;
  for (int _1682 = _7432; _1682 < _7433; ++_1682)
  {
    {
      _ptr__1681[((_1680 - _1682) - (int)1)] = safe_mul( _ptr__1681[(_1680 - _1682)],((*shape)((_1680 - _1682))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1683 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1677)->size(0)))});
  _checked_ptr_1<int> _ptr__1683(_1683 ? _1683->raw() : nullptr,_1683 ? _1683->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1684;
  _checked_ptr_1<long long> _ptr__1684(_1684 ? _1684->raw() : nullptr,_1684 ? _1684->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1685 = nullptr;
  _checked_ptr_1<long long> _ptr__1685(_1685 ? _1685->raw() : nullptr,_1685 ? _1685->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _1684 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1677)->size(0)))));
      _ptr__1684.update(_1684 ? _1684->raw() : nullptr, _1684 ? _1684->size(0) : 0);
      {
        int _7434 = (int)0;
        int _7435 = (int)((_1677)->size(0));
        for (int _1686 = _7434; _1686 < _7435; ++_1686)
        {
          {
            long long _1687 = (long long)0;
            int _7436 = (int)0;
            int _7437 = _1680;
            for (int _1688 = _7436; _1688 < _7437; ++_1688)
            {
              {
                _1687 += safe_mul( _ptr__1681[_1688],((*_1677)(_1686,_1688)) );
              }
            }
            _ptr__1684[_1686] = ((*nativeidxs)(_1687));
          }
        }
      }
    }
  }
  else
  {
    {
      int _1689 = (int)0;
      int _7438 = (int)0;
      int _7439 = (int)((_1677)->size(0));
      for (int _1690 = _7438; _1690 < _7439; ++_1690)
      {
        {
          long long _1691 = (long long)0;
          int _7440 = (int)0;
          int _7441 = _1680;
          for (int _1692 = _7440; _1692 < _7441; ++_1692)
          {
            {
              _1691 += safe_mul( _ptr__1681[_1692],((*_1677)(_1690,_1692)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1691) >= (int)0))
          {
            {
              ++ _1689;
            }
          }
          {}
        }
      }
      _1684 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1689)));
      _ptr__1684.update(_1684 ? _1684->raw() : nullptr, _1684 ? _1684->size(0) : 0);
      _1685 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1689)));
      _ptr__1685.update(_1685 ? _1685->raw() : nullptr, _1685 ? _1685->size(0) : 0);
      {
        int _1693 = (int)0;
        int _7442 = (int)0;
        int _7443 = (int)((_1677)->size(0));
        for (int _1694 = _7442; _1694 < _7443; ++_1694)
        {
          {
            long long _1695 = (long long)0;
            int _7444 = (int)0;
            int _7445 = _1680;
            for (int _1696 = _7444; _1696 < _7445; ++_1696)
            {
              {
                _1695 += safe_mul( _ptr__1681[_1696],((*_1677)(_1694,_1696)) );
              }
            }
            int _1697 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1695);
            if ((_1697 >= (int)0))
            {
              {
                _ptr__1684[_1693] = ((*nativeidxs)(_1697));
                _ptr__1685[_1693] = _1694;
                ++ _1693;
              }
            }
            {}
          }
        }
      }
      if ((_1689 == (int)((_1677)->size(0))))
      {
        {
          _1685 = nullptr;
          _ptr__1685.update(_1685 ? _1685->raw() : nullptr, _1685 ? _1685->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1683,_1685,_1684)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_1698); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return __mosek_2fusion_2BaseVariable__pick(_1698); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return __mosek_2fusion_2BaseVariable__pick(_1698); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698){
  _checked_ptr_1<int> _ptr__1698(_1698 ? _1698->raw() : nullptr, _1698 ? _1698->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _7446 = (int)0;
  int _7447 = (int)((_1698)->size(0));
  for (int _1699 = _7446; _1699 < _7447; ++_1699)
  {
    {
      if (((_ptr__1698[_1699] < (int)0) || (_ptr__1698[_1699] >= ((*shape)((int)0)))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1700;
  _checked_ptr_1<long long> _ptr__1700(_1700 ? _1700->raw() : nullptr,_1700 ? _1700->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1701 = nullptr;
  _checked_ptr_1<long long> _ptr__1701(_1701 ? _1701->raw() : nullptr,_1701 ? _1701->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _7448;
      for (int _1702 = (int)0, _7449 = (int)((_1698)->size(0)); _1702 < _7449 ; ++_1702)
      {
        _7448.push_back(((*nativeidxs)(_ptr__1698[_1702])));
      }
      auto _7450 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7448.size()),_7448.begin(),_7448.end()));
      _1700 = _7450;
      _ptr__1700.update(_1700 ? _1700->raw() : nullptr, _1700 ? _1700->size(0) : 0);
    }
  }
  else
  {
    {
      int _1703 = (int)0;
      int _7451 = (int)0;
      int _7452 = (int)((_1698)->size(0));
      for (int _1704 = _7451; _1704 < _7452; ++_1704)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1698[_1704])) >= (int)0))
          {
            {
              ++ _1703;
            }
          }
          {}
        }
      }
      _1700 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1703)));
      _ptr__1700.update(_1700 ? _1700->raw() : nullptr, _1700 ? _1700->size(0) : 0);
      _1701 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1703)));
      _ptr__1701.update(_1701 ? _1701->raw() : nullptr, _1701 ? _1701->size(0) : 0);
      int _1705 = (int)0;
      int _7453 = (int)0;
      int _7454 = (int)((_1698)->size(0));
      for (int _1706 = _7453; _1706 < _7454; ++_1706)
      {
        {
          int _1707 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__1698[_1706]));
          if ((_1707 >= (int)0))
          {
            {
              _ptr__1701[_1705] = _1706;
              _ptr__1700[_1705] = ((*nativeidxs)(_1707));
              ++ _1705;
            }
          }
          {}
        }
      }
      if ((_1703 == (int)((_1698)->size(0))))
      {
        {
          _1701 = nullptr;
          _ptr__1701.update(_1701 ? _1701->raw() : nullptr, _1701 ? _1701->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_1698)->size(0)))}),_1701,_1700)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _1708) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_1708); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _1708) { return __mosek_2fusion_2BaseVariable__antidiag(_1708); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _1708) { return __mosek_2fusion_2BaseVariable__antidiag(_1708); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1708){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_1708 >= ((*shape)((int)1))) || ((-_1708) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1708 >= (int)0))
  {
    {
      int _7455;
      bool _7456 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1708));
      if (_7456)
      {
        _7455 = ((*shape)((int)0));
      }
      else
      {
        _7455 = (((*shape)((int)1)) - _1708);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _1708))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7455);
    }
  }
  else
  {
    {
      int _7457;
      bool _7458 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1708 ));
      if (_7458)
      {
        _7457 = ((*shape)((int)1));
      }
      else
      {
        _7457 = safe_add( ((*shape)((int)0)),_1708 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1708)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7457);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7459;
  bool _7460 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7460)
  {
    _7459 = ((*shape)((int)0));
  }
  else
  {
    _7459 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_7459);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _1709) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_1709); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _1709) { return __mosek_2fusion_2BaseVariable__diag(_1709); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _1709) { return __mosek_2fusion_2BaseVariable__diag(_1709); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _1709){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_1709 >= ((*shape)((int)1))) || ((-_1709) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_1709 >= (int)0))
  {
    {
      int _7461;
      bool _7462 = (((*shape)((int)0)) < (((*shape)((int)1)) - _1709));
      if (_7462)
      {
        _7461 = ((*shape)((int)0));
      }
      else
      {
        _7461 = (((*shape)((int)1)) - _1709);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_1709)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7461);
    }
  }
  else
  {
    {
      int _7463;
      bool _7464 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_1709 ));
      if (_7464)
      {
        _7463 = ((*shape)((int)1));
      }
      else
      {
        _7463 = safe_add( ((*shape)((int)0)),_1709 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_1709)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7463);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _7465;
  bool _7466 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_7466)
  {
    _7465 = ((*shape)((int)0));
  }
  else
  {
    _7465 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_7465);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1710,std::shared_ptr< monty::ndarray< int,1 > > _1711,int _1712){
  _checked_ptr_1<int> _ptr__1710(_1710 ? _1710->raw() : nullptr, _1710 ? _1710->size(0) : 0);
  _checked_ptr_1<int> _ptr__1711(_1711 ? _1711->raw() : nullptr, _1711 ? _1711->size(0) : 0);
  int _1713 = (int)((shape)->size(0));
  if (((_1713 != (int)((_1710)->size(0))) || (_1713 != (int)((_1711)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _7467 = (int)0;
  int _7468 = _1713;
  for (int _1714 = _7467; _1714 < _7468; ++_1714)
  {
    {
      if (((_ptr__1710[_1714] < (int)0) || (_ptr__1710[_1714] >= ((*shape)(_1714)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1715 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1713)));
  _checked_ptr_1<long long> _ptr__1715(_1715 ? _1715->raw() : nullptr,_1715 ? _1715->size(0) : 0);
  _ptr__1715[(_1713 - (int)1)] = (int)1;
  int _7469 = (int)1;
  int _7470 = _1713;
  for (int _1716 = _7469; _1716 < _7470; ++_1716)
  {
    {
      _ptr__1715[((_1713 - _1716) - (int)1)] = safe_mul( _ptr__1715[(_1713 - _1716)],((*shape)((_1713 - _1716))) );
    }
  }
  long long _1717 = (long long)0;
  int _7471 = (int)0;
  int _7472 = (int)((_1711)->size(0));
  for (int _1718 = _7471; _1718 < _7472; ++_1718)
  {
    {
      _1717 += safe_mul( _ptr__1710[_1718],_ptr__1715[_1718] );
    }
  }
  long long _1719 = (long long)0;
  int _7473 = (int)0;
  int _7474 = (int)((_1711)->size(0));
  for (int _1720 = _7473; _1720 < _7474; ++_1720)
  {
    {
      _1719 += safe_mul( _ptr__1711[_1720],_ptr__1715[_1720] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1721 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1712)));
      _checked_ptr_1<long long> _ptr__1721(_1721 ? _1721->raw() : nullptr,_1721 ? _1721->size(0) : 0);
      int _7475 = (int)0;
      int _7476 = _1712;
      for (int _1722 = _7475; _1722 < _7476; ++_1722)
      {
        {
          _ptr__1721[_1722] = ((*nativeidxs)(safe_add( _1717,safe_mul( _1719,_1722 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1712)}),nullptr,_1721)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1723 = (int)0;
      int _7477 = (int)0;
      int _7478 = _1712;
      for (int _1724 = _7477; _1724 < _7478; ++_1724)
      {
        {
          long long _1725 = safe_add( _1717,safe_mul( _1719,_1724 ) );
          int _1726 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1725);
          if ((_1726 >= (int)0))
          {
            {
              ++ _1723;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1727 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1723)));
      _checked_ptr_1<long long> _ptr__1727(_1727 ? _1727->raw() : nullptr,_1727 ? _1727->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1728 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1723)));
      _checked_ptr_1<long long> _ptr__1728(_1728 ? _1728->raw() : nullptr,_1728 ? _1728->size(0) : 0);
      int _1729 = (int)0;
      int _7479 = (int)0;
      int _7480 = _1712;
      for (int _1730 = _7479; _1730 < _7480; ++_1730)
      {
        {
          _ptr__1727[_1730] = ((*nativeidxs)(safe_add( _1717,safe_mul( _1719,_1730 ) )));
          long long _1731 = safe_add( _1717,safe_mul( _1719,_1730 ) );
          int _1732 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_1731);
          if ((_1732 >= (int)0))
          {
            {
              _ptr__1728[_1729] = _1730;
              _ptr__1727[_1729] = ((*nativeidxs)(_1732));
              ++ _1729;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1712)}),_1728,_1727)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1733,std::shared_ptr< monty::ndarray< int,1 > > _1734) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1733,_1734); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1733,std::shared_ptr< monty::ndarray< int,1 > > _1734) { return __mosek_2fusion_2BaseVariable__slice(_1733,_1734); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1733,std::shared_ptr< monty::ndarray< int,1 > > _1734) { return __mosek_2fusion_2BaseVariable__slice(_1733,_1734); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1733,std::shared_ptr< monty::ndarray< int,1 > > _1734){
  _checked_ptr_1<int> _ptr__1733(_1733 ? _1733->raw() : nullptr, _1733 ? _1733->size(0) : 0);
  _checked_ptr_1<int> _ptr__1734(_1734 ? _1734->raw() : nullptr, _1734 ? _1734->size(0) : 0);
  if (((int)((_1733)->size(0)) != (int)((_1734)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_1733)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7481 = (int)0;
      int _7482 = (int)((shape)->size(0));
      for (int _1735 = _7481; _1735 < _7482; ++_1735)
      {
        {
          if (((_ptr__1733[_1735] < (int)0) || (_ptr__1734[_1735] > ((*shape)(_1735)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__1733[_1735] > _ptr__1734[_1735]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _1736 = (int)((shape)->size(0));
      std::vector<int> _7483;
      for (int _1738 = (int)0, _7484 = _1736; _1738 < _7484 ; ++_1738)
      {
        _7483.push_back((_ptr__1734[_1738] - _ptr__1733[_1738]));
      }
      auto _7485 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7483.size()),_7483.begin(),_7483.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _1737 = _7485;
      _checked_ptr_1<int> _ptr__1737(_1737 ? _1737->raw() : nullptr,_1737 ? _1737->size(0) : 0);
      int _1739 = (int)1;
      int _7486 = (int)0;
      int _7487 = _1736;
      for (int _1740 = _7486; _1740 < _7487; ++_1740)
      {
        {
          _1739 *= (_ptr__1734[_1740] - _ptr__1733[_1740]);
        }
      }
      if ((_1739 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _1741 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _1742 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1736)));
          _checked_ptr_1<int> _ptr__1742(_1742 ? _1742->raw() : nullptr,_1742 ? _1742->size(0) : 0);
          int _7488 = (int)0;
          int _7489 = (int)((sparsity)->size(0));
          for (int _1743 = _7488; _1743 < _7489; ++_1743)
          {
            {
              long long _1744 = ((*sparsity)(_1743));
              int _7490 = (int)1;
              int _7491 = _1736;
              for (int _1745 = _7490; _1745 < _7491; ++_1745)
              {
                {
                  _ptr__1742[(_1736 - _1745)] = (int)(_1744 % ((*shape)((_1736 - _1745))));
                  _1744 /= ((*shape)((_1736 - _1745)));
                }
              }
              _ptr__1742[(int)0] = (int)_1744;
              int _1746 = (int)0;
              while ( ((_ptr__1742[_1746] >= _ptr__1733[_1746]) && (_ptr__1742[_1746] < _ptr__1734[_1746])) )
              {
                {
                  ++ _1746;
                }
              }
              if ((_1746 == _1736))
              {
                {
                  ++ _1741;
                }
              }
              {}
            }
          }
          int _1747 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _1748 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1741)));
          _checked_ptr_1<long long> _ptr__1748(_1748 ? _1748->raw() : nullptr,_1748 ? _1748->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1749 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1741)));
          _checked_ptr_1<long long> _ptr__1749(_1749 ? _1749->raw() : nullptr,_1749 ? _1749->size(0) : 0);
          int _7492 = (int)0;
          int _7493 = (int)((sparsity)->size(0));
          for (int _1750 = _7492; _1750 < _7493; ++_1750)
          {
            {
              long long _1751 = ((*sparsity)(_1750));
              int _7494 = (int)1;
              int _7495 = _1736;
              for (int _1752 = _7494; _1752 < _7495; ++_1752)
              {
                {
                  _ptr__1742[(_1736 - _1752)] = (int)(_1751 % ((*shape)((_1736 - _1752))));
                  _1751 /= ((*shape)((_1736 - _1752)));
                }
              }
              _ptr__1742[(int)0] = (int)_1751;
              int _1753 = (int)0;
              while ( ((_ptr__1742[_1753] >= _ptr__1733[_1753]) && (_ptr__1742[_1753] < _ptr__1734[_1753])) )
              {
                {
                  ++ _1753;
                }
              }
              if ((_1753 == _1736))
              {
                {
                  _ptr__1748[_1747] = ((*nativeidxs)(_1750));
                  int _1754 = (int)0;
                  int _7496 = (int)0;
                  int _7497 = _1736;
                  for (int _1755 = _7496; _1755 < _7497; ++_1755)
                  {
                    {
                      _1754 = safe_add( safe_mul( _1754,_ptr__1737[_1755] ),(_ptr__1742[_1755] - _ptr__1733[_1755]) );
                    }
                  }
                  _ptr__1749[_1747] = _1754;
                  ++ _1747;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1737,_1749,_1748)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1756 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1739)));
          _checked_ptr_1<long long> _ptr__1756(_1756 ? _1756->raw() : nullptr,_1756 ? _1756->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _1757 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1736)));
            _checked_ptr_1<int> _ptr__1757(_1757 ? _1757->raw() : nullptr,_1757 ? _1757->size(0) : 0);
            _ptr__1757[(_1736 - (int)1)] = (int)1;
            int _7498 = (int)1;
            int _7499 = _1736;
            for (int _1758 = _7498; _1758 < _7499; ++_1758)
            {
              {
                _ptr__1757[((_1736 - _1758) - (int)1)] = safe_mul( _ptr__1757[(_1736 - _1758)],((*shape)((_1736 - _1758))) );
              }
            }
            int _1759 = (int)0;
            int _7500 = (int)0;
            int _7501 = _1736;
            for (int _1760 = _7500; _1760 < _7501; ++_1760)
            {
              {
                _1759 += safe_mul( _ptr__1733[_1760],_ptr__1757[_1760] );
              }
            }
            std::vector<int> _7502;
            for (int _1762 = (int)0, _7503 = _1736; _1762 < _7503 ; ++_1762)
            {
              _7502.push_back(_1759);
            }
            auto _7504 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7502.size()),_7502.begin(),_7502.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1761 = _7504;
            _checked_ptr_1<int> _ptr__1761(_1761 ? _1761->raw() : nullptr,_1761 ? _1761->size(0) : 0);
            std::vector<int> _7505;
            for (int _1764 = (int)0, _7506 = _1736; _1764 < _7506 ; ++_1764)
            {
              _7505.push_back(_ptr__1733[_1764]);
            }
            auto _7507 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7505.size()),_7505.begin(),_7505.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _1763 = _7507;
            _checked_ptr_1<int> _ptr__1763(_1763 ? _1763->raw() : nullptr,_1763 ? _1763->size(0) : 0);
            int _7508 = (int)0;
            int _7509 = _1739;
            for (int _1765 = _7508; _1765 < _7509; ++_1765)
            {
              {
                _ptr__1756[_1765] = ((*nativeidxs)(_ptr__1761[(_1736 - (int)1)]));
                _ptr__1763[(_1736 - (int)1)] += (int)1;
                _ptr__1761[(_1736 - (int)1)] += _ptr__1757[(_1736 - (int)1)];
                if ((_ptr__1763[(_1736 - (int)1)] >= _ptr__1734[(_1736 - (int)1)]))
                {
                  {
                    int _1766 = (_1736 - (int)1);
                    while ( ((_1766 > (int)0) && (_ptr__1763[_1766] >= _ptr__1734[_1766])) )
                    {
                      {
                        _ptr__1763[_1766] = _ptr__1733[_1766];
                        _ptr__1763[(_1766 - (int)1)] += (int)1;
                        _ptr__1761[(_1766 - (int)1)] += _ptr__1757[(_1766 - (int)1)];
                        -- _1766;
                      }
                    }
                    int _7510 = safe_add( _1766,(int)1 );
                    int _7511 = _1736;
                    for (int _1767 = _7510; _1767 < _7511; ++_1767)
                    {
                      {
                        _ptr__1761[_1767] = _ptr__1761[_1766];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1737,nullptr,_1756)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _1768,int _1769) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_1768,_1769); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _1768,int _1769) { return __mosek_2fusion_2BaseVariable__slice(_1768,_1769); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _1768,int _1769) { return __mosek_2fusion_2BaseVariable__slice(_1768,_1769); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _1768,int _1769){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_1768 == (int)0) && (_1769 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_1768 < (int)0) || (_1769 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_1768 > _1769))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_1768 == _1769))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _1770 = (_1769 - _1768);
      int _1771 = (int)0;
      int _1772 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1768));
      int _1773 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_1769));
      std::vector<long long> _7512;
      for (int _1774 = _1772, _7513 = _1773; _1774 < _7513 ; ++_1774)
      {
        _7512.push_back((((*sparsity)(_1774)) - _1768));
      }
      auto _7514 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7512.size()),_7512.begin(),_7512.end()));
      std::vector<long long> _7515;
      for (int _1775 = _1772, _7516 = _1773; _1775 < _7516 ; ++_1775)
      {
        _7515.push_back(((*nativeidxs)(_1775)));
      }
      auto _7517 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7515.size()),_7515.begin(),_7515.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1770)}),_7514,_7517)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1776 = (_1769 - _1768);
      std::shared_ptr< monty::ndarray< long long,1 > > _1777 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1776)));
      _checked_ptr_1<long long> _ptr__1777(_1777 ? _1777->raw() : nullptr,_1777 ? _1777->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_1768,_1777,(int)0,_1776);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1776)}),nullptr,_1777)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _1778,std::shared_ptr< monty::ndarray< long long,1 > > _1779,int _1780,std::shared_ptr< monty::ndarray< long long,1 > > _1781) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1778,_1779,_1780,_1781); }int mosek::fusion::p_BaseVariable::inst(int _1778,std::shared_ptr< monty::ndarray< long long,1 > > _1779,int _1780,std::shared_ptr< monty::ndarray< long long,1 > > _1781){
  _checked_ptr_1<long long> _ptr__1779(_1779 ? _1779->raw() : nullptr, _1779 ? _1779->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1781(_1781 ? _1781->raw() : nullptr, _1781 ? _1781->size(0) : 0);
  if ((NULL == mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity.get()))
  {
    {
      int _7518 = (int)0;
      int _7519 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
      for (int _1782 = _7518; _1782 < _7519; ++_1782)
      {
        {
          _ptr__1779[safe_add( _1782,_1778 )] = _1782;
          _ptr__1781[safe_add( _1782,_1780 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1782));
        }
      }
    }
  }
  else
  {
    {
      int _7520 = (int)0;
      int _7521 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _1783 = _7520; _1783 < _7521; ++_1783)
      {
        {
          _ptr__1779[safe_add( _1778,_1783 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)(_1783));
          _ptr__1781[safe_add( _1783,_1780 )] = ((*mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)(_1783));
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _1784,std::shared_ptr< monty::ndarray< long long,1 > > _1785) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_1784,_1785); }void mosek::fusion::p_BaseVariable::inst(int _1784,std::shared_ptr< monty::ndarray< long long,1 > > _1785){
  _checked_ptr_1<long long> _ptr__1785(_1785 ? _1785->raw() : nullptr, _1785 ? _1785->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _7522 = (int)0;
      int _7523 = (int)((nativeidxs)->size(0));
      for (int _1786 = _7522; _1786 < _7523; ++_1786)
      {
        {
          _ptr__1785[safe_add( _1784,_1786 )] = ((*nativeidxs)(_1786));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1787 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__1787(_1787 ? _1787->raw() : nullptr,_1787 ? _1787->size(0) : 0);
      int _1788 = (int)1;
      int _7524 = (int)0;
      int _7525 = (int)((_1787)->size(0));
      for (int _1789 = _7524; _1789 < _7525; ++_1789)
      {
        {
          _1788 *= _ptr__1787[_1789];
        }
      }
      int _7526 = (int)0;
      int _7527 = _1788;
      for (int _1790 = _7526; _1790 < _7527; ++_1790)
      {
        {
          _ptr__1785[safe_add( _1784,_1790 )] = (int)0;
        }
      }
      int _7528 = (int)0;
      int _7529 = (int)((sparsity)->size(0));
      for (int _1791 = _7528; _1791 < _7529; ++_1791)
      {
        {
          _ptr__1785[safe_add( _1784,((*sparsity)(_1791)) )] = ((*nativeidxs)(_1791));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1792,bool _1793) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_1792,_1793); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1792,bool _1793){
  _checked_ptr_1<double> _ptr__1792(_1792 ? _1792->raw() : nullptr, _1792 ? _1792->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1793,nativeidxs,_1792);
    }
  }
  else
  {
    {
      int _1794 = (int)1;
      int _7530 = (int)0;
      int _7531 = (int)((shape)->size(0));
      for (int _1795 = _7530; _1795 < _7531; ++_1795)
      {
        {
          _1794 *= ((*shape)(_1795));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1796 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1794)));
      _checked_ptr_1<long long> _ptr__1796(_1796 ? _1796->raw() : nullptr,_1796 ? _1796->size(0) : 0);
      int _7532 = (int)0;
      int _7533 = (int)((nativeidxs)->size(0));
      for (int _1797 = _7532; _1797 < _7533; ++_1797)
      {
        {
          _ptr__1796[((*sparsity)(_1797))] = ((*nativeidxs)(_1797));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_1793,_1796,_1792);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _1798,std::shared_ptr< monty::ndarray< double,1 > > _1799,bool _1800){
  _checked_ptr_1<double> _ptr__1799(_1799 ? _1799->raw() : nullptr, _1799 ? _1799->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_1800,nativeidxs,_1799,_1798);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1801 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1801(_1801 ? _1801->raw() : nullptr,_1801 ? _1801->size(0) : 0);
      int _7534 = (int)0;
      int _7535 = (int)((sparsity)->size(0));
      for (int _1802 = _7534; _1802 < _7535; ++_1802)
      {
        {
          _ptr__1801[((*sparsity)(_1802))] = ((*nativeidxs)(_1802));
        }
      }
      model->getVariableDuals(_1800,_1801,_1799,_1798);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _1803,std::shared_ptr< monty::ndarray< double,1 > > _1804,bool _1805) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_1803,_1804,_1805); }void mosek::fusion::p_BaseVariable::values(int _1803,std::shared_ptr< monty::ndarray< double,1 > > _1804,bool _1805){
  _checked_ptr_1<double> _ptr__1804(_1804 ? _1804->raw() : nullptr, _1804 ? _1804->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_1805,nativeidxs,_1804,_1803);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1806 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__1806(_1806 ? _1806->raw() : nullptr,_1806 ? _1806->size(0) : 0);
      int _7536 = (int)0;
      int _7537 = (int)((sparsity)->size(0));
      for (int _1807 = _7536; _1807 < _7537; ++_1807)
      {
        {
          _ptr__1806[((*sparsity)(_1807))] = ((*nativeidxs)(_1807));
        }
      }
      model->getVariableValues(_1805,_1806,_1804,_1803);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _1815) { return __mosek_2fusion_2Variable__reshape(_1815); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1821,std::shared_ptr< monty::ndarray< int,1 > > _1822,std::shared_ptr< monty::ndarray< int,1 > > _1823) { return __mosek_2fusion_2Variable__pick(_1821,_1822,_1823); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1824,std::shared_ptr< monty::ndarray< int,1 > > _1825) { return __mosek_2fusion_2Variable__pick(_1824,_1825); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _1826) { return __mosek_2fusion_2Variable__pick(_1826); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1826) { return __mosek_2fusion_2Variable__pick(_1826); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _1827) { return __mosek_2fusion_2Variable__pick(_1827); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1827) { return __mosek_2fusion_2Variable__pick(_1827); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _1828) { return __mosek_2fusion_2Variable__antidiag(_1828); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _1829) { return __mosek_2fusion_2Variable__diag(_1829); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _1830) { return __mosek_2fusion_2Variable__index(_1830); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _1830) { return __mosek_2fusion_2Variable__index(_1830); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1831,int _1832,int _1833) { return __mosek_2fusion_2Variable__index(_1831,_1832,_1833); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1834,int _1835) { return __mosek_2fusion_2Variable__index(_1834,_1835); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _1836) { return __mosek_2fusion_2Variable__index(_1836); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _1836) { return __mosek_2fusion_2Variable__index(_1836); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _1837,std::shared_ptr< monty::ndarray< int,1 > > _1838) { return __mosek_2fusion_2Variable__slice(_1837,_1838); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1837,std::shared_ptr< monty::ndarray< int,1 > > _1838) { return __mosek_2fusion_2Variable__slice(_1837,_1838); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _1839,int _1840) { return __mosek_2fusion_2Variable__slice(_1839,_1840); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _1839,int _1840) { return __mosek_2fusion_2Variable__slice(_1839,_1840); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _1841) { return mosek::fusion::p_Var::empty(_1841); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _1841){
  _checked_ptr_1<int> _ptr__1841(_1841 ? _1841->raw() : nullptr, _1841 ? _1841->size(0) : 0);
  int _7538 = (int)0;
  int _7539 = (int)((_1841)->size(0));
  for (int _1842 = _7538; _1842 < _7539; ++_1842)
  {
    {
      if ((_ptr__1841[_1842] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_1841)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _1843) { return mosek::fusion::p_Var::compress(_1843); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _1843){
  std::shared_ptr< monty::ndarray< int,1 > > _1844 = _1843->getShape();
  _checked_ptr_1<int> _ptr__1844(_1844 ? _1844->raw() : nullptr,_1844 ? _1844->size(0) : 0);
  int _1845 = (int)((_1844)->size(0));
  int _1846 = (int)0;
  int _7540 = (int)0;
  int _7541 = _1845;
  for (int _1847 = _7540; _1847 < _7541; ++_1847)
  {
    {
      if ((_ptr__1844[_1847] != (int)1))
      {
        {
          ++ _1846;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1848 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1846)));
  _checked_ptr_1<int> _ptr__1848(_1848 ? _1848->raw() : nullptr,_1848 ? _1848->size(0) : 0);
  {
    int _1849 = (int)0;
    int _7542 = (int)0;
    int _7543 = _1845;
    for (int _1850 = _7542; _1850 < _7543; ++_1850)
    {
      {
        if ((_ptr__1844[_1850] != (int)1))
        {
          {
            _ptr__1848[_1849] = _ptr__1844[_1850];
            ++ _1849;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_1843,_1848);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1851,    int _1852) { return mosek::fusion::p_Var::reshape(_1851,_1852); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1851,int _1852){
  return ::mosek::fusion::p_Var::reshape(_1851,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1852)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1853,    int _1854,    int _1855) { return mosek::fusion::p_Var::reshape(_1853,_1854,_1855); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1853,int _1854,int _1855){
  return ::mosek::fusion::p_Var::reshape(_1853,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1854),(int)(_1855)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _1856) { return mosek::fusion::p_Var::flatten(_1856); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1856){
  return ::mosek::fusion::p_Var::reshape(_1856,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_1856->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _1857,    std::shared_ptr< monty::ndarray< int,1 > > _1858) { return mosek::fusion::p_Var::reshape(_1857,_1858); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1857,std::shared_ptr< monty::ndarray< int,1 > > _1858){
  _checked_ptr_1<int> _ptr__1858(_1858 ? _1858->raw() : nullptr, _1858 ? _1858->size(0) : 0);
  return _1857->__mosek_2fusion_2Variable__reshape(_1858);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1859,std::shared_ptr< monty::ndarray< int,1 > > _1860){
  _checked_ptr_1<int> _ptr__1860(_1860 ? _1860->raw() : nullptr, _1860 ? _1860->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1861;
  _checked_ptr_1<long long> _ptr__1861(_1861 ? _1861->raw() : nullptr,_1861 ? _1861->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1862;
  _checked_ptr_1<long long> _ptr__1862(_1862 ? _1862->raw() : nullptr,_1862 ? _1862->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1863 = _1859->getShape();
  _checked_ptr_1<int> _ptr__1863(_1863 ? _1863->raw() : nullptr,_1863 ? _1863->size(0) : 0);
  int _1864 = (int)((_1863)->size(0));
  int _1865 = (int)1;
  int _7544 = (int)0;
  int _7545 = _1864;
  for (int _1866 = _7544; _1866 < _7545; ++_1866)
  {
    {
      _1865 *= _ptr__1863[_1866];
    }
  }
  int _1867 = _1859->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1868 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1864)));
  _checked_ptr_1<long long> _ptr__1868(_1868 ? _1868->raw() : nullptr,_1868 ? _1868->size(0) : 0);
  _ptr__1868[(_1864 - (int)1)] = (int)1;
  int _7546 = (int)1;
  int _7547 = _1864;
  for (int _1869 = _7546; _1869 < _7547; ++_1869)
  {
    {
      _ptr__1868[((_1864 - _1869) - (int)1)] = safe_mul( _ptr__1868[(_1864 - _1869)],_ptr__1863[_ptr__1860[(_1864 - _1869)]] );
    }
  }
  if ((_1867 < _1865))
  {
    {
      _1861 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1867)));
      _ptr__1861.update(_1861 ? _1861->raw() : nullptr, _1861 ? _1861->size(0) : 0);
      _1862 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1867)));
      _ptr__1862.update(_1862 ? _1862->raw() : nullptr, _1862 ? _1862->size(0) : 0);
      _1859->inst((int)0,_1861,(int)0,_1862);
    }
  }
  else
  {
    {
      _1861 = nullptr;
      _ptr__1861.update(_1861 ? _1861->raw() : nullptr, _1861 ? _1861->size(0) : 0);
      _1862 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1867)));
      _ptr__1862.update(_1862 ? _1862->raw() : nullptr, _1862 ? _1862->size(0) : 0);
      _1859->inst((int)0,_1862);
    }
  }
  if ((NULL == _1861.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1870 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1867)));
      _checked_ptr_1<long long> _ptr__1870(_1870 ? _1870->raw() : nullptr,_1870 ? _1870->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1871 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1864)));
        _checked_ptr_1<int> _ptr__1871(_1871 ? _1871->raw() : nullptr,_1871 ? _1871->size(0) : 0);
        int _7548 = (int)0;
        int _7549 = _1867;
        for (int _1872 = _7548; _1872 < _7549; ++_1872)
        {
          {
            int _1873 = _1872;
            int _7550 = (int)0;
            int _7551 = _1864;
            for (int _1874 = _7550; _1874 < _7551; ++_1874)
            {
              {
                _ptr__1871[((_1864 - _1872) - (int)1)] = (_1873 % _ptr__1863[((_1864 - _1872) - (int)1)]);
                _1873 /= _ptr__1863[((_1864 - _1872) - (int)1)];
              }
            }
            int _1875 = (int)0;
            int _7552 = (int)0;
            int _7553 = _1864;
            for (int _1876 = _7552; _1876 < _7553; ++_1876)
            {
              {
                _1875 += (int)safe_mul( _ptr__1871[_ptr__1860[_1876]],_ptr__1868[_1876] );
              }
            }
            _ptr__1870[_1875] = _ptr__1862[_1872];
          }
        }
      }
      _1862 = _1870;
      _ptr__1862.update(_1862 ? _1862->raw() : nullptr, _1862 ? _1862->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1877 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1867)));
      _checked_ptr_1<long long> _ptr__1877(_1877 ? _1877->raw() : nullptr,_1877 ? _1877->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1878 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1864)));
        _checked_ptr_1<int> _ptr__1878(_1878 ? _1878->raw() : nullptr,_1878 ? _1878->size(0) : 0);
        int _7554 = (int)0;
        int _7555 = _1867;
        for (int _1879 = _7554; _1879 < _7555; ++_1879)
        {
          {
            int _1880 = _1879;
            int _7556 = (int)0;
            int _7557 = _1864;
            for (int _1881 = _7556; _1881 < _7557; ++_1881)
            {
              {
                _ptr__1878[((_1864 - _1879) - (int)1)] = (_1880 % _ptr__1863[((_1864 - _1879) - (int)1)]);
                _1880 /= _ptr__1863[((_1864 - _1879) - (int)1)];
              }
            }
            int _1882 = (int)0;
            int _7558 = (int)0;
            int _7559 = _1864;
            for (int _1883 = _7558; _1883 < _7559; ++_1883)
            {
              {
                _1882 += (int)safe_mul( _ptr__1878[_ptr__1860[_1883]],_ptr__1868[_1883] );
              }
            }
            _ptr__1877[_1879] = _1882;
          }
        }
      }
      std::vector<long long> _7560;
      for (int _1885 = (int)0, _7561 = _1867; _1885 < _7561 ; ++_1885)
      {
        _7560.push_back(_1885);
      }
      auto _7562 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7560.size()),_7560.begin(),_7560.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1884 = _7562;
      _checked_ptr_1<long long> _ptr__1884(_1884 ? _1884->raw() : nullptr,_1884 ? _1884->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1884,_1877,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1867));
      std::vector<long long> _7563;
      for (int _1886 = (int)0, _7564 = _1867; _1886 < _7564 ; ++_1886)
      {
        _7563.push_back(_ptr__1861[_ptr__1884[_1886]]);
      }
      auto _7565 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7563.size()),_7563.begin(),_7563.end()));
      _1861 = _7565;
      _ptr__1861.update(_1861 ? _1861->raw() : nullptr, _1861 ? _1861->size(0) : 0);
      std::vector<long long> _7566;
      for (int _1887 = (int)0, _7567 = _1867; _1887 < _7567 ; ++_1887)
      {
        _7566.push_back(_ptr__1862[_ptr__1884[_1887]]);
      }
      auto _7568 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7566.size()),_7566.begin(),_7566.end()));
      _1862 = _7568;
      _ptr__1862.update(_1862 ? _1862->raw() : nullptr, _1862 ? _1862->size(0) : 0);
    }
  }
  std::vector<int> _7569;
  for (int _1888 = (int)0, _7570 = _1864; _1888 < _7570 ; ++_1888)
  {
    _7569.push_back(_ptr__1863[_ptr__1860[_1888]]);
  }
  auto _7571 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7569.size()),_7569.begin(),_7569.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1859->__mosek_2fusion_2Variable__getModel(),_7571,_1861,_1862)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1889,    int _1890) { return mosek::fusion::p_Var::hrepeat(_1889,_1890); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1889,int _1890){
  return ::mosek::fusion::p_Var::drepeat(_1889,(int)1,_1890);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1891,    int _1892) { return mosek::fusion::p_Var::vrepeat(_1891,_1892); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1891,int _1892){
  return ::mosek::fusion::p_Var::drepeat(_1891,(int)0,_1892);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1893,    int _1894) { return mosek::fusion::p_Var::repeat(_1893,_1894); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1893,int _1894){
  return ::mosek::fusion::p_Var::drepeat(_1893,(int)0,_1894);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _1895,    int _1896,    int _1897) { return mosek::fusion::p_Var::repeat(_1895,_1896,_1897); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1895,int _1896,int _1897){
  return ::mosek::fusion::p_Var::drepeat(_1895,_1896,_1897);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1898,int _1899,int _1900){
  if ((_1900 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_1900 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_1900 == (int)1))
  {
    {
      return _1898;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _1901 = _1898->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _1902 = _1898->getShape();
      _checked_ptr_1<int> _ptr__1902(_1902 ? _1902->raw() : nullptr,_1902 ? _1902->size(0) : 0);
      int _1903 = (int)((_1902)->size(0));
      if (((_1899 < (int)0) || (_1899 > _1903)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _1904 = ::mosek::fusion::p_Set::size(_1902);
      int _1905 = _1898->numInst();
      int _1906 = safe_mul( _1905,_1900 );
      int _1907 = (int)1;
      int _7572 = (int)0;
      int _7573 = _1899;
      for (int _1908 = _7572; _1908 < _7573; ++_1908)
      {
        {
          _1907 *= _ptr__1902[_1908];
        }
      }
      int _7574;
      bool _7575 = (_1899 < _1903);
      if (_7575)
      {
        _7574 = _ptr__1902[_1899];
      }
      else
      {
        _7574 = (int)1;
      }
      int _1909 = _7574;
      int _1910 = safe_mul( _1909,_1900 );
      int _1911 = (int)1;
      int _7576 = safe_add( _1899,(int)1 );
      int _7577 = _1903;
      for (int _1912 = _7576; _1912 < _7577; ++_1912)
      {
        {
          _1911 *= _ptr__1902[_1912];
        }
      }
      int _7578;
      bool _7579 = (_1899 < _1903);
      if (_7579)
      {
        _7578 = _1903;
      }
      else
      {
        _7578 = safe_add( _1899,(int)1 );
      }
      int _1913 = _7578;
      std::shared_ptr< monty::ndarray< int,1 > > _1914 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1913)));
      _checked_ptr_1<int> _ptr__1914(_1914 ? _1914->raw() : nullptr,_1914 ? _1914->size(0) : 0);
      int _7580 = (int)0;
      int _7581 = _1903;
      for (int _1915 = _7580; _1915 < _7581; ++_1915)
      {
        {
          _ptr__1914[_1915] = _ptr__1902[_1915];
        }
      }
      int _7582 = _1903;
      int _7583 = _1913;
      for (int _1916 = _7582; _1916 < _7583; ++_1916)
      {
        {
          _ptr__1914[_1916] = (int)1;
        }
      }
      _ptr__1914[_1899] = _1910;
      if ((_1905 < _1904))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1917 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1905)));
          _checked_ptr_1<long long> _ptr__1917(_1917 ? _1917->raw() : nullptr,_1917 ? _1917->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1918 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1905)));
          _checked_ptr_1<long long> _ptr__1918(_1918 ? _1918->raw() : nullptr,_1918 ? _1918->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1919 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1906)));
          _checked_ptr_1<long long> _ptr__1919(_1919 ? _1919->raw() : nullptr,_1919 ? _1919->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1920 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1906)));
          _checked_ptr_1<long long> _ptr__1920(_1920 ? _1920->raw() : nullptr,_1920 ? _1920->size(0) : 0);
          _1898->inst((int)0,_1918,(int)0,_1917);
          {
            int _1921 = safe_mul( _1910,_1911 );
            int _1922 = safe_mul( _1909,_1911 );
            int _1923 = _1911;
            if ((_1899 == (int)0))
            {
              {
                int _1924 = (int)0;
                int _7584 = (int)0;
                int _7585 = _1900;
                for (int _1925 = _7584; _1925 < _7585; ++_1925)
                {
                  {
                    int _7586 = (int)0;
                    int _7587 = _1905;
                    for (int _1926 = _7586; _1926 < _7587; ++_1926)
                    {
                      {
                        _ptr__1920[_1924] = safe_add( _ptr__1918[_1926],safe_mul( _1925,_1904 ) );
                        _ptr__1919[_1924] = _ptr__1917[_1926];
                        ++ _1924;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1901,_1914,_1920,_1919)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_1899 >= _1903))
            {
              {
                int _1927 = (int)0;
                int _7588 = (int)0;
                int _7589 = _1905;
                for (int _1928 = _7588; _1928 < _7589; ++_1928)
                {
                  {
                    int _7590 = (int)0;
                    int _7591 = _1900;
                    for (int _1929 = _7590; _1929 < _7591; ++_1929)
                    {
                      {
                        _ptr__1920[_1927] = safe_add( safe_mul( _ptr__1918[_1928],_1900 ),_1929 );
                        _ptr__1919[_1927] = _ptr__1917[_1928];
                        ++ _1927;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1901,_1914,_1920,_1919)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _1930 = (int)0;
                int _7592 = (int)0;
                int _7593 = _1905;
                for (int _1931 = _7592; _1931 < _7593; ++_1931)
                {
                  {
                    long long _1932 = (_ptr__1918[_1931] / _1922);
                    long long _1933 = ((_ptr__1918[_1931] / _1923) % _1909);
                    long long _1934 = (_ptr__1918[_1931] % _1911);
                    int _7594 = (int)0;
                    int _7595 = _1900;
                    for (int _1935 = _7594; _1935 < _7595; ++_1935)
                    {
                      {
                        _ptr__1920[_1930] = safe_add( safe_add( safe_mul( _1932,_1921 ),safe_mul( safe_add( _1933,safe_mul( _1909,_1935 ) ),_1911 ) ),_1934 );
                        _ptr__1919[_1930] = _ptr__1917[_1931];
                        ++ _1930;
                      }
                    }
                  }
                }
                int _1936 = (int)1;
                int _7596 = (int)0;
                int _7597 = _1913;
                for (int _1937 = _7596; _1937 < _7597; ++_1937)
                {
                  {
                    if ((_1936 < _ptr__1914[_1937]))
                    {
                      {
                        _1936 = _ptr__1914[_1937];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _1938 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1906)));
                _checked_ptr_1<int> _ptr__1938(_1938 ? _1938->raw() : nullptr,_1938 ? _1938->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _1939 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1906)));
                _checked_ptr_1<int> _ptr__1939(_1939 ? _1939->raw() : nullptr,_1939 ? _1939->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _1940 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1936,(int)1 ))));
                  _checked_ptr_1<int> _ptr__1940(_1940 ? _1940->raw() : nullptr,_1940 ? _1940->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _1941 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1913)));
                  _checked_ptr_1<long long> _ptr__1941(_1941 ? _1941->raw() : nullptr,_1941 ? _1941->size(0) : 0);
                  _ptr__1941[(_1913 - (int)1)] = (int)1;
                  int _7598 = (int)1;
                  int _7599 = _1913;
                  for (int _1942 = _7598; _1942 < _7599; ++_1942)
                  {
                    {
                      _ptr__1941[((_1913 - _1942) - (int)1)] = safe_mul( _ptr__1941[(_1913 - _1942)],_ptr__1914[(_1913 - _1942)] );
                    }
                  }
                  int _7600 = (int)0;
                  int _7601 = _1906;
                  for (int _1943 = _7600; _1943 < _7601; ++_1943)
                  {
                    {
                      _ptr__1938[_1943] = _1943;
                    }
                  }
                  int _7602 = (int)0;
                  int _7603 = _1913;
                  for (int _1944 = _7602; _1944 < _7603; ++_1944)
                  {
                    {
                      int _1945 = ((_1913 - _1944) - (int)1);
                      int _7604 = (int)0;
                      int _7605 = safe_add( _ptr__1914[_1945],(int)1 );
                      for (int _1946 = _7604; _1946 < _7605; ++_1946)
                      {
                        {
                          _ptr__1940[_1946] = (int)0;
                        }
                      }
                      int _7606 = (int)0;
                      int _7607 = _1906;
                      for (int _1947 = _7606; _1947 < _7607; ++_1947)
                      {
                        {
                          ++ _ptr__1940[safe_add( ((_ptr__1920[_1947] / _ptr__1941[_1945]) % _ptr__1914[_1945]),(int)1 )];
                        }
                      }
                      int _7608 = (int)0;
                      int _7609 = _ptr__1914[_1945];
                      for (int _1948 = _7608; _1948 < _7609; ++_1948)
                      {
                        {
                          _ptr__1940[safe_add( _1948,(int)1 )] += _ptr__1940[_1948];
                        }
                      }
                      int _7610 = (int)0;
                      int _7611 = _1906;
                      for (int _1949 = _7610; _1949 < _7611; ++_1949)
                      {
                        {
                          int _1950 = _ptr__1938[_1949];
                          long long _1951 = ((_ptr__1920[_1950] / _ptr__1941[_1945]) % _ptr__1914[_1945]);
                          _ptr__1939[_ptr__1940[_1951]] = _1950;
                          ++ _ptr__1940[_1951];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _1952 = _1938;
                      _checked_ptr_1<int> _ptr__1952(_1952 ? _1952->raw() : nullptr,_1952 ? _1952->size(0) : 0);
                      _1938 = _1939;
                      _ptr__1938.update(_1938 ? _1938->raw() : nullptr, _1938 ? _1938->size(0) : 0);
                      _1939 = _1952;
                      _ptr__1939.update(_1939 ? _1939->raw() : nullptr, _1939 ? _1939->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _7612;
                for (int _1953 = (int)0, _7613 = _1906; _1953 < _7613 ; ++_1953)
                {
                  _7612.push_back(_ptr__1920[_ptr__1938[_1953]]);
                }
                auto _7614 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7612.size()),_7612.begin(),_7612.end()));
                std::vector<long long> _7615;
                for (int _1954 = (int)0, _7616 = _1906; _1954 < _7616 ; ++_1954)
                {
                  _7615.push_back(_ptr__1919[_ptr__1938[_1954]]);
                }
                auto _7617 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7615.size()),_7615.begin(),_7615.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1901,_1914,_7614,_7617)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _1955 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1905)));
          _checked_ptr_1<long long> _ptr__1955(_1955 ? _1955->raw() : nullptr,_1955 ? _1955->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _1956 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1905,_1900 ))));
          _checked_ptr_1<long long> _ptr__1956(_1956 ? _1956->raw() : nullptr,_1956 ? _1956->size(0) : 0);
          _1898->inst((int)0,_1955);
          int _1957 = safe_mul( _1910,_1911 );
          int _1958 = _1911;
          int _1959 = (int)0;
          int _7618 = (int)0;
          int _7619 = _1907;
          for (int _1960 = _7618; _1960 < _7619; ++_1960)
          {
            {
              int _7620 = (int)0;
              int _7621 = _1909;
              for (int _1961 = _7620; _1961 < _7621; ++_1961)
              {
                {
                  int _7622 = (int)0;
                  int _7623 = _1911;
                  for (int _1962 = _7622; _1962 < _7623; ++_1962)
                  {
                    {
                      int _7624 = (int)0;
                      int _7625 = _1900;
                      for (int _1963 = _7624; _1963 < _7625; ++_1963)
                      {
                        {
                          _ptr__1956[safe_add( safe_add( safe_mul( _1960,_1957 ),safe_mul( safe_add( _1961,safe_mul( _1963,_1909 ) ),_1958 ) ),_1962 )] = _ptr__1955[_1959];
                        }
                      }
                      ++ _1959;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1901,_1914,nullptr,_1956)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1964) { return mosek::fusion::p_Var::stack(_1964); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1964){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _7626;
  for (int _1965 = (int)0, _7627 = (int)((_1964)->size(0)); _1965 < _7627 ; ++_1965)
  {
    _7626.push_back(::mosek::fusion::p_Var::dstack(((*_1964)(_1965)),(int)1));
  }
  auto _7628 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_7626.size()),_7626.begin(),_7626.end()));
  return ::mosek::fusion::p_Var::dstack(_7628,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1966,    monty::rc_ptr< ::mosek::fusion::Variable > _1967,    monty::rc_ptr< ::mosek::fusion::Variable > _1968) { return mosek::fusion::p_Var::vstack(_1966,_1967,_1968); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1966,monty::rc_ptr< ::mosek::fusion::Variable > _1967,monty::rc_ptr< ::mosek::fusion::Variable > _1968){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1966.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1967.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1968.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1969,    monty::rc_ptr< ::mosek::fusion::Variable > _1970) { return mosek::fusion::p_Var::vstack(_1969,_1970); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1969,monty::rc_ptr< ::mosek::fusion::Variable > _1970){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1969.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1970.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1971) { return mosek::fusion::p_Var::vstack(_1971); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1971){
  return ::mosek::fusion::p_Var::dstack(_1971,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1972,    monty::rc_ptr< ::mosek::fusion::Variable > _1973,    monty::rc_ptr< ::mosek::fusion::Variable > _1974) { return mosek::fusion::p_Var::hstack(_1972,_1973,_1974); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1972,monty::rc_ptr< ::mosek::fusion::Variable > _1973,monty::rc_ptr< ::mosek::fusion::Variable > _1974){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1972.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1973.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1974.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1975,    monty::rc_ptr< ::mosek::fusion::Variable > _1976) { return mosek::fusion::p_Var::hstack(_1975,_1976); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1975,monty::rc_ptr< ::mosek::fusion::Variable > _1976){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1975.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1976.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1977) { return mosek::fusion::p_Var::hstack(_1977); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1977){
  return ::mosek::fusion::p_Var::dstack(_1977,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1978,    monty::rc_ptr< ::mosek::fusion::Variable > _1979,    monty::rc_ptr< ::mosek::fusion::Variable > _1980,    int _1981) { return mosek::fusion::p_Var::stack(_1978,_1979,_1980,_1981); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1978,monty::rc_ptr< ::mosek::fusion::Variable > _1979,monty::rc_ptr< ::mosek::fusion::Variable > _1980,int _1981){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1978.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1979.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1980.get())}),_1981);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _1982,    monty::rc_ptr< ::mosek::fusion::Variable > _1983,    int _1984) { return mosek::fusion::p_Var::stack(_1982,_1983,_1984); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _1982,monty::rc_ptr< ::mosek::fusion::Variable > _1983,int _1984){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_1982.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_1983.get())}),_1984);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1985,    int _1986) { return mosek::fusion::p_Var::stack(_1985,_1986); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1985,int _1986){
  int _1987 = _1986;
  int _7629 = (int)0;
  int _7630 = (int)((_1985)->size(0));
  for (int _1988 = _7629; _1988 < _7630; ++_1988)
  {
    {
      if ((_1987 < ((*_1985)(_1988))->getND()))
      {
        {
          _1987 = ((*_1985)(_1988))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_1985,_1986);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _1989,    int _1990) { return mosek::fusion::p_Var::promote(_1989,_1990); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _1989,int _1990){
  if ((_1990 > _1989->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1991 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1990)));
      _checked_ptr_1<int> _ptr__1991(_1991 ? _1991->raw() : nullptr,_1991 ? _1991->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1992 = _1989->getShape();
      _checked_ptr_1<int> _ptr__1992(_1992 ? _1992->raw() : nullptr,_1992 ? _1992->size(0) : 0);
      int _7631 = (int)0;
      int _7632 = (int)((_1992)->size(0));
      for (int _1993 = _7631; _1993 < _7632; ++_1993)
      {
        {
          _ptr__1991[_1993] = _ptr__1992[_1993];
        }
      }
      int _7633 = (int)((_1992)->size(0));
      int _7634 = _1990;
      for (int _1994 = _7633; _1994 < _7634; ++_1994)
      {
        {
          _ptr__1991[_1994] = (int)1;
        }
      }
      return _1989->__mosek_2fusion_2Variable__reshape(_1991);
    }
  }
  else
  {
    {
      return _1989;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1995,int _1996){
  if ((_1996 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _1997 = nullptr;
  {
    int _7635 = (int)0;
    int _7636 = (int)((_1995)->size(0));
    for (int _1998 = _7635; _1998 < _7636; ++_1998)
    {
      {
        if ((NULL == _1997.get()))
        {
          {
            _1997 = ((*_1995)(_1998))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_1995)(_1998))->__mosek_2fusion_2Variable__getModel().get()) && (((*_1995)(_1998))->__mosek_2fusion_2Variable__getModel() != _1997)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1999 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7637;
            bool _7638 = ((int)((mosek::fusion::p_Model::_get_impl(_1997.get())->getName()).size()) > (int)0);
            if (_7638)
            {
              _7637 = mosek::fusion::p_Model::_get_impl(_1997.get())->getName();
            }
            else
            {
              _7637 = std::string ("?");
            }
            std::string _2000 = _7637;
            std::string _7639;
            bool _7640 = ((int)((mosek::fusion::p_Model::_get_impl(((*_1995)(_1998))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_7640)
            {
              _7639 = mosek::fusion::p_Model::_get_impl(((*_1995)(_1998))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _7639 = std::string ("?");
            }
            std::string _2001 = _7639;
            _1999->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2000)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2001)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_1999->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_1995)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_1995)->size(0)) == (int)1))
  {
    {
      return ((*_1995)((int)1));
    }
  }
  else
  {
    {
      int _2002 = (int)((_1995)->size(0));
      std::vector<int> _7641;
      for (int _2004 = (int)0, _7642 = _2002; _2004 < _7642 ; ++_2004)
      {
        _7641.push_back(((*_1995)(_2004))->numInst());
      }
      auto _7643 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7641.size()),_7641.begin(),_7641.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2003 = _7643;
      _checked_ptr_1<int> _ptr__2003(_2003 ? _2003->raw() : nullptr,_2003 ? _2003->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7644;
      for (int _2006 = (int)0, _7645 = _2002; _2006 < _7645 ; ++_2006)
      {
        _7644.push_back(((*_1995)(_2006))->getShape());
      }
      auto _7646 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7644.size()),_7644.begin(),_7644.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2005 = _7646;
      std::vector<int> _7647;
      for (int _2008 = (int)0, _7648 = _2002; _2008 < _7648 ; ++_2008)
      {
        _7647.push_back((int)((((*_2005)(_2008)))->size(0)));
      }
      auto _7649 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7647.size()),_7647.begin(),_7647.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2007 = _7649;
      _checked_ptr_1<int> _ptr__2007(_2007 ? _2007->raw() : nullptr,_2007 ? _2007->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2009 = ((*_2005)((int)0));
      _checked_ptr_1<int> _ptr__2009(_2009 ? _2009->raw() : nullptr,_2009 ? _2009->size(0) : 0);
      int _2010 = _ptr__2007[(int)0];
      int _2011 = (int)0;
      int _7650 = (int)0;
      int _7651 = _2002;
      for (int _2012 = _7650; _2012 < _7651; ++_2012)
      {
        {
          _2011 += _ptr__2003[_2012];
        }
      }
      int _2013 = safe_add( _1996,(int)1 );
      int _7652 = (int)0;
      int _7653 = _2002;
      for (int _2014 = _7652; _2014 < _7653; ++_2014)
      {
        {
          if ((_2013 < _ptr__2007[_2014]))
          {
            {
              _2013 = _ptr__2007[_2014];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2015 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2013)));
      _checked_ptr_1<int> _ptr__2015(_2015 ? _2015->raw() : nullptr,_2015 ? _2015->size(0) : 0);
      int _7654 = (int)0;
      int _7655 = _2010;
      for (int _2016 = _7654; _2016 < _7655; ++_2016)
      {
        {
          _ptr__2015[_2016] = _ptr__2009[_2016];
        }
      }
      int _7656 = _2010;
      int _7657 = _2013;
      for (int _2017 = _7656; _2017 < _7657; ++_2017)
      {
        {
          _ptr__2015[_2017] = (int)1;
        }
      }
      _ptr__2015[_1996] = (int)0;
      int _7658 = (int)0;
      int _7659 = _2002;
      for (int _2018 = _7658; _2018 < _7659; ++_2018)
      {
        {
          int _7660;
          bool _7661 = ((int)((((*_2005)(_2018)))->size(0)) > _1996);
          if (_7661)
          {
            _7660 = ((*((*_2005)(_2018)))(_1996));
          }
          else
          {
            _7660 = (int)1;
          }
          _ptr__2015[_1996] += _7660;
        }
      }
      int _7662 = (int)0;
      int _7663 = _2002;
      for (int _2019 = _7662; _2019 < _7663; ++_2019)
      {
        {
          int _7664 = (int)0;
          int _7665 = (int)((((*_2005)(_2019)))->size(0));
          for (int _2020 = _7664; _2020 < _7665; ++_2020)
          {
            {
              if (((_2020 != _1996) && (((*((*_2005)(_2019)))(_2020)) != _ptr__2015[_2020])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _7666 = (int)((((*_2005)(_2019)))->size(0));
          int _7667 = _2013;
          for (int _2021 = _7666; _2021 < _7667; ++_2021)
          {
            {
              if (((_2021 != _1996) && ((int)1 != _ptr__2015[_2021])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2022 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2011)));
      _checked_ptr_1<long long> _ptr__2022(_2022 ? _2022->raw() : nullptr,_2022 ? _2022->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2023 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2011)));
      _checked_ptr_1<long long> _ptr__2023(_2023 ? _2023->raw() : nullptr,_2023 ? _2023->size(0) : 0);
      std::vector<int> _7668;
      for (int _2025 = (int)0, _7669 = (int)((_1995)->size(0)); _2025 < _7669 ; ++_2025)
      {
        int _7670;
        bool _7671 = (_1996 < (int)((((*_2005)(_2025)))->size(0)));
        if (_7671)
        {
          _7670 = ((*((*_2005)(_2025)))(_1996));
        }
        else
        {
          _7670 = (int)1;
        }
        _7668.push_back(_7670);
      }
      auto _7672 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7668.size()),_7668.begin(),_7668.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2024 = _7672;
      _checked_ptr_1<int> _ptr__2024(_2024 ? _2024->raw() : nullptr,_2024 ? _2024->size(0) : 0);
      int _2026 = (int)1;
      int _7673 = (int)0;
      int _7674 = _1996;
      for (int _2027 = _7673; _2027 < _7674; ++_2027)
      {
        {
          int _7675;
          bool _7676 = (_2027 < (int)((_2009)->size(0)));
          if (_7676)
          {
            _7675 = _ptr__2009[_2027];
          }
          else
          {
            _7675 = (int)1;
          }
          _2026 *= _7675;
        }
      }
      int _2028 = (int)0;
      int _7677 = (int)0;
      int _7678 = _2002;
      for (int _2029 = _7677; _2029 < _7678; ++_2029)
      {
        {
          _2028 += _ptr__2024[_2029];
        }
      }
      int _2030 = (int)1;
      int _7679 = safe_add( _1996,(int)1 );
      int _7680 = (int)((_2009)->size(0));
      for (int _2031 = _7679; _2031 < _7680; ++_2031)
      {
        {
          _2030 *= _ptr__2009[_2031];
        }
      }
      if ((_2026 == (int)1))
      {
        {
          int _2032 = (int)0;
          long long _2033 = (int)0;
          int _7681 = (int)0;
          int _7682 = _2002;
          for (int _2034 = _7681; _2034 < _7682; ++_2034)
          {
            {
              ((*_1995)(_2034))->inst(_2032,_2023,_2032,_2022);
              int _7683 = (int)0;
              int _7684 = _ptr__2003[_2034];
              for (int _2035 = _7683; _2035 < _7684; ++_2035)
              {
                {
                  _ptr__2023[_2032] += _2033;
                  ++ _2032;
                }
              }
              _2033 += ::mosek::fusion::p_Set::size(((*_2005)(_2034)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7685;
          bool _7686 = (_2011 < safe_mul( safe_mul( _2026,_2028 ),_2030 ));
          if (_7686)
          {
            _7685 = _2023;
          }
          else
          {
            _7685 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1997,_2015,_7685,_2022)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2036 = (int)0;
          int _7687 = (int)0;
          int _7688 = _2002;
          for (int _2037 = _7687; _2037 < _7688; ++_2037)
          {
            {
              _2036 += ((*_1995)(_2037))->inst(_2036,_2023,_2036,_2022);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2038 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2011)));
          _checked_ptr_1<int> _ptr__2038(_2038 ? _2038->raw() : nullptr,_2038 ? _2038->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2039 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2011)));
          _checked_ptr_1<int> _ptr__2039(_2039 ? _2039->raw() : nullptr,_2039 ? _2039->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2040 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2002)));
          _checked_ptr_1<int> _ptr__2040(_2040 ? _2040->raw() : nullptr,_2040 ? _2040->size(0) : 0);
          int _7689 = (int)0;
          int _7690 = (_2002 - (int)1);
          for (int _2041 = _7689; _2041 < _7690; ++_2041)
          {
            {
              _ptr__2040[safe_add( _2041,(int)1 )] = safe_add( _ptr__2040[_2041],_ptr__2024[_2041] );
            }
          }
          int _7691 = (int)0;
          int _7692 = _2011;
          for (int _2042 = _7691; _2042 < _7692; ++_2042)
          {
            {
              _ptr__2038[_2042] = _2042;
            }
          }
          int _2043 = (int)0;
          int _7693 = (int)0;
          int _7694 = _2002;
          for (int _2044 = _7693; _2044 < _7694; ++_2044)
          {
            {
              int _7695 = (int)0;
              int _7696 = _ptr__2003[_2044];
              for (int _2045 = _7695; _2045 < _7696; ++_2045)
              {
                {
                  long long _2046 = (_ptr__2023[_2043] / safe_mul( _ptr__2024[_2044],_2030 ));
                  long long _2047 = ((_ptr__2023[_2043] / _2030) % _ptr__2024[_2044]);
                  long long _2048 = (_ptr__2023[_2043] % _2030);
                  _ptr__2023[_2043] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2046,_2028 ),_2047 ),_ptr__2040[_2044] ),_2030 ),_2048 );
                  ++ _2043;
                }
              }
            }
          }
          int _2049 = (int)1;
          int _7697 = (int)0;
          int _7698 = _2013;
          for (int _2050 = _7697; _2050 < _7698; ++_2050)
          {
            {
              int _7699;
              bool _7700 = (_2049 < _ptr__2015[_2050]);
              if (_7700)
              {
                _7699 = _ptr__2015[_2050];
              }
              else
              {
                _7699 = _2049;
              }
              _2049 = _7699;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2051 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2013)));
          _checked_ptr_1<long long> _ptr__2051(_2051 ? _2051->raw() : nullptr,_2051 ? _2051->size(0) : 0);
          _ptr__2051[(_2013 - (int)1)] = (int)1;
          int _7701 = (int)1;
          int _7702 = _2013;
          for (int _2052 = _7701; _2052 < _7702; ++_2052)
          {
            {
              _ptr__2051[((_2013 - _2052) - (int)1)] = safe_mul( _ptr__2051[(_2013 - _2052)],_ptr__2015[(_2013 - _2052)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2053 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2049,(int)1 ))));
          _checked_ptr_1<int> _ptr__2053(_2053 ? _2053->raw() : nullptr,_2053 ? _2053->size(0) : 0);
          int _7703 = (int)0;
          int _7704 = _2013;
          for (int _2054 = _7703; _2054 < _7704; ++_2054)
          {
            {
              int _2055 = ((_2013 - _2054) - (int)1);
              int _7705 = (int)0;
              int _7706 = safe_add( _ptr__2015[_2055],(int)1 );
              for (int _2056 = _7705; _2056 < _7706; ++_2056)
              {
                {
                  _ptr__2053[_2056] = (int)0;
                }
              }
              int _7707 = (int)0;
              int _7708 = _2011;
              for (int _2057 = _7707; _2057 < _7708; ++_2057)
              {
                {
                  ++ _ptr__2053[safe_add( ((_ptr__2023[_2057] / _ptr__2051[_2055]) % _ptr__2015[_2055]),(int)1 )];
                }
              }
              int _7709 = (int)0;
              int _7710 = _ptr__2015[_2055];
              for (int _2058 = _7709; _2058 < _7710; ++_2058)
              {
                {
                  _ptr__2053[safe_add( _2058,(int)1 )] += _ptr__2053[_2058];
                }
              }
              int _7711 = (int)0;
              int _7712 = _2011;
              for (int _2059 = _7711; _2059 < _7712; ++_2059)
              {
                {
                  int _2060 = _ptr__2038[_2059];
                  long long _2061 = ((_ptr__2023[_2060] / _ptr__2051[_2055]) % _ptr__2015[_2055]);
                  _ptr__2039[_ptr__2053[_2061]] = _2060;
                  ++ _ptr__2053[_2061];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2062 = _2038;
              _checked_ptr_1<int> _ptr__2062(_2062 ? _2062->raw() : nullptr,_2062 ? _2062->size(0) : 0);
              _2038 = _2039;
              _ptr__2038.update(_2038 ? _2038->raw() : nullptr, _2038 ? _2038->size(0) : 0);
              _2039 = _2062;
              _ptr__2039.update(_2039 ? _2039->raw() : nullptr, _2039 ? _2039->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _7713;
          bool _7714 = (_2011 < safe_mul( safe_mul( _2026,_2028 ),_2030 ));
          if (_7714)
          {
            std::vector<long long> _7715;
            for (int _2063 = (int)0, _7716 = _2011; _2063 < _7716 ; ++_2063)
            {
              _7715.push_back(_ptr__2023[_ptr__2038[_2063]]);
            }
            auto _7717 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7715.size()),_7715.begin(),_7715.end()));
            _7713 = _7717;
          }
          else
          {
            _7713 = nullptr;
          }
          std::vector<long long> _7718;
          for (int _2064 = (int)0, _7719 = _2011; _2064 < _7719 ; ++_2064)
          {
            _7718.push_back(_ptr__2022[_ptr__2038[_2064]]);
          }
          auto _7720 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7718.size()),_7718.begin(),_7718.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_1997,_2015,_7713,_7720)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2065,    monty::rc_ptr< ::mosek::fusion::Model > _2066){ return new mosek::fusion::LinearPSDConstraint(_2065,_2066); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2065,    monty::rc_ptr< ::mosek::fusion::Model > _2066) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2065,_2066); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2065,    monty::rc_ptr< ::mosek::fusion::Model > _2066){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2065,_2066);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2065)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2065)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2065)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2065)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2065)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2067,    const std::string &  _2068,    int _2069,    std::shared_ptr< monty::ndarray< int,1 > > _2070,    int _2071,    std::shared_ptr< monty::ndarray< int,1 > > _2072,    std::shared_ptr< monty::ndarray< long long,1 > > _2073){ return new mosek::fusion::LinearPSDConstraint(_2067,_2068,_2069,_2070,_2071,_2072,_2073); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2067,    const std::string &  _2068,    int _2069,    std::shared_ptr< monty::ndarray< int,1 > > _2070,    int _2071,    std::shared_ptr< monty::ndarray< int,1 > > _2072,    std::shared_ptr< monty::ndarray< long long,1 > > _2073) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2067,_2068,_2069,_2070,_2071,_2072,_2073); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2067,    const std::string &  _2068,    int _2069,    std::shared_ptr< monty::ndarray< int,1 > > _2070,    int _2071,    std::shared_ptr< monty::ndarray< int,1 > > _2072,    std::shared_ptr< monty::ndarray< long long,1 > > _2073){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2070(_2070 ? _2070->raw() : nullptr, _2070 ? _2070->size(0) : 0);
    _checked_ptr_1<int> _ptr__2072(_2072 ? _2072->raw() : nullptr, _2072 ? _2072->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2073(_2073 ? _2073->raw() : nullptr, _2073 ? _2073->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2067,_2068,_2070,_2072);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2069;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2073;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2072;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2071;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2070;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2074,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2075){
  std::shared_ptr< monty::ndarray< int,1 > > _2076 = ::mosek::fusion::p_Set::idxtokey(shape,_2074);
  _checked_ptr_1<int> _ptr__2076(_2076 ? _2076->raw() : nullptr,_2076 ? _2076->size(0) : 0);
  _2075->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2076[(int)0]);
  int _7721 = (int)1;
  int _7722 = (int)((_2076)->size(0));
  for (int _2077 = _7721; _2077 < _7722; ++_2077)
  {
    {
      _2075->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2076[_2077]);
    }
  }
  _2075->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _7723 = (int)1;
  int _7724 = (int)((_2076)->size(0));
  for (int _2078 = _7723; _2078 < _7724; ++_2078)
  {
    {
      _2075->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2078)));
    }
  }
  _2075->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2079){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2079)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2080,    monty::rc_ptr< ::mosek::fusion::Model > _2081){ return new mosek::fusion::PSDConstraint(_2080,_2081); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2080,    monty::rc_ptr< ::mosek::fusion::Model > _2081) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2080,_2081); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2080,    monty::rc_ptr< ::mosek::fusion::Model > _2081){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2080,_2081);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2080)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2082,    const std::string &  _2083,    int _2084,    std::shared_ptr< monty::ndarray< int,1 > > _2085,    int _2086,    int _2087,    std::shared_ptr< monty::ndarray< long long,1 > > _2088,    std::shared_ptr< monty::ndarray< int,1 > > _2089){ return new mosek::fusion::PSDConstraint(_2082,_2083,_2084,_2085,_2086,_2087,_2088,_2089); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2082,    const std::string &  _2083,    int _2084,    std::shared_ptr< monty::ndarray< int,1 > > _2085,    int _2086,    int _2087,    std::shared_ptr< monty::ndarray< long long,1 > > _2088,    std::shared_ptr< monty::ndarray< int,1 > > _2089) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2082,_2083,_2084,_2085,_2086,_2087,_2088,_2089); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2082,    const std::string &  _2083,    int _2084,    std::shared_ptr< monty::ndarray< int,1 > > _2085,    int _2086,    int _2087,    std::shared_ptr< monty::ndarray< long long,1 > > _2088,    std::shared_ptr< monty::ndarray< int,1 > > _2089){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2085(_2085 ? _2085->raw() : nullptr, _2085 ? _2085->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2088(_2088 ? _2088->raw() : nullptr, _2088 ? _2088->size(0) : 0);
    _checked_ptr_1<int> _ptr__2089(_2089 ? _2089->raw() : nullptr, _2089 ? _2089->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2082,_2083,_2085,::mosek::fusion::p_PSDConstraint::computenidxs(_2085,_2086,_2087,_2089));
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2084;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2089;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2088;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2083;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2085;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2086;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2087;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2090){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2090)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2091,int _2092,int _2093,std::shared_ptr< monty::ndarray< int,1 > > _2094){
  _checked_ptr_1<int> _ptr__2091(_2091 ? _2091->raw() : nullptr, _2091 ? _2091->size(0) : 0);
  _checked_ptr_1<int> _ptr__2094(_2094 ? _2094->raw() : nullptr, _2094 ? _2094->size(0) : 0);
  int _2095 = (int)((_2091)->size(0));
  bool _2096 = (_2092 < _2093);
  int _7725;
  bool _7726 = _2096;
  if (_7726)
  {
    _7725 = _2092;
  }
  else
  {
    _7725 = _2093;
  }
  int _2097 = _7725;
  int _7727;
  bool _7728 = _2096;
  if (_7728)
  {
    _7727 = _2093;
  }
  else
  {
    _7727 = _2092;
  }
  int _2098 = _7727;
  std::shared_ptr< monty::ndarray< int,1 > > _2099 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2099(_2099 ? _2099->raw() : nullptr,_2099 ? _2099->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2100 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2100(_2100 ? _2100->raw() : nullptr,_2100 ? _2100->size(0) : 0);
  int _2101 = (int)1;
  int _7729 = (int)0;
  int _7730 = (int)((_2091)->size(0));
  for (int _2102 = _7729; _2102 < _7730; ++_2102)
  {
    {
      _2101 *= _ptr__2091[_2102];
    }
  }
  int _7731 = (int)0;
  int _7732 = _2097;
  for (int _2103 = _7731; _2103 < _7732; ++_2103)
  {
    {
      _ptr__2099[(int)0] *= _ptr__2091[_2103];
    }
  }
  _ptr__2099[(int)1] = _ptr__2091[_2097];
  int _7733 = safe_add( _2097,(int)1 );
  int _7734 = _2098;
  for (int _2104 = _7733; _2104 < _7734; ++_2104)
  {
    {
      _ptr__2099[(int)2] *= _ptr__2091[_2104];
    }
  }
  _ptr__2099[(int)3] = _ptr__2091[_2098];
  int _7735 = safe_add( _2098,(int)1 );
  int _7736 = _2095;
  for (int _2105 = _7735; _2105 < _7736; ++_2105)
  {
    {
      _ptr__2099[(int)4] *= _ptr__2091[_2105];
    }
  }
  _ptr__2100[(int)4] = (int)1;
  int _7737 = (int)1;
  int _7738 = (int)5;
  for (int _2106 = _7737; _2106 < _7738; ++_2106)
  {
    {
      _ptr__2100[(((int)5 - _2106) - (int)1)] = safe_mul( _ptr__2100[((int)5 - _2106)],_ptr__2099[((int)5 - _2106)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2107 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2101)));
  _checked_ptr_1<int> _ptr__2107(_2107 ? _2107->raw() : nullptr,_2107 ? _2107->size(0) : 0);
  int _2108 = (int)0;
  if (_2096)
  {
    {
      int _7739 = (int)0;
      int _7740 = _ptr__2099[(int)0];
      for (int _2109 = _7739; _2109 < _7740; ++_2109)
      {
        {
          int _7741 = (int)0;
          int _7742 = _ptr__2099[(int)1];
          for (int _2110 = _7741; _2110 < _7742; ++_2110)
          {
            {
              int _7743 = (int)0;
              int _7744 = _ptr__2099[(int)2];
              for (int _2111 = _7743; _2111 < _7744; ++_2111)
              {
                {
                  int _7745 = _2110;
                  int _7746 = _ptr__2099[(int)1];
                  for (int _2112 = _7745; _2112 < _7746; ++_2112)
                  {
                    {
                      int _7747 = (int)0;
                      int _7748 = _ptr__2099[(int)4];
                      for (int _2113 = _7747; _2113 < _7748; ++_2113)
                      {
                        {
                          _ptr__2107[safe_add( safe_add( safe_add( safe_add( safe_mul( _2109,_ptr__2100[(int)0] ),safe_mul( _2110,_ptr__2100[(int)1] ) ),safe_mul( _2111,_ptr__2100[(int)2] ) ),safe_mul( _2112,_ptr__2100[(int)3] ) ),safe_mul( _2113,_ptr__2100[(int)4] ) )] = _ptr__2094[_2108];
                          _ptr__2107[safe_add( safe_add( safe_add( safe_add( safe_mul( _2109,_ptr__2100[(int)0] ),safe_mul( _2112,_ptr__2100[(int)1] ) ),safe_mul( _2111,_ptr__2100[(int)2] ) ),safe_mul( _2110,_ptr__2100[(int)3] ) ),safe_mul( _2113,_ptr__2100[(int)4] ) )] = _ptr__2094[_2108];
                          ++ _2108;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _7749 = (int)0;
      int _7750 = _ptr__2099[(int)0];
      for (int _2114 = _7749; _2114 < _7750; ++_2114)
      {
        {
          int _7751 = (int)0;
          int _7752 = _ptr__2099[(int)1];
          for (int _2115 = _7751; _2115 < _7752; ++_2115)
          {
            {
              int _7753 = (int)0;
              int _7754 = _ptr__2099[(int)2];
              for (int _2116 = _7753; _2116 < _7754; ++_2116)
              {
                {
                  int _7755 = (int)0;
                  int _7756 = safe_add( _2115,(int)1 );
                  for (int _2117 = _7755; _2117 < _7756; ++_2117)
                  {
                    {
                      int _7757 = (int)0;
                      int _7758 = _ptr__2099[(int)4];
                      for (int _2118 = _7757; _2118 < _7758; ++_2118)
                      {
                        {
                          _ptr__2107[safe_add( safe_add( safe_add( safe_add( safe_mul( _2114,_ptr__2100[(int)0] ),safe_mul( _2115,_ptr__2100[(int)1] ) ),safe_mul( _2116,_ptr__2100[(int)2] ) ),safe_mul( _2117,_ptr__2100[(int)3] ) ),safe_mul( _2118,_ptr__2100[(int)4] ) )] = _ptr__2094[_2108];
                          _ptr__2107[safe_add( safe_add( safe_add( safe_add( safe_mul( _2114,_ptr__2100[(int)0] ),safe_mul( _2117,_ptr__2100[(int)1] ) ),safe_mul( _2116,_ptr__2100[(int)2] ) ),safe_mul( _2115,_ptr__2100[(int)3] ) ),safe_mul( _2118,_ptr__2100[(int)4] ) )] = _ptr__2094[_2108];
                          ++ _2108;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2107;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2119){ return new mosek::fusion::ConstraintCache(_2119); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2119) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2119); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2119){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2119)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2119)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7759;
    bool _7760 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->subj.get());
    if (_7760)
    {
      _7759 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->subj);
    }
    else
    {
      _7759 = nullptr;
    }
    subj = _7759;
    std::shared_ptr< monty::ndarray< int,1 > > _7761;
    bool _7762 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->subi.get());
    if (_7762)
    {
      _7761 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->subi);
    }
    else
    {
      _7761 = nullptr;
    }
    subi = _7761;
    std::shared_ptr< monty::ndarray< double,1 > > _7763;
    bool _7764 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->cof.get());
    if (_7764)
    {
      _7763 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->cof);
    }
    else
    {
      _7763 = nullptr;
    }
    cof = _7763;
    std::shared_ptr< monty::ndarray< double,1 > > _7765;
    bool _7766 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->bfix.get());
    if (_7766)
    {
      _7765 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->bfix);
    }
    else
    {
      _7765 = nullptr;
    }
    bfix = _7765;
    std::shared_ptr< monty::ndarray< double,1 > > _7767;
    bool _7768 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->buffer_cof.get());
    if (_7768)
    {
      _7767 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->buffer_cof);
    }
    else
    {
      _7767 = nullptr;
    }
    buffer_cof = _7767;
    std::shared_ptr< monty::ndarray< int,1 > > _7769;
    bool _7770 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->buffer_subj.get());
    if (_7770)
    {
      _7769 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->buffer_subj);
    }
    else
    {
      _7769 = nullptr;
    }
    buffer_subj = _7769;
    std::shared_ptr< monty::ndarray< int,1 > > _7771;
    bool _7772 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->buffer_subi.get());
    if (_7772)
    {
      _7771 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->buffer_subi);
    }
    else
    {
      _7771 = nullptr;
    }
    buffer_subi = _7771;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2119)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2119)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _7773;
    bool _7774 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->barsubi.get());
    if (_7774)
    {
      _7773 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->barsubi);
    }
    else
    {
      _7773 = nullptr;
    }
    barsubi = _7773;
    std::shared_ptr< monty::ndarray< int,1 > > _7775;
    bool _7776 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->barsubj.get());
    if (_7776)
    {
      _7775 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->barsubj);
    }
    else
    {
      _7775 = nullptr;
    }
    barsubj = _7775;
    std::shared_ptr< monty::ndarray< int,1 > > _7777;
    bool _7778 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2119)->barmatidx.get());
    if (_7778)
    {
      _7777 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2119)->barmatidx);
    }
    else
    {
      _7777 = nullptr;
    }
    barmatidx = _7777;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2120,    std::shared_ptr< monty::ndarray< double,1 > > _2121,    std::shared_ptr< monty::ndarray< int,1 > > _2122,    std::shared_ptr< monty::ndarray< double,1 > > _2123,    std::shared_ptr< monty::ndarray< int,1 > > _2124,    std::shared_ptr< monty::ndarray< int,1 > > _2125,    std::shared_ptr< monty::ndarray< int,1 > > _2126){ return new mosek::fusion::ConstraintCache(_2120,_2121,_2122,_2123,_2124,_2125,_2126); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2120,    std::shared_ptr< monty::ndarray< double,1 > > _2121,    std::shared_ptr< monty::ndarray< int,1 > > _2122,    std::shared_ptr< monty::ndarray< double,1 > > _2123,    std::shared_ptr< monty::ndarray< int,1 > > _2124,    std::shared_ptr< monty::ndarray< int,1 > > _2125,    std::shared_ptr< monty::ndarray< int,1 > > _2126) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2120,_2121,_2122,_2123,_2124,_2125,_2126); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2120,    std::shared_ptr< monty::ndarray< double,1 > > _2121,    std::shared_ptr< monty::ndarray< int,1 > > _2122,    std::shared_ptr< monty::ndarray< double,1 > > _2123,    std::shared_ptr< monty::ndarray< int,1 > > _2124,    std::shared_ptr< monty::ndarray< int,1 > > _2125,    std::shared_ptr< monty::ndarray< int,1 > > _2126){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2120(_2120 ? _2120->raw() : nullptr, _2120 ? _2120->size(0) : 0);
    _checked_ptr_1<double> _ptr__2121(_2121 ? _2121->raw() : nullptr, _2121 ? _2121->size(0) : 0);
    _checked_ptr_1<int> _ptr__2122(_2122 ? _2122->raw() : nullptr, _2122 ? _2122->size(0) : 0);
    _checked_ptr_1<double> _ptr__2123(_2123 ? _2123->raw() : nullptr, _2123 ? _2123->size(0) : 0);
    _checked_ptr_1<int> _ptr__2124(_2124 ? _2124->raw() : nullptr, _2124 ? _2124->size(0) : 0);
    _checked_ptr_1<int> _ptr__2125(_2125 ? _2125->raw() : nullptr, _2125 ? _2125->size(0) : 0);
    _checked_ptr_1<int> _ptr__2126(_2126 ? _2126->raw() : nullptr, _2126 ? _2126->size(0) : 0);
    nrows = ((int)((_2120)->size(0)) - (int)1);
    nnz = _ptr__2120[((int)((_2120)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2123.get()))
    {
      {
        bfix = _2123;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2124.get()) && ((NULL != _2125.get()) && (NULL != _2126.get()))))
    {
      {
        nbarnz = (int)((_2124)->size(0));
        if ((nbarnz > (int)((_2125)->size(0))))
        {
          {
            nbarnz = (int)((_2125)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2126)->size(0))))
        {
          {
            nbarnz = (int)((_2126)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2124,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2125,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2126,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2122,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2121,(long long)0,cof,(long long)0,nnz);
    int _7779 = (int)0;
    int _7780 = nrows;
    for (int _2127 = _7779; _2127 < _7780; ++_2127)
    {
      {
        long long _7781 = _ptr__2120[_2127];
        long long _7782 = _ptr__2120[safe_add( _2127,(int)1 )];
        for (long long _2128 = _7781; _2128 < _7782; ++_2128)
        {
          {
            ((*subi)(_2128)) = _2127;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2129){
  _checked_ptr_1<double> _ptr__2129(_2129 ? _2129->raw() : nullptr, _2129 ? _2129->size(0) : 0);
  int _7783 = (int)0;
  int _7784 = nrows;
  for (int _2130 = _7783; _2130 < _7784; ++_2130)
  {
    {
      ((*bfix)(_2130)) = (((*bfix)(_2130)) + _ptr__2129[_2130]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _7785;
  for (long long _2132 = (long long)0, _7786 = nbarnz; _2132 < _7786 ; ++_2132)
  {
    _7785.push_back(_2132);
  }
  auto _7787 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7785.size()),_7785.begin(),_7785.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2131 = _7787;
  _checked_ptr_1<long long> _ptr__2131(_2131 ? _2131->raw() : nullptr,_2131 ? _2131->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2131,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2131,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2133 = barsubi;
      _checked_ptr_1<int> _ptr__2133(_2133 ? _2133->raw() : nullptr,_2133 ? _2133->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2134 = barsubj;
      _checked_ptr_1<int> _ptr__2134(_2134 ? _2134->raw() : nullptr,_2134 ? _2134->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2135 = barmatidx;
      _checked_ptr_1<int> _ptr__2135(_2135 ? _2135->raw() : nullptr,_2135 ? _2135->size(0) : 0);
      std::vector<int> _7788;
      for (long long _2136 = (int)0, _7789 = nbarnz; _2136 < _7789 ; ++_2136)
      {
        _7788.push_back(_ptr__2133[_ptr__2131[_2136]]);
      }
      auto _7790 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7788.size()),_7788.begin(),_7788.end()));
      barsubi = _7790;
      std::vector<int> _7791;
      for (long long _2137 = (int)0, _7792 = nbarnz; _2137 < _7792 ; ++_2137)
      {
        _7791.push_back(_ptr__2134[_ptr__2131[_2137]]);
      }
      auto _7793 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7791.size()),_7791.begin(),_7791.end()));
      barsubj = _7793;
      std::vector<int> _7794;
      for (long long _2138 = (int)0, _7795 = nbarnz; _2138 < _7795 ; ++_2138)
      {
        _7794.push_back(_ptr__2135[_ptr__2131[_2138]]);
      }
      auto _7796 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7794.size()),_7794.begin(),_7794.end()));
      barmatidx = _7796;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2139,std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< int,1 > > _2141){
  _checked_ptr_1<int> _ptr__2139(_2139 ? _2139->raw() : nullptr, _2139 ? _2139->size(0) : 0);
  _checked_ptr_1<int> _ptr__2140(_2140 ? _2140->raw() : nullptr, _2140 ? _2140->size(0) : 0);
  _checked_ptr_1<int> _ptr__2141(_2141 ? _2141->raw() : nullptr, _2141 ? _2141->size(0) : 0);
  if ((NULL != _2139.get()))
  {
    {
      int _2142 = (int)((_2139)->size(0));
      if (((int)((_2139)->size(0)) <= safe_add( nbarnz,_2142 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2143 = barsubi;
          _checked_ptr_1<int> _ptr__2143(_2143 ? _2143->raw() : nullptr,_2143 ? _2143->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2144 = barsubj;
          _checked_ptr_1<int> _ptr__2144(_2144 ? _2144->raw() : nullptr,_2144 ? _2144->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2145 = barmatidx;
          _checked_ptr_1<int> _ptr__2145(_2145 ? _2145->raw() : nullptr,_2145 ? _2145->size(0) : 0);
          long long _7797;
          bool _7798 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2142 ));
          if (_7798)
          {
            _7797 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _7797 = safe_add( nbarnz,safe_mul( _2142,(int)2 ) );
          }
          long long _2146 = _7797;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2146)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2146)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2146)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2143,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2144,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2145,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2139,(long long)((int)0),barsubi,nbarnz,(long long)(_2142));
      ::mosek::fusion::Utils::Tools::arraycopy(_2140,(long long)((int)0),barsubj,nbarnz,(long long)(_2142));
      ::mosek::fusion::Utils::Tools::arraycopy(_2141,(long long)((int)0),barmatidx,nbarnz,(long long)(_2142));
      nbarnz += _2142;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2147,std::shared_ptr< monty::ndarray< int,1 > > _2148,std::shared_ptr< monty::ndarray< double,1 > > _2149,std::shared_ptr< monty::ndarray< double,1 > > _2150){
  _checked_ptr_1<long long> _ptr__2147(_2147 ? _2147->raw() : nullptr, _2147 ? _2147->size(0) : 0);
  _checked_ptr_1<int> _ptr__2148(_2148 ? _2148->raw() : nullptr, _2148 ? _2148->size(0) : 0);
  _checked_ptr_1<double> _ptr__2149(_2149 ? _2149->raw() : nullptr, _2149 ? _2149->size(0) : 0);
  _checked_ptr_1<double> _ptr__2150(_2150 ? _2150->raw() : nullptr, _2150 ? _2150->size(0) : 0);
  long long _2151 = safe_add( nunordered,_ptr__2147[nrows] );
  long long _2152 = _ptr__2147[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2153;
  _checked_ptr_1<int> _ptr__2153(_2153 ? _2153->raw() : nullptr,_2153 ? _2153->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2154;
  _checked_ptr_1<int> _ptr__2154(_2154 ? _2154->raw() : nullptr,_2154 ? _2154->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2155;
  _checked_ptr_1<double> _ptr__2155(_2155 ? _2155->raw() : nullptr,_2155 ? _2155->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2151)))
  {
    {
      _2153 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2151)));
      _ptr__2153.update(_2153 ? _2153->raw() : nullptr, _2153 ? _2153->size(0) : 0);
      _2154 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2151)));
      _ptr__2154.update(_2154 ? _2154->raw() : nullptr, _2154 ? _2154->size(0) : 0);
      _2155 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2151)));
      _ptr__2155.update(_2155 ? _2155->raw() : nullptr, _2155 ? _2155->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2153,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2154,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2155,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2153 = buffer_subi;
      _ptr__2153.update(_2153 ? _2153->raw() : nullptr, _2153 ? _2153->size(0) : 0);
      _2154 = buffer_subj;
      _ptr__2154.update(_2154 ? _2154->raw() : nullptr, _2154 ? _2154->size(0) : 0);
      _2155 = buffer_cof;
      _ptr__2155.update(_2155 ? _2155->raw() : nullptr, _2155 ? _2155->size(0) : 0);
    }
  }
  int _7799 = (int)0;
  int _7800 = nrows;
  for (int _2156 = _7799; _2156 < _7800; ++_2156)
  {
    {
      long long _7801 = _ptr__2147[_2156];
      long long _7802 = _ptr__2147[safe_add( _2156,(int)1 )];
      for (long long _2157 = _7801; _2157 < _7802; ++_2157)
      {
        {
          _ptr__2153[safe_add( nunordered,_2157 )] = _2156;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2148,(long long)0,_2154,nunordered,_2152);
  ::mosek::fusion::Utils::Tools::arraycopy(_2149,(long long)0,_2155,nunordered,_2152);
  buffer_subi = _2153;
  buffer_subj = _2154;
  buffer_cof = _2155;
  if ((NULL != _2150.get()))
  {
    {
      int _7803 = (int)0;
      int _7804 = nrows;
      for (int _2158 = _7803; _2158 < _7804; ++_2158)
      {
        {
          ((*bfix)(_2158)) = (((*bfix)(_2158)) + _ptr__2150[_2158]);
        }
      }
    }
  }
  {}
  nunordered = _2151;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2159,std::shared_ptr< monty::ndarray< int,1 > > _2160,std::shared_ptr< monty::ndarray< double,1 > > _2161,std::shared_ptr< monty::ndarray< double,1 > > _2162) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2159,_2160,_2161,_2162); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2159,std::shared_ptr< monty::ndarray< int,1 > > _2160,std::shared_ptr< monty::ndarray< double,1 > > _2161,std::shared_ptr< monty::ndarray< double,1 > > _2162){
  _checked_ptr_1<long long> _ptr__2159(_2159 ? _2159->raw() : nullptr, _2159 ? _2159->size(0) : 0);
  _checked_ptr_1<int> _ptr__2160(_2160 ? _2160->raw() : nullptr, _2160 ? _2160->size(0) : 0);
  _checked_ptr_1<double> _ptr__2161(_2161 ? _2161->raw() : nullptr, _2161 ? _2161->size(0) : 0);
  _checked_ptr_1<double> _ptr__2162(_2162 ? _2162->raw() : nullptr, _2162 ? _2162->size(0) : 0);
  if ((((int)((_2159)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2162.get()) && ((int)((_2162)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2159,_2160,_2161,_2162);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< int,1 > > _2164,std::shared_ptr< monty::ndarray< double,1 > > _2165,std::shared_ptr< monty::ndarray< double,1 > > _2166) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2163,_2164,_2165,_2166); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< int,1 > > _2164,std::shared_ptr< monty::ndarray< double,1 > > _2165,std::shared_ptr< monty::ndarray< double,1 > > _2166){
  _checked_ptr_1<int> _ptr__2163(_2163 ? _2163->raw() : nullptr, _2163 ? _2163->size(0) : 0);
  _checked_ptr_1<int> _ptr__2164(_2164 ? _2164->raw() : nullptr, _2164 ? _2164->size(0) : 0);
  _checked_ptr_1<double> _ptr__2165(_2165 ? _2165->raw() : nullptr, _2165 ? _2165->size(0) : 0);
  _checked_ptr_1<double> _ptr__2166(_2166 ? _2166->raw() : nullptr, _2166 ? _2166->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2167 = nullptr;
  _checked_ptr_1<long long> _ptr__2167(_2167 ? _2167->raw() : nullptr,_2167 ? _2167->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2166.get())))
  {
    {
      int _7805 = (int)0;
      int _7806 = nrows;
      for (int _2168 = _7805; _2168 < _7806; ++_2168)
      {
        {
          _ptr__2166[_2168] = ((*bfix)(_2168));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2169 = false;
  {
    int _2170 = (int)1;
    while ( ((_2170 < nunordered) && ((((*buffer_subi)((_2170 - (int)1))) < ((*buffer_subi)(_2170))) || ((((*buffer_subi)((_2170 - (int)1))) == ((*buffer_subi)(_2170))) && (((*buffer_subj)((_2170 - (int)1))) <= ((*buffer_subj)(_2170)))))) )
    {
      {
        ++ _2170;
      }
    }
    _2169 = (_2170 == nunordered);
  }
  if ((!_2169))
  {
    {
      std::vector<long long> _7807;
      for (long long _2171 = (int)0, _7808 = nunordered; _2171 < _7808 ; ++_2171)
      {
        _7807.push_back(_2171);
      }
      auto _7809 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7807.size()),_7807.begin(),_7807.end()));
      _2167 = _7809;
      _ptr__2167.update(_2167 ? _2167->raw() : nullptr, _2167 ? _2167->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2167,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2172 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2172 ))));
  _checked_ptr_1<int> _ptr__2173(_2173 ? _2173->raw() : nullptr,_2173 ? _2173->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2174 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2172 ))));
  _checked_ptr_1<int> _ptr__2174(_2174 ? _2174->raw() : nullptr,_2174 ? _2174->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2175 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2172 ))));
  _checked_ptr_1<double> _ptr__2175(_2175 ? _2175->raw() : nullptr,_2175 ? _2175->size(0) : 0);
  long long _2176 = (long long)0;
  if (_2169)
  {
    {
      long long _2177 = (long long)0;
      int _2178 = (int)0;
      long long _2179 = nunordered;
      long long _2180 = _2172;
      int _2181 = (int)0;
      int _2182 = (int)0;
      while ( ((_2182 < _2180) && (_2181 < _2179)) )
      {
        {
          if (((((*subi)(_2182)) < ((*buffer_subi)(_2181))) || ((((*subi)(_2182)) == ((*buffer_subi)(_2181))) && (((*subj)(_2182)) < ((*buffer_subj)(_2181))))))
          {
            {
              _ptr__2173[_2178] = ((*subi)(_2182));
              _ptr__2174[_2178] = ((*subj)(_2182));
              _ptr__2175[_2178] = ((*cof)(_2182));
              ++ _2182;
              ++ _2178;
            }
          }
          else if(((((*subi)(_2182)) > ((*buffer_subi)(_2181))) || ((((*subi)(_2182)) == ((*buffer_subi)(_2181))) && (((*subj)(_2182)) > ((*buffer_subj)(_2181))))))
          {
            {
              _ptr__2173[_2178] = ((*buffer_subi)(_2181));
              _ptr__2174[_2178] = ((*buffer_subj)(_2181));
              _ptr__2175[_2178] = ((*buffer_cof)(_2181));
              _ptr__2163[_2176] = _ptr__2173[_2178];
              _ptr__2164[_2176] = _ptr__2174[_2178];
              _ptr__2165[_2176] = _ptr__2175[_2178];
              ++ _2176;
              ++ _2181;
              ++ _2178;
            }
          }
          else
          {
            {
              _ptr__2173[_2178] = ((*subi)(_2182));
              _ptr__2174[_2178] = ((*subj)(_2182));
              _ptr__2175[_2178] = ((*cof)(_2182));
              while ( ((_2182 < (int)((subi)->size(0))) && ((_2181 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2182)) == ((*buffer_subi)(_2181))) && (((*subj)(_2182)) == ((*buffer_subj)(_2181)))))) )
              {
                {
                  _ptr__2175[_2178] = (_ptr__2175[_2178] + ((*buffer_cof)(_2181)));
                  ++ _2181;
                }
              }
              _ptr__2163[_2176] = _ptr__2173[_2178];
              _ptr__2164[_2176] = _ptr__2174[_2178];
              _ptr__2165[_2176] = _ptr__2175[_2178];
              ++ _2176;
              ++ _2182;
              ++ _2178;
            }
          }
        }
      }
      while ( (_2182 < _2180) )
      {
        {
          _ptr__2173[_2178] = ((*subi)(_2182));
          _ptr__2174[_2178] = ((*subj)(_2182));
          _ptr__2175[_2178] = ((*cof)(_2182));
          ++ _2182;
          ++ _2178;
        }
      }
      while ( (_2181 < _2179) )
      {
        {
          _ptr__2173[_2178] = ((*buffer_subi)(_2181));
          _ptr__2174[_2178] = ((*buffer_subj)(_2181));
          _ptr__2175[_2178] = ((*buffer_cof)(_2181));
          _ptr__2163[_2176] = _ptr__2173[_2178];
          _ptr__2164[_2176] = _ptr__2174[_2178];
          _ptr__2165[_2176] = _ptr__2175[_2178];
          ++ _2176;
          ++ _2181;
          ++ _2178;
        }
      }
      nnz = _2178;
    }
  }
  else
  {
    {
      long long _2183 = (long long)0;
      int _2184 = (int)0;
      long long _2185 = nunordered;
      long long _2186 = _2172;
      int _2187 = (int)0;
      int _2188 = (int)0;
      while ( ((_2188 < _2186) && (_2187 < _2185)) )
      {
        {
          if (((((*subi)(_2188)) < ((*buffer_subi)(_ptr__2167[_2187]))) || ((((*subi)(_2188)) == ((*buffer_subi)(_ptr__2167[_2187]))) && (((*subj)(_2188)) < ((*buffer_subj)(_ptr__2167[_2187]))))))
          {
            {
              _ptr__2173[_2184] = ((*subi)(_2188));
              _ptr__2174[_2184] = ((*subj)(_2188));
              _ptr__2175[_2184] = ((*cof)(_2188));
              ++ _2188;
              ++ _2184;
            }
          }
          else if(((((*subi)(_2188)) > ((*buffer_subi)(_ptr__2167[_2187]))) || ((((*subi)(_2188)) == ((*buffer_subi)(_ptr__2167[_2187]))) && (((*subj)(_2188)) > ((*buffer_subj)(_ptr__2167[_2187]))))))
          {
            {
              _ptr__2173[_2184] = ((*buffer_subi)(_ptr__2167[_2187]));
              _ptr__2174[_2184] = ((*buffer_subj)(_ptr__2167[_2187]));
              _ptr__2175[_2184] = ((*buffer_cof)(_ptr__2167[_2187]));
              _ptr__2163[_2176] = _ptr__2173[_2184];
              _ptr__2164[_2176] = _ptr__2174[_2184];
              _ptr__2165[_2176] = _ptr__2175[_2184];
              ++ _2176;
              ++ _2187;
              ++ _2184;
            }
          }
          else
          {
            {
              _ptr__2173[_2184] = ((*subi)(_2188));
              _ptr__2174[_2184] = ((*subj)(_2188));
              _ptr__2175[_2184] = ((*cof)(_2188));
              while ( ((((*subi)(_2188)) == ((*buffer_subi)(_ptr__2167[_2187]))) && (((*subj)(_2188)) == ((*buffer_subj)(_ptr__2167[_2187])))) )
              {
                {
                  _ptr__2175[_2184] = (_ptr__2175[_2184] + ((*buffer_cof)(_ptr__2167[_2187])));
                  ++ _2187;
                }
              }
              _ptr__2163[_2176] = _ptr__2173[_2184];
              _ptr__2164[_2176] = _ptr__2174[_2184];
              _ptr__2165[_2176] = _ptr__2175[_2184];
              ++ _2176;
              ++ _2188;
              ++ _2184;
            }
          }
        }
      }
      nnz = _2184;
    }
  }
  subi = _2173;
  subj = _2174;
  cof = _2175;
  nunordered = (long long)0;
  return _2176;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2189,    std::shared_ptr< monty::ndarray< int,1 > > _2190,    std::shared_ptr< monty::ndarray< int,1 > > _2191){ return new mosek::fusion::SliceConstraint(_2189,_2190,_2191); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2189,    std::shared_ptr< monty::ndarray< int,1 > > _2190,    std::shared_ptr< monty::ndarray< int,1 > > _2191) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2189,_2190,_2191); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2189,    std::shared_ptr< monty::ndarray< int,1 > > _2190,    std::shared_ptr< monty::ndarray< int,1 > > _2191){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2190(_2190 ? _2190->raw() : nullptr, _2190 ? _2190->size(0) : 0);
    _checked_ptr_1<int> _ptr__2191(_2191 ? _2191->raw() : nullptr, _2191 ? _2191->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2189,_2190,_2191);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2192 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2192->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2192->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2193,    monty::rc_ptr< ::mosek::fusion::Model > _2194){ return new mosek::fusion::RangedConstraint(_2193,_2194); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2193,    monty::rc_ptr< ::mosek::fusion::Model > _2194) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2193,_2194); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2193,    monty::rc_ptr< ::mosek::fusion::Model > _2194){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2193,_2194);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2193)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2193)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2195,    const std::string &  _2196,    std::shared_ptr< monty::ndarray< int,1 > > _2197,    std::shared_ptr< monty::ndarray< int,1 > > _2198){ return new mosek::fusion::RangedConstraint(_2195,_2196,_2197,_2198); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2195,    const std::string &  _2196,    std::shared_ptr< monty::ndarray< int,1 > > _2197,    std::shared_ptr< monty::ndarray< int,1 > > _2198) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2195,_2196,_2197,_2198); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2195,    const std::string &  _2196,    std::shared_ptr< monty::ndarray< int,1 > > _2197,    std::shared_ptr< monty::ndarray< int,1 > > _2198){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2197(_2197 ? _2197->raw() : nullptr, _2197 ? _2197->size(0) : 0);
    _checked_ptr_1<int> _ptr__2198(_2198 ? _2198->raw() : nullptr, _2198 ? _2198->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2195,_2196,_2197,_2198);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2197;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2198;
  }
}monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2199){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2199)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2200,    monty::rc_ptr< ::mosek::fusion::Model > _2201){ return new mosek::fusion::ConicConstraint(_2200,_2201); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2200,    monty::rc_ptr< ::mosek::fusion::Model > _2201) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2200,_2201); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2200,    monty::rc_ptr< ::mosek::fusion::Model > _2201){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2200,_2201);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2200)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2202,    const std::string &  _2203,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2204,    std::shared_ptr< monty::ndarray< int,1 > > _2205,    int _2206,    std::shared_ptr< monty::ndarray< int,1 > > _2207,    std::shared_ptr< monty::ndarray< int,1 > > _2208){ return new mosek::fusion::ConicConstraint(_2202,_2203,_2204,_2205,_2206,_2207,_2208); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2202,    const std::string &  _2203,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2204,    std::shared_ptr< monty::ndarray< int,1 > > _2205,    int _2206,    std::shared_ptr< monty::ndarray< int,1 > > _2207,    std::shared_ptr< monty::ndarray< int,1 > > _2208) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2202,_2203,_2204,_2205,_2206,_2207,_2208); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2202,    const std::string &  _2203,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2204,    std::shared_ptr< monty::ndarray< int,1 > > _2205,    int _2206,    std::shared_ptr< monty::ndarray< int,1 > > _2207,    std::shared_ptr< monty::ndarray< int,1 > > _2208){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2205(_2205 ? _2205->raw() : nullptr, _2205 ? _2205->size(0) : 0);
    _checked_ptr_1<int> _ptr__2207(_2207 ? _2207->raw() : nullptr, _2207 ? _2207->size(0) : 0);
    _checked_ptr_1<int> _ptr__2208(_2208 ? _2208->raw() : nullptr, _2208 ? _2208->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2202,_2203,_2205,_2207);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2204;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2205;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2203;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2207;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2208;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2206;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2209 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2210 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _7810 = (int)0;
          int _7811 = _2209;
          for (int _2211 = _7810; _2211 < _7811; ++_2211)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2210.get())->task_var_name(((*nativeslack)(_2211)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2212 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _7812 = (int)0;
          int _7813 = _2209;
          for (int _2213 = _7812; _2213 < _7813; ++_2213)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2210.get())->task_var_name(((*nativeslack)(_2213)),_2212->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2213)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2214 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2214->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2214->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2215,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2216){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2217){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2217)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2218,    monty::rc_ptr< ::mosek::fusion::Model > _2219){ return new mosek::fusion::LinearConstraint(_2218,_2219); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2218,    monty::rc_ptr< ::mosek::fusion::Model > _2219) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2218,_2219); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2218,    monty::rc_ptr< ::mosek::fusion::Model > _2219){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2218,_2219);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2218)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2218)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2220,    const std::string &  _2221,    int _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223,    std::shared_ptr< monty::ndarray< int,1 > > _2224){ return new mosek::fusion::LinearConstraint(_2220,_2221,_2222,_2223,_2224); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2220,    const std::string &  _2221,    int _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223,    std::shared_ptr< monty::ndarray< int,1 > > _2224) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2220,_2221,_2222,_2223,_2224); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2220,    const std::string &  _2221,    int _2222,    std::shared_ptr< monty::ndarray< int,1 > > _2223,    std::shared_ptr< monty::ndarray< int,1 > > _2224){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2223(_2223 ? _2223->raw() : nullptr, _2223 ? _2223->size(0) : 0);
    _checked_ptr_1<int> _ptr__2224(_2224 ? _2224->raw() : nullptr, _2224 ? _2224->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2220,_2221,_2223,_2224);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2222;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2221;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2225 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2225->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2225->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2226,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2227){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2228){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2228)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2229,    monty::rc_ptr< ::mosek::fusion::Model > _2230){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2229,_2230);
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2229)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2229)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2229)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2229)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2231,    const std::string &  _2232,    std::shared_ptr< monty::ndarray< int,1 > > _2233,    std::shared_ptr< monty::ndarray< int,1 > > _2234){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2233(_2233 ? _2233->raw() : nullptr, _2233 ? _2233->size(0) : 0);
    _checked_ptr_1<int> _ptr__2234(_2234 ? _2234->raw() : nullptr, _2234 ? _2234->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2231,_2233,_2234);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2232;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2234;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2233;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2235 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2235->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2235->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2236 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          mosek::fusion::p_Model::_get_impl(_2236.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2237 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          _2237->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
          if ((_pubthis->getND() > (int)0))
          {
            {
              _2237->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
              int _7814 = (int)1;
              int _7815 = _pubthis->getND();
              for (int _2238 = _7814; _2238 < _7815; ++_2238)
              {
                {
                  _2237->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2238);
                }
              }
            }
          }
          {}
          _2237->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
          std::shared_ptr< monty::ndarray< int,1 > > _7816;
          bool _7817 = (_pubthis->getND() > (int)0);
          if (_7817)
          {
            _7816 = _pubthis->getShape();
          }
          else
          {
            _7816 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
          }
          mosek::fusion::p_Model::_get_impl(_2236.get())->connames(nativeidxs,_2237->toString(),_7816,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
          names_flushed = true;
        }
      }
    }
  }
  {}
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2240,    monty::rc_ptr< ::mosek::fusion::Model > _2241){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2241;
    shape = mosek::fusion::p_Constraint::_get_impl(_2240)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2240)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2242,    std::shared_ptr< monty::ndarray< int,1 > > _2243,    std::shared_ptr< monty::ndarray< int,1 > > _2244){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2243(_2243 ? _2243->raw() : nullptr, _2243 ? _2243->size(0) : 0);
    _checked_ptr_1<int> _ptr__2244(_2244 ? _2244->raw() : nullptr, _2244 ? _2244->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2242;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2243;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2244;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2245,long long _2246,std::shared_ptr< monty::ndarray< std::string,1 > > _2247){
  _checked_ptr_1<long long> _ptr__2245(_2245 ? _2245->raw() : nullptr, _2245 ? _2245->size(0) : 0);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2248 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2248(_2248 ? _2248->raw() : nullptr,_2248 ? _2248->size(0) : 0);
  values(false,(int)0,_2248);
  return _2248;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2249 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2249(_2249 ? _2249->raw() : nullptr,_2249 ? _2249->size(0) : 0);
  values(true,(int)0,_2249);
  return _2249;
}
void mosek::fusion::p_Constraint::values(bool _2250,int _2251,std::shared_ptr< monty::ndarray< double,1 > > _2252){
  _checked_ptr_1<double> _ptr__2252(_2252 ? _2252->raw() : nullptr, _2252 ? _2252->size(0) : 0);
  model->getConstraintValues(_2250,nativeidxs,_2252,_2251);
}
void mosek::fusion::Constraint :: update(std::shared_ptr< monty::ndarray< double,1 > > _2253) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2253); }void mosek::fusion::p_Constraint::update(std::shared_ptr< monty::ndarray< double,1 > > _2253){
  _checked_ptr_1<double> _ptr__2253(_2253 ? _2253->raw() : nullptr, _2253 ? _2253->size(0) : 0);
  mosek::fusion::p_Model::_get_impl(model.get())->update_bfix(nativeidxs,_2253);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2254) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2254); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2254){
  std::shared_ptr< monty::ndarray< int,1 > > _2255 = _2254->getShape();
  _checked_ptr_1<int> _ptr__2255(_2255 ? _2255->raw() : nullptr,_2255 ? _2255->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2255)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7818 = (int)0;
  int _7819 = (int)((_2255)->size(0));
  for (int _2256 = _7818; _2256 < _7819; ++_2256)
  {
    {
      if ((_ptr__2255[_2256] != ((*shape)(_2256))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7820 = (int)((_2255)->size(0));
  int _7821 = (int)((shape)->size(0));
  for (int _2257 = _7820; _2257 < _7821; ++_2257)
  {
    {
      if ((((*shape)(_2257)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2254);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2258,monty::rc_ptr< ::mosek::fusion::Variable > _2259,bool _2260) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2258,_2259,_2260); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2258,monty::rc_ptr< ::mosek::fusion::Variable > _2259,bool _2260){
  int _2261 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2262 = _2258->getShape();
  _checked_ptr_1<int> _ptr__2262(_2262 ? _2262->raw() : nullptr,_2262 ? _2262->size(0) : 0);
  if ((_2261 < (int)((_2262)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _7822 = (int)0;
  int _7823 = (int)((_2262)->size(0));
  for (int _2263 = _7822; _2263 < _7823; ++_2263)
  {
    {
      if ((_ptr__2262[_2263] != ((*shape)(_2263))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _7824 = (int)((_2262)->size(0));
  int _7825 = (int)((shape)->size(0));
  for (int _2264 = _7824; _2264 < _7825; ++_2264)
  {
    {
      if ((((*shape)(_2264)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2265 = _2259->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2266 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2265)));
  _checked_ptr_1<long long> _ptr__2266(_2266 ? _2266->raw() : nullptr,_2266 ? _2266->size(0) : 0);
  if ((_2265 < _2259->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2267 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2265)));
      _checked_ptr_1<long long> _ptr__2267(_2267 ? _2267->raw() : nullptr,_2267 ? _2267->size(0) : 0);
      _2259->inst((int)0,_2267,(int)0,_2266);
    }
  }
  else
  {
    {
      _2259->inst((int)0,_2266);
    }
  }
  int _7826 = (int)0;
  int _7827 = _2265;
  for (int _2268 = _7826; _2268 < _7827; ++_2268)
  {
    {
      if ((_ptr__2266[_2268] < (int)0))
      {
        {
          throw ::mosek::fusion::UnimplementedError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2269;
  _checked_ptr_1<int> _ptr__2269(_2269 ? _2269->raw() : nullptr,_2269 ? _2269->size(0) : 0);
  {
    bool _2270 = true;
    int _7828 = (int)0;
    int _7829 = (_2265 - (int)1);
    for (int _2271 = _7828; _2271 < _7829; ++_2271)
    {
      {
        _2270 = (_2270 && (_ptr__2266[_2271] < _ptr__2266[safe_add( _2271,(int)1 )]));
      }
    }
    if (_2270)
    {
      {
        std::vector<int> _7830;
        for (int _2272 = (int)0, _7831 = _2265; _2272 < _7831 ; ++_2272)
        {
          _7830.push_back((int)(_ptr__2266[_2272] - (int)1));
        }
        auto _7832 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7830.size()),_7830.begin(),_7830.end()));
        _2269 = _7832;
        _ptr__2269.update(_2269 ? _2269->raw() : nullptr, _2269 ? _2269->size(0) : 0);
      }
    }
    else
    {
      {
        std::vector<long long> _7833;
        for (int _2274 = (int)0, _7834 = _2265; _2274 < _7834 ; ++_2274)
        {
          _7833.push_back(_2274);
        }
        auto _7835 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7833.size()),_7833.begin(),_7833.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2273 = _7835;
        _checked_ptr_1<long long> _ptr__2273(_2273 ? _2273->raw() : nullptr,_2273 ? _2273->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2273,_2266,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2265));
        int _2275 = (int)1;
        int _7836 = (int)1;
        int _7837 = _2265;
        for (int _2276 = _7836; _2276 < _7837; ++_2276)
        {
          {
            if ((_ptr__2266[_ptr__2273[(_2276 - (int)1)]] < _ptr__2266[_ptr__2273[_2276]]))
            {
              {
                ++ _2275;
              }
            }
            {}
          }
        }
        _2269 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2275)));
        _ptr__2269.update(_2269 ? _2269->raw() : nullptr, _2269 ? _2269->size(0) : 0);
        int _2277 = (int)0;
        _ptr__2269[(int)0] = (int)(_ptr__2266[_ptr__2273[(int)0]] - (int)1);
        int _7838 = (int)1;
        int _7839 = _2265;
        for (int _2278 = _7838; _2278 < _7839; ++_2278)
        {
          {
            if ((_ptr__2266[(_2278 - (int)1)] < _ptr__2266[_2278]))
            {
              {
                _ptr__2269[_2277] = (int)(_ptr__2266[_ptr__2273[_2278]] - (int)1);
                ++ _2277;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2258,_2269,_2260);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2279,monty::rc_ptr< ::mosek::fusion::Variable > _2280) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2279,_2280); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2279,monty::rc_ptr< ::mosek::fusion::Variable > _2280){
  _pubthis->update(_2279,_2280,false);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2281 = (int)1;
  int _7840 = (int)0;
  int _7841 = (int)((shape)->size(0));
  for (int _2282 = _7840; _2282 < _7841; ++_2282)
  {
    {
      _2281 *= ((*shape)(_2282));
    }
  }
  return _2281;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2283,    int _2284) { return mosek::fusion::p_Constraint::stack(_2283,_2284); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2283,int _2284){
  return ::mosek::fusion::p_Constraint::dstack(_2283,_2284);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2285,    monty::rc_ptr< ::mosek::fusion::Constraint > _2286,    monty::rc_ptr< ::mosek::fusion::Constraint > _2287,    int _2288) { return mosek::fusion::p_Constraint::stack(_2285,_2286,_2287,_2288); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2285,monty::rc_ptr< ::mosek::fusion::Constraint > _2286,monty::rc_ptr< ::mosek::fusion::Constraint > _2287,int _2288){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2285.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2286.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2287.get())}),_2288);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2289,    monty::rc_ptr< ::mosek::fusion::Constraint > _2290,    int _2291) { return mosek::fusion::p_Constraint::stack(_2289,_2290,_2291); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2289,monty::rc_ptr< ::mosek::fusion::Constraint > _2290,int _2291){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2289.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2290.get())}),_2291);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2292) { return mosek::fusion::p_Constraint::hstack(_2292); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2292){
  return ::mosek::fusion::p_Constraint::dstack(_2292,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2293) { return mosek::fusion::p_Constraint::vstack(_2293); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2293){
  return ::mosek::fusion::p_Constraint::dstack(_2293,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2294,    monty::rc_ptr< ::mosek::fusion::Constraint > _2295,    monty::rc_ptr< ::mosek::fusion::Constraint > _2296) { return mosek::fusion::p_Constraint::hstack(_2294,_2295,_2296); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2294,monty::rc_ptr< ::mosek::fusion::Constraint > _2295,monty::rc_ptr< ::mosek::fusion::Constraint > _2296){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2294.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2295.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2296.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2297,    monty::rc_ptr< ::mosek::fusion::Constraint > _2298,    monty::rc_ptr< ::mosek::fusion::Constraint > _2299) { return mosek::fusion::p_Constraint::vstack(_2297,_2298,_2299); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2297,monty::rc_ptr< ::mosek::fusion::Constraint > _2298,monty::rc_ptr< ::mosek::fusion::Constraint > _2299){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2297.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2298.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2299.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2300,    monty::rc_ptr< ::mosek::fusion::Constraint > _2301) { return mosek::fusion::p_Constraint::hstack(_2300,_2301); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2300,monty::rc_ptr< ::mosek::fusion::Constraint > _2301){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2300.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2301.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2302,    monty::rc_ptr< ::mosek::fusion::Constraint > _2303) { return mosek::fusion::p_Constraint::vstack(_2302,_2303); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2302,monty::rc_ptr< ::mosek::fusion::Constraint > _2303){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2302.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2303.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2304,int _2305){
  monty::rc_ptr< ::mosek::fusion::Model > _2306 = nullptr;
  {
    int _7842 = (int)0;
    int _7843 = (int)((_2304)->size(0));
    for (int _2307 = _7842; _2307 < _7843; ++_2307)
    {
      {
        if ((NULL == _2306.get()))
        {
          {
            _2306 = ((*_2304)(_2307))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2304)(_2307)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2304)(_2307)))->model != _2306)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2308 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _7844;
            bool _7845 = ((int)((mosek::fusion::p_Model::_get_impl(_2306.get())->getName()).size()) > (int)0);
            if (_7845)
            {
              _7844 = mosek::fusion::p_Model::_get_impl(_2306.get())->getName();
            }
            else
            {
              _7844 = std::string ("?");
            }
            std::string _2309 = _7844;
            std::string _7846;
            bool _7847 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2304)(_2307))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_7847)
            {
              _7846 = mosek::fusion::p_Model::_get_impl(((*_2304)(_2307))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _7846 = std::string ("?");
            }
            std::string _2310 = _7846;
            _2308->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2309)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2310)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2308->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2304)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2304)->size(0)) == (int)1))
  {
    {
      return ((*_2304)((int)1));
    }
  }
  else
  {
    {
      int _2311 = (int)((_2304)->size(0));
      int _2312 = (int)1;
      int _7848 = (int)0;
      int _7849 = _2311;
      for (int _2313 = _7848; _2313 < _7849; ++_2313)
      {
        {
          int _7850;
          bool _7851 = (((*_2304)(_2313))->getND() > _2312);
          if (_7851)
          {
            _7850 = ((*_2304)(_2313))->getND();
          }
          else
          {
            _7850 = _2312;
          }
          _2312 = _7850;
        }
      }
      if ((_2305 == _2312))
      {
        {
          ++ _2312;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2314 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2311,_2312)));
      int _7852 = (int)0;
      int _7853 = _2311;
      for (int _2315 = _7852; _2315 < _7853; ++_2315)
      {
        {
          int _7854 = (int)0;
          int _7855 = _2312;
          for (int _2316 = _7854; _2316 < _7855; ++_2316)
          {
            {
              ((*_2314)(_2315,_2316)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _7856;
      for (int _2318 = (int)0, _7857 = _2311; _2318 < _7857 ; ++_2318)
      {
        _7856.push_back(((*_2304)(_2318))->getSize());
      }
      auto _7858 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7856.size()),_7856.begin(),_7856.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2317 = _7858;
      _checked_ptr_1<int> _ptr__2317(_2317 ? _2317->raw() : nullptr,_2317 ? _2317->size(0) : 0);
      int _2319 = (int)0;
      int _7859 = (int)0;
      int _7860 = _2311;
      for (int _2320 = _7859; _2320 < _7860; ++_2320)
      {
        {
          _2319 += _ptr__2317[_2320];
        }
      }
      int _7861 = (int)0;
      int _7862 = _2311;
      for (int _2321 = _7861; _2321 < _7862; ++_2321)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2322 = ((*_2304)(_2321))->getShape();
          _checked_ptr_1<int> _ptr__2322(_2322 ? _2322->raw() : nullptr,_2322 ? _2322->size(0) : 0);
          int _7863 = (int)0;
          int _7864 = (int)((_2322)->size(0));
          for (int _2323 = _7863; _2323 < _7864; ++_2323)
          {
            {
              ((*_2314)(_2321,_2323)) = _ptr__2322[_2323];
            }
          }
        }
      }
      if (((_2305 < (int)0) || (_2305 > _2312)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _7865 = (int)0;
      int _7866 = _2305;
      for (int _2324 = _7865; _2324 < _7866; ++_2324)
      {
        {
          int _7867 = (int)1;
          int _7868 = _2311;
          for (int _2325 = _7867; _2325 < _7868; ++_2325)
          {
            {
              if ((((*_2314)((int)0,_2324)) != ((*_2314)(_2325,_2324))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _7869 = safe_add( _2305,(int)1 );
      int _7870 = _2312;
      for (int _2326 = _7869; _2326 < _7870; ++_2326)
      {
        {
          int _7871 = (int)1;
          int _7872 = _2311;
          for (int _2327 = _7871; _2327 < _7872; ++_2327)
          {
            {
              if ((((*_2314)((int)0,_2326)) != ((*_2314)(_2327,_2326))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2328 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2319)));
      _checked_ptr_1<int> _ptr__2328(_2328 ? _2328->raw() : nullptr,_2328 ? _2328->size(0) : 0);
      std::vector<int> _7873;
      for (int _2330 = (int)0, _7874 = _2312; _2330 < _7874 ; ++_2330)
      {
        _7873.push_back(((*_2314)((int)0,_2330)));
      }
      auto _7875 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7873.size()),_7873.begin(),_7873.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2329 = _7875;
      _checked_ptr_1<int> _ptr__2329(_2329 ? _2329->raw() : nullptr,_2329 ? _2329->size(0) : 0);
      int _7876 = (int)0;
      int _7877 = _2312;
      for (int _2331 = _7876; _2331 < _7877; ++_2331)
      {
        {
          _ptr__2329[_2305] += ((*_2314)(_2331,_2305));
        }
      }
      {
        int _2332 = (int)((_2329)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2333 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2304)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2333(_2333 ? _2333->raw() : nullptr,_2333 ? _2333->size(0) : 0);
        int _7878 = (int)0;
        int _7879 = (int)((_2304)->size(0));
        for (int _2334 = _7878; _2334 < _7879; ++_2334)
        {
          {
            _ptr__2333[safe_add( _2334,(int)1 )] = safe_add( _ptr__2333[_2334],((*_2314)(_2334,_2305)) );
          }
        }
        if ((_2305 == (int)0))
        {
          {
            int _2335 = (int)0;
            int _7880 = (int)0;
            int _7881 = _2311;
            for (int _2336 = _7880; _2336 < _7881; ++_2336)
            {
              {
                int _2337 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2304)(_2336)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2304)(_2336)))->nativeidxs,(int)0,_2328,_2335,_2337);
                _2335 += _2337;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _7882;
            for (int _2339 = (int)0, _7883 = _2311; _2339 < _7883 ; ++_2339)
            {
              _7882.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2304)(_2339)))->nativeidxs);
            }
            auto _7884 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_7882.size()),_7882.begin(),_7882.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2338 = _7884;
            if ((_2305 < _2312))
            {
              {
                int _2340 = (int)1;
                int _7885 = (int)0;
                int _7886 = _2305;
                for (int _2341 = _7885; _2341 < _7886; ++_2341)
                {
                  {
                    _2340 *= _ptr__2329[_2341];
                  }
                }
                int _2342 = (int)1;
                int _7887 = safe_add( _2305,(int)1 );
                int _7888 = _2312;
                for (int _2343 = _7887; _2343 < _7888; ++_2343)
                {
                  {
                    _2342 *= _ptr__2329[_2343];
                  }
                }
                int _2344 = (int)0;
                int _7889 = (int)0;
                int _7890 = _2340;
                for (int _2345 = _7889; _2345 < _7890; ++_2345)
                {
                  {
                    int _7891 = (int)0;
                    int _7892 = _2311;
                    for (int _2346 = _7891; _2346 < _7892; ++_2346)
                    {
                      {
                        int _2347 = (int)0;
                        int _2348 = ((*_2314)(_2346,_2305));
                        int _7893 = (int)0;
                        int _7894 = _2348;
                        for (int _2349 = _7893; _2349 < _7894; ++_2349)
                        {
                          {
                            int _7895 = (int)0;
                            int _7896 = _2342;
                            for (int _2350 = _7895; _2350 < _7896; ++_2350)
                            {
                              {
                                _ptr__2328[_2344] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2304)(_2311)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2345,_2342 ),_2348 ),_2347 )));
                                ++ _2344;
                                ++ _2347;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2351 = (int)1;
                int _7897 = (int)0;
                int _7898 = _2312;
                for (int _2352 = _7897; _2352 < _7898; ++_2352)
                {
                  {
                    _2351 *= _ptr__2329[_2352];
                  }
                }
                int _2353 = (int)0;
                int _7899 = (int)0;
                int _7900 = _2351;
                for (int _2354 = _7899; _2354 < _7900; ++_2354)
                {
                  {
                    int _7901 = (int)0;
                    int _7902 = _2311;
                    for (int _2355 = _7901; _2355 < _7902; ++_2355)
                    {
                      {
                        _ptr__2328[_2353] = ((*((*_2338)(_2355)))(_2354));
                        ++ _2353;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2306,_2329,_2328)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2356) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2356); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2356) { return __mosek_2fusion_2Constraint__index(_2356); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2356){
  _checked_ptr_1<int> _ptr__2356(_2356 ? _2356->raw() : nullptr, _2356 ? _2356->size(0) : 0);
  if (((int)((_2356)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7903 = (int)0;
      int _7904 = (int)((shape)->size(0));
      for (int _2357 = _7903; _2357 < _7904; ++_2357)
      {
        {
          if (((_ptr__2356[_2357] < (int)0) || (_ptr__2356[_2357] > ((*shape)(_2357)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2358 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2359 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2358)));
      _checked_ptr_1<long long> _ptr__2359(_2359 ? _2359->raw() : nullptr,_2359 ? _2359->size(0) : 0);
      _ptr__2359[(_2358 - (int)1)] = (int)1;
      int _7905 = (int)1;
      int _7906 = _2358;
      for (int _2360 = _7905; _2360 < _7906; ++_2360)
      {
        {
          _ptr__2359[((_2358 - _2360) - (int)1)] = safe_mul( _ptr__2359[(_2358 - _2360)],((*shape)(_2360)) );
        }
      }
      int _2361 = (int)0;
      int _7907 = (int)0;
      int _7908 = _2358;
      for (int _2362 = _7907; _2362 < _7908; ++_2362)
      {
        {
          _2361 += (int)safe_mul( _ptr__2359[_2362],_ptr__2356[_2362] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2361)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2363) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2363); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2363) { return __mosek_2fusion_2Constraint__index(_2363); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2363){
  if ((((int)((shape)->size(0)) == (int)0) && (_2363 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2363 < (int)0) || (_2363 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2363)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2364,std::shared_ptr< monty::ndarray< int,1 > > _2365) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2364,_2365); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2364,std::shared_ptr< monty::ndarray< int,1 > > _2365) { return __mosek_2fusion_2Constraint__slice(_2364,_2365); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2364,std::shared_ptr< monty::ndarray< int,1 > > _2365){
  _checked_ptr_1<int> _ptr__2364(_2364 ? _2364->raw() : nullptr, _2364 ? _2364->size(0) : 0);
  _checked_ptr_1<int> _ptr__2365(_2365 ? _2365->raw() : nullptr, _2365 ? _2365->size(0) : 0);
  if (((int)((_2364)->size(0)) != (int)((_2365)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2364)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _7909 = (int)0;
      int _7910 = (int)((shape)->size(0));
      for (int _2366 = _7909; _2366 < _7910; ++_2366)
      {
        {
          if (((_ptr__2364[_2366] < (int)0) || (_ptr__2365[_2366] > ((*shape)(_2366)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2364[_2366] > _ptr__2365[_2366]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2367 = (int)((shape)->size(0));
      std::vector<int> _7911;
      for (int _2369 = (int)0, _7912 = _2367; _2369 < _7912 ; ++_2369)
      {
        _7911.push_back((_ptr__2365[_2369] - _ptr__2364[_2369]));
      }
      auto _7913 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7911.size()),_7911.begin(),_7911.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2368 = _7913;
      _checked_ptr_1<int> _ptr__2368(_2368 ? _2368->raw() : nullptr,_2368 ? _2368->size(0) : 0);
      int _2370 = (int)1;
      int _7914 = (int)0;
      int _7915 = _2367;
      for (int _2371 = _7914; _2371 < _7915; ++_2371)
      {
        {
          _2370 *= (_ptr__2365[_2371] - _ptr__2364[_2371]);
        }
      }
      if ((_2370 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2368,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2372 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2370)));
          _checked_ptr_1<int> _ptr__2372(_2372 ? _2372->raw() : nullptr,_2372 ? _2372->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2373 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2367)));
            _checked_ptr_1<int> _ptr__2373(_2373 ? _2373->raw() : nullptr,_2373 ? _2373->size(0) : 0);
            _ptr__2373[(_2367 - (int)1)] = (int)1;
            int _7916 = (int)1;
            int _7917 = _2367;
            for (int _2374 = _7916; _2374 < _7917; ++_2374)
            {
              {
                _ptr__2373[((_2367 - _2374) - (int)1)] = safe_mul( _ptr__2373[(_2367 - _2374)],((*shape)((_2367 - _2374))) );
              }
            }
            int _2375 = (int)0;
            int _7918 = (int)0;
            int _7919 = _2367;
            for (int _2376 = _7918; _2376 < _7919; ++_2376)
            {
              {
                _2375 += safe_mul( _ptr__2364[_2376],_ptr__2373[_2376] );
              }
            }
            std::vector<int> _7920;
            for (int _2378 = (int)0, _7921 = _2367; _2378 < _7921 ; ++_2378)
            {
              _7920.push_back(_2375);
            }
            auto _7922 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7920.size()),_7920.begin(),_7920.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2377 = _7922;
            _checked_ptr_1<int> _ptr__2377(_2377 ? _2377->raw() : nullptr,_2377 ? _2377->size(0) : 0);
            std::vector<int> _7923;
            for (int _2380 = (int)0, _7924 = _2367; _2380 < _7924 ; ++_2380)
            {
              _7923.push_back(_ptr__2364[_2380]);
            }
            auto _7925 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7923.size()),_7923.begin(),_7923.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2379 = _7925;
            _checked_ptr_1<int> _ptr__2379(_2379 ? _2379->raw() : nullptr,_2379 ? _2379->size(0) : 0);
            int _7926 = (int)0;
            int _7927 = _2370;
            for (int _2381 = _7926; _2381 < _7927; ++_2381)
            {
              {
                _ptr__2372[_2381] = ((*nativeidxs)(_ptr__2377[(_2367 - (int)1)]));
                _ptr__2379[(_2367 - (int)1)] += (int)1;
                _ptr__2377[(_2367 - (int)1)] += _ptr__2373[(_2367 - (int)1)];
                if ((_ptr__2379[(_2367 - (int)1)] >= _ptr__2365[(_2367 - (int)1)]))
                {
                  {
                    int _2382 = (_2367 - (int)1);
                    while ( ((_2382 > (int)0) && (_ptr__2379[_2382] >= _ptr__2365[_2382])) )
                    {
                      {
                        _ptr__2379[_2382] = _ptr__2364[_2382];
                        _ptr__2379[(_2382 - (int)1)] += (int)1;
                        _ptr__2377[(_2382 - (int)1)] += _ptr__2373[(_2382 - (int)1)];
                        -- _2382;
                      }
                    }
                    int _7928 = safe_add( _2382,(int)1 );
                    int _7929 = _2367;
                    for (int _2383 = _7928; _2383 < _7929; ++_2383)
                    {
                      {
                        _ptr__2377[_2383] = _ptr__2377[_2382];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2368,_2372)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2384,int _2385) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2384,_2385); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2384,int _2385) { return __mosek_2fusion_2Constraint__slice(_2384,_2385); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2384,int _2385){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2384 == (int)0) && (_2385 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2384 < (int)0) || (_2385 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2384 > _2385))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _7930;
      for (int _2386 = _2384, _7931 = _2385; _2386 < _7931 ; ++_2386)
      {
        _7930.push_back(((*nativeidxs)(_2386)));
      }
      auto _7932 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7930.size()),_7930.begin(),_7930.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2385 - _2384))}),_7932)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2387 = (int)1;
  int _7933 = (int)0;
  int _7934 = (int)((shape)->size(0));
  for (int _2388 = _7933; _2388 < _7934; ++_2388)
  {
    {
      _2387 *= ((*shape)(_2388));
    }
  }
  return _2387;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _7935;
  for (int _2389 = (int)0, _7936 = (int)((shape)->size(0)); _2389 < _7936 ; ++_2389)
  {
    _7935.push_back(((*shape)(_2389)));
  }
  auto _7937 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7935.size()),_7935.begin(),_7935.end()));
  return _7937;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2390) { return mosek::fusion::p_Set::size(_2390); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2390){
  _checked_ptr_1<int> _ptr__2390(_2390 ? _2390->raw() : nullptr, _2390 ? _2390->size(0) : 0);
  long long _2391 = (long long)1;
  int _7938 = (int)0;
  int _7939 = (int)((_2390)->size(0));
  for (int _2392 = _7938; _2392 < _7939; ++_2392)
  {
    {
      _2391 *= _ptr__2390[_2392];
    }
  }
  return _2391;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2393,    std::shared_ptr< monty::ndarray< int,1 > > _2394) { return mosek::fusion::p_Set::match(_2393,_2394); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2393,std::shared_ptr< monty::ndarray< int,1 > > _2394){
  _checked_ptr_1<int> _ptr__2393(_2393 ? _2393->raw() : nullptr, _2393 ? _2393->size(0) : 0);
  _checked_ptr_1<int> _ptr__2394(_2394 ? _2394->raw() : nullptr, _2394 ? _2394->size(0) : 0);
  if (((int)((_2393)->size(0)) != (int)((_2394)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _7940 = (int)0;
  int _7941 = (int)((_2393)->size(0));
  for (int _2395 = _7940; _2395 < _7941; ++_2395)
  {
    {
      if ((_ptr__2393[_2395] != _ptr__2394[_2395]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2396,    std::shared_ptr< monty::ndarray< int,1 > > _2397) { return mosek::fusion::p_Set::linearidx(_2396,_2397); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2396,std::shared_ptr< monty::ndarray< int,1 > > _2397){
  _checked_ptr_1<int> _ptr__2396(_2396 ? _2396->raw() : nullptr, _2396 ? _2396->size(0) : 0);
  _checked_ptr_1<int> _ptr__2397(_2397 ? _2397->raw() : nullptr, _2397 ? _2397->size(0) : 0);
  long long _2398 = _ptr__2397[(int)0];
  int _7942 = (int)1;
  int _7943 = (int)((_2397)->size(0));
  for (int _2399 = _7942; _2399 < _7943; ++_2399)
  {
    {
      _2398 = safe_add( safe_mul( _2398,_ptr__2396[_2399] ),_ptr__2397[_2399] );
    }
  }
  return _2398;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2400,    long long _2401) { return mosek::fusion::p_Set::idxtokey(_2400,_2401); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2400,long long _2401){
  _checked_ptr_1<int> _ptr__2400(_2400 ? _2400->raw() : nullptr, _2400 ? _2400->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2402 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2400)->size(0)))));
  _checked_ptr_1<int> _ptr__2402(_2402 ? _2402->raw() : nullptr,_2402 ? _2402->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2400,_2401,_2402);
  return _2402;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2403,    long long _2404,    std::shared_ptr< monty::ndarray< int,1 > > _2405) { mosek::fusion::p_Set::idxtokey(_2403,_2404,_2405); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2403,long long _2404,std::shared_ptr< monty::ndarray< int,1 > > _2405){
  _checked_ptr_1<int> _ptr__2403(_2403 ? _2403->raw() : nullptr, _2403 ? _2403->size(0) : 0);
  _checked_ptr_1<int> _ptr__2405(_2405 ? _2405->raw() : nullptr, _2405 ? _2405->size(0) : 0);
  int _2406 = (int)((_2403)->size(0));
  if ((_2406 > (int)0))
  {
    {
      long long _2407 = _2404;
      int _7944 = (int)0;
      int _7945 = (_2406 - (int)1);
      for (int _2408 = _7944; _2408 < _7945; ++_2408)
      {
        {
          _ptr__2405[((_2406 - _2408) - (int)1)] = (int)(_2407 % _ptr__2403[((_2406 - _2408) - (int)1)]);
          _2407 /= _ptr__2403[((_2406 - _2408) - (int)1)];
        }
      }
      _ptr__2405[(int)0] = (int)_2407;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2409,    long long _2410) { return mosek::fusion::p_Set::indexToString(_2409,_2410); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2409,long long _2410){
  _checked_ptr_1<int> _ptr__2409(_2409 ? _2409->raw() : nullptr, _2409 ? _2409->size(0) : 0);
  int _2411 = (int)((_2409)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2412 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2411 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2411 == (int)1))
  {
    {
      return _2412->__mosek_2fusion_2Utils_2StringBuffer__a(_2410)->toString();
    }
  }
  else
  {
    {
      long long _2413 = _2410;
      std::shared_ptr< monty::ndarray< int,1 > > _2414 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2411)));
      _checked_ptr_1<int> _ptr__2414(_2414 ? _2414->raw() : nullptr,_2414 ? _2414->size(0) : 0);
      int _7946 = (int)1;
      int _7947 = _2411;
      for (int _2415 = _7946; _2415 < _7947; ++_2415)
      {
        {
          _ptr__2414[(_2411 - _2415)] = (int)(_2413 % _ptr__2409[(_2411 - _2415)]);
          _2413 /= _ptr__2409[(_2411 - _2415)];
        }
      }
      _ptr__2414[(int)0] = (int)_2413;
      _2412->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2414[(int)0]);
      int _7948 = (int)1;
      int _7949 = _2411;
      for (int _2416 = _7948; _2416 < _7949; ++_2416)
      {
        {
          _2412->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2414[_2416]);
        }
      }
      return _2412->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2417) { return mosek::fusion::p_Set::keyToString(_2417); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2417){
  _checked_ptr_1<int> _ptr__2417(_2417 ? _2417->raw() : nullptr, _2417 ? _2417->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2418 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2418->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2417[(int)0]);
  int _7950 = (int)1;
  int _7951 = (int)((_2417)->size(0));
  for (int _2419 = _7950; _2419 < _7951; ++_2419)
  {
    {
      _2418->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2417[_2419]);
    }
  }
  return _2418->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2420,    long long _2421,    std::shared_ptr< monty::ndarray< int,1 > > _2422) { mosek::fusion::p_Set::indexToKey(_2420,_2421,_2422); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2420,long long _2421,std::shared_ptr< monty::ndarray< int,1 > > _2422){
  _checked_ptr_1<int> _ptr__2420(_2420 ? _2420->raw() : nullptr, _2420 ? _2420->size(0) : 0);
  _checked_ptr_1<int> _ptr__2422(_2422 ? _2422->raw() : nullptr, _2422 ? _2422->size(0) : 0);
  int _2423 = (int)((_2420)->size(0));
  if ((_2423 == (int)1))
  {
    {
      _ptr__2422[(int)0] = (int)_2421;
    }
  }
  else
  {
    {
      long long _2424 = _2421;
      int _7952 = (int)1;
      int _7953 = _2423;
      for (int _2425 = _7952; _2425 < _7953; ++_2425)
      {
        {
          _ptr__2422[(_2423 - _2425)] = (int)(_2424 % _ptr__2420[(_2423 - _2425)]);
          _2424 /= _ptr__2420[(_2423 - _2425)];
        }
      }
      _ptr__2422[(int)0] = (int)_2424;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2426) { return mosek::fusion::p_Set::strides(_2426); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2426){
  _checked_ptr_1<int> _ptr__2426(_2426 ? _2426->raw() : nullptr, _2426 ? _2426->size(0) : 0);
  int _2427 = (int)((_2426)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2428 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2427)));
  _checked_ptr_1<long long> _ptr__2428(_2428 ? _2428->raw() : nullptr,_2428 ? _2428->size(0) : 0);
  _ptr__2428[(_2427 - (int)1)] = (int)1;
  int _7954 = (int)1;
  int _7955 = _2427;
  for (int _2429 = _7954; _2429 < _7955; ++_2429)
  {
    {
      _ptr__2428[((_2427 - _2429) - (int)1)] = safe_mul( _ptr__2428[(_2427 - _2429)],_ptr__2426[(_2427 - _2429)] );
    }
  }
  return _2428;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2430,    std::shared_ptr< monty::ndarray< int,1 > > _2431) { return mosek::fusion::p_Set::make(_2430,_2431); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2430,std::shared_ptr< monty::ndarray< int,1 > > _2431){
  _checked_ptr_1<int> _ptr__2430(_2430 ? _2430->raw() : nullptr, _2430 ? _2430->size(0) : 0);
  _checked_ptr_1<int> _ptr__2431(_2431 ? _2431->raw() : nullptr, _2431 ? _2431->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2432 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2430)->size(0)),(int)((_2431)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2432(_2432 ? _2432->raw() : nullptr,_2432 ? _2432->size(0) : 0);
  int _7956 = (int)0;
  int _7957 = (int)((_2430)->size(0));
  for (int _2433 = _7956; _2433 < _7957; ++_2433)
  {
    {
      _ptr__2432[_2433] = _ptr__2430[_2433];
    }
  }
  int _7958 = (int)0;
  int _7959 = (int)((_2431)->size(0));
  for (int _2434 = _7958; _2434 < _7959; ++_2434)
  {
    {
      _ptr__2432[safe_add( (int)((_2430)->size(0)),_2434 )] = _ptr__2431[_2434];
    }
  }
  return _2432;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2435) { return mosek::fusion::p_Set::make(_2435); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2435){
  _checked_ptr_1<int> _ptr__2435(_2435 ? _2435->raw() : nullptr, _2435 ? _2435->size(0) : 0);
  std::vector<int> _7960;
  for (int _2436 = (int)0, _7961 = (int)((_2435)->size(0)); _2436 < _7961 ; ++_2436)
  {
    _7960.push_back(_ptr__2435[_2436]);
  }
  auto _7962 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7960.size()),_7960.begin(),_7960.end()));
  return _7962;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2437,    int _2438,    int _2439) { return mosek::fusion::p_Set::make(_2437,_2438,_2439); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2437,int _2438,int _2439){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2437),(int)(_2438),(int)(_2439)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2440,    int _2441) { return mosek::fusion::p_Set::make(_2440,_2441); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2440,int _2441){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2440),(int)(_2441)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2442) { return mosek::fusion::p_Set::make(_2442); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2442){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2442)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2443) { return mosek::fusion::p_Set::make(_2443); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2443){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2443)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2444,    double _2445,    std::shared_ptr< monty::ndarray< int,1 > > _2446){ return new mosek::fusion::ConeDomain(_2444,_2445,_2446); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2444,    double _2445,    std::shared_ptr< monty::ndarray< int,1 > > _2446) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2444,_2445,_2446); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2444,    double _2445,    std::shared_ptr< monty::ndarray< int,1 > > _2446){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2446(_2446 ? _2446->raw() : nullptr, _2446 ? _2446->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _7963;
    bool _7964 = (NULL != _2446.get());
    if (_7964)
    {
      _7963 = ::mosek::fusion::p_Set::make(_2446);
    }
    else
    {
      _7963 = nullptr;
    }
    shape = _7963;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2445;
    key = _2444;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2445;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2447,    std::shared_ptr< monty::ndarray< int,1 > > _2448){ return new mosek::fusion::ConeDomain(_2447,_2448); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2447,    std::shared_ptr< monty::ndarray< int,1 > > _2448) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2447,_2448); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2447,    std::shared_ptr< monty::ndarray< int,1 > > _2448){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2448(_2448 ? _2448->raw() : nullptr, _2448 ? _2448->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2447,1.0,_2448);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2449){
  _checked_ptr_1<int> _ptr__2449(_2449 ? _2449->raw() : nullptr, _2449 ? _2449->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2449,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2450) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2450); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2450) { return __mosek_2fusion_2ConeDomain__axis(_2450); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2450){
  axisidx = _2450;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2451,    int _2452){ return new mosek::fusion::LinPSDDomain(_2451,_2452); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2451,    int _2452) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2451,_2452); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2451,    int _2452){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2451(_2451 ? _2451->raw() : nullptr, _2451 ? _2451->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2452;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2451);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2453){ return new mosek::fusion::LinPSDDomain(_2453); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2453) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2453); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2453){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2453(_2453 ? _2453->raw() : nullptr, _2453 ? _2453->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2453);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2454,    std::shared_ptr< monty::ndarray< int,1 > > _2455,    int _2456,    int _2457){ return new mosek::fusion::PSDDomain(_2454,_2455,_2456,_2457); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2454,    std::shared_ptr< monty::ndarray< int,1 > > _2455,    int _2456,    int _2457) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2454,_2455,_2456,_2457); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2454,    std::shared_ptr< monty::ndarray< int,1 > > _2455,    int _2456,    int _2457){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2455(_2455 ? _2455->raw() : nullptr, _2455 ? _2455->size(0) : 0);
    axisIsSet = true;
    shape = _2455;
    key = _2454;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2456;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2457;
    int _2458 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2456) && (((int)((shape)->size(0)) > _2457) && ((_2456 >= (int)0) && ((_2457 >= (int)0) && (_2456 != _2457)))))) && (((*shape)(_2456)) == ((*shape)(_2457)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2459,    std::shared_ptr< monty::ndarray< int,1 > > _2460){ return new mosek::fusion::PSDDomain(_2459,_2460); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2459,    std::shared_ptr< monty::ndarray< int,1 > > _2460) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2459,_2460); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2459,    std::shared_ptr< monty::ndarray< int,1 > > _2460){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2460(_2460 ? _2460->raw() : nullptr, _2460 ? _2460->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2459,_2460,((int)((_2460)->size(0)) - (int)2),((int)((_2460)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2461){ return new mosek::fusion::PSDDomain(_2461); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2461) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2461); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2461){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2461;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2462,int _2463) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2462,_2463); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2462,int _2463) { return __mosek_2fusion_2PSDDomain__axis(_2462,_2463); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2462,int _2463){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2462;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2463;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2462 >= (int)0) && ((_2463 >= (int)0) && (_2462 != _2463))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2462) && (((int)((shape)->size(0)) > _2463) && ((_2462 >= (int)0) && ((_2463 >= (int)0) && (_2462 != _2463)))))) && (((*shape)(_2462)) == ((*shape)(_2463))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2464){ return new mosek::fusion::SymmetricRangeDomain(_2464); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2464) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2464); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2464){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2464);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7965;
    bool _7966 = (NULL == shape.get());
    if (_7966)
    {
      _7965 = (int)0;
    }
    else
    {
      _7965 = ((*shape)((int)0));
    }
    dim = _7965;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2465,    std::shared_ptr< monty::ndarray< double,1 > > _2466,    std::shared_ptr< monty::ndarray< double,1 > > _2467,    std::shared_ptr< monty::ndarray< int,1 > > _2468){ return new mosek::fusion::RangeDomain(_2465,_2466,_2467,_2468); }mosek::fusion::RangeDomain::RangeDomain  (bool _2465,    std::shared_ptr< monty::ndarray< double,1 > > _2466,    std::shared_ptr< monty::ndarray< double,1 > > _2467,    std::shared_ptr< monty::ndarray< int,1 > > _2468) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2465,_2466,_2467,_2468); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2465,    std::shared_ptr< monty::ndarray< double,1 > > _2466,    std::shared_ptr< monty::ndarray< double,1 > > _2467,    std::shared_ptr< monty::ndarray< int,1 > > _2468){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2466(_2466 ? _2466->raw() : nullptr, _2466 ? _2466->size(0) : 0);
    _checked_ptr_1<double> _ptr__2467(_2467 ? _2467->raw() : nullptr, _2467 ? _2467->size(0) : 0);
    _checked_ptr_1<int> _ptr__2468(_2468 ? _2468->raw() : nullptr, _2468 ? _2468->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2465,_2466,_2467,_2468,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2469,    std::shared_ptr< monty::ndarray< double,1 > > _2470,    std::shared_ptr< monty::ndarray< double,1 > > _2471,    std::shared_ptr< monty::ndarray< int,1 > > _2472,    std::shared_ptr< monty::ndarray< int,2 > > _2473){ return new mosek::fusion::RangeDomain(_2469,_2470,_2471,_2472,_2473); }mosek::fusion::RangeDomain::RangeDomain  (bool _2469,    std::shared_ptr< monty::ndarray< double,1 > > _2470,    std::shared_ptr< monty::ndarray< double,1 > > _2471,    std::shared_ptr< monty::ndarray< int,1 > > _2472,    std::shared_ptr< monty::ndarray< int,2 > > _2473) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2469,_2470,_2471,_2472,_2473); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2469,    std::shared_ptr< monty::ndarray< double,1 > > _2470,    std::shared_ptr< monty::ndarray< double,1 > > _2471,    std::shared_ptr< monty::ndarray< int,1 > > _2472,    std::shared_ptr< monty::ndarray< int,2 > > _2473){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2470(_2470 ? _2470->raw() : nullptr, _2470 ? _2470->size(0) : 0);
    _checked_ptr_1<double> _ptr__2471(_2471 ? _2471->raw() : nullptr, _2471 ? _2471->size(0) : 0);
    _checked_ptr_1<int> _ptr__2472(_2472 ? _2472->raw() : nullptr, _2472 ? _2472->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2469,_2470,_2471,_2472,_2473,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2474,    std::shared_ptr< monty::ndarray< double,1 > > _2475,    std::shared_ptr< monty::ndarray< double,1 > > _2476,    std::shared_ptr< monty::ndarray< int,1 > > _2477,    std::shared_ptr< monty::ndarray< int,2 > > _2478,    int _2479){ return new mosek::fusion::RangeDomain(_2474,_2475,_2476,_2477,_2478,_2479); }mosek::fusion::RangeDomain::RangeDomain  (bool _2474,    std::shared_ptr< monty::ndarray< double,1 > > _2475,    std::shared_ptr< monty::ndarray< double,1 > > _2476,    std::shared_ptr< monty::ndarray< int,1 > > _2477,    std::shared_ptr< monty::ndarray< int,2 > > _2478,    int _2479) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2474,_2475,_2476,_2477,_2478,_2479); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2474,    std::shared_ptr< monty::ndarray< double,1 > > _2475,    std::shared_ptr< monty::ndarray< double,1 > > _2476,    std::shared_ptr< monty::ndarray< int,1 > > _2477,    std::shared_ptr< monty::ndarray< int,2 > > _2478,    int _2479){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2475(_2475 ? _2475->raw() : nullptr, _2475 ? _2475->size(0) : 0);
    _checked_ptr_1<double> _ptr__2476(_2476 ? _2476->raw() : nullptr, _2476 ? _2476->size(0) : 0);
    _checked_ptr_1<int> _ptr__2477(_2477 ? _2477->raw() : nullptr, _2477 ? _2477->size(0) : 0);
    cardinal_flag = false;
    shape = _2477;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2474;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2476;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2475;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2478;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2480){ return new mosek::fusion::RangeDomain(_2480); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2480) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2480); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2480){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2480)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2480)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2480)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2480)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2480)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2480)->lb;
    empty = mosek::fusion::p_RangeDomain::_get_impl(_2480)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2481); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481) { return __mosek_2fusion_2RangeDomain__sparse(_2481); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2481)->size(0)),(int)((_2481)->size(1)))));
  {
    int _2482 = (int)0;
    for(;(_2482 < (int)((_2481)->size(0)));++ _2482)
    {
      {
        {
          int _2483 = (int)0;
          for(;(_2483 < (int)((_2481)->size(1)));++ _2483)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2482,_2483)) = ((*_2481)(_2482,_2483));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2484); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484) { return __mosek_2fusion_2RangeDomain__sparse(_2484); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484){
  _checked_ptr_1<int> _ptr__2484(_2484 ? _2484->raw() : nullptr, _2484 ? _2484->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2484)->size(0)),(int)1)));
  int _7967 = (int)0;
  int _7968 = (int)((_2484)->size(0));
  for (int _2485 = _7967; _2485 < _7968; ++_2485)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2485,(int)0)) = _ptr__2484[_2485];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse() { return __mosek_2fusion_2RangeDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2486); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486) { return __mosek_2fusion_2RangeDomain__withShape(_2486); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486){
  _checked_ptr_1<int> _ptr__2486(_2486 ? _2486->raw() : nullptr, _2486 ? _2486->size(0) : 0);
  shape = _2486;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2487){
  _checked_ptr_1<int> _ptr__2487(_2487 ? _2487->raw() : nullptr, _2487 ? _2487->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2487)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _7969 = (int)0;
      int _7970 = (int)((shape)->size(0));
      for (int _2488 = _7969; _2488 < _7970; ++_2488)
      {
        {
          if ((((*shape)(_2488)) != _ptr__2487[_2488]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2489){ return new mosek::fusion::SymmetricLinearDomain(_2489); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2489) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2489); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2489){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2489;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2489)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2489)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2489)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2489)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _7971;
    bool _7972 = (NULL == shape.get());
    if (_7972)
    {
      _7971 = (int)0;
    }
    else
    {
      _7971 = ((*shape)((int)0));
    }
    dim = _7971;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2490) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2490); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2490) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2490); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2490){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2490)->size(0)),(int)((_2490)->size(1)))));
  {
    int _2491 = (int)0;
    for(;(_2491 < (int)((_2490)->size(0)));++ _2491)
    {
      {
        {
          int _2492 = (int)0;
          for(;(_2492 < (int)((_2490)->size(1)));++ _2492)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2491,_2492)) = ((*_2490)(_2491,_2492));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2493) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2493); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2493) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2493); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2493){
  _checked_ptr_1<int> _ptr__2493(_2493 ? _2493->raw() : nullptr, _2493 ? _2493->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2493)->size(0)),(int)1)));
  int _7973 = (int)0;
  int _7974 = (int)((_2493)->size(0));
  for (int _2494 = _7973; _2494 < _7974; ++_2494)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2494,(int)0)) = _ptr__2493[_2494];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2495){
  _checked_ptr_1<int> _ptr__2495(_2495 ? _2495->raw() : nullptr, _2495 ? _2495->size(0) : 0);
  int _7975 = (int)0;
  int _7976 = (int)((_2495)->size(0));
  for (int _2496 = _7975; _2496 < _7976; ++_2496)
  {
    {
      if ((_ptr__2495[_2496] == ((*shape)(_2496))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2497,    bool _2498,    std::shared_ptr< monty::ndarray< double,1 > > _2499,    std::shared_ptr< monty::ndarray< int,1 > > _2500){ return new mosek::fusion::LinearDomain(_2497,_2498,_2499,_2500); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2497,    bool _2498,    std::shared_ptr< monty::ndarray< double,1 > > _2499,    std::shared_ptr< monty::ndarray< int,1 > > _2500) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2497,_2498,_2499,_2500); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2497,    bool _2498,    std::shared_ptr< monty::ndarray< double,1 > > _2499,    std::shared_ptr< monty::ndarray< int,1 > > _2500){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2499(_2499 ? _2499->raw() : nullptr, _2499 ? _2499->size(0) : 0);
    _checked_ptr_1<int> _ptr__2500(_2500 ? _2500->raw() : nullptr, _2500 ? _2500->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2497,_2498,_2499,_2500,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2501,    bool _2502,    std::shared_ptr< monty::ndarray< double,1 > > _2503,    std::shared_ptr< monty::ndarray< int,1 > > _2504,    std::shared_ptr< monty::ndarray< int,2 > > _2505,    int _2506){ return new mosek::fusion::LinearDomain(_2501,_2502,_2503,_2504,_2505,_2506); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2501,    bool _2502,    std::shared_ptr< monty::ndarray< double,1 > > _2503,    std::shared_ptr< monty::ndarray< int,1 > > _2504,    std::shared_ptr< monty::ndarray< int,2 > > _2505,    int _2506) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2501,_2502,_2503,_2504,_2505,_2506); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2501,    bool _2502,    std::shared_ptr< monty::ndarray< double,1 > > _2503,    std::shared_ptr< monty::ndarray< int,1 > > _2504,    std::shared_ptr< monty::ndarray< int,2 > > _2505,    int _2506){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2503(_2503 ? _2503->raw() : nullptr, _2503 ? _2503->size(0) : 0);
    _checked_ptr_1<int> _ptr__2504(_2504 ? _2504->raw() : nullptr, _2504 ? _2504->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2502;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2504;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2501;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2503;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2505;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2507){ return new mosek::fusion::LinearDomain(_2507); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2507) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2507); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2507){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2507)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2507)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2507)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2507)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2507)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2507)->cardinal_flag;
    empty = mosek::fusion::p_LinearDomain::_get_impl(_2507)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2508) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2508); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2508) { return __mosek_2fusion_2LinearDomain__sparse(_2508); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2508){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2508)->size(0)),(int)((_2508)->size(1)))));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  {
    int _2509 = (int)0;
    for(;(_2509 < (int)((_2508)->size(0)));++ _2509)
    {
      {
        {
          int _2510 = (int)0;
          for(;(_2510 < (int)((_2508)->size(1)));++ _2510)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2509,_2510)) = ((*_2508)(_2509,_2510));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2511) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2511); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2511) { return __mosek_2fusion_2LinearDomain__sparse(_2511); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2511){
  _checked_ptr_1<int> _ptr__2511(_2511 ? _2511->raw() : nullptr, _2511 ? _2511->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2511)->size(0)),(int)1)));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  int _7977 = (int)0;
  int _7978 = (int)((_2511)->size(0));
  for (int _2512 = _7977; _2512 < _7978; ++_2512)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2512,(int)0)) = _ptr__2511[_2512];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse() { return __mosek_2fusion_2LinearDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2513) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2513); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2513) { return __mosek_2fusion_2LinearDomain__withShape(_2513); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2513){
  _checked_ptr_1<int> _ptr__2513(_2513 ? _2513->raw() : nullptr, _2513 ? _2513->size(0) : 0);
  shape = _2513;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2514){
  _checked_ptr_1<int> _ptr__2514(_2514 ? _2514->raw() : nullptr, _2514 ? _2514->size(0) : 0);
  if ((!scalable))
  {
    {
      int _7979 = (int)0;
      int _7980 = (int)((_2514)->size(0));
      for (int _2515 = _7979; _2515 < _7980; ++_2515)
      {
        {
          if ((_ptr__2514[_2515] == ((*shape)(_2515))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2516){
  _checked_ptr_1<int> _ptr__2516(_2516 ? _2516->raw() : nullptr, _2516 ? _2516->size(0) : 0);
  long long _2517 = (long long)1;
  int _7981 = (int)0;
  int _7982 = (int)((_2516)->size(0));
  for (int _2518 = _7981; _2518 < _7982; ++_2518)
  {
    {
      _2517 *= _ptr__2516[_2518];
    }
  }
  return _2517;
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _2519,monty::rc_ptr< ::mosek::fusion::Matrix > _2520){
  if (_2520->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2521 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2520->numNonzeros())));
      _checked_ptr_1<int> _ptr__2521(_2521 ? _2521->raw() : nullptr,_2521 ? _2521->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2522 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2520->numNonzeros())));
      _checked_ptr_1<int> _ptr__2522(_2522 ? _2522->raw() : nullptr,_2522 ? _2522->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2523 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2520->numNonzeros())));
      _checked_ptr_1<double> _ptr__2523(_2523 ? _2523->raw() : nullptr,_2523 ? _2523->size(0) : 0);
      _2520->getDataAsTriplets(_2521,_2522,_2523);
      std::shared_ptr< monty::ndarray< int,2 > > _2524 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2521)->size(0)),(int)2)));
      int _7983 = (int)0;
      int _7984 = (int)((_2521)->size(0));
      for (int _2525 = _7983; _2525 < _7984; ++_2525)
      {
        {
          ((*_2524)(_2525,(int)0)) = _ptr__2521[_2525];
          ((*_2524)(_2525,(int)1)) = _ptr__2522[_2525];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2519,false,_2523,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2520)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2520)->dimj)}),_2524,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_2519,false,_2520->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2520)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2520)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _2526){
  _checked_ptr_1<int> _ptr__2526(_2526 ? _2526->raw() : nullptr, _2526 ? _2526->size(0) : 0);
  long long _2527 = (int)1;
  int _7985 = (int)0;
  int _7986 = (int)((_2526)->size(0));
  for (int _2528 = _7985; _2528 < _7986; ++_2528)
  {
    {
      _2527 *= _ptr__2526[_2528];
    }
  }
  return _2527;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _2529,std::shared_ptr< monty::ndarray< double,1 > > _2530,std::shared_ptr< monty::ndarray< double,1 > > _2531,std::shared_ptr< monty::ndarray< int,2 > > _2532,std::shared_ptr< monty::ndarray< int,1 > > _2533){
  _checked_ptr_1<double> _ptr__2530(_2530 ? _2530->raw() : nullptr, _2530 ? _2530->size(0) : 0);
  _checked_ptr_1<double> _ptr__2531(_2531 ? _2531->raw() : nullptr, _2531 ? _2531->size(0) : 0);
  _checked_ptr_1<int> _ptr__2533(_2533 ? _2533->raw() : nullptr, _2533 ? _2533->size(0) : 0);
  if (((!_2529) && ((int)((_2530)->size(0)) != (int)((_2531)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _2532.get()) && ((int)((_2532)->size(0)) != (int)((_2530)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _7987 = (int)0;
  int _7988 = (int)((_2531)->size(0));
  for (int _2534 = _7987; _2534 < _7988; ++_2534)
  {
    {
      if ((_ptr__2530[_2534] > _ptr__2531[_2534]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _2533.get()) && (::mosek::fusion::p_Domain::dimsize(_2533) != (int)((_2530)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_2529,_2530,_2531,_2533)->__mosek_2fusion_2RangeDomain__sparse(_2532);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2535) { return mosek::fusion::p_Domain::symmetric(_2535); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2535){
  return _2535->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2536) { return mosek::fusion::p_Domain::symmetric(_2536); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2536){
  return _2536->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2537,    std::shared_ptr< monty::ndarray< int,2 > > _2538) { return mosek::fusion::p_Domain::sparse(_2537,_2538); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2537,std::shared_ptr< monty::ndarray< int,2 > > _2538){
  return _2537->__mosek_2fusion_2RangeDomain__sparse(_2538);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2539,    std::shared_ptr< monty::ndarray< int,1 > > _2540) { return mosek::fusion::p_Domain::sparse(_2539,_2540); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2539,std::shared_ptr< monty::ndarray< int,1 > > _2540){
  _checked_ptr_1<int> _ptr__2540(_2540 ? _2540->raw() : nullptr, _2540 ? _2540->size(0) : 0);
  return _2539->__mosek_2fusion_2RangeDomain__sparse(_2540);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2541,    std::shared_ptr< monty::ndarray< int,2 > > _2542) { return mosek::fusion::p_Domain::sparse(_2541,_2542); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2541,std::shared_ptr< monty::ndarray< int,2 > > _2542){
  return _2541->__mosek_2fusion_2LinearDomain__sparse(_2542);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2543,    std::shared_ptr< monty::ndarray< int,1 > > _2544) { return mosek::fusion::p_Domain::sparse(_2543,_2544); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2543,std::shared_ptr< monty::ndarray< int,1 > > _2544){
  _checked_ptr_1<int> _ptr__2544(_2544 ? _2544->raw() : nullptr, _2544 ? _2544->size(0) : 0);
  return _2543->__mosek_2fusion_2LinearDomain__sparse(_2544);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _2545) { return mosek::fusion::p_Domain::integral(_2545); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2545){
  return _2545->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _2546) { return mosek::fusion::p_Domain::integral(_2546); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2546){
  return _2546->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2547) { return mosek::fusion::p_Domain::integral(_2547); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2547){
  return _2547->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _2548,    int _2549) { return mosek::fusion::p_Domain::axis(_2548,_2549); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2548,int _2549){
  return _2548->__mosek_2fusion_2ConeDomain__axis(_2549);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2550,    std::shared_ptr< monty::ndarray< int,1 > > _2551) { return mosek::fusion::p_Domain::inDPowerCone(_2550,_2551); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2550,std::shared_ptr< monty::ndarray< int,1 > > _2551){
  _checked_ptr_1<int> _ptr__2551(_2551 ? _2551->raw() : nullptr, _2551 ? _2551->size(0) : 0);
  std::vector<int> _7989;
  for (int _2552 = (int)0, _7990 = (int)((_2551)->size(0)); _2552 < _7990 ; ++_2552)
  {
    _7989.push_back(_ptr__2551[_2552]);
  }
  auto _7991 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7989.size()),_7989.begin(),_7989.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2550,_7991);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2553,    int _2554) { return mosek::fusion::p_Domain::inDPowerCone(_2553,_2554); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2553,int _2554){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2553,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2554),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _2555) { return mosek::fusion::p_Domain::inDPowerCone(_2555); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _2555){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_2555,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2556,    std::shared_ptr< monty::ndarray< int,1 > > _2557) { return mosek::fusion::p_Domain::inPPowerCone(_2556,_2557); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2556,std::shared_ptr< monty::ndarray< int,1 > > _2557){
  _checked_ptr_1<int> _ptr__2557(_2557 ? _2557->raw() : nullptr, _2557 ? _2557->size(0) : 0);
  std::vector<int> _7992;
  for (int _2558 = (int)0, _7993 = (int)((_2557)->size(0)); _2558 < _7993 ; ++_2558)
  {
    _7992.push_back(_ptr__2557[_2558]);
  }
  auto _7994 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7992.size()),_7992.begin(),_7992.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2556,_7994);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2559,    int _2560) { return mosek::fusion::p_Domain::inPPowerCone(_2559,_2560); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2559,int _2560){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2559,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2560),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _2561) { return mosek::fusion::p_Domain::inPPowerCone(_2561); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _2561){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_2561,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2562) { return mosek::fusion::p_Domain::inDExpCone(_2562); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2562){
  _checked_ptr_1<int> _ptr__2562(_2562 ? _2562->raw() : nullptr, _2562 ? _2562->size(0) : 0);
  std::vector<int> _7995;
  for (int _2563 = (int)0, _7996 = (int)((_2562)->size(0)); _2563 < _7996 ; ++_2563)
  {
    _7995.push_back(_ptr__2562[_2563]);
  }
  auto _7997 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7995.size()),_7995.begin(),_7995.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_7997);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _2564) { return mosek::fusion::p_Domain::inDExpCone(_2564); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _2564){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2564),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2565) { return mosek::fusion::p_Domain::inPExpCone(_2565); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2565){
  _checked_ptr_1<int> _ptr__2565(_2565 ? _2565->raw() : nullptr, _2565 ? _2565->size(0) : 0);
  std::vector<int> _7998;
  for (int _2566 = (int)0, _7999 = (int)((_2565)->size(0)); _2566 < _7999 ; ++_2566)
  {
    _7998.push_back(_ptr__2565[_2566]);
  }
  auto _8000 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7998.size()),_7998.begin(),_7998.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_8000);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _2567) { return mosek::fusion::p_Domain::inPExpCone(_2567); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _2567){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2567),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2568) { return mosek::fusion::p_Domain::inRotatedQCone(_2568); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2568){
  _checked_ptr_1<int> _ptr__2568(_2568 ? _2568->raw() : nullptr, _2568 ? _2568->size(0) : 0);
  std::vector<int> _8001;
  for (int _2569 = (int)0, _8002 = (int)((_2568)->size(0)); _2569 < _8002 ; ++_2569)
  {
    _8001.push_back(_ptr__2568[_2569]);
  }
  auto _8003 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8001.size()),_8001.begin(),_8001.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_8003);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2570,    int _2571) { return mosek::fusion::p_Domain::inRotatedQCone(_2570,_2571); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2570,int _2571){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2570),(int)(_2571)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _2572) { return mosek::fusion::p_Domain::inRotatedQCone(_2572); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _2572){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2572)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _2573) { return mosek::fusion::p_Domain::inQCone(_2573); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2573){
  _checked_ptr_1<int> _ptr__2573(_2573 ? _2573->raw() : nullptr, _2573 ? _2573->size(0) : 0);
  std::vector<int> _8004;
  for (int _2574 = (int)0, _8005 = (int)((_2573)->size(0)); _2574 < _8005 ; ++_2574)
  {
    _8004.push_back(_ptr__2573[_2574]);
  }
  auto _8006 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8004.size()),_8004.begin(),_8004.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_8006);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2575,    int _2576) { return mosek::fusion::p_Domain::inQCone(_2575,_2576); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2575,int _2576){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2575),(int)(_2576)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _2577) { return mosek::fusion::p_Domain::inQCone(_2577); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _2577){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2577)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2578,    int _2579) { return mosek::fusion::p_Domain::isLinPSD(_2578,_2579); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2578,int _2579){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2578,safe_add( _2578,(int)1 ) ) / (int)2),_2579));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _2580) { return mosek::fusion::p_Domain::isLinPSD(_2580); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _2580){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _2580,safe_add( _2580,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2581,    int _2582) { return mosek::fusion::p_Domain::isTrilPSD(_2581,_2582); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2581,int _2582){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2582),(int)(_2581),(int)(_2581)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _2583) { return mosek::fusion::p_Domain::isTrilPSD(_2583); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _2583){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2583),(int)(_2583)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2584,    int _2585) { return mosek::fusion::p_Domain::inPSDCone(_2584,_2585); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2584,int _2585){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2585),(int)(_2584),(int)(_2584)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _2586) { return mosek::fusion::p_Domain::inPSDCone(_2586); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _2586){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2586),(int)(_2586)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _2587) { return mosek::fusion::p_Domain::binary(_2587); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _2587){
  _checked_ptr_1<int> _ptr__2587(_2587 ? _2587->raw() : nullptr, _2587 ? _2587->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_2587)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2588,    int _2589) { return mosek::fusion::p_Domain::binary(_2588,_2589); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2588,int _2589){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2588),(int)(_2589)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _2590) { return mosek::fusion::p_Domain::binary(_2590); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _2590){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2590)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2591,    std::shared_ptr< monty::ndarray< double,1 > > _2592,    std::shared_ptr< monty::ndarray< int,1 > > _2593) { return mosek::fusion::p_Domain::inRange(_2591,_2592,_2593); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2591,std::shared_ptr< monty::ndarray< double,1 > > _2592,std::shared_ptr< monty::ndarray< int,1 > > _2593){
  _checked_ptr_1<double> _ptr__2591(_2591 ? _2591->raw() : nullptr, _2591 ? _2591->size(0) : 0);
  _checked_ptr_1<double> _ptr__2592(_2592 ? _2592->raw() : nullptr, _2592 ? _2592->size(0) : 0);
  _checked_ptr_1<int> _ptr__2593(_2593 ? _2593->raw() : nullptr, _2593 ? _2593->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2591,_2592,_2593);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2594,    double _2595,    std::shared_ptr< monty::ndarray< int,1 > > _2596) { return mosek::fusion::p_Domain::inRange(_2594,_2595,_2596); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2594,double _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596){
  _checked_ptr_1<double> _ptr__2594(_2594 ? _2594->raw() : nullptr, _2594 ? _2594->size(0) : 0);
  _checked_ptr_1<int> _ptr__2596(_2596 ? _2596->raw() : nullptr, _2596 ? _2596->size(0) : 0);
  std::vector<double> _8007;
  for (int _2597 = (int)0, _8008 = (int)((_2594)->size(0)); _2597 < _8008 ; ++_2597)
  {
    _8007.push_back(_2595);
  }
  auto _8009 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8007.size()),_8007.begin(),_8007.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2594,_8009,_2596);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2598,    std::shared_ptr< monty::ndarray< double,1 > > _2599,    std::shared_ptr< monty::ndarray< int,1 > > _2600) { return mosek::fusion::p_Domain::inRange(_2598,_2599,_2600); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2598,std::shared_ptr< monty::ndarray< double,1 > > _2599,std::shared_ptr< monty::ndarray< int,1 > > _2600){
  _checked_ptr_1<double> _ptr__2599(_2599 ? _2599->raw() : nullptr, _2599 ? _2599->size(0) : 0);
  _checked_ptr_1<int> _ptr__2600(_2600 ? _2600->raw() : nullptr, _2600 ? _2600->size(0) : 0);
  std::vector<double> _8010;
  for (int _2601 = (int)0, _8011 = (int)((_2599)->size(0)); _2601 < _8011 ; ++_2601)
  {
    _8010.push_back(_2598);
  }
  auto _8012 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8010.size()),_8010.begin(),_8010.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8012,_2599,_2600);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2602,    double _2603,    std::shared_ptr< monty::ndarray< int,1 > > _2604) { return mosek::fusion::p_Domain::inRange(_2602,_2603,_2604); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2602,double _2603,std::shared_ptr< monty::ndarray< int,1 > > _2604){
  _checked_ptr_1<int> _ptr__2604(_2604 ? _2604->raw() : nullptr, _2604 ? _2604->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2602)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2603)}),_2604);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2605,    std::shared_ptr< monty::ndarray< double,1 > > _2606) { return mosek::fusion::p_Domain::inRange(_2605,_2606); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2605,std::shared_ptr< monty::ndarray< double,1 > > _2606){
  _checked_ptr_1<double> _ptr__2605(_2605 ? _2605->raw() : nullptr, _2605 ? _2605->size(0) : 0);
  _checked_ptr_1<double> _ptr__2606(_2606 ? _2606->raw() : nullptr, _2606 ? _2606->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2605,_2606,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2605)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _2607,    double _2608) { return mosek::fusion::p_Domain::inRange(_2607,_2608); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _2607,double _2608){
  _checked_ptr_1<double> _ptr__2607(_2607 ? _2607->raw() : nullptr, _2607 ? _2607->size(0) : 0);
  std::vector<double> _8013;
  for (int _2609 = (int)0, _8014 = (int)((_2607)->size(0)); _2609 < _8014 ; ++_2609)
  {
    _8013.push_back(_2608);
  }
  auto _8015 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8013.size()),_8013.begin(),_8013.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2607,_8015,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2607)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2610,    std::shared_ptr< monty::ndarray< double,1 > > _2611) { return mosek::fusion::p_Domain::inRange(_2610,_2611); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2610,std::shared_ptr< monty::ndarray< double,1 > > _2611){
  _checked_ptr_1<double> _ptr__2611(_2611 ? _2611->raw() : nullptr, _2611 ? _2611->size(0) : 0);
  std::vector<double> _8016;
  for (int _2612 = (int)0, _8017 = (int)((_2611)->size(0)); _2612 < _8017 ; ++_2612)
  {
    _8016.push_back(_2610);
  }
  auto _8018 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8016.size()),_8016.begin(),_8016.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_8018,_2611,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2611)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _2613,    double _2614) { return mosek::fusion::p_Domain::inRange(_2613,_2614); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _2613,double _2614){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2613)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2614)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2615) { return mosek::fusion::p_Domain::greaterThan(_2615); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2615){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_2615);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2616,    std::shared_ptr< monty::ndarray< int,1 > > _2617) { return mosek::fusion::p_Domain::greaterThan(_2616,_2617); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2616,std::shared_ptr< monty::ndarray< int,1 > > _2617){
  _checked_ptr_1<double> _ptr__2616(_2616 ? _2616->raw() : nullptr, _2616 ? _2616->size(0) : 0);
  _checked_ptr_1<int> _ptr__2617(_2617 ? _2617->raw() : nullptr, _2617 ? _2617->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2616),_2617);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2618) { return mosek::fusion::p_Domain::greaterThan(_2618); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2618){
  std::vector<double> _8019;
  for (int _2619 = (int)0, _8020 = (int)((_2618)->size(0)); _2619 < _8020 ; ++_2619)
  {
    for (int _2620 = (int)0, _8021 = (int)((_2618)->size(1)); _2620 < _8021 ; ++_2620)
    {
      _8019.push_back(((*_2618)(_2619,_2620)));
    }
  }
  auto _8022 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8019.size()),_8019.begin(),_8019.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_8022,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2618)->size(0))),(int)((int)((_2618)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2621) { return mosek::fusion::p_Domain::greaterThan(_2621); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2621){
  _checked_ptr_1<double> _ptr__2621(_2621 ? _2621->raw() : nullptr, _2621 ? _2621->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2621),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2621)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2622,    std::shared_ptr< monty::ndarray< int,1 > > _2623) { return mosek::fusion::p_Domain::greaterThan(_2622,_2623); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2622,std::shared_ptr< monty::ndarray< int,1 > > _2623){
  _checked_ptr_1<int> _ptr__2623(_2623 ? _2623->raw() : nullptr, _2623 ? _2623->size(0) : 0);
  std::vector<double> _8023;
  for (long long _2624 = (int)0, _8024 = ::mosek::fusion::p_Domain::prod(_2623); _2624 < _8024 ; ++_2624)
  {
    _8023.push_back(_2622);
  }
  auto _8025 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8023.size()),_8023.begin(),_8023.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8025,_2623);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2625,    int _2626,    int _2627) { return mosek::fusion::p_Domain::greaterThan(_2625,_2626,_2627); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2625,int _2626,int _2627){
  std::vector<double> _8026;
  for (int _2628 = (int)0, _8027 = safe_mul( _2627,_2626 ); _2628 < _8027 ; ++_2628)
  {
    _8026.push_back(_2625);
  }
  auto _8028 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8026.size()),_8026.begin(),_8026.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8028,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2626),(int)(_2627)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2629,    int _2630) { return mosek::fusion::p_Domain::greaterThan(_2629,_2630); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2629,int _2630){
  std::vector<double> _8029;
  for (int _2631 = (int)0, _8030 = _2630; _2631 < _8030 ; ++_2631)
  {
    _8029.push_back(_2629);
  }
  auto _8031 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8029.size()),_8029.begin(),_8029.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_8031,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2630)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _2632) { return mosek::fusion::p_Domain::greaterThan(_2632); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _2632){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2632)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2633) { return mosek::fusion::p_Domain::lessThan(_2633); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2633){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_2633);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2634,    std::shared_ptr< monty::ndarray< int,1 > > _2635) { return mosek::fusion::p_Domain::lessThan(_2634,_2635); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2634,std::shared_ptr< monty::ndarray< int,1 > > _2635){
  _checked_ptr_1<double> _ptr__2634(_2634 ? _2634->raw() : nullptr, _2634 ? _2634->size(0) : 0);
  _checked_ptr_1<int> _ptr__2635(_2635 ? _2635->raw() : nullptr, _2635 ? _2635->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2634),_2635);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _2636) { return mosek::fusion::p_Domain::lessThan(_2636); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2636){
  std::vector<double> _8032;
  for (int _2637 = (int)0, _8033 = (int)((_2636)->size(0)); _2637 < _8033 ; ++_2637)
  {
    for (int _2638 = (int)0, _8034 = (int)((_2636)->size(1)); _2638 < _8034 ; ++_2638)
    {
      _8032.push_back(((*_2636)(_2637,_2638)));
    }
  }
  auto _8035 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8032.size()),_8032.begin(),_8032.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_8035,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2636)->size(0))),(int)((int)((_2636)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _2639) { return mosek::fusion::p_Domain::lessThan(_2639); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2639){
  _checked_ptr_1<double> _ptr__2639(_2639 ? _2639->raw() : nullptr, _2639 ? _2639->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_2639),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2639)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2640,    std::shared_ptr< monty::ndarray< int,1 > > _2641) { return mosek::fusion::p_Domain::lessThan(_2640,_2641); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2640,std::shared_ptr< monty::ndarray< int,1 > > _2641){
  _checked_ptr_1<int> _ptr__2641(_2641 ? _2641->raw() : nullptr, _2641 ? _2641->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2640)}),_2641);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2642,    int _2643,    int _2644) { return mosek::fusion::p_Domain::lessThan(_2642,_2643,_2644); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2642,int _2643,int _2644){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2642)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2643),(int)(_2644)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2645,    int _2646) { return mosek::fusion::p_Domain::lessThan(_2645,_2646); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2645,int _2646){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2645)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2646)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _2647) { return mosek::fusion::p_Domain::lessThan(_2647); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _2647){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2647)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _2648) { return mosek::fusion::p_Domain::equalsTo(_2648); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2648){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_2648);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2649,    std::shared_ptr< monty::ndarray< int,1 > > _2650) { return mosek::fusion::p_Domain::equalsTo(_2649,_2650); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2649,std::shared_ptr< monty::ndarray< int,1 > > _2650){
  _checked_ptr_1<double> _ptr__2649(_2649 ? _2649->raw() : nullptr, _2649 ? _2649->size(0) : 0);
  _checked_ptr_1<int> _ptr__2650(_2650 ? _2650->raw() : nullptr, _2650 ? _2650->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2649),_2650);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _2651) { return mosek::fusion::p_Domain::equalsTo(_2651); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2651){
  std::vector<double> _8036;
  for (int _2652 = (int)0, _8037 = (int)((_2651)->size(0)); _2652 < _8037 ; ++_2652)
  {
    for (int _2653 = (int)0, _8038 = (int)((_2651)->size(1)); _2653 < _8038 ; ++_2653)
    {
      _8036.push_back(((*_2651)(_2652,_2653)));
    }
  }
  auto _8039 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8036.size()),_8036.begin(),_8036.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_8039,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2651)->size(0))),(int)((int)((_2651)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _2654) { return mosek::fusion::p_Domain::equalsTo(_2654); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2654){
  _checked_ptr_1<double> _ptr__2654(_2654 ? _2654->raw() : nullptr, _2654 ? _2654->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_2654),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2654)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2655,    std::shared_ptr< monty::ndarray< int,1 > > _2656) { return mosek::fusion::p_Domain::equalsTo(_2655,_2656); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2655,std::shared_ptr< monty::ndarray< int,1 > > _2656){
  _checked_ptr_1<int> _ptr__2656(_2656 ? _2656->raw() : nullptr, _2656 ? _2656->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2655)}),_2656);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2657,    int _2658,    int _2659) { return mosek::fusion::p_Domain::equalsTo(_2657,_2658,_2659); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2657,int _2658,int _2659){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2657)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2658),(int)(_2659)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2660,    int _2661) { return mosek::fusion::p_Domain::equalsTo(_2660,_2661); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2660,int _2661){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2660)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2661)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _2662) { return mosek::fusion::p_Domain::equalsTo(_2662); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _2662){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_2662)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _2663) { return mosek::fusion::p_Domain::unbounded(_2663); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2663){
  _checked_ptr_1<int> _ptr__2663(_2663 ? _2663->raw() : nullptr, _2663 ? _2663->size(0) : 0);
  std::vector<int> _8040;
  for (int _2664 = (int)0, _8041 = (int)((_2663)->size(0)); _2664 < _8041 ; ++_2664)
  {
    _8040.push_back(_ptr__2663[_2664]);
  }
  auto _8042 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8040.size()),_8040.begin(),_8040.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_8042);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2665,    int _2666) { return mosek::fusion::p_Domain::unbounded(_2665,_2666); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2665,int _2666){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2665),(int)(_2666)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _2667) { return mosek::fusion::p_Domain::unbounded(_2667); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _2667){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2667)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2668,    std::shared_ptr< monty::ndarray< long long,1 > > _2669,    std::shared_ptr< monty::ndarray< double,1 > > _2670){ return new mosek::fusion::ExprConst(_2668,_2669,_2670); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2668,    std::shared_ptr< monty::ndarray< long long,1 > > _2669,    std::shared_ptr< monty::ndarray< double,1 > > _2670) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2668,_2669,_2670); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2668,    std::shared_ptr< monty::ndarray< long long,1 > > _2669,    std::shared_ptr< monty::ndarray< double,1 > > _2670){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2668(_2668 ? _2668->raw() : nullptr, _2668 ? _2668->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2669(_2669 ? _2669->raw() : nullptr, _2669 ? _2669->size(0) : 0);
    _checked_ptr_1<double> _ptr__2670(_2670 ? _2670->raw() : nullptr, _2670 ? _2670->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2668);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_2670);
    std::shared_ptr< monty::ndarray< long long,1 > > _8043;
    bool _8044 = (NULL != _2669.get());
    if (_8044)
    {
      _8043 = ::mosek::fusion::Utils::Tools::arraycopy(_2669);
    }
    else
    {
      _8043 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8043;
    ::mosek::fusion::p_ExprConst::validate(_2668,_2670,_2669);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2671,    std::shared_ptr< monty::ndarray< long long,1 > > _2672,    double _2673){ return new mosek::fusion::ExprConst(_2671,_2672,_2673); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _2671,    std::shared_ptr< monty::ndarray< long long,1 > > _2672,    double _2673) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_2671,_2672,_2673); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2671,    std::shared_ptr< monty::ndarray< long long,1 > > _2672,    double _2673){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2671(_2671 ? _2671->raw() : nullptr, _2671 ? _2671->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2672(_2672 ? _2672->raw() : nullptr, _2672 ? _2672->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_2671);
    long long _8045;
    bool _8046 = (NULL == _2672.get());
    if (_8046)
    {
      _8045 = ::mosek::fusion::p_Set::size(_2671);
    }
    else
    {
      _8045 = (int)((_2672)->size(0));
    }
    long long _2674 = _8045;
    std::vector<double> _8047;
    for (long long _2675 = (int)0, _8048 = _2674; _2675 < _8048 ; ++_2675)
    {
      _8047.push_back(_2673);
    }
    auto _8049 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8047.size()),_8047.begin(),_8047.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _8049;
    std::shared_ptr< monty::ndarray< long long,1 > > _8050;
    bool _8051 = (NULL != _2672.get());
    if (_8051)
    {
      _8050 = ::mosek::fusion::Utils::Tools::arraycopy(_2672);
    }
    else
    {
      _8050 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _8050;
    ::mosek::fusion::p_ExprConst::validate(_2671,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_2672);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2676,monty::rc_ptr< ::mosek::fusion::WorkStack > _2677,monty::rc_ptr< ::mosek::fusion::WorkStack > _2678) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_2676,_2677,_2678); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2676,monty::rc_ptr< ::mosek::fusion::WorkStack > _2677,monty::rc_ptr< ::mosek::fusion::WorkStack > _2678){
  std::shared_ptr< monty::ndarray< int,1 > > _2679 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__2679(_2679 ? _2679->raw() : nullptr,_2679 ? _2679->size(0) : 0);
  int _2680 = (int)((bfix)->size(0));
  bool _2681 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_2679)));
  int _2682 = _2676->alloci32(safe_add( _2680,(int)1 ));
  int _8052;
  bool _8053 = _2681;
  if (_8053)
  {
    _8052 = (int)1;
  }
  else
  {
    _8052 = (int)0;
  }
  _2676->pushi32(_8052);
  _2676->pushi32((int)0);
  _2676->pushi32(_2680);
  int _8054 = (int)0;
  int _8055 = (int)((_2679)->size(0));
  for (int _2683 = _8054; _2683 < _8055; ++_2683)
  {
    {
      _2676->pushi32(_ptr__2679[_2683]);
    }
  }
  _2676->pushi32((int)((_2679)->size(0)));
  if ((NULL != sparsity.get()))
  {
    {
      int _2684 = _2676->alloci64((int)((sparsity)->size(0)));
      std::shared_ptr< monty::ndarray< long long,1 > > _2685 = mosek::fusion::p_WorkStack::_get_impl(_2676)->i64;
      _checked_ptr_1<long long> _ptr__2685(_2685 ? _2685->raw() : nullptr,_2685 ? _2685->size(0) : 0);
      int _8056 = (int)0;
      int _8057 = (int)((sparsity)->size(0));
      for (int _2686 = _8056; _2686 < _8057; ++_2686)
      {
        {
          _ptr__2685[safe_add( _2684,_2686 )] = ((*sparsity)(_2686));
        }
      }
    }
  }
  {}
  int _2687 = _2676->allocf64((int)((bfix)->size(0)));
  std::shared_ptr< monty::ndarray< double,1 > > _2688 = mosek::fusion::p_WorkStack::_get_impl(_2676)->f64;
  _checked_ptr_1<double> _ptr__2688(_2688 ? _2688->raw() : nullptr,_2688 ? _2688->size(0) : 0);
  int _8058 = (int)0;
  int _8059 = (int)((bfix)->size(0));
  for (int _2689 = _8058; _2689 < _8059; ++_2689)
  {
    {
      _ptr__2688[safe_add( _2687,_2689 )] = ((*bfix)(_2689));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2690 = mosek::fusion::p_WorkStack::_get_impl(_2676)->i32;
  _checked_ptr_1<int> _ptr__2690(_2690 ? _2690->raw() : nullptr,_2690 ? _2690->size(0) : 0);
  int _8060 = (int)0;
  int _8061 = safe_add( _2680,(int)1 );
  for (int _2691 = _8060; _2691 < _8061; ++_2691)
  {
    {
      _ptr__2690[safe_add( _2682,_2691 )] = (int)0;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _2692,std::shared_ptr< monty::ndarray< double,1 > > _2693,std::shared_ptr< monty::ndarray< long long,1 > > _2694){
  _checked_ptr_1<int> _ptr__2692(_2692 ? _2692->raw() : nullptr, _2692 ? _2692->size(0) : 0);
  _checked_ptr_1<double> _ptr__2693(_2693 ? _2693->raw() : nullptr, _2693 ? _2693->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2694(_2694 ? _2694->raw() : nullptr, _2694 ? _2694->size(0) : 0);
  long long _2695 = ::mosek::fusion::p_Set::size(_2692);
  if ((NULL != _2694.get()))
  {
    {
      if (((int)((_2694)->size(0)) != (int)((_2693)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      int _8062 = (int)0;
      int _8063 = (int)((_2694)->size(0));
      for (int _2696 = _8062; _2696 < _8063; ++_2696)
      {
        {
          if (((_ptr__2694[_2696] < (int)0) || (_ptr__2694[_2696] >= _2695)))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_2693)->size(0)) != _2695))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2697,    std::shared_ptr< monty::ndarray< int,2 > > _2698){ return new mosek::fusion::ExprPick(_2697,_2698); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2697,    std::shared_ptr< monty::ndarray< int,2 > > _2698) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2697,_2698); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2697,    std::shared_ptr< monty::ndarray< int,2 > > _2698){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2698)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _2699 = _2697->getShape();
    _checked_ptr_1<int> _ptr__2699(_2699 ? _2699->raw() : nullptr,_2699 ? _2699->size(0) : 0);
    int _2700 = (int)((_2699)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2697;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2698)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _2701 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__2701(_2701 ? _2701->raw() : nullptr,_2701 ? _2701->size(0) : 0);
    if (((int)((_2698)->size(1)) != _2700))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    int _8064 = (int)0;
    int _8065 = (int)((_2698)->size(0));
    for (int _2702 = _8064; _2702 < _8065; ++_2702)
    {
      {
        int _8066 = (int)0;
        int _8067 = _2700;
        for (int _2703 = _8066; _2703 < _8067; ++_2703)
        {
          {
            if (((((*_2698)(_2702,_2703)) < (int)0) || (((*_2698)(_2702,_2703)) >= _ptr__2699[_2703])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2704 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2700)));
      _checked_ptr_1<long long> _ptr__2704(_2704 ? _2704->raw() : nullptr,_2704 ? _2704->size(0) : 0);
      _ptr__2704[(_2700 - (int)1)] = (int)1;
      int _8068 = (int)1;
      int _8069 = _2700;
      for (int _2705 = _8068; _2705 < _8069; ++_2705)
      {
        {
          _ptr__2704[((_2700 - _2705) - (int)1)] = safe_mul( _ptr__2704[(_2700 - _2705)],_ptr__2699[(_2700 - _2705)] );
        }
      }
      int _8070 = (int)0;
      int _8071 = (int)((_2698)->size(0));
      for (int _2706 = _8070; _2706 < _8071; ++_2706)
      {
        {
          long long _2707 = (long long)0;
          int _8072 = (int)0;
          int _8073 = _2700;
          for (int _2708 = _8072; _2708 < _8073; ++_2708)
          {
            {
              _2707 += safe_mul( _ptr__2704[_2708],((*_2698)(_2706,_2708)) );
            }
          }
          _ptr__2701[_2706] = _2707;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2709,    std::shared_ptr< monty::ndarray< long long,1 > > _2710){ return new mosek::fusion::ExprPick(_2709,_2710); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _2709,    std::shared_ptr< monty::ndarray< long long,1 > > _2710) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_2709,_2710); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2709,    std::shared_ptr< monty::ndarray< long long,1 > > _2710){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2710(_2710 ? _2710->raw() : nullptr, _2710 ? _2710->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2710)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _2709;
    std::shared_ptr< monty::ndarray< int,1 > > _2711 = _2709->getShape();
    _checked_ptr_1<int> _ptr__2711(_2711 ? _2711->raw() : nullptr,_2711 ? _2711->size(0) : 0);
    long long _2712 = ::mosek::fusion::p_Set::size(_2711);
    int _8074 = (int)0;
    int _8075 = (int)((_2710)->size(0));
    for (int _2713 = _8074; _2713 < _8075; ++_2713)
    {
      {
        if (((_ptr__2710[_2713] < (int)0) || (_ptr__2710[_2713] >= _2712)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
          }
        }
        {}
      }
    }
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_2710);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2714,monty::rc_ptr< ::mosek::fusion::WorkStack > _2715,monty::rc_ptr< ::mosek::fusion::WorkStack > _2716) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_2714,_2715,_2716); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2714,monty::rc_ptr< ::mosek::fusion::WorkStack > _2715,monty::rc_ptr< ::mosek::fusion::WorkStack > _2716){
  expr->eval(_2715,_2714,_2716);
  _2715->pop_expr();
  int _2717 = mosek::fusion::p_WorkStack::_get_impl(_2715)->nd;
  int _2718 = mosek::fusion::p_WorkStack::_get_impl(_2715)->shape_base;
  int _2719 = mosek::fusion::p_WorkStack::_get_impl(_2715)->nelem;
  int _2720 = mosek::fusion::p_WorkStack::_get_impl(_2715)->nnz;
  bool _2721 = mosek::fusion::p_WorkStack::_get_impl(_2715)->hassp;
  int _2722 = mosek::fusion::p_WorkStack::_get_impl(_2715)->ptr_base;
  int _2723 = mosek::fusion::p_WorkStack::_get_impl(_2715)->sp_base;
  int _2724 = mosek::fusion::p_WorkStack::_get_impl(_2715)->nidxs_base;
  int _2725 = mosek::fusion::p_WorkStack::_get_impl(_2715)->bfix_base;
  int _2726 = mosek::fusion::p_WorkStack::_get_impl(_2715)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _2727 = mosek::fusion::p_WorkStack::_get_impl(_2715)->i32;
  _checked_ptr_1<int> _ptr__2727(_2727 ? _2727->raw() : nullptr,_2727 ? _2727->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2728 = mosek::fusion::p_WorkStack::_get_impl(_2715)->i64;
  _checked_ptr_1<long long> _ptr__2728(_2728 ? _2728->raw() : nullptr,_2728 ? _2728->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2729 = mosek::fusion::p_WorkStack::_get_impl(_2715)->f64;
  _checked_ptr_1<double> _ptr__2729(_2729 ? _2729->raw() : nullptr,_2729 ? _2729->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2730 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__2730(_2730 ? _2730->raw() : nullptr,_2730 ? _2730->size(0) : 0);
  if ((!_2721))
  {
    {
      int _2731 = (int)((_2730)->size(0));
      int _2732 = (int)1;
      int _2733 = (int)0;
      int _8076 = (int)0;
      int _8077 = (int)((_2730)->size(0));
      for (int _2734 = _8076; _2734 < _8077; ++_2734)
      {
        {
          _2733 += (_ptr__2727[safe_add( safe_add( _2722,_ptr__2730[_2734] ),(int)1 )] - _ptr__2727[safe_add( _2722,_ptr__2730[_2734] )]);
        }
      }
      _2714->alloc_expr(_2732,_2731,_2733,false);
      int _2735 = mosek::fusion::p_WorkStack::_get_impl(_2714)->cof_base;
      int _2736 = mosek::fusion::p_WorkStack::_get_impl(_2714)->bfix_base;
      int _2737 = mosek::fusion::p_WorkStack::_get_impl(_2714)->nidxs_base;
      int _2738 = mosek::fusion::p_WorkStack::_get_impl(_2714)->ptr_base;
      int _2739 = mosek::fusion::p_WorkStack::_get_impl(_2714)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2740 = mosek::fusion::p_WorkStack::_get_impl(_2714)->i32;
      _checked_ptr_1<int> _ptr__2740(_2740 ? _2740->raw() : nullptr,_2740 ? _2740->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2741 = mosek::fusion::p_WorkStack::_get_impl(_2714)->i64;
      _checked_ptr_1<long long> _ptr__2741(_2741 ? _2741->raw() : nullptr,_2741 ? _2741->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2742 = mosek::fusion::p_WorkStack::_get_impl(_2714)->f64;
      _checked_ptr_1<double> _ptr__2742(_2742 ? _2742->raw() : nullptr,_2742 ? _2742->size(0) : 0);
      _ptr__2740[_2739] = (int)((_2730)->size(0));
      int _2743 = (int)0;
      _ptr__2740[_2738] = (int)0;
      int _8078 = (int)0;
      int _8079 = (int)((_2730)->size(0));
      for (int _2744 = _8078; _2744 < _8079; ++_2744)
      {
        {
          int _8080 = _ptr__2727[safe_add( _2722,_ptr__2730[_2744] )];
          int _8081 = _ptr__2727[safe_add( safe_add( _2722,_ptr__2730[_2744] ),(int)1 )];
          for (int _2745 = _8080; _2745 < _8081; ++_2745)
          {
            {
              _ptr__2741[safe_add( _2737,_2743 )] = _ptr__2728[safe_add( _2724,_2745 )];
              _ptr__2742[safe_add( _2735,_2743 )] = _ptr__2729[safe_add( _2726,_2745 )];
              ++ _2743;
            }
          }
          _ptr__2742[safe_add( _2736,_2744 )] = _ptr__2729[safe_add( _2725,_ptr__2730[_2744] )];
          _ptr__2740[safe_add( safe_add( _2738,_2744 ),(int)1 )] = _2743;
        }
      }
    }
  }
  else
  {
    {
      int _2746 = (int)1;
      int _2747 = (int)((_2730)->size(0));
      int _2748 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _2749 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__2749(_2749 ? _2749->raw() : nullptr,_2749 ? _2749->size(0) : 0);
      int _2750 = _2716->alloci32((int)((_2749)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _2751 = mosek::fusion::p_WorkStack::_get_impl(_2716)->i32;
      _checked_ptr_1<int> _ptr__2751(_2751 ? _2751->raw() : nullptr,_2751 ? _2751->size(0) : 0);
      int _8082 = (int)0;
      int _8083 = (int)((_2749)->size(0));
      for (int _2752 = _8082; _2752 < _8083; ++_2752)
      {
        {
          int _2753 = _2719;
          int _2754 = (int)0;
          while ( (_2754 < (_2753 - (int)1)) )
          {
            {
              int _2755 = (safe_add( safe_add( _2753,_2754 ),(int)1 ) / (int)2);
              if ((_ptr__2728[safe_add( _2723,_2755 )] >= _ptr__2749[_2752]))
              {
                {
                  _2753 = _2755;
                }
              }
              else
              {
                {
                  _2754 = _2755;
                }
              }
            }
          }
          ++ _2754;
          if (((_2754 < _2719) && (_ptr__2728[safe_add( _2723,_2754 )] == _ptr__2749[_2752])))
          {
            {
              _ptr__2751[safe_add( _2750,_2752 )] = _2754;
              _2748 += (_ptr__2727[safe_add( safe_add( _2722,_2754 ),(int)1 )] - _ptr__2727[safe_add( _2722,_2754 )]);
            }
          }
          else
          {
            {
              _ptr__2751[safe_add( _2750,_2752 )] = (-(int)1);
            }
          }
        }
      }
      _2714->alloc_expr(_2746,_2747,_2748,false);
      int _2756 = mosek::fusion::p_WorkStack::_get_impl(_2714)->ptr_base;
      int _2757 = mosek::fusion::p_WorkStack::_get_impl(_2714)->nidxs_base;
      int _2758 = mosek::fusion::p_WorkStack::_get_impl(_2714)->cof_base;
      int _2759 = mosek::fusion::p_WorkStack::_get_impl(_2714)->bfix_base;
      int _2760 = mosek::fusion::p_WorkStack::_get_impl(_2714)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2761 = mosek::fusion::p_WorkStack::_get_impl(_2714)->i32;
      _checked_ptr_1<int> _ptr__2761(_2761 ? _2761->raw() : nullptr,_2761 ? _2761->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2762 = mosek::fusion::p_WorkStack::_get_impl(_2714)->i64;
      _checked_ptr_1<long long> _ptr__2762(_2762 ? _2762->raw() : nullptr,_2762 ? _2762->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2763 = mosek::fusion::p_WorkStack::_get_impl(_2714)->f64;
      _checked_ptr_1<double> _ptr__2763(_2763 ? _2763->raw() : nullptr,_2763 ? _2763->size(0) : 0);
      _ptr__2761[_2760] = (int)((_2749)->size(0));
      _ptr__2761[_2756] = (int)0;
      int _2764 = (int)0;
      int _8084 = (int)0;
      int _8085 = (int)((_2749)->size(0));
      for (int _2765 = _8084; _2765 < _8085; ++_2765)
      {
        {
          if ((_ptr__2751[safe_add( _2750,_2765 )] >= (int)0))
          {
            {
              int _2766 = _ptr__2751[safe_add( _2750,_2765 )];
              int _8086 = _ptr__2727[safe_add( _2722,_2766 )];
              int _8087 = _ptr__2727[safe_add( safe_add( _2722,_2766 ),(int)1 )];
              for (int _2767 = _8086; _2767 < _8087; ++_2767)
              {
                {
                  _ptr__2762[safe_add( _2757,_2764 )] = _ptr__2728[safe_add( _2724,_2767 )];
                  _ptr__2763[safe_add( _2758,_2764 )] = _ptr__2729[safe_add( _2726,_2767 )];
                  ++ _2764;
                }
              }
              _ptr__2763[safe_add( _2759,_2765 )] = _ptr__2729[safe_add( _2725,_2766 )];
            }
          }
          else
          {
            {
              _ptr__2763[safe_add( _2759,_2765 )] = 0.0;
            }
          }
          _ptr__2761[safe_add( safe_add( _2756,_2765 ),(int)1 )] = _2764;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2768,    std::shared_ptr< monty::ndarray< int,1 > > _2769,    std::shared_ptr< monty::ndarray< int,1 > > _2770){ return new mosek::fusion::ExprSlice(_2768,_2769,_2770); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _2768,    std::shared_ptr< monty::ndarray< int,1 > > _2769,    std::shared_ptr< monty::ndarray< int,1 > > _2770) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_2768,_2769,_2770); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2768,    std::shared_ptr< monty::ndarray< int,1 > > _2769,    std::shared_ptr< monty::ndarray< int,1 > > _2770){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2769(_2769 ? _2769->raw() : nullptr, _2769 ? _2769->size(0) : 0);
    _checked_ptr_1<int> _ptr__2770(_2770 ? _2770->raw() : nullptr, _2770 ? _2770->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_2768->getShape(),_2769,_2770));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _2768;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _2769;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _2770;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2771,monty::rc_ptr< ::mosek::fusion::WorkStack > _2772,monty::rc_ptr< ::mosek::fusion::WorkStack > _2773) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_2771,_2772,_2773); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2771,monty::rc_ptr< ::mosek::fusion::WorkStack > _2772,monty::rc_ptr< ::mosek::fusion::WorkStack > _2773){
  expr->eval(_2772,_2771,_2773);
  int _2774 = _2772->popi32();
  int _2775 = _2772->popi32(_2774);
  int _2776 = _2772->popi32();
  int _2777 = _2772->popi32();
  bool _2778 = (_2772->popi32() != (int)0);
  int _2779 = _2772->popi32(safe_add( _2776,(int)1 ));
  int _8088;
  bool _8089 = _2778;
  if (_8089)
  {
    _8088 = _2772->popi64(_2776);
  }
  else
  {
    _8088 = (-(int)1);
  }
  int _2780 = _8088;
  int _2781 = _2772->popi64(_2777);
  int _2782 = _2772->popf64(_2776);
  int _2783 = _2772->popf64(_2777);
  std::shared_ptr< monty::ndarray< int,1 > > _2784 = mosek::fusion::p_WorkStack::_get_impl(_2772)->i32;
  _checked_ptr_1<int> _ptr__2784(_2784 ? _2784->raw() : nullptr,_2784 ? _2784->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2785 = mosek::fusion::p_WorkStack::_get_impl(_2772)->i64;
  _checked_ptr_1<long long> _ptr__2785(_2785 ? _2785->raw() : nullptr,_2785 ? _2785->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2786 = mosek::fusion::p_WorkStack::_get_impl(_2772)->f64;
  _checked_ptr_1<double> _ptr__2786(_2786 ? _2786->raw() : nullptr,_2786 ? _2786->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2787 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2774)));
  _checked_ptr_1<long long> _ptr__2787(_2787 ? _2787->raw() : nullptr,_2787 ? _2787->size(0) : 0);
  _ptr__2787[(_2774 - (int)1)] = (int)1;
  int _8090 = (int)1;
  int _8091 = _2774;
  for (int _2788 = _8090; _2788 < _8091; ++_2788)
  {
    {
      _ptr__2787[((_2774 - _2788) - (int)1)] = safe_mul( _ptr__2787[(_2774 - _2788)],_ptr__2784[(safe_add( _2775,_2774 ) - _2788)] );
    }
  }
  int _2789 = (int)0;
  int _2790 = (int)0;
  if (_2778)
  {
    {
      int _8092 = (int)0;
      int _8093 = _2776;
      for (int _2791 = _8092; _2791 < _8093; ++_2791)
      {
        {
          bool _2792 = true;
          int _8094 = (int)0;
          int _8095 = _2774;
          for (int _2793 = _8094; _2793 < _8095; ++_2793)
          {
            {
              long long _2794 = ((_ptr__2785[safe_add( _2780,_2791 )] / _ptr__2787[_2793]) % _ptr__2784[safe_add( _2775,_2793 )]);
              _2792 = (_2792 && ((_2794 >= ((*first)(_2793))) && (_2794 < ((*last)(_2793)))));
            }
          }
          if (_2792)
          {
            {
              _2790 += (_ptr__2784[safe_add( safe_add( _2779,_2791 ),(int)1 )] - _ptr__2784[safe_add( _2779,_2791 )]);
              ++ _2789;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _2789 = (int)1;
      int _8096 = (int)0;
      int _8097 = _2774;
      for (int _2795 = _8096; _2795 < _8097; ++_2795)
      {
        {
          _2789 *= (((*last)(_2795)) - ((*first)(_2795)));
        }
      }
      int _8098 = (int)0;
      int _8099 = _2776;
      for (int _2796 = _8098; _2796 < _8099; ++_2796)
      {
        {
          bool _2797 = true;
          int _8100 = (int)0;
          int _8101 = _2774;
          for (int _2798 = _8100; _2798 < _8101; ++_2798)
          {
            {
              long long _2799 = ((_2796 / _ptr__2787[_2798]) % _ptr__2784[safe_add( _2775,_2798 )]);
              _2797 = (_2797 && ((_2799 >= ((*first)(_2798))) && (_2799 < ((*last)(_2798)))));
            }
          }
          if (_2797)
          {
            {
              _2790 += (_ptr__2784[safe_add( safe_add( _2779,_2796 ),(int)1 )] - _ptr__2784[safe_add( _2779,_2796 )]);
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _8102;
  for (int _2801 = (int)0, _8103 = _2774; _2801 < _8103 ; ++_2801)
  {
    _8102.push_back((((*last)(_2801)) - ((*first)(_2801))));
  }
  auto _8104 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8102.size()),_8102.begin(),_8102.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _2800 = _8104;
  _checked_ptr_1<int> _ptr__2800(_2800 ? _2800->raw() : nullptr,_2800 ? _2800->size(0) : 0);
  int _2802 = _2771->allocf64(_2790);
  int _2803 = _2771->allocf64(_2789);
  int _2804 = _2771->alloci64(_2790);
  int _8105;
  bool _8106 = _2778;
  if (_8106)
  {
    _8105 = _2771->alloci64(_2789);
  }
  else
  {
    _8105 = (-(int)1);
  }
  int _2805 = _8105;
  int _2806 = _2771->alloci32(safe_add( _2789,(int)1 ));
  int _8107;
  bool _8108 = _2778;
  if (_8108)
  {
    _8107 = (int)1;
  }
  else
  {
    _8107 = (int)0;
  }
  _2771->pushi32(_8107);
  _2771->pushi32(_2790);
  _2771->pushi32(_2789);
  int _8109 = (int)0;
  int _8110 = _2774;
  for (int _2807 = _8109; _2807 < _8110; ++_2807)
  {
    {
      _2771->pushi32(_ptr__2800[_2807]);
    }
  }
  _2771->pushi32(_2774);
  std::shared_ptr< monty::ndarray< int,1 > > _2808 = mosek::fusion::p_WorkStack::_get_impl(_2771)->i32;
  _checked_ptr_1<int> _ptr__2808(_2808 ? _2808->raw() : nullptr,_2808 ? _2808->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2809 = mosek::fusion::p_WorkStack::_get_impl(_2771)->i64;
  _checked_ptr_1<long long> _ptr__2809(_2809 ? _2809->raw() : nullptr,_2809 ? _2809->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2810 = mosek::fusion::p_WorkStack::_get_impl(_2771)->f64;
  _checked_ptr_1<double> _ptr__2810(_2810 ? _2810->raw() : nullptr,_2810 ? _2810->size(0) : 0);
  _ptr__2808[_2806] = (int)0;
  std::shared_ptr< monty::ndarray< long long,1 > > _2811 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2774)));
  _checked_ptr_1<long long> _ptr__2811(_2811 ? _2811->raw() : nullptr,_2811 ? _2811->size(0) : 0);
  _ptr__2811[(_2774 - (int)1)] = (int)1;
  int _8111 = (int)1;
  int _8112 = _2774;
  for (int _2812 = _8111; _2812 < _8112; ++_2812)
  {
    {
      _ptr__2811[((_2774 - _2812) - (int)1)] = safe_mul( _ptr__2811[(_2774 - _2812)],_ptr__2800[(_2774 - _2812)] );
    }
  }
  int _2813 = (int)0;
  int _2814 = (int)0;
  if (_2778)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2815 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2774)));
      _checked_ptr_1<int> _ptr__2815(_2815 ? _2815->raw() : nullptr,_2815 ? _2815->size(0) : 0);
      int _8113 = (int)0;
      int _8114 = _2776;
      for (int _2816 = _8113; _2816 < _8114; ++_2816)
      {
        {
          bool _2817 = true;
          int _8115 = (int)0;
          int _8116 = _2774;
          for (int _2818 = _8115; _2818 < _8116; ++_2818)
          {
            {
              _ptr__2815[_2818] = (int)((_ptr__2785[safe_add( _2780,_2816 )] / _ptr__2787[_2818]) % _ptr__2784[safe_add( _2775,_2818 )]);
              _2817 = (_2817 && ((_ptr__2815[_2818] >= ((*first)(_2818))) && (_ptr__2815[_2818] < ((*last)(_2818)))));
            }
          }
          if (_2817)
          {
            {
              int _8117 = _ptr__2784[safe_add( _2779,_2816 )];
              int _8118 = _ptr__2784[safe_add( safe_add( _2779,_2816 ),(int)1 )];
              for (int _2819 = _8117; _2819 < _8118; ++_2819)
              {
                {
                  _ptr__2809[safe_add( _2804,_2814 )] = _ptr__2785[safe_add( _2781,_2819 )];
                  _ptr__2810[safe_add( _2802,_2814 )] = _ptr__2786[safe_add( _2783,_2819 )];
                  ++ _2814;
                }
              }
              long long _2820 = (long long)0;
              int _8119 = (int)0;
              int _8120 = _2774;
              for (int _2821 = _8119; _2821 < _8120; ++_2821)
              {
                {
                  _2820 += safe_mul( _ptr__2811[_2821],(_ptr__2815[_2821] - ((*first)(_2821))) );
                }
              }
              _ptr__2809[safe_add( _2805,_2813 )] = _2820;
              _ptr__2810[safe_add( _2803,_2813 )] = _ptr__2786[safe_add( _2782,_2816 )];
              _ptr__2808[safe_add( safe_add( _2806,_2813 ),(int)1 )] = _2814;
              ++ _2813;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _8121 = (int)0;
      int _8122 = _2776;
      for (int _2822 = _8121; _2822 < _8122; ++_2822)
      {
        {
          bool _2823 = true;
          int _8123 = (int)0;
          int _8124 = _2774;
          for (int _2824 = _8123; _2824 < _8124; ++_2824)
          {
            {
              long long _2825 = ((_2822 / _ptr__2787[_2824]) % _ptr__2784[safe_add( _2775,_2824 )]);
              _2823 = (_2823 && ((_2825 >= ((*first)(_2824))) && (_2825 < ((*last)(_2824)))));
            }
          }
          if (_2823)
          {
            {
              int _8125 = _ptr__2784[safe_add( _2779,_2822 )];
              int _8126 = _ptr__2784[safe_add( safe_add( _2779,_2822 ),(int)1 )];
              for (int _2826 = _8125; _2826 < _8126; ++_2826)
              {
                {
                  _ptr__2809[safe_add( _2804,_2814 )] = _ptr__2785[safe_add( _2781,_2826 )];
                  _ptr__2810[safe_add( _2802,_2814 )] = _ptr__2786[safe_add( _2783,_2826 )];
                  ++ _2814;
                }
              }
              _ptr__2810[safe_add( _2803,_2813 )] = _ptr__2786[safe_add( _2782,_2822 )];
              _ptr__2808[safe_add( safe_add( _2806,_2813 ),(int)1 )] = _2814;
              ++ _2813;
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2827,std::shared_ptr< monty::ndarray< int,1 > > _2828,std::shared_ptr< monty::ndarray< int,1 > > _2829){
  _checked_ptr_1<int> _ptr__2827(_2827 ? _2827->raw() : nullptr, _2827 ? _2827->size(0) : 0);
  _checked_ptr_1<int> _ptr__2828(_2828 ? _2828->raw() : nullptr, _2828 ? _2828->size(0) : 0);
  _checked_ptr_1<int> _ptr__2829(_2829 ? _2829->raw() : nullptr, _2829 ? _2829->size(0) : 0);
  if ((((int)((_2827)->size(0)) != (int)((_2828)->size(0))) || ((int)((_2827)->size(0)) != (int)((_2829)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _8127 = (int)0;
  int _8128 = (int)((_2827)->size(0));
  for (int _2830 = _8127; _2830 < _8128; ++_2830)
  {
    {
      if (((_ptr__2828[_2830] < (int)0) || ((_ptr__2829[_2830] < _ptr__2828[_2830]) || (_ptr__2829[_2830] > _ptr__2827[_2830]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _8129;
  for (int _2831 = (int)0, _8130 = (int)((_2827)->size(0)); _2831 < _8130 ; ++_2831)
  {
    _8129.push_back((_ptr__2829[_2831] - _ptr__2828[_2831]));
  }
  auto _8131 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8129.size()),_8129.begin(),_8129.end()));
  return _8131;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2832 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _8132 = (int)1;
  int _8133 = (int)((first)->size(0));
  for (int _2833 = _8132; _2833 < _8133; ++_2833)
  {
    {
      _2832->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_2833)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_2833)));
    }
  }
  _2832->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _2832->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2834,    monty::rc_ptr< ::mosek::fusion::Expression > _2835){ return new mosek::fusion::ExprPermuteDims(_2834,_2835); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2834,    monty::rc_ptr< ::mosek::fusion::Expression > _2835) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2834,_2835); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2834,    monty::rc_ptr< ::mosek::fusion::Expression > _2835){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2834(_2834 ? _2834->raw() : nullptr, _2834 ? _2834->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_2834,_2835,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _2836 = _2835->getShape();
    _checked_ptr_1<int> _ptr__2836(_2836 ? _2836->raw() : nullptr,_2836 ? _2836->size(0) : 0);
    if (((int)((_2834)->size(0)) != (int)((_2836)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _8134;
    for (int _2838 = (int)0, _8135 = (int)((_2834)->size(0)); _2838 < _8135 ; ++_2838)
    {
      _8134.push_back((int)0);
    }
    auto _8136 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8134.size()),_8134.begin(),_8134.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _2837 = _8136;
    _checked_ptr_1<int> _ptr__2837(_2837 ? _2837->raw() : nullptr,_2837 ? _2837->size(0) : 0);
    int _8137 = (int)0;
    int _8138 = (int)((_2837)->size(0));
    for (int _2839 = _8137; _2839 < _8138; ++_2839)
    {
      {
        if (((_ptr__2834[_2839] < (int)0) || (_ptr__2834[_2839] > (int)((_2836)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__2837[_ptr__2834[_2839]];
      }
    }
    int _8139 = (int)0;
    int _8140 = (int)((_2837)->size(0));
    for (int _2840 = _8139; _2840 < _8140; ++_2840)
    {
      {
        if (((_ptr__2837[_2840] < (int)1) || (_ptr__2837[_2840] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2841,    monty::rc_ptr< ::mosek::fusion::Expression > _2842,    int _2843){ return new mosek::fusion::ExprPermuteDims(_2841,_2842,_2843); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _2841,    monty::rc_ptr< ::mosek::fusion::Expression > _2842,    int _2843) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_2841,_2842,_2843); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2841,    monty::rc_ptr< ::mosek::fusion::Expression > _2842,    int _2843){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2841(_2841 ? _2841->raw() : nullptr, _2841 ? _2841->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_2841,_2842->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _2842;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_2841);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2844,monty::rc_ptr< ::mosek::fusion::WorkStack > _2845,monty::rc_ptr< ::mosek::fusion::WorkStack > _2846) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_2844,_2845,_2846); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2844,monty::rc_ptr< ::mosek::fusion::WorkStack > _2845,monty::rc_ptr< ::mosek::fusion::WorkStack > _2846){
  expr->eval(_2845,_2844,_2846);
  int _2847 = _2845->popi32();
  int _2848 = _2845->popi32(_2847);
  std::shared_ptr< monty::ndarray< long long,1 > > _2849 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2847)));
  _checked_ptr_1<long long> _ptr__2849(_2849 ? _2849->raw() : nullptr,_2849 ? _2849->size(0) : 0);
  _ptr__2849[(_2847 - (int)1)] = (int)1;
  int _8141 = (int)1;
  int _8142 = _2847;
  for (int _2850 = _8141; _2850 < _8142; ++_2850)
  {
    {
      _ptr__2849[((_2847 - _2850) - (int)1)] = safe_mul( _ptr__2849[(_2847 - _2850)],((*mosek::fusion::p_WorkStack::_get_impl(_2845)->i32)((safe_add( _2848,_2847 ) - _2850))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2847)));
  _checked_ptr_1<int> _ptr__2851(_2851 ? _2851->raw() : nullptr,_2851 ? _2851->size(0) : 0);
  _ptr__2851[(_2847 - (int)1)] = (int)1;
  int _8143 = (int)1;
  int _8144 = _2847;
  for (int _2852 = _8143; _2852 < _8144; ++_2852)
  {
    {
      _ptr__2851[((_2847 - _2852) - (int)1)] = safe_mul( _ptr__2851[(_2847 - _2852)],((*mosek::fusion::p_WorkStack::_get_impl(_2845)->i32)(safe_add( _2848,((*dperm)((_2847 - _2852))) ))) );
    }
  }
  int _2853 = _2845->popi32();
  int _2854 = _2845->popi32();
  bool _2855 = (_2845->popi32() != (int)0);
  int _2856 = _2845->popi32(safe_add( _2853,(int)1 ));
  int _8145;
  bool _8146 = (!_2855);
  if (_8146)
  {
    _8145 = (-(int)1);
  }
  else
  {
    _8145 = _2845->popi64(_2853);
  }
  int _2857 = _8145;
  int _2858 = _2845->popi64(_2854);
  int _2859 = _2845->popf64(_2853);
  int _2860 = _2845->popf64(_2854);
  std::shared_ptr< monty::ndarray< int,1 > > _2861 = mosek::fusion::p_WorkStack::_get_impl(_2845)->i32;
  _checked_ptr_1<int> _ptr__2861(_2861 ? _2861->raw() : nullptr,_2861 ? _2861->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2862 = mosek::fusion::p_WorkStack::_get_impl(_2845)->i64;
  _checked_ptr_1<long long> _ptr__2862(_2862 ? _2862->raw() : nullptr,_2862 ? _2862->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2863 = mosek::fusion::p_WorkStack::_get_impl(_2845)->f64;
  _checked_ptr_1<double> _ptr__2863(_2863 ? _2863->raw() : nullptr,_2863 ? _2863->size(0) : 0);
  if (_2855)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2864 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2853)));
      _checked_ptr_1<long long> _ptr__2864(_2864 ? _2864->raw() : nullptr,_2864 ? _2864->size(0) : 0);
      {
        int _8147 = (int)0;
        int _8148 = _2853;
        for (int _2865 = _8147; _2865 < _8148; ++_2865)
        {
          {
            long long _2866 = (long long)0;
            int _8149 = (int)0;
            int _8150 = _2847;
            for (int _2867 = _8149; _2867 < _8150; ++_2867)
            {
              {
                _2866 += safe_mul( ((_ptr__2862[safe_add( _2857,_2865 )] / _ptr__2849[_2867]) % _ptr__2861[safe_add( _2848,_2867 )]),_ptr__2851[((*dperm)(_2867))] );
              }
            }
            _ptr__2864[_2865] = _2866;
          }
        }
      }
      std::vector<long long> _8151;
      for (int _2869 = (int)0, _8152 = _2853; _2869 < _8152 ; ++_2869)
      {
        _8151.push_back(_2869);
      }
      auto _8153 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8151.size()),_8151.begin(),_8151.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2868 = _8153;
      _checked_ptr_1<long long> _ptr__2868(_2868 ? _2868->raw() : nullptr,_2868 ? _2868->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2868,_2864,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2853));
      int _2870 = _2844->alloci32(safe_add( _2853,(int)1 ));
      int _2871 = _2844->alloci64(_2854);
      int _2872 = _2844->alloci64(_2853);
      int _2873 = _2844->allocf64(_2854);
      int _2874 = _2844->allocf64(_2853);
      _2844->pushi32((int)1);
      _2844->pushi32(_2854);
      _2844->pushi32(_2853);
      int _8154 = (int)0;
      int _8155 = _2847;
      for (int _2875 = _8154; _2875 < _8155; ++_2875)
      {
        {
          _2844->pushi32(_ptr__2861[safe_add( _2848,((*dperm)(_2875)) )]);
        }
      }
      _2844->pushi32(_2847);
      std::shared_ptr< monty::ndarray< int,1 > > _2876 = mosek::fusion::p_WorkStack::_get_impl(_2844)->i32;
      _checked_ptr_1<int> _ptr__2876(_2876 ? _2876->raw() : nullptr,_2876 ? _2876->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2877 = mosek::fusion::p_WorkStack::_get_impl(_2844)->i64;
      _checked_ptr_1<long long> _ptr__2877(_2877 ? _2877->raw() : nullptr,_2877 ? _2877->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2878 = mosek::fusion::p_WorkStack::_get_impl(_2844)->f64;
      _checked_ptr_1<double> _ptr__2878(_2878 ? _2878->raw() : nullptr,_2878 ? _2878->size(0) : 0);
      _ptr__2876[_2870] = (int)0;
      int _2879 = (int)0;
      int _2880 = (int)0;
      int _8156 = (int)0;
      int _8157 = _2853;
      for (int _2881 = _8156; _2881 < _8157; ++_2881)
      {
        {
          long long _2882 = _ptr__2868[_2881];
          int _8158 = _ptr__2861[safe_add( _2856,_2882 )];
          int _8159 = _ptr__2861[safe_add( safe_add( _2856,_2882 ),(int)1 )];
          for (int _2883 = _8158; _2883 < _8159; ++_2883)
          {
            {
              _ptr__2877[safe_add( _2871,_2880 )] = _ptr__2862[safe_add( _2858,_2883 )];
              _ptr__2878[safe_add( _2873,_2880 )] = _ptr__2863[safe_add( _2860,_2883 )];
              ++ _2880;
            }
          }
          _ptr__2877[safe_add( _2872,_2881 )] = _ptr__2864[_2882];
          _ptr__2878[safe_add( _2874,_2881 )] = _ptr__2863[safe_add( _2859,_2882 )];
          ++ _2879;
          _ptr__2876[safe_add( safe_add( _2870,_2881 ),(int)1 )] = _2880;
        }
      }
    }
  }
  else
  {
    {
      int _2884 = _2844->alloci32(safe_add( _2853,(int)1 ));
      int _2885 = _2844->alloci64(_2854);
      int _2886 = _2844->allocf64(_2854);
      int _2887 = _2844->allocf64(_2853);
      _2844->pushi32((int)0);
      _2844->pushi32(_2854);
      _2844->pushi32(_2853);
      int _8160 = (int)0;
      int _8161 = _2847;
      for (int _2888 = _8160; _2888 < _8161; ++_2888)
      {
        {
          _2844->pushi32(_ptr__2861[safe_add( _2848,((*dperm)(_2888)) )]);
        }
      }
      _2844->pushi32(_2847);
      std::shared_ptr< monty::ndarray< int,1 > > _2889 = mosek::fusion::p_WorkStack::_get_impl(_2844)->i32;
      _checked_ptr_1<int> _ptr__2889(_2889 ? _2889->raw() : nullptr,_2889 ? _2889->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2890 = mosek::fusion::p_WorkStack::_get_impl(_2844)->i64;
      _checked_ptr_1<long long> _ptr__2890(_2890 ? _2890->raw() : nullptr,_2890 ? _2890->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2891 = mosek::fusion::p_WorkStack::_get_impl(_2844)->f64;
      _checked_ptr_1<double> _ptr__2891(_2891 ? _2891->raw() : nullptr,_2891 ? _2891->size(0) : 0);
      _ptr__2889[_2884] = (int)0;
      int _2892 = (int)0;
      int _2893 = (int)0;
      int _8162 = (int)0;
      int _8163 = _2853;
      for (int _2894 = _8162; _2894 < _8163; ++_2894)
      {
        {
          long long _2895 = (long long)0;
          int _8164 = (int)0;
          int _8165 = _2847;
          for (int _2896 = _8164; _2896 < _8165; ++_2896)
          {
            {
              _2895 += safe_mul( ((_2894 / _ptr__2849[((*dperm)(_2896))]) % _ptr__2861[safe_add( _2848,((*dperm)(_2896)) )]),_ptr__2851[_2896] );
            }
          }
          int _8166 = _ptr__2861[safe_add( _2856,_2895 )];
          int _8167 = _ptr__2861[safe_add( safe_add( _2856,_2895 ),(int)1 )];
          for (int _2897 = _8166; _2897 < _8167; ++_2897)
          {
            {
              _ptr__2890[safe_add( _2885,_2893 )] = _ptr__2862[safe_add( _2858,_2897 )];
              _ptr__2891[safe_add( _2886,_2893 )] = _ptr__2863[safe_add( _2860,_2897 )];
              ++ _2893;
            }
          }
          _ptr__2891[safe_add( _2887,_2892 )] = _ptr__2863[safe_add( _2859,_2895 )];
          ++ _2892;
          _ptr__2889[safe_add( _2884,_2892 )] = _2893;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2898,std::shared_ptr< monty::ndarray< int,1 > > _2899){
  _checked_ptr_1<int> _ptr__2898(_2898 ? _2898->raw() : nullptr, _2898 ? _2898->size(0) : 0);
  _checked_ptr_1<int> _ptr__2899(_2899 ? _2899->raw() : nullptr, _2899 ? _2899->size(0) : 0);
  std::vector<int> _8168;
  for (int _2900 = (int)0, _8169 = (int)((_2898)->size(0)); _2900 < _8169 ; ++_2900)
  {
    _8168.push_back(_ptr__2899[_ptr__2898[_2900]]);
  }
  auto _8170 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8168.size()),_8168.begin(),_8168.end()));
  return _8170;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2901){ return new mosek::fusion::ExprTranspose(_2901); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _2901) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_2901); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _2901){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_2901->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _2901;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2902,monty::rc_ptr< ::mosek::fusion::WorkStack > _2903,monty::rc_ptr< ::mosek::fusion::WorkStack > _2904) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_2902,_2903,_2904); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2902,monty::rc_ptr< ::mosek::fusion::WorkStack > _2903,monty::rc_ptr< ::mosek::fusion::WorkStack > _2904){
  expr->eval(_2903,_2902,_2904);
  _2903->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_2903)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _2905 = mosek::fusion::p_WorkStack::_get_impl(_2903)->shape_base;
      int _2906 = mosek::fusion::p_WorkStack::_get_impl(_2903)->nelem;
      int _2907 = mosek::fusion::p_WorkStack::_get_impl(_2903)->nnz;
      bool _2908 = mosek::fusion::p_WorkStack::_get_impl(_2903)->hassp;
      int _2909 = mosek::fusion::p_WorkStack::_get_impl(_2903)->ptr_base;
      int _2910 = mosek::fusion::p_WorkStack::_get_impl(_2903)->sp_base;
      int _2911 = mosek::fusion::p_WorkStack::_get_impl(_2903)->nidxs_base;
      int _2912 = mosek::fusion::p_WorkStack::_get_impl(_2903)->bfix_base;
      int _2913 = mosek::fusion::p_WorkStack::_get_impl(_2903)->cof_base;
      int _2914 = ((*mosek::fusion::p_WorkStack::_get_impl(_2903)->i32)(_2905));
      int _2915 = ((*mosek::fusion::p_WorkStack::_get_impl(_2903)->i32)(safe_add( _2905,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _2916 = mosek::fusion::p_WorkStack::_get_impl(_2903)->i32;
      _checked_ptr_1<int> _ptr__2916(_2916 ? _2916->raw() : nullptr,_2916 ? _2916->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2917 = mosek::fusion::p_WorkStack::_get_impl(_2903)->i64;
      _checked_ptr_1<long long> _ptr__2917(_2917 ? _2917->raw() : nullptr,_2917 ? _2917->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2918 = mosek::fusion::p_WorkStack::_get_impl(_2903)->f64;
      _checked_ptr_1<double> _ptr__2918(_2918 ? _2918->raw() : nullptr,_2918 ? _2918->size(0) : 0);
      _2902->alloc_expr((int)2,_2906,_2907,_2908);
      int _2919 = mosek::fusion::p_WorkStack::_get_impl(_2902)->ptr_base;
      int _2920 = mosek::fusion::p_WorkStack::_get_impl(_2902)->nidxs_base;
      int _2921 = mosek::fusion::p_WorkStack::_get_impl(_2902)->sp_base;
      int _2922 = mosek::fusion::p_WorkStack::_get_impl(_2902)->cof_base;
      int _2923 = mosek::fusion::p_WorkStack::_get_impl(_2902)->bfix_base;
      int _2924 = mosek::fusion::p_WorkStack::_get_impl(_2902)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _2925 = mosek::fusion::p_WorkStack::_get_impl(_2902)->i32;
      _checked_ptr_1<int> _ptr__2925(_2925 ? _2925->raw() : nullptr,_2925 ? _2925->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2926 = mosek::fusion::p_WorkStack::_get_impl(_2902)->i64;
      _checked_ptr_1<long long> _ptr__2926(_2926 ? _2926->raw() : nullptr,_2926 ? _2926->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2927 = mosek::fusion::p_WorkStack::_get_impl(_2902)->f64;
      _checked_ptr_1<double> _ptr__2927(_2927 ? _2927->raw() : nullptr,_2927 ? _2927->size(0) : 0);
      _ptr__2925[_2924] = _2915;
      _ptr__2925[safe_add( _2924,(int)1 )] = _2914;
      if (_2908)
      {
        {
          int _2928 = _2904->alloci32(_2906);
          int _2929 = _2904->alloci32(safe_add( _2915,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _2930 = mosek::fusion::p_WorkStack::_get_impl(_2904)->i32;
          _checked_ptr_1<int> _ptr__2930(_2930 ? _2930->raw() : nullptr,_2930 ? _2930->size(0) : 0);
          int _8171 = (int)0;
          int _8172 = safe_add( _2915,(int)1 );
          for (int _2931 = _8171; _2931 < _8172; ++_2931)
          {
            {
              _ptr__2930[safe_add( _2929,_2931 )] = (int)0;
            }
          }
          int _8173 = (int)0;
          int _8174 = _2906;
          for (int _2932 = _8173; _2932 < _8174; ++_2932)
          {
            {
              ++ _ptr__2930[safe_add( safe_add( _2929,(_ptr__2917[safe_add( _2910,_2932 )] % _2915) ),(int)1 )];
            }
          }
          int _8175 = (int)0;
          int _8176 = _2915;
          for (int _2933 = _8175; _2933 < _8176; ++_2933)
          {
            {
              _ptr__2930[safe_add( safe_add( _2929,_2933 ),(int)1 )] += _ptr__2930[safe_add( _2929,_2933 )];
            }
          }
          int _8177 = (int)0;
          int _8178 = _2906;
          for (int _2934 = _8177; _2934 < _8178; ++_2934)
          {
            {
              long long _2935 = (_ptr__2917[safe_add( _2910,_2934 )] % _2915);
              _ptr__2930[safe_add( _2928,_ptr__2930[safe_add( _2929,_2935 )] )] = _2934;
              ++ _ptr__2930[safe_add( _2929,_2935 )];
            }
          }
          _ptr__2925[_2919] = (int)0;
          int _2936 = (int)0;
          int _8179 = (int)0;
          int _8180 = _2906;
          for (int _2937 = _8179; _2937 < _8180; ++_2937)
          {
            {
              int _2938 = _ptr__2930[safe_add( _2928,_2937 )];
              int _8181 = _ptr__2916[safe_add( _2909,_2938 )];
              int _8182 = _ptr__2916[safe_add( safe_add( _2909,_2938 ),(int)1 )];
              for (int _2939 = _8181; _2939 < _8182; ++_2939)
              {
                {
                  _ptr__2926[safe_add( _2920,_2936 )] = _ptr__2917[safe_add( _2911,_2939 )];
                  _ptr__2927[safe_add( _2922,_2936 )] = _ptr__2918[safe_add( _2913,_2939 )];
                  ++ _2936;
                }
              }
              long long _2940 = (_ptr__2917[safe_add( _2910,_2938 )] / _2915);
              long long _2941 = (_ptr__2917[safe_add( _2910,_2938 )] % _2915);
              _ptr__2925[safe_add( safe_add( _2919,_2937 ),(int)1 )] = _2936;
              _ptr__2926[safe_add( _2921,_2937 )] = safe_add( safe_mul( _2941,_2914 ),_2940 );
              _ptr__2927[safe_add( _2923,_2937 )] = _ptr__2918[safe_add( _2912,_2938 )];
            }
          }
        }
      }
      else
      {
        {
          _ptr__2925[_2919] = (int)0;
          int _2942 = (int)0;
          int _2943 = (int)0;
          int _8183 = (int)0;
          int _8184 = _2915;
          for (int _2944 = _8183; _2944 < _8184; ++_2944)
          {
            {
              int _8185 = (int)0;
              int _8186 = _2914;
              for (int _2945 = _8185; _2945 < _8186; ++_2945)
              {
                {
                  int _2946 = safe_add( safe_mul( _2945,_2915 ),_2944 );
                  int _8187 = _ptr__2916[safe_add( _2909,_2946 )];
                  int _8188 = _ptr__2916[safe_add( safe_add( _2909,_2946 ),(int)1 )];
                  for (int _2947 = _8187; _2947 < _8188; ++_2947)
                  {
                    {
                      _ptr__2926[safe_add( _2920,_2942 )] = _ptr__2917[safe_add( _2911,_2947 )];
                      _ptr__2927[safe_add( _2922,_2942 )] = _ptr__2918[safe_add( _2913,_2947 )];
                      ++ _2942;
                    }
                  }
                  _ptr__2927[safe_add( _2923,_2943 )] = _ptr__2918[safe_add( _2912,_2946 )];
                  _ptr__2925[safe_add( safe_add( _2919,_2943 ),(int)1 )] = _2942;
                  ++ _2943;
                }
              }
            }
          }
        }
      }
      _2904->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2948){
  _checked_ptr_1<int> _ptr__2948(_2948 ? _2948->raw() : nullptr, _2948 ? _2948->size(0) : 0);
  if (((int)((_2948)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__2948[(int)1]),(int)(_ptr__2948[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2949,    int _2950){ return new mosek::fusion::ExprStack(_2949,_2950); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2949,    int _2950) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_2949,_2950); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2949,    int _2950){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_2949,_2950));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8189;
    for (int _2951 = (int)0, _8190 = (int)((_2949)->size(0)); _2951 < _8190 ; ++_2951)
    {
      _8189.push_back(((*_2949)(_2951)));
    }
    auto _8191 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8189.size()),_8189.begin(),_8189.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _8191;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _2950;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2952,monty::rc_ptr< ::mosek::fusion::WorkStack > _2953,monty::rc_ptr< ::mosek::fusion::WorkStack > _2954) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_2952,_2953,_2954); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2952,monty::rc_ptr< ::mosek::fusion::WorkStack > _2953,monty::rc_ptr< ::mosek::fusion::WorkStack > _2954){
  int _2955 = (int)((exprs)->size(0));
  if ((_2955 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_2952,_2953,_2954);
    }
  }
  else
  {
    {
      int _8192 = (int)0;
      int _8193 = _2955;
      for (int _2956 = _8192; _2956 < _8193; ++_2956)
      {
        {
          ((*exprs)(((_2955 - _2956) - (int)1)))->eval(_2953,_2952,_2954);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2957 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2957(_2957 ? _2957->raw() : nullptr,_2957 ? _2957->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2958 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2958(_2958 ? _2958->raw() : nullptr,_2958 ? _2958->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2959 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2959(_2959 ? _2959->raw() : nullptr,_2959 ? _2959->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2960 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2960(_2960 ? _2960->raw() : nullptr,_2960 ? _2960->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _2961 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_2955)));
      std::shared_ptr< monty::ndarray< int,1 > > _2962 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2962(_2962 ? _2962->raw() : nullptr,_2962 ? _2962->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2963(_2963 ? _2963->raw() : nullptr,_2963 ? _2963->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2964(_2964 ? _2964->raw() : nullptr,_2964 ? _2964->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2965 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2965(_2965 ? _2965->raw() : nullptr,_2965 ? _2965->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2966 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2966(_2966 ? _2966->raw() : nullptr,_2966 ? _2966->size(0) : 0);
      int _8194 = (int)0;
      int _8195 = _2955;
      for (int _2967 = _8194; _2967 < _8195; ++_2967)
      {
        {
          _2953->pop_expr();
          _ptr__2957[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->nd;
          _ptr__2958[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->shape_base;
          _ptr__2959[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->nelem;
          _ptr__2960[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->nnz;
          ((*_2961)(_2967)) = mosek::fusion::p_WorkStack::_get_impl(_2953)->hassp;
          _ptr__2962[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->ptr_base;
          _ptr__2964[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->sp_base;
          _ptr__2963[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->nidxs_base;
          _ptr__2966[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->bfix_base;
          _ptr__2965[_2967] = mosek::fusion::p_WorkStack::_get_impl(_2953)->cof_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2968 = mosek::fusion::p_WorkStack::_get_impl(_2953)->i32;
      _checked_ptr_1<int> _ptr__2968(_2968 ? _2968->raw() : nullptr,_2968 ? _2968->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2969 = mosek::fusion::p_WorkStack::_get_impl(_2953)->i64;
      _checked_ptr_1<long long> _ptr__2969(_2969 ? _2969->raw() : nullptr,_2969 ? _2969->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2970 = mosek::fusion::p_WorkStack::_get_impl(_2953)->f64;
      _checked_ptr_1<double> _ptr__2970(_2970 ? _2970->raw() : nullptr,_2970 ? _2970->size(0) : 0);
      int _2971 = _ptr__2957[(int)0];
      int _2972 = _ptr__2958[(int)0];
      bool _2973 = (!((*_2961)((int)0)));
      bool _2974 = false;
      int _8196 = (int)1;
      int _8197 = _2955;
      for (int _2975 = _8196; _2975 < _8197; ++_2975)
      {
        {
          _2974 = (_2974 || ((dim != _2975) && (_ptr__2957[_2975] != _2971)));
          if ((!_2974))
          {
            {
              int _8198 = (int)0;
              int _8199 = dim;
              for (int _2976 = _8198; _2976 < _8199; ++_2976)
              {
                {
                  _2974 = (_2974 || (_ptr__2968[safe_add( _2972,_2976 )] != _ptr__2968[safe_add( _ptr__2958[_2975],_2976 )]));
                }
              }
            }
          }
          {}
          if ((!_2974))
          {
            {
              int _8200 = safe_add( dim,(int)1 );
              int _8201 = _2971;
              for (int _2977 = _8200; _2977 < _8201; ++_2977)
              {
                {
                  _2974 = (_2974 || (_ptr__2968[safe_add( _2972,_2977 )] != _ptr__2968[safe_add( _ptr__2958[_2975],_2977 )]));
                }
              }
            }
          }
          {}
          _2973 = (_2973 && (!((*_2961)(_2975))));
        }
      }
      if (_2974)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _2978 = (int)0;
      if ((dim < _2971))
      {
        {
          int _8202 = (int)0;
          int _8203 = _2955;
          for (int _2979 = _8202; _2979 < _8203; ++_2979)
          {
            {
              _2978 += _ptr__2968[safe_add( _ptr__2958[_2979],dim )];
            }
          }
        }
      }
      else
      {
        {
          _2978 = _2955;
        }
      }
      int _8204;
      bool _8205 = (dim < _2971);
      if (_8205)
      {
        _8204 = _2971;
      }
      else
      {
        _8204 = safe_add( _2971,(int)1 );
      }
      int _2980 = _8204;
      if ((_2980 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Oops!!"));
        }
      }
      {}
      int _2981 = (int)0;
      int _2982 = (int)0;
      {
        int _8206 = (int)0;
        int _8207 = _2955;
        for (int _2983 = _8206; _2983 < _8207; ++_2983)
        {
          {
            _2982 += _ptr__2960[_2983];
          }
        }
        int _8208 = (int)0;
        int _8209 = _2955;
        for (int _2984 = _8208; _2984 < _8209; ++_2984)
        {
          {
            _2981 += _ptr__2959[_2984];
          }
        }
      }
      int _2985 = (int)1;
      int _8210 = (int)0;
      int _8211 = dim;
      for (int _2986 = _8210; _2986 < _8211; ++_2986)
      {
        {
          _2985 *= _ptr__2968[safe_add( _2972,_2986 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _8212;
      bool _8213 = (dim < _2971);
      if (_8213)
      {
        std::vector<int> _8214;
        for (int _2988 = (int)0, _8215 = _2955; _2988 < _8215 ; ++_2988)
        {
          _8214.push_back(_ptr__2968[safe_add( _ptr__2958[_2988],dim )]);
        }
        auto _8216 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8214.size()),_8214.begin(),_8214.end()));
        _8212 = _8216;
      }
      else
      {
        std::vector<int> _8217;
        for (int _2989 = (int)0, _8218 = _2955; _2989 < _8218 ; ++_2989)
        {
          _8217.push_back((int)1);
        }
        auto _8219 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8217.size()),_8217.begin(),_8217.end()));
        _8212 = _8219;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2987 = _8212;
      _checked_ptr_1<int> _ptr__2987(_2987 ? _2987->raw() : nullptr,_2987 ? _2987->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2990 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2955)));
      _checked_ptr_1<int> _ptr__2990(_2990 ? _2990->raw() : nullptr,_2990 ? _2990->size(0) : 0);
      _ptr__2990[(int)0] = (int)0;
      int _8220 = (int)1;
      int _8221 = _2955;
      for (int _2991 = _8220; _2991 < _8221; ++_2991)
      {
        {
          _ptr__2990[_2991] = safe_add( _ptr__2990[(_2991 - (int)1)],_ptr__2987[(_2991 - (int)1)] );
        }
      }
      int _2992 = (int)0;
      int _8222 = (int)0;
      int _8223 = _2955;
      for (int _2993 = _8222; _2993 < _8223; ++_2993)
      {
        {
          _2992 += _ptr__2987[_2993];
        }
      }
      int _2994 = (int)1;
      int _8224 = safe_add( dim,(int)1 );
      int _8225 = _2971;
      for (int _2995 = _8224; _2995 < _8225; ++_2995)
      {
        {
          _2994 *= _ptr__2968[safe_add( _2972,_2995 )];
        }
      }
      if (_2973)
      {
        {
          _2952->alloc_expr(_2980,_2981,_2982,false);
          int _2996 = mosek::fusion::p_WorkStack::_get_impl(_2952)->ptr_base;
          int _2997 = mosek::fusion::p_WorkStack::_get_impl(_2952)->shape_base;
          int _2998 = mosek::fusion::p_WorkStack::_get_impl(_2952)->nidxs_base;
          int _2999 = mosek::fusion::p_WorkStack::_get_impl(_2952)->cof_base;
          int _3000 = mosek::fusion::p_WorkStack::_get_impl(_2952)->bfix_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3001 = mosek::fusion::p_WorkStack::_get_impl(_2952)->i32;
          _checked_ptr_1<int> _ptr__3001(_3001 ? _3001->raw() : nullptr,_3001 ? _3001->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3002 = mosek::fusion::p_WorkStack::_get_impl(_2952)->i64;
          _checked_ptr_1<long long> _ptr__3002(_3002 ? _3002->raw() : nullptr,_3002 ? _3002->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3003 = mosek::fusion::p_WorkStack::_get_impl(_2952)->f64;
          _checked_ptr_1<double> _ptr__3003(_3003 ? _3003->raw() : nullptr,_3003 ? _3003->size(0) : 0);
          int _8226 = (int)0;
          int _8227 = _2971;
          for (int _3004 = _8226; _3004 < _8227; ++_3004)
          {
            {
              _ptr__3001[safe_add( _2997,_3004 )] = _ptr__2968[safe_add( _2972,_3004 )];
            }
          }
          _ptr__3001[safe_add( _2997,dim )] = _2978;
          {
            _ptr__3001[_2996] = (int)0;
            {
              int _3005 = (int)0;
              int _8228 = (int)0;
              int _8229 = _2955;
              for (int _3006 = _8228; _3006 < _8229; ++_3006)
              {
                {
                  int _3007 = _ptr__2962[_3006];
                  int _3008 = (int)0;
                  int _8230 = (int)0;
                  int _8231 = _2985;
                  for (int _3009 = _8230; _3009 < _8231; ++_3009)
                  {
                    {
                      int _8232 = (int)0;
                      int _8233 = _ptr__2987[_3006];
                      for (int _3010 = _8232; _3010 < _8233; ++_3010)
                      {
                        {
                          int _8234 = (int)0;
                          int _8235 = _2994;
                          for (int _3011 = _8234; _3011 < _8235; ++_3011)
                          {
                            {
                              int _3012 = safe_add( safe_add( _3011,safe_mul( safe_add( _3010,_3005 ),_2994 ) ),safe_mul( safe_mul( _3009,_2992 ),_2994 ) );
                              int _3013 = (_ptr__2968[safe_add( safe_add( _3007,_3008 ),(int)1 )] - _ptr__2968[safe_add( _3007,_3008 )]);
                              _ptr__3001[safe_add( safe_add( _2996,_3012 ),(int)1 )] = _3013;
                              _ptr__3003[safe_add( _3000,_3012 )] = _ptr__2970[safe_add( _ptr__2966[_3006],_3008 )];
                              ++ _3008;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3005 += _ptr__2987[_3006];
                }
              }
              int _8236 = (int)0;
              int _8237 = _2981;
              for (int _3014 = _8236; _3014 < _8237; ++_3014)
              {
                {
                  _ptr__3001[safe_add( safe_add( _2996,_3014 ),(int)1 )] += _ptr__3001[safe_add( _2996,_3014 )];
                }
              }
            }
            {
              int _3015 = (int)0;
              int _8238 = (int)0;
              int _8239 = _2955;
              for (int _3016 = _8238; _3016 < _8239; ++_3016)
              {
                {
                  int _3017 = _ptr__2962[_3016];
                  int _3018 = (int)0;
                  int _8240 = (int)0;
                  int _8241 = _2985;
                  for (int _3019 = _8240; _3019 < _8241; ++_3019)
                  {
                    {
                      int _8242 = (int)0;
                      int _8243 = _ptr__2987[_3016];
                      for (int _3020 = _8242; _3020 < _8243; ++_3020)
                      {
                        {
                          int _8244 = (int)0;
                          int _8245 = _2994;
                          for (int _3021 = _8244; _3021 < _8245; ++_3021)
                          {
                            {
                              int _3022 = safe_add( safe_add( _3021,safe_mul( safe_add( _3020,_3015 ),_2994 ) ),safe_mul( safe_mul( _3019,_2992 ),_2994 ) );
                              int _3023 = _ptr__2968[safe_add( _3017,_3018 )];
                              int _3024 = (_ptr__2968[safe_add( safe_add( _3017,_3018 ),(int)1 )] - _3023);
                              int _8246 = (int)0;
                              int _8247 = _3024;
                              for (int _3025 = _8246; _3025 < _8247; ++_3025)
                              {
                                {
                                  _ptr__3002[safe_add( safe_add( _2998,_ptr__3001[safe_add( _2996,_3022 )] ),_3025 )] = _ptr__2969[safe_add( safe_add( _ptr__2963[_3016],_3023 ),_3025 )];
                                }
                              }
                              int _8248 = (int)0;
                              int _8249 = _3024;
                              for (int _3026 = _8248; _3026 < _8249; ++_3026)
                              {
                                {
                                  _ptr__3003[safe_add( safe_add( _2999,_ptr__3001[safe_add( _2996,_3022 )] ),_3026 )] = _ptr__2970[safe_add( safe_add( _ptr__2965[_3016],_3023 ),_3026 )];
                                }
                              }
                              ++ _3018;
                            }
                          }
                        }
                      }
                    }
                  }
                  _3015 += _ptr__2987[_3016];
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3027 = (int)1;
          int _8250 = (int)0;
          int _8251 = dim;
          for (int _3028 = _8250; _3028 < _8251; ++_3028)
          {
            {
              _3027 *= _ptr__2968[safe_add( _2972,_3028 )];
            }
          }
          _3027 *= _2978;
          int _8252 = safe_add( dim,(int)1 );
          int _8253 = _2971;
          for (int _3029 = _8252; _3029 < _8253; ++_3029)
          {
            {
              _3027 *= _ptr__2968[safe_add( _2972,_3029 )];
            }
          }
          bool _3030 = (_2981 < _3027);
          _2952->alloc_expr(_2980,_2981,_2982,_3030);
          int _3031 = mosek::fusion::p_WorkStack::_get_impl(_2952)->ptr_base;
          int _3032 = mosek::fusion::p_WorkStack::_get_impl(_2952)->nidxs_base;
          int _8254;
          bool _8255 = _3030;
          if (_8255)
          {
            _8254 = mosek::fusion::p_WorkStack::_get_impl(_2952)->sp_base;
          }
          else
          {
            _8254 = _2952->alloci64(_2981);
          }
          int _3033 = _8254;
          int _3034 = mosek::fusion::p_WorkStack::_get_impl(_2952)->cof_base;
          int _3035 = mosek::fusion::p_WorkStack::_get_impl(_2952)->bfix_base;
          int _3036 = mosek::fusion::p_WorkStack::_get_impl(_2952)->shape_base;
          int _8256 = (int)0;
          int _8257 = _2971;
          for (int _3037 = _8256; _3037 < _8257; ++_3037)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_2952)->i32)(safe_add( _3036,_3037 ))) = _ptr__2968[safe_add( _2972,_3037 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_2952)->i32)(safe_add( _3036,dim ))) = _2978;
          int _3038 = _2954->alloci32(safe_add( _2981,(int)1 ));
          int _3039 = _2954->alloci64(_2982);
          int _3040 = _2954->alloci64(_2981);
          int _3041 = _2954->allocf64(_2982);
          int _3042 = _2954->allocf64(_2981);
          std::shared_ptr< monty::ndarray< int,1 > > _3043 = mosek::fusion::p_WorkStack::_get_impl(_2952)->i32;
          _checked_ptr_1<int> _ptr__3043(_3043 ? _3043->raw() : nullptr,_3043 ? _3043->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3044 = mosek::fusion::p_WorkStack::_get_impl(_2952)->i64;
          _checked_ptr_1<long long> _ptr__3044(_3044 ? _3044->raw() : nullptr,_3044 ? _3044->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3045 = mosek::fusion::p_WorkStack::_get_impl(_2952)->f64;
          _checked_ptr_1<double> _ptr__3045(_3045 ? _3045->raw() : nullptr,_3045 ? _3045->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _3046 = mosek::fusion::p_WorkStack::_get_impl(_2954)->i32;
          _checked_ptr_1<int> _ptr__3046(_3046 ? _3046->raw() : nullptr,_3046 ? _3046->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3047 = mosek::fusion::p_WorkStack::_get_impl(_2954)->i64;
          _checked_ptr_1<long long> _ptr__3047(_3047 ? _3047->raw() : nullptr,_3047 ? _3047->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3048 = mosek::fusion::p_WorkStack::_get_impl(_2954)->f64;
          _checked_ptr_1<double> _ptr__3048(_3048 ? _3048->raw() : nullptr,_3048 ? _3048->size(0) : 0);
          {
            int _3049 = (int)0;
            int _3050 = (int)0;
            int _8258 = (int)0;
            int _8259 = _2955;
            for (int _3051 = _8258; _3051 < _8259; ++_3051)
            {
              {
                ::mosek::fusion::Utils::Tools::arraycopy(_2969,_ptr__2963[_3051],_3047,safe_add( _3039,_3050 ),_ptr__2960[_3051]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2970,_ptr__2965[_3051],_3048,safe_add( _3041,_3050 ),_ptr__2960[_3051]);
                ::mosek::fusion::Utils::Tools::arraycopy(_2970,_ptr__2966[_3051],_3048,safe_add( _3042,_3049 ),_ptr__2959[_3051]);
                _3050 += _ptr__2960[_3051];
                _3049 += _ptr__2959[_3051];
              }
            }
          }
          {
            _ptr__3046[_3038] = (int)0;
            int _3052 = (int)0;
            int _3053 = (int)0;
            int _8260 = (int)0;
            int _8261 = _2955;
            for (int _3054 = _8260; _3054 < _8261; ++_3054)
            {
              {
                int _3055 = _ptr__2987[_3054];
                int _3056 = safe_mul( _3055,_2994 );
                int _3057 = _2994;
                if (((*_2961)(_3054)))
                {
                  {
                    int _8262 = (int)0;
                    int _8263 = _ptr__2959[_3054];
                    for (int _3058 = _8262; _3058 < _8263; ++_3058)
                    {
                      {
                        long long _3059 = (_ptr__2969[safe_add( _ptr__2964[_3054],_3058 )] / _3056);
                        long long _3060 = ((_ptr__2969[safe_add( _ptr__2964[_3054],_3058 )] / _3057) % _3055);
                        long long _3061 = (_ptr__2969[safe_add( _ptr__2964[_3054],_3058 )] % _2994);
                        _ptr__3047[safe_add( _3040,_3053 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3059,_2978 ),_3060 ),_ptr__2990[_3054] ),_2994 ),_3061 );
                        _ptr__3046[safe_add( safe_add( _3038,_3053 ),(int)1 )] = safe_add( _3052,_ptr__2968[safe_add( safe_add( _ptr__2962[_3054],_3058 ),(int)1 )] );
                        ++ _3053;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _3062 = (int)0;
                    int _8264 = (int)0;
                    int _8265 = _2985;
                    for (int _3063 = _8264; _3063 < _8265; ++_3063)
                    {
                      {
                        int _8266 = (int)0;
                        int _8267 = _3055;
                        for (int _3064 = _8266; _3064 < _8267; ++_3064)
                        {
                          {
                            int _8268 = (int)0;
                            int _8269 = _2994;
                            for (int _3065 = _8268; _3065 < _8269; ++_3065)
                            {
                              {
                                _ptr__3047[safe_add( _3040,_3053 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _3063,_2978 ),_3064 ),_ptr__2990[_3054] ),_2994 ),_3065 );
                                _ptr__3046[safe_add( safe_add( _3038,_3053 ),(int)1 )] = safe_add( _3052,_ptr__2968[safe_add( safe_add( _ptr__2962[_3054],_3062 ),(int)1 )] );
                                ++ _3053;
                                ++ _3062;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
                _3052 += _ptr__2960[_3054];
              }
            }
          }
          if ((dim > (int)0))
          {
            {
              int _3066 = (int)0;
              int _8270 = (int)0;
              int _8271 = _2980;
              for (int _3067 = _8270; _3067 < _8271; ++_3067)
              {
                {
                  if ((_3066 < _ptr__3043[safe_add( _3036,_3067 )]))
                  {
                    {
                      _3066 = _ptr__3043[safe_add( _3036,_3067 )];
                    }
                  }
                  {}
                }
              }
              std::shared_ptr< monty::ndarray< long long,1 > > _3068 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2980)));
              _checked_ptr_1<long long> _ptr__3068(_3068 ? _3068->raw() : nullptr,_3068 ? _3068->size(0) : 0);
              _ptr__3068[(_2980 - (int)1)] = (int)1;
              int _8272 = (int)1;
              int _8273 = _2980;
              for (int _3069 = _8272; _3069 < _8273; ++_3069)
              {
                {
                  _ptr__3068[((_2980 - _3069) - (int)1)] = safe_mul( _ptr__3068[(_2980 - _3069)],_ptr__3043[(safe_add( _3036,_2980 ) - _3069)] );
                }
              }
              int _3070 = _2954->alloci32(_2981);
              int _3071 = _2954->alloci32(_2981);
              int _3072 = _2954->alloci32(safe_add( _3066,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _3073 = mosek::fusion::p_WorkStack::_get_impl(_2954)->i32;
              _checked_ptr_1<int> _ptr__3073(_3073 ? _3073->raw() : nullptr,_3073 ? _3073->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _3074 = mosek::fusion::p_WorkStack::_get_impl(_2954)->i64;
              _checked_ptr_1<long long> _ptr__3074(_3074 ? _3074->raw() : nullptr,_3074 ? _3074->size(0) : 0);
              std::shared_ptr< monty::ndarray< double,1 > > _3075 = mosek::fusion::p_WorkStack::_get_impl(_2954)->f64;
              _checked_ptr_1<double> _ptr__3075(_3075 ? _3075->raw() : nullptr,_3075 ? _3075->size(0) : 0);
              {
                int _8274 = (int)0;
                int _8275 = _2981;
                for (int _3076 = _8274; _3076 < _8275; ++_3076)
                {
                  {
                    _ptr__3073[safe_add( _3070,_3076 )] = _3076;
                  }
                }
                int _8276 = (int)0;
                int _8277 = _2980;
                for (int _3077 = _8276; _3077 < _8277; ++_3077)
                {
                  {
                    int _3078 = ((_2980 - _3077) - (int)1);
                    int _3079 = _ptr__3043[safe_add( _3036,_3078 )];
                    int _8278 = (int)0;
                    int _8279 = safe_add( _3079,(int)1 );
                    for (int _3080 = _8278; _3080 < _8279; ++_3080)
                    {
                      {
                        _ptr__3073[safe_add( _3072,_3080 )] = (int)0;
                      }
                    }
                    int _8280 = (int)0;
                    int _8281 = _2981;
                    for (int _3081 = _8280; _3081 < _8281; ++_3081)
                    {
                      {
                        int _3082 = _ptr__3073[safe_add( _3070,_3081 )];
                        long long _3083 = ((_ptr__3074[safe_add( _3040,_3082 )] / _ptr__3068[_3078]) % _3079);
                        ++ _ptr__3073[safe_add( safe_add( _3072,_3083 ),(int)1 )];
                      }
                    }
                    {
                      int _8282 = (int)0;
                      int _8283 = _3079;
                      for (int _3084 = _8282; _3084 < _8283; ++_3084)
                      {
                        {
                          _ptr__3073[safe_add( safe_add( _3072,_3084 ),(int)1 )] += _ptr__3073[safe_add( _3072,_3084 )];
                        }
                      }
                      int _8284 = (int)0;
                      int _8285 = _2981;
                      for (int _3085 = _8284; _3085 < _8285; ++_3085)
                      {
                        {
                          int _3086 = _ptr__3073[safe_add( _3070,_3085 )];
                          long long _3087 = ((_ptr__3074[safe_add( _3040,_3086 )] / _ptr__3068[_3078]) % _3079);
                          _ptr__3073[safe_add( _3071,_ptr__3073[safe_add( _3072,_3087 )] )] = _3086;
                          ++ _ptr__3073[safe_add( _3072,_3087 )];
                        }
                      }
                    }
                    int _3088 = _3070;
                    _3070 = _3071;
                    _3071 = _3088;
                  }
                }
                int _3089 = (int)0;
                _ptr__3043[_3031] = (int)0;
                int _8286 = (int)0;
                int _8287 = _2981;
                for (int _3090 = _8286; _3090 < _8287; ++_3090)
                {
                  {
                    int _3091 = _ptr__3073[safe_add( _3070,_3090 )];
                    int _3092 = _ptr__3073[safe_add( _3038,_3091 )];
                    int _3093 = _ptr__3073[safe_add( safe_add( _3038,_3091 ),(int)1 )];
                    int _3094 = (_3093 - _3092);
                    _ptr__3043[safe_add( safe_add( _3031,_3090 ),(int)1 )] = safe_add( _ptr__3043[safe_add( _3031,_3090 )],_3094 );
                    _ptr__3045[safe_add( _3035,_3090 )] = _ptr__3075[safe_add( _3042,_3091 )];
                    _ptr__3044[safe_add( _3033,_3090 )] = _ptr__3074[safe_add( _3040,_3091 )];
                    int _8288 = _3092;
                    int _8289 = _3093;
                    for (int _3095 = _8288; _3095 < _8289; ++_3095)
                    {
                      {
                        _ptr__3044[safe_add( _3032,_3089 )] = _ptr__3074[safe_add( _3039,_3095 )];
                        _ptr__3045[safe_add( _3034,_3089 )] = _ptr__3075[safe_add( _3041,_3095 )];
                        ++ _3089;
                      }
                    }
                  }
                }
              }
            }
          }
          else
          {
            {
              int _3096 = (int)0;
              _ptr__3043[_3031] = (int)0;
              int _8290 = (int)0;
              int _8291 = _2981;
              for (int _3097 = _8290; _3097 < _8291; ++_3097)
              {
                {
                  int _3098 = _ptr__3046[safe_add( _3038,_3097 )];
                  int _3099 = _ptr__3046[safe_add( safe_add( _3038,_3097 ),(int)1 )];
                  int _3100 = (_3099 - _3098);
                  _ptr__3043[safe_add( safe_add( _3031,_3097 ),(int)1 )] = safe_add( _ptr__3043[safe_add( _3031,_3097 )],_3100 );
                  _ptr__3045[safe_add( _3035,_3097 )] = _ptr__3048[safe_add( _3042,_3097 )];
                  _ptr__3044[safe_add( _3033,_3097 )] = _ptr__3047[safe_add( _3040,_3097 )];
                  int _8292 = _3098;
                  int _8293 = _3099;
                  for (int _3101 = _8292; _3101 < _8293; ++_3101)
                  {
                    {
                      _ptr__3044[safe_add( _3032,_3096 )] = _ptr__3047[safe_add( _3039,_3101 )];
                      _ptr__3045[safe_add( _3034,_3096 )] = _ptr__3048[safe_add( _3041,_3101 )];
                      ++ _3096;
                    }
                  }
                }
              }
            }
          }
          if ((!_3030))
          {
            {
              _2952->popi64(_2981);
            }
          }
          {}
          _2954->clear();
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3102,int _3103){
  if (((int)((_3102)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_3102)->size(0)) == (int)1))
  {
    {
      return ((*_3102)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _8294;
      for (int _3105 = (int)0, _8295 = (int)((_3102)->size(0)); _3105 < _8295 ; ++_3105)
      {
        _8294.push_back(((*_3102)(_3105))->getShape());
      }
      auto _8296 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_8294.size()),_8294.begin(),_8294.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _3104 = _8296;
      std::shared_ptr< monty::ndarray< int,1 > > _3106 = ((*_3104)((int)0));
      _checked_ptr_1<int> _ptr__3106(_3106 ? _3106->raw() : nullptr,_3106 ? _3106->size(0) : 0);
      int _3107 = (int)((_3106)->size(0));
      int _8297 = (int)1;
      int _8298 = (int)((_3104)->size(0));
      for (int _3108 = _8297; _3108 < _8298; ++_3108)
      {
        {
          if ((_3107 != (int)((((*_3104)(_3108)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _8299 = (int)0;
          int _8300 = _3103;
          for (int _3109 = _8299; _3109 < _8300; ++_3109)
          {
            {
              if ((_ptr__3106[_3109] != ((*((*_3104)(_3108)))(_3109))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _8301 = safe_add( _3103,(int)1 );
          int _8302 = _3107;
          for (int _3110 = _8301; _3110 < _8302; ++_3110)
          {
            {
              if ((_ptr__3106[_3110] != ((*((*_3104)(_3108)))(_3110))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_3103 == _3107))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3111 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3107,(int)1 ))));
          _checked_ptr_1<int> _ptr__3111(_3111 ? _3111->raw() : nullptr,_3111 ? _3111->size(0) : 0);
          int _8303 = (int)0;
          int _8304 = _3107;
          for (int _3112 = _8303; _3112 < _8304; ++_3112)
          {
            {
              _ptr__3111[_3112] = _ptr__3106[_3112];
            }
          }
          _ptr__3111[_3107] = (int)((_3104)->size(0));
          return _3111;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _3113 = _3106;
          _checked_ptr_1<int> _ptr__3113(_3113 ? _3113->raw() : nullptr,_3113 ? _3113->size(0) : 0);
          int _8305 = (int)1;
          int _8306 = (int)((_3104)->size(0));
          for (int _3114 = _8305; _3114 < _8306; ++_3114)
          {
            {
              _ptr__3113[_3103] += ((*((*_3104)(_3114)))(_3103));
            }
          }
          return _3113;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _3115 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _8307 = (int)1;
  int _8308 = (int)((exprs)->size(0));
  for (int _3116 = _8307; _3116 < _8308; ++_3116)
  {
    {
      _3115->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_3116))->toString());
    }
  }
  _3115->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _3115->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3117,    std::shared_ptr< monty::ndarray< long long,1 > > _3118,    std::shared_ptr< monty::ndarray< double,1 > > _3119){ return new mosek::fusion::ExprInner(_3117,_3118,_3119); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3117,    std::shared_ptr< monty::ndarray< long long,1 > > _3118,    std::shared_ptr< monty::ndarray< double,1 > > _3119) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3117,_3118,_3119); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3117,    std::shared_ptr< monty::ndarray< long long,1 > > _3118,    std::shared_ptr< monty::ndarray< double,1 > > _3119){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__3118(_3118 ? _3118->raw() : nullptr, _3118 ? _3118->size(0) : 0);
    _checked_ptr_1<double> _ptr__3119(_3119 ? _3119->raw() : nullptr, _3119 ? _3119->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _3117;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _3118;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _3119;
    if (((int)((_3118)->size(0)) != (int)((_3119)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _3120 = _3117->getShape();
    _checked_ptr_1<int> _ptr__3120(_3120 ? _3120->raw() : nullptr,_3120 ? _3120->size(0) : 0);
    long long _3121 = ::mosek::fusion::p_Set::size(_3120);
    int _8309 = (int)1;
    int _8310 = (int)((_3118)->size(0));
    for (int _3122 = _8309; _3122 < _8310; ++_3122)
    {
      {
        if ((_ptr__3118[_3122] <= _ptr__3118[(_3122 - (int)1)]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
          }
        }
        {}
      }
    }
    if (((int)((_3118)->size(0)) > (int)0))
    {
      {
        if (((_ptr__3118[(int)0] < (int)0) || (_ptr__3118[((int)((_3118)->size(0)) - (int)1)] > _3121)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
          }
        }
        {}
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3123,    std::shared_ptr< monty::ndarray< double,1 > > _3124){ return new mosek::fusion::ExprInner(_3123,_3124); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3123,    std::shared_ptr< monty::ndarray< double,1 > > _3124) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3123,_3124); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3123,    std::shared_ptr< monty::ndarray< double,1 > > _3124){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3124(_3124 ? _3124->raw() : nullptr, _3124 ? _3124->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3123,::mosek::fusion::p_ExprInner::range((int)((_3124)->size(0))),_3124);
    std::shared_ptr< monty::ndarray< int,1 > > _3125 = _3123->getShape();
    _checked_ptr_1<int> _ptr__3125(_3125 ? _3125->raw() : nullptr,_3125 ? _3125->size(0) : 0);
    if ((((int)((_3125)->size(0)) != (int)1) || (_ptr__3125[(int)0] != (int)((_3124)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3126,    std::shared_ptr< monty::ndarray< int,2 > > _3127,    std::shared_ptr< monty::ndarray< double,1 > > _3128){ return new mosek::fusion::ExprInner(_3126,_3127,_3128); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _3126,    std::shared_ptr< monty::ndarray< int,2 > > _3127,    std::shared_ptr< monty::ndarray< double,1 > > _3128) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_3126,_3127,_3128); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3126,    std::shared_ptr< monty::ndarray< int,2 > > _3127,    std::shared_ptr< monty::ndarray< double,1 > > _3128){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3128(_3128 ? _3128->raw() : nullptr, _3128 ? _3128->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_3126,::mosek::fusion::p_ExprInner::convert(_3126->getShape(),_3127),_3128);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3129,monty::rc_ptr< ::mosek::fusion::WorkStack > _3130,monty::rc_ptr< ::mosek::fusion::WorkStack > _3131) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_3129,_3130,_3131); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3129,monty::rc_ptr< ::mosek::fusion::WorkStack > _3130,monty::rc_ptr< ::mosek::fusion::WorkStack > _3131){
  expr->eval(_3130,_3129,_3131);
  int _3132 = _3130->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _3133 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3132)));
  _checked_ptr_1<int> _ptr__3133(_3133 ? _3133->raw() : nullptr,_3133 ? _3133->size(0) : 0);
  _3130->popi32(_3132,_3133,(int)0);
  int _3134 = _3130->popi32();
  int _3135 = _3130->popi32();
  bool _3136 = (_3130->popi32() != (int)0);
  int _3137 = _3130->popi32(safe_add( _3134,(int)1 ));
  int _8311;
  bool _8312 = _3136;
  if (_8312)
  {
    _8311 = _3130->popi64(_3134);
  }
  else
  {
    _8311 = (int)0;
  }
  int _3138 = _8311;
  int _3139 = _3130->popi64(_3135);
  int _3140 = _3130->popf64(_3134);
  int _3141 = _3130->popf64(_3135);
  std::shared_ptr< monty::ndarray< int,1 > > _3142 = mosek::fusion::p_WorkStack::_get_impl(_3130)->i32;
  _checked_ptr_1<int> _ptr__3142(_3142 ? _3142->raw() : nullptr,_3142 ? _3142->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3143 = mosek::fusion::p_WorkStack::_get_impl(_3130)->i64;
  _checked_ptr_1<long long> _ptr__3143(_3143 ? _3143->raw() : nullptr,_3143 ? _3143->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3144 = mosek::fusion::p_WorkStack::_get_impl(_3130)->f64;
  _checked_ptr_1<double> _ptr__3144(_3144 ? _3144->raw() : nullptr,_3144 ? _3144->size(0) : 0);
  int _3145 = (int)0;
  if (_3136)
  {
    {
      int _3146 = (int)0;
      int _3147 = (int)0;
      while ( ((_3147 < (int)((vsub)->size(0))) && (_3146 < _3134)) )
      {
        {
          if ((_ptr__3143[safe_add( _3138,_3146 )] < ((*vsub)(_3147))))
          {
            {
              ++ _3146;
            }
          }
          else if((_ptr__3143[safe_add( _3138,_3146 )] > ((*vsub)(_3147))))
          {
            {
              ++ _3147;
            }
          }
          else
          {
            {
              _3145 += (_ptr__3142[safe_add( safe_add( _3137,_3146 ),(int)1 )] - _ptr__3142[safe_add( _3137,_3146 )]);
              ++ _3147;
              ++ _3146;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8313 = (int)0;
      int _8314 = (int)((vsub)->size(0));
      for (int _3148 = _8313; _3148 < _8314; ++_3148)
      {
        {
          _3145 += (_ptr__3142[safe_add( safe_add( _3137,((*vsub)(_3148)) ),(int)1 )] - _ptr__3142[safe_add( _3137,((*vsub)(_3148)) )]);
        }
      }
    }
  }
  int _3149 = _3129->alloci32((int)2);
  int _3150 = _3129->alloci64(_3145);
  int _3151 = _3129->allocf64(_3145);
  int _3152 = _3129->allocf64((int)1);
  _3129->pushi32((int)0);
  _3129->pushi32(_3145);
  _3129->pushi32((int)1);
  _3129->pushi32((int)0);
  std::shared_ptr< monty::ndarray< int,1 > > _3153 = mosek::fusion::p_WorkStack::_get_impl(_3129)->i32;
  _checked_ptr_1<int> _ptr__3153(_3153 ? _3153->raw() : nullptr,_3153 ? _3153->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3154 = mosek::fusion::p_WorkStack::_get_impl(_3129)->i64;
  _checked_ptr_1<long long> _ptr__3154(_3154 ? _3154->raw() : nullptr,_3154 ? _3154->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3155 = mosek::fusion::p_WorkStack::_get_impl(_3129)->f64;
  _checked_ptr_1<double> _ptr__3155(_3155 ? _3155->raw() : nullptr,_3155 ? _3155->size(0) : 0);
  _ptr__3153[_3149] = (int)0;
  _ptr__3153[safe_add( _3149,(int)1 )] = _3145;
  int _3156 = (int)0;
  double _3157 = 0.0;
  if (_3136)
  {
    {
      int _3158 = (int)0;
      int _3159 = (int)0;
      while ( ((_3159 < (int)((vsub)->size(0))) && (_3158 < _3134)) )
      {
        {
          if ((_ptr__3143[safe_add( _3138,_3158 )] < ((*vsub)(_3159))))
          {
            {
              ++ _3158;
            }
          }
          else if((_ptr__3143[safe_add( _3138,_3158 )] > ((*vsub)(_3159))))
          {
            {
              ++ _3159;
            }
          }
          else
          {
            {
              int _3160 = _ptr__3142[safe_add( _3137,_3158 )];
              int _3161 = _ptr__3142[safe_add( safe_add( _3137,_3158 ),(int)1 )];
              int _8315 = _3160;
              int _8316 = _3161;
              for (int _3162 = _8315; _3162 < _8316; ++_3162)
              {
                {
                  _ptr__3154[safe_add( _3150,_3156 )] = _ptr__3143[safe_add( _3139,_3162 )];
                  _ptr__3155[safe_add( _3151,_3156 )] = (((*vcof)(_3159)) * _ptr__3144[safe_add( _3141,_3162 )]);
                  ++ _3156;
                }
              }
              _3157 += (((*vcof)(_3159)) * _ptr__3144[safe_add( _3140,_3158 )]);
              ++ _3159;
              ++ _3158;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _8317 = (int)0;
      int _8318 = (int)((vsub)->size(0));
      for (int _3163 = _8317; _3163 < _8318; ++_3163)
      {
        {
          int _3164 = _ptr__3142[safe_add( _3137,((*vsub)(_3163)) )];
          int _3165 = _ptr__3142[safe_add( safe_add( _3137,((*vsub)(_3163)) ),(int)1 )];
          int _8319 = _3164;
          int _8320 = _3165;
          for (int _3166 = _8319; _3166 < _8320; ++_3166)
          {
            {
              _ptr__3154[safe_add( _3150,_3156 )] = _ptr__3143[safe_add( _3139,_3166 )];
              _ptr__3155[safe_add( _3151,_3156 )] = (((*vcof)(_3163)) * _ptr__3144[safe_add( _3141,_3166 )]);
              ++ _3156;
            }
          }
          _3157 += (((*vcof)(_3163)) * _ptr__3144[safe_add( _3140,((*vsub)(_3163)) )]);
        }
      }
    }
  }
  _ptr__3155[_3152] = _3157;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _3167){
  std::vector<long long> _8321;
  for (int _3168 = (int)0, _8322 = _3167; _3168 < _8322 ; ++_3168)
  {
    _8321.push_back(_3168);
  }
  auto _8323 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8321.size()),_8321.begin(),_8321.end()));
  return _8323;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _3169,std::shared_ptr< monty::ndarray< int,2 > > _3170){
  _checked_ptr_1<int> _ptr__3169(_3169 ? _3169->raw() : nullptr, _3169 ? _3169->size(0) : 0);
  int _3171 = (int)((_3169)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _3172 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3171)));
  _checked_ptr_1<long long> _ptr__3172(_3172 ? _3172->raw() : nullptr,_3172 ? _3172->size(0) : 0);
  _ptr__3172[(_3171 - (int)1)] = (int)1;
  int _8324 = (int)1;
  int _8325 = _3171;
  for (int _3173 = _8324; _3173 < _8325; ++_3173)
  {
    {
      _ptr__3172[((_3171 - _3173) - (int)1)] = safe_mul( _ptr__3172[(_3171 - _3173)],_ptr__3169[(_3171 - _3173)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3174 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3170)->size(0)))));
  _checked_ptr_1<long long> _ptr__3174(_3174 ? _3174->raw() : nullptr,_3174 ? _3174->size(0) : 0);
  int _8326 = (int)0;
  int _8327 = (int)((_3170)->size(0));
  for (int _3175 = _8326; _3175 < _8327; ++_3175)
  {
    {
      int _8328 = (int)0;
      int _8329 = _3171;
      for (int _3176 = _8328; _3176 < _8329; ++_3176)
      {
        {
          _ptr__3174[_3175] += safe_mul( _ptr__3172[_3176],((*_3170)(_3175,_3176)) );
        }
      }
    }
  }
  return _3174;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3177,    int _3178,    std::shared_ptr< monty::ndarray< int,1 > > _3179,    std::shared_ptr< monty::ndarray< int,1 > > _3180,    std::shared_ptr< monty::ndarray< double,1 > > _3181,    monty::rc_ptr< ::mosek::fusion::Expression > _3182,    int _3183){ return new mosek::fusion::ExprMulDiagRight(_3177,_3178,_3179,_3180,_3181,_3182,_3183); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3177,    int _3178,    std::shared_ptr< monty::ndarray< int,1 > > _3179,    std::shared_ptr< monty::ndarray< int,1 > > _3180,    std::shared_ptr< monty::ndarray< double,1 > > _3181,    monty::rc_ptr< ::mosek::fusion::Expression > _3182,    int _3183) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3177,_3178,_3179,_3180,_3181,_3182,_3183); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3177,    int _3178,    std::shared_ptr< monty::ndarray< int,1 > > _3179,    std::shared_ptr< monty::ndarray< int,1 > > _3180,    std::shared_ptr< monty::ndarray< double,1 > > _3181,    monty::rc_ptr< ::mosek::fusion::Expression > _3182,    int _3183){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3179(_3179 ? _3179->raw() : nullptr, _3179 ? _3179->size(0) : 0);
    _checked_ptr_1<int> _ptr__3180(_3180 ? _3180->raw() : nullptr, _3180 ? _3180->size(0) : 0);
    _checked_ptr_1<double> _ptr__3181(_3181 ? _3181->raw() : nullptr, _3181 ? _3181->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3178)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _3177;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _3178;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _3179;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _3180;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _3181;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _3182;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _3184,    int _3185,    std::shared_ptr< monty::ndarray< int,1 > > _3186,    std::shared_ptr< monty::ndarray< int,1 > > _3187,    std::shared_ptr< monty::ndarray< double,1 > > _3188,    monty::rc_ptr< ::mosek::fusion::Expression > _3189){ return new mosek::fusion::ExprMulDiagRight(_3184,_3185,_3186,_3187,_3188,_3189); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _3184,    int _3185,    std::shared_ptr< monty::ndarray< int,1 > > _3186,    std::shared_ptr< monty::ndarray< int,1 > > _3187,    std::shared_ptr< monty::ndarray< double,1 > > _3188,    monty::rc_ptr< ::mosek::fusion::Expression > _3189) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_3184,_3185,_3186,_3187,_3188,_3189); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _3184,    int _3185,    std::shared_ptr< monty::ndarray< int,1 > > _3186,    std::shared_ptr< monty::ndarray< int,1 > > _3187,    std::shared_ptr< monty::ndarray< double,1 > > _3188,    monty::rc_ptr< ::mosek::fusion::Expression > _3189){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3186(_3186 ? _3186->raw() : nullptr, _3186 ? _3186->size(0) : 0);
    _checked_ptr_1<int> _ptr__3187(_3187 ? _3187->raw() : nullptr, _3187 ? _3187->size(0) : 0);
    _checked_ptr_1<double> _ptr__3188(_3188 ? _3188->raw() : nullptr, _3188 ? _3188->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_3184,_3185,_3186,_3187,_3188,_3189,::mosek::fusion::p_ExprMulDiagRight::validate(_3184,_3185,_3186,_3187,_3188,_3189));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3190,monty::rc_ptr< ::mosek::fusion::WorkStack > _3191,monty::rc_ptr< ::mosek::fusion::WorkStack > _3192) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_3190,_3191,_3192); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3190,monty::rc_ptr< ::mosek::fusion::WorkStack > _3191,monty::rc_ptr< ::mosek::fusion::WorkStack > _3192){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_3191,_3190,_3192);
  int _3193 = (int)0;
  int _3194 = (int)99999;
  int _3195 = (int)0;
  bool _3196 = (_3191->peeki32((int)5) != (int)0);
  if (_3196)
  {
    {
      _3195 = _3191->peeki32((int)2);
      _3194 = _3191->alloci32(safe_add( _3195,(int)1 ));
      _3193 += safe_add( _3195,(int)1 );
    }
  }
  {}
  int _3197 = (int)((mval)->size(0));
  int _3198 = _3191->alloci32(_3197);
  int _3199 = _3191->alloci32(safe_add( mdim1,(int)1 ));
  _3193 += safe_add( safe_add( _3197,mdim1 ),(int)1 );
  {
    std::shared_ptr< monty::ndarray< int,1 > > _3200 = mosek::fusion::p_WorkStack::_get_impl(_3191)->i32;
    _checked_ptr_1<int> _ptr__3200(_3200 ? _3200->raw() : nullptr,_3200 ? _3200->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _3201 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj;
    _checked_ptr_1<int> _ptr__3201(_3201 ? _3201->raw() : nullptr,_3201 ? _3201->size(0) : 0);
    {
      int _8330 = (int)0;
      int _8331 = safe_add( mdim1,(int)1 );
      for (int _3202 = _8330; _3202 < _8331; ++_3202)
      {
        {
          _ptr__3200[safe_add( _3199,_3202 )] = (int)0;
        }
      }
      int _8332 = (int)0;
      int _8333 = _3197;
      for (int _3203 = _8332; _3203 < _8333; ++_3203)
      {
        {
          ++ _ptr__3200[safe_add( safe_add( _3199,_ptr__3201[_3203] ),(int)1 )];
        }
      }
      int _8334 = (int)0;
      int _8335 = mdim1;
      for (int _3204 = _8334; _3204 < _8335; ++_3204)
      {
        {
          _ptr__3200[safe_add( safe_add( _3199,_3204 ),(int)1 )] += _ptr__3200[safe_add( _3199,_3204 )];
        }
      }
      int _8336 = (int)0;
      int _8337 = _3197;
      for (int _3205 = _8336; _3205 < _8337; ++_3205)
      {
        {
          _ptr__3200[safe_add( _3198,_ptr__3200[safe_add( _3199,_ptr__3201[_3205] )] )] = _3205;
          ++ _ptr__3200[safe_add( _3199,_ptr__3201[_3205] )];
        }
      }
      int _8338 = (int)0;
      int _8339 = mdim1;
      for (int _3206 = _8338; _3206 < _8339; ++_3206)
      {
        {
          _ptr__3200[(safe_add( _3199,mdim1 ) - _3206)] = _ptr__3200[((safe_add( _3199,mdim1 ) - _3206) - (int)1)];
        }
      }
      _ptr__3200[_3199] = (int)0;
    }
  }
  _3191->popi32(_3193);
  int _3207 = _3191->popi32();
  if ((_3207 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3208 = _3191->popi32();
  int _3209 = _3191->popi32();
  int _3210 = _3191->popi32();
  int _3211 = _3191->popi32();
  bool _3212 = (_3191->popi32() != (int)0);
  int _3213 = _3191->popi32(safe_add( _3210,(int)1 ));
  int _8340;
  bool _8341 = _3212;
  if (_8341)
  {
    _8340 = _3191->popi64(_3210);
  }
  else
  {
    _8340 = (int)9999;
  }
  int _3214 = _8340;
  int _3215 = _3191->popi64(_3211);
  int _3216 = _3191->popf64(_3210);
  int _3217 = _3191->popf64(_3211);
  std::shared_ptr< monty::ndarray< int,1 > > _3218 = mosek::fusion::p_WorkStack::_get_impl(_3191)->i32;
  _checked_ptr_1<int> _ptr__3218(_3218 ? _3218->raw() : nullptr,_3218 ? _3218->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3219 = mosek::fusion::p_WorkStack::_get_impl(_3191)->i64;
  _checked_ptr_1<long long> _ptr__3219(_3219 ? _3219->raw() : nullptr,_3219 ? _3219->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3220 = mosek::fusion::p_WorkStack::_get_impl(_3191)->f64;
  _checked_ptr_1<double> _ptr__3220(_3220 ? _3220->raw() : nullptr,_3220 ? _3220->size(0) : 0);
  if (_3212)
  {
    {
      int _8342 = (int)0;
      int _8343 = safe_add( _3209,(int)1 );
      for (int _3221 = _8342; _3221 < _8343; ++_3221)
      {
        {
          _ptr__3218[safe_add( _3194,_3221 )] = (int)0;
        }
      }
      int _8344 = (int)0;
      int _8345 = _3210;
      for (int _3222 = _8344; _3222 < _8345; ++_3222)
      {
        {
          ++ _ptr__3218[safe_add( safe_add( _3194,(_ptr__3219[safe_add( _3214,_3222 )] / _3208) ),(int)1 )];
        }
      }
      int _8346 = (int)0;
      int _8347 = _3209;
      for (int _3223 = _8346; _3223 < _8347; ++_3223)
      {
        {
          _ptr__3218[safe_add( safe_add( _3194,_3223 ),(int)1 )] += _ptr__3218[safe_add( _3194,_3223 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3224 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3224(_3224 ? _3224->raw() : nullptr,_3224 ? _3224->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3225 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3225(_3225 ? _3225->raw() : nullptr,_3225 ? _3225->size(0) : 0);
      int _3226 = (int)0;
      int _3227 = (int)0;
      {
        int _8348 = (int)0;
        int _8349 = _3209;
        for (int _3228 = _8348; _3228 < _8349; ++_3228)
        {
          {
            int _3229 = _ptr__3218[safe_add( safe_add( _3199,_3228 ),(int)1 )];
            int _3230 = _ptr__3218[safe_add( _3199,_3228 )];
            int _3231 = _ptr__3218[safe_add( safe_add( _3194,_3228 ),(int)1 )];
            int _3232 = _ptr__3218[safe_add( _3194,_3228 )];
            bool _3233 = false;
            while ( ((_3232 < _3231) && (_3230 < _3229)) )
            {
              {
                int _3234 = _ptr__3218[safe_add( _3198,_3230 )];
                long long _3235 = (_ptr__3219[safe_add( _3214,_3232 )] % _3208);
                if ((_ptr__3224[_3234] < _3235))
                {
                  {
                    ++ _3230;
                  }
                }
                else if((_ptr__3224[_3234] > _3235))
                {
                  {
                    ++ _3232;
                  }
                }
                else
                {
                  {
                    _3233 = true;
                    _3226 += (_ptr__3218[safe_add( safe_add( _3213,_3232 ),(int)1 )] - _ptr__3218[safe_add( _3213,_3232 )]);
                    ++ _3232;
                    ++ _3230;
                  }
                }
              }
            }
            if (_3233)
            {
              {
                ++ _3227;
              }
            }
            {}
          }
        }
      }
      bool _3236 = (_3227 < _3209);
      int _3237 = _3190->alloci32(safe_add( _3227,(int)1 ));
      int _3238 = _3190->alloci64(_3226);
      int _3239 = _3190->alloci64(_3227);
      int _3240 = _3190->allocf64(_3226);
      int _3241 = _3190->allocf64(_3227);
      int _8350;
      bool _8351 = _3236;
      if (_8351)
      {
        _8350 = (int)1;
      }
      else
      {
        _8350 = (int)0;
      }
      _3190->pushi32(_8350);
      _3190->pushi32(_3226);
      _3190->pushi32(_3227);
      _3190->pushi32(_3209);
      _3190->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3242 = mosek::fusion::p_WorkStack::_get_impl(_3190)->i32;
      _checked_ptr_1<int> _ptr__3242(_3242 ? _3242->raw() : nullptr,_3242 ? _3242->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3243 = mosek::fusion::p_WorkStack::_get_impl(_3190)->i64;
      _checked_ptr_1<long long> _ptr__3243(_3243 ? _3243->raw() : nullptr,_3243 ? _3243->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3244 = mosek::fusion::p_WorkStack::_get_impl(_3190)->f64;
      _checked_ptr_1<double> _ptr__3244(_3244 ? _3244->raw() : nullptr,_3244 ? _3244->size(0) : 0);
      {
        int _3245 = (int)0;
        int _3246 = (int)0;
        _ptr__3242[_3237] = (int)0;
        int _8352 = (int)0;
        int _8353 = _3209;
        for (int _3247 = _8352; _3247 < _8353; ++_3247)
        {
          {
            int _3248 = _ptr__3218[safe_add( safe_add( _3199,_3247 ),(int)1 )];
            int _3249 = _ptr__3218[safe_add( _3199,_3247 )];
            int _3250 = _ptr__3218[safe_add( safe_add( _3194,_3247 ),(int)1 )];
            int _3251 = _ptr__3218[safe_add( _3194,_3247 )];
            bool _3252 = false;
            double _3253 = 0.0;
            while ( ((_3251 < _3250) && (_3249 < _3248)) )
            {
              {
                int _3254 = _ptr__3218[safe_add( _3198,_3249 )];
                long long _3255 = (_ptr__3219[safe_add( _3214,_3251 )] % _3208);
                if ((_ptr__3224[_3254] < _3255))
                {
                  {
                    ++ _3249;
                  }
                }
                else if((_ptr__3224[_3254] > _3255))
                {
                  {
                    ++ _3251;
                  }
                }
                else
                {
                  {
                    _3252 = true;
                    int _8354 = _ptr__3218[safe_add( _3213,_3251 )];
                    int _8355 = _ptr__3218[safe_add( safe_add( _3213,_3251 ),(int)1 )];
                    for (int _3256 = _8354; _3256 < _8355; ++_3256)
                    {
                      {
                        _ptr__3243[safe_add( _3238,_3246 )] = _ptr__3219[safe_add( _3215,_3256 )];
                        _ptr__3244[safe_add( _3240,_3246 )] = (_ptr__3220[safe_add( _3217,_3256 )] * _ptr__3225[_3254]);
                        ++ _3246;
                      }
                    }
                    _3253 += (_ptr__3220[safe_add( _3216,_3251 )] * _ptr__3225[_3254]);
                    ++ _3251;
                    ++ _3249;
                  }
                }
              }
            }
            if (_3252)
            {
              {
                _ptr__3242[safe_add( safe_add( _3237,_3245 ),(int)1 )] = _3246;
                _ptr__3243[safe_add( _3239,_3245 )] = _3247;
                _ptr__3244[safe_add( _3241,_3245 )] = _3253;
                ++ _3245;
              }
            }
            {}
          }
        }
      }
      if ((!_3236))
      {
        {
          _3190->popi64(_3227);
        }
      }
      {}
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3257 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi;
      _checked_ptr_1<int> _ptr__3257(_3257 ? _3257->raw() : nullptr,_3257 ? _3257->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3258 = mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval;
      _checked_ptr_1<double> _ptr__3258(_3258 ? _3258->raw() : nullptr,_3258 ? _3258->size(0) : 0);
      int _3259 = (int)0;
      int _3260 = (int)0;
      {
        int _8356 = (int)0;
        int _8357 = _3209;
        for (int _3261 = _8356; _3261 < _8357; ++_3261)
        {
          {
            bool _3262 = false;
            int _8358 = _ptr__3218[safe_add( _3199,_3261 )];
            int _8359 = _ptr__3218[safe_add( safe_add( _3199,_3261 ),(int)1 )];
            for (int _3263 = _8358; _3263 < _8359; ++_3263)
            {
              {
                int _3264 = _ptr__3218[safe_add( _3198,_3263 )];
                int _3265 = safe_add( safe_mul( _3261,_3208 ),_ptr__3257[_3264] );
                _3260 += (_ptr__3218[safe_add( safe_add( _3213,_3265 ),(int)1 )] - _ptr__3218[safe_add( _3213,_3265 )]);
                if ((_ptr__3218[safe_add( safe_add( _3213,_3265 ),(int)1 )] > _ptr__3218[safe_add( _3213,_3265 )]))
                {
                  {
                    _3262 = true;
                  }
                }
                {}
              }
            }
            if (_3262)
            {
              {
                ++ _3259;
              }
            }
            {}
          }
        }
      }
      bool _3266 = (_3259 < _3209);
      int _3267 = _3190->alloci32(safe_add( _3259,(int)1 ));
      int _3268 = _3190->alloci64(_3260);
      int _3269 = _3190->alloci64(_3259);
      int _3270 = _3190->allocf64(_3260);
      int _3271 = _3190->allocf64(_3259);
      int _8360;
      bool _8361 = _3266;
      if (_8361)
      {
        _8360 = (int)1;
      }
      else
      {
        _8360 = (int)0;
      }
      _3190->pushi32(_8360);
      _3190->pushi32(_3260);
      _3190->pushi32(_3259);
      _3190->pushi32(_3209);
      _3190->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3272 = mosek::fusion::p_WorkStack::_get_impl(_3190)->i32;
      _checked_ptr_1<int> _ptr__3272(_3272 ? _3272->raw() : nullptr,_3272 ? _3272->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3273 = mosek::fusion::p_WorkStack::_get_impl(_3190)->i64;
      _checked_ptr_1<long long> _ptr__3273(_3273 ? _3273->raw() : nullptr,_3273 ? _3273->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3274 = mosek::fusion::p_WorkStack::_get_impl(_3190)->f64;
      _checked_ptr_1<double> _ptr__3274(_3274 ? _3274->raw() : nullptr,_3274 ? _3274->size(0) : 0);
      {
        int _3275 = (int)0;
        int _3276 = (int)0;
        _ptr__3272[_3267] = (int)0;
        int _8362 = (int)0;
        int _8363 = _3209;
        for (int _3277 = _8362; _3277 < _8363; ++_3277)
        {
          {
            bool _3278 = false;
            double _3279 = 0.0;
            int _8364 = _ptr__3218[safe_add( _3199,_3277 )];
            int _8365 = _ptr__3218[safe_add( safe_add( _3199,_3277 ),(int)1 )];
            for (int _3280 = _8364; _3280 < _8365; ++_3280)
            {
              {
                int _3281 = _ptr__3218[safe_add( _3198,_3280 )];
                int _3282 = safe_add( safe_mul( _3277,_3208 ),_ptr__3257[_3281] );
                int _8366 = _ptr__3218[safe_add( _3213,_3282 )];
                int _8367 = _ptr__3218[safe_add( safe_add( _3213,_3282 ),(int)1 )];
                for (int _3283 = _8366; _3283 < _8367; ++_3283)
                {
                  {
                    _3278 = true;
                    _ptr__3273[safe_add( _3268,_3276 )] = _ptr__3219[safe_add( _3215,_3283 )];
                    _ptr__3274[safe_add( _3270,_3276 )] = (_ptr__3220[safe_add( _3217,_3283 )] * _ptr__3258[_3281]);
                    ++ _3276;
                  }
                }
                _3279 += (_ptr__3220[safe_add( _3216,_3282 )] * _ptr__3258[_3281]);
              }
            }
            if (_3278)
            {
              {
                _ptr__3274[safe_add( _3271,_3275 )] = _3279;
                _ptr__3273[safe_add( _3269,_3275 )] = _3277;
                _ptr__3272[safe_add( safe_add( _3267,_3275 ),(int)1 )] = _3276;
                ++ _3275;
              }
            }
            {}
          }
        }
      }
      if ((!_3266))
      {
        {
          _3190->popi64(_3259);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _3284,int _3285,std::shared_ptr< monty::ndarray< int,1 > > _3286,std::shared_ptr< monty::ndarray< int,1 > > _3287,std::shared_ptr< monty::ndarray< double,1 > > _3288,monty::rc_ptr< ::mosek::fusion::Expression > _3289){
  _checked_ptr_1<int> _ptr__3286(_3286 ? _3286->raw() : nullptr, _3286 ? _3286->size(0) : 0);
  _checked_ptr_1<int> _ptr__3287(_3287 ? _3287->raw() : nullptr, _3287 ? _3287->size(0) : 0);
  _checked_ptr_1<double> _ptr__3288(_3288 ? _3288->raw() : nullptr, _3288 ? _3288->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3290 = _3289->getShape();
  _checked_ptr_1<int> _ptr__3290(_3290 ? _3290->raw() : nullptr,_3290 ? _3290->size(0) : 0);
  if (((int)((_3290)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3291 = _ptr__3290[(int)0];
  int _3292 = _ptr__3290[(int)1];
  if (((_3284 < (int)0) || ((_3285 < (int)0) || ((_3291 < (int)0) || (_3292 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3284 != _3292) || (_3285 != _3291)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3286)->size(0)) != (int)((_3287)->size(0))) || ((int)((_3286)->size(0)) != (int)((_3288)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3293 = (int)((_3286)->size(0));
  int _8368 = (int)0;
  int _8369 = _3293;
  for (int _3294 = _8368; _3294 < _8369; ++_3294)
  {
    {
      if (((_ptr__3286[_3294] < (int)0) || ((_ptr__3286[_3294] >= _3284) || ((_ptr__3287[_3294] < (int)0) || (_ptr__3287[_3294] >= _3285)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8370 = (int)0;
  int _8371 = (_3293 - (int)1);
  for (int _3295 = _8370; _3295 < _8371; ++_3295)
  {
    {
      if (((_ptr__3286[_3295] > _ptr__3286[safe_add( _3295,(int)1 )]) || ((_ptr__3286[_3295] == _ptr__3286[safe_add( _3295,(int)1 )]) && (_ptr__3287[_3295] >= _ptr__3287[safe_add( _3295,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8372 = (int)0;
  int _8373 = _3293;
  for (int _3296 = _8372; _3296 < _8373; ++_3296)
  {
    {
      if (((_ptr__3286[_3296] < (int)0) || ((_ptr__3286[_3296] >= _3284) || ((_ptr__3287[_3296] < (int)0) || (_ptr__3287[_3296] >= _3285)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return std::string ("ExprMulDiagRight()");
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3297,    int _3298,    std::shared_ptr< monty::ndarray< int,1 > > _3299,    std::shared_ptr< monty::ndarray< int,1 > > _3300,    std::shared_ptr< monty::ndarray< double,1 > > _3301,    monty::rc_ptr< ::mosek::fusion::Expression > _3302,    int _3303){ return new mosek::fusion::ExprMulDiagLeft(_3297,_3298,_3299,_3300,_3301,_3302,_3303); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3297,    int _3298,    std::shared_ptr< monty::ndarray< int,1 > > _3299,    std::shared_ptr< monty::ndarray< int,1 > > _3300,    std::shared_ptr< monty::ndarray< double,1 > > _3301,    monty::rc_ptr< ::mosek::fusion::Expression > _3302,    int _3303) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3297,_3298,_3299,_3300,_3301,_3302,_3303); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3297,    int _3298,    std::shared_ptr< monty::ndarray< int,1 > > _3299,    std::shared_ptr< monty::ndarray< int,1 > > _3300,    std::shared_ptr< monty::ndarray< double,1 > > _3301,    monty::rc_ptr< ::mosek::fusion::Expression > _3302,    int _3303){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3299(_3299 ? _3299->raw() : nullptr, _3299 ? _3299->size(0) : 0);
    _checked_ptr_1<int> _ptr__3300(_3300 ? _3300->raw() : nullptr, _3300 ? _3300->size(0) : 0);
    _checked_ptr_1<double> _ptr__3301(_3301 ? _3301->raw() : nullptr, _3301 ? _3301->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3297)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _3297;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _3298;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _3299;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _3300;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _3301;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _3302;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _3304,    int _3305,    std::shared_ptr< monty::ndarray< int,1 > > _3306,    std::shared_ptr< monty::ndarray< int,1 > > _3307,    std::shared_ptr< monty::ndarray< double,1 > > _3308,    monty::rc_ptr< ::mosek::fusion::Expression > _3309){ return new mosek::fusion::ExprMulDiagLeft(_3304,_3305,_3306,_3307,_3308,_3309); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _3304,    int _3305,    std::shared_ptr< monty::ndarray< int,1 > > _3306,    std::shared_ptr< monty::ndarray< int,1 > > _3307,    std::shared_ptr< monty::ndarray< double,1 > > _3308,    monty::rc_ptr< ::mosek::fusion::Expression > _3309) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_3304,_3305,_3306,_3307,_3308,_3309); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _3304,    int _3305,    std::shared_ptr< monty::ndarray< int,1 > > _3306,    std::shared_ptr< monty::ndarray< int,1 > > _3307,    std::shared_ptr< monty::ndarray< double,1 > > _3308,    monty::rc_ptr< ::mosek::fusion::Expression > _3309){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3306(_3306 ? _3306->raw() : nullptr, _3306 ? _3306->size(0) : 0);
    _checked_ptr_1<int> _ptr__3307(_3307 ? _3307->raw() : nullptr, _3307 ? _3307->size(0) : 0);
    _checked_ptr_1<double> _ptr__3308(_3308 ? _3308->raw() : nullptr, _3308 ? _3308->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_3304,_3305,_3306,_3307,_3308,_3309,::mosek::fusion::p_ExprMulDiagLeft::validate(_3304,_3305,_3306,_3307,_3308,_3309));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3310,monty::rc_ptr< ::mosek::fusion::WorkStack > _3311,monty::rc_ptr< ::mosek::fusion::WorkStack > _3312) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_3310,_3311,_3312); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3310,monty::rc_ptr< ::mosek::fusion::WorkStack > _3311,monty::rc_ptr< ::mosek::fusion::WorkStack > _3312){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_3311,_3310,_3312);
  if ((_3311->peeki32() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3313 = (int)((msubi)->size(0));
  int _3314 = (int)9999;
  int _3315 = (int)9999;
  int _3316 = (int)0;
  int _3317 = _3311->peeki32((int)5);
  if ((_3317 != (int)0))
  {
    {
      int _3318 = _3311->peeki32((int)1);
      int _3319 = _3311->peeki32((int)3);
      _3314 = _3311->alloci32(safe_add( _3318,(int)1 ));
      _3315 = _3311->alloci32(_3319);
      _3316 += safe_add( safe_add( _3319,_3318 ),(int)1 );
    }
  }
  {}
  int _3320 = _3311->alloci32(safe_add( mdim0,(int)1 ));
  _3316 += safe_add( mdim0,(int)1 );
  _3311->popi32(_3316);
  std::shared_ptr< monty::ndarray< int,1 > > _3321 = mosek::fusion::p_WorkStack::_get_impl(_3311)->i32;
  _checked_ptr_1<int> _ptr__3321(_3321 ? _3321->raw() : nullptr,_3321 ? _3321->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3322 = mosek::fusion::p_WorkStack::_get_impl(_3311)->i64;
  _checked_ptr_1<long long> _ptr__3322(_3322 ? _3322->raw() : nullptr,_3322 ? _3322->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3323 = mosek::fusion::p_WorkStack::_get_impl(_3311)->f64;
  _checked_ptr_1<double> _ptr__3323(_3323 ? _3323->raw() : nullptr,_3323 ? _3323->size(0) : 0);
  int _8374 = (int)0;
  int _8375 = safe_add( mdim0,(int)1 );
  for (int _3324 = _8374; _3324 < _8375; ++_3324)
  {
    {
      _ptr__3321[safe_add( _3320,_3324 )] = (int)0;
    }
  }
  int _8376 = (int)0;
  int _8377 = _3313;
  for (int _3325 = _8376; _3325 < _8377; ++_3325)
  {
    {
      ++ _ptr__3321[safe_add( safe_add( _3320,((*msubi)(_3325)) ),(int)1 )];
    }
  }
  int _8378 = (int)0;
  int _8379 = mdim0;
  for (int _3326 = _8378; _3326 < _8379; ++_3326)
  {
    {
      _ptr__3321[safe_add( safe_add( _3320,_3326 ),(int)1 )] += _ptr__3321[safe_add( _3320,_3326 )];
    }
  }
  int _3327 = _3311->popi32();
  int _3328 = _3311->popi32();
  int _3329 = _3311->popi32();
  int _3330 = _3311->popi32();
  int _3331 = _3311->popi32();
  bool _3332 = (_3311->popi32() != (int)0);
  int _3333 = _3311->popi32(safe_add( _3330,(int)1 ));
  int _8380;
  bool _8381 = _3332;
  if (_8381)
  {
    _8380 = _3311->popi64(_3330);
  }
  else
  {
    _8380 = (int)9999;
  }
  int _3334 = _8380;
  int _3335 = _3311->popi64(_3331);
  int _3336 = _3311->popf64(_3330);
  int _3337 = _3311->popf64(_3331);
  if ((!_3332))
  {
    {
      int _3338 = (int)((msubi)->size(0));
      int _3339 = (int)0;
      int _8382 = (int)0;
      int _8383 = mdim0;
      for (int _3340 = _8382; _3340 < _8383; ++_3340)
      {
        {
          if ((_ptr__3321[safe_add( _3320,_3340 )] < _ptr__3321[safe_add( safe_add( _3320,_3340 ),(int)1 )]))
          {
            {
              ++ _3339;
            }
          }
          {}
        }
      }
      bool _3341 = (_3339 < mdim0);
      int _3342 = _3310->alloci32(safe_add( _3339,(int)1 ));
      int _3343 = _3310->alloci64(_3338);
      int _3344 = _3310->alloci64(_3339);
      int _3345 = _3310->allocf64(_3338);
      int _3346 = _3310->allocf64(_3339);
      int _8384;
      bool _8385 = _3341;
      if (_8385)
      {
        _8384 = (int)1;
      }
      else
      {
        _8384 = (int)0;
      }
      _3310->pushi32(_8384);
      _3310->pushi32(_3338);
      _3310->pushi32(_3339);
      _3310->pushi32(mdim0);
      _3310->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3347 = mosek::fusion::p_WorkStack::_get_impl(_3310)->i32;
      _checked_ptr_1<int> _ptr__3347(_3347 ? _3347->raw() : nullptr,_3347 ? _3347->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3348 = mosek::fusion::p_WorkStack::_get_impl(_3310)->i64;
      _checked_ptr_1<long long> _ptr__3348(_3348 ? _3348->raw() : nullptr,_3348 ? _3348->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3349 = mosek::fusion::p_WorkStack::_get_impl(_3310)->f64;
      _checked_ptr_1<double> _ptr__3349(_3349 ? _3349->raw() : nullptr,_3349 ? _3349->size(0) : 0);
      {
        _ptr__3347[_3342] = (int)0;
        int _3350 = (int)0;
        int _3351 = (int)0;
        int _8386 = (int)0;
        int _8387 = mdim0;
        for (int _3352 = _8386; _3352 < _8387; ++_3352)
        {
          {
            if ((_ptr__3321[safe_add( _3320,_3352 )] < _ptr__3321[safe_add( safe_add( _3320,_3352 ),(int)1 )]))
            {
              {
                int _3353 = (int)0;
                int _8388 = _ptr__3321[safe_add( _3320,_3352 )];
                int _8389 = _ptr__3321[safe_add( safe_add( _3320,_3352 ),(int)1 )];
                for (int _3354 = _8388; _3354 < _8389; ++_3354)
                {
                  {
                    int _3355 = ((*msubj)(_3354));
                    int _3356 = safe_add( safe_mul( _3355,_3328 ),_3352 );
                    int _8390 = _ptr__3321[safe_add( _3333,_3356 )];
                    int _8391 = _ptr__3321[safe_add( safe_add( _3333,_3356 ),(int)1 )];
                    for (int _3357 = _8390; _3357 < _8391; ++_3357)
                    {
                      {
                        _ptr__3348[safe_add( _3343,_3351 )] = _ptr__3322[safe_add( _3335,_3357 )];
                        _ptr__3349[safe_add( _3345,_3351 )] = (_ptr__3323[safe_add( _3337,_3357 )] * ((*mval)(_3354)));
                        ++ _3351;
                      }
                    }
                  }
                }
                _ptr__3349[safe_add( _3346,_3350 )] = _3353;
                _ptr__3348[safe_add( _3344,_3350 )] = _3352;
                _ptr__3347[safe_add( safe_add( _3342,_3350 ),(int)1 )] = _3351;
                ++ _3350;
              }
            }
            {}
          }
        }
      }
      if ((!_3341))
      {
        {
          _3310->popi64(_3339);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _8392 = (int)0;
      int _8393 = safe_add( _3328,(int)1 );
      for (int _3358 = _8392; _3358 < _8393; ++_3358)
      {
        {
          _ptr__3321[safe_add( _3314,_3358 )] = (int)0;
        }
      }
      int _8394 = (int)0;
      int _8395 = _3330;
      for (int _3359 = _8394; _3359 < _8395; ++_3359)
      {
        {
          ++ _ptr__3321[safe_add( safe_add( _3314,(_ptr__3322[safe_add( _3334,_3359 )] % _3328) ),(int)1 )];
        }
      }
      int _8396 = (int)0;
      int _8397 = _3328;
      for (int _3360 = _8396; _3360 < _8397; ++_3360)
      {
        {
          _ptr__3321[safe_add( safe_add( _3314,_3360 ),(int)1 )] += _ptr__3321[safe_add( _3314,_3360 )];
        }
      }
      int _8398 = (int)0;
      int _8399 = _3330;
      for (int _3361 = _8398; _3361 < _8399; ++_3361)
      {
        {
          long long _3362 = (_ptr__3322[safe_add( _3334,_3361 )] % _3328);
          _ptr__3321[safe_add( _3315,_ptr__3321[safe_add( _3314,_3362 )] )] = _3361;
          ++ _ptr__3321[safe_add( _3314,_3362 )];
        }
      }
      int _8400 = (int)0;
      int _8401 = _3328;
      for (int _3363 = _8400; _3363 < _8401; ++_3363)
      {
        {
          _ptr__3321[(safe_add( _3314,_3328 ) - _3363)] = _ptr__3321[((safe_add( _3314,_3328 ) - _3363) - (int)1)];
        }
      }
      _ptr__3321[_3314] = (int)0;
      int _3364 = (int)0;
      int _3365 = (int)0;
      {
        int _8402 = (int)0;
        int _8403 = mdim0;
        for (int _3366 = _8402; _3366 < _8403; ++_3366)
        {
          {
            int _3367 = _ptr__3321[safe_add( safe_add( _3314,_3366 ),(int)1 )];
            int _3368 = _ptr__3321[safe_add( _3314,_3366 )];
            int _3369 = _ptr__3321[safe_add( safe_add( _3320,_3366 ),(int)1 )];
            int _3370 = _ptr__3321[safe_add( _3320,_3366 )];
            bool _3371 = false;
            while ( ((_3370 < _3369) && (_3368 < _3367)) )
            {
              {
                int _3372 = _ptr__3321[safe_add( _3315,_3368 )];
                long long _3373 = (_ptr__3322[safe_add( _3334,_3372 )] / _3328);
                if ((((*msubj)(_3370)) < _3373))
                {
                  {
                    ++ _3370;
                  }
                }
                else if((((*msubj)(_3370)) > _3373))
                {
                  {
                    ++ _3368;
                  }
                }
                else
                {
                  {
                    _3371 = true;
                    _3365 += (_ptr__3321[safe_add( safe_add( _3333,_3372 ),(int)1 )] - _ptr__3321[safe_add( _3333,_3372 )]);
                    ++ _3370;
                    ++ _3368;
                  }
                }
              }
            }
            if (_3371)
            {
              {
                ++ _3364;
              }
            }
            {}
          }
        }
      }
      int _3374 = _3364;
      int _3375 = _3365;
      bool _3376 = (_3374 < mdim0);
      int _3377 = _3310->alloci32(safe_add( _3374,(int)1 ));
      int _3378 = _3310->alloci64(_3375);
      int _3379 = _3310->alloci64(_3374);
      int _3380 = _3310->allocf64(_3375);
      int _3381 = _3310->allocf64(_3374);
      int _8404;
      bool _8405 = _3376;
      if (_8405)
      {
        _8404 = (int)1;
      }
      else
      {
        _8404 = (int)0;
      }
      _3310->pushi32(_8404);
      _3310->pushi32(_3375);
      _3310->pushi32(_3374);
      _3310->pushi32(mdim0);
      _3310->pushi32((int)1);
      std::shared_ptr< monty::ndarray< int,1 > > _3382 = mosek::fusion::p_WorkStack::_get_impl(_3310)->i32;
      _checked_ptr_1<int> _ptr__3382(_3382 ? _3382->raw() : nullptr,_3382 ? _3382->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3383 = mosek::fusion::p_WorkStack::_get_impl(_3310)->i64;
      _checked_ptr_1<long long> _ptr__3383(_3383 ? _3383->raw() : nullptr,_3383 ? _3383->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3384 = mosek::fusion::p_WorkStack::_get_impl(_3310)->f64;
      _checked_ptr_1<double> _ptr__3384(_3384 ? _3384->raw() : nullptr,_3384 ? _3384->size(0) : 0);
      {
        _ptr__3382[_3377] = (int)0;
        int _3385 = (int)0;
        int _3386 = (int)0;
        int _8406 = (int)0;
        int _8407 = mdim0;
        for (int _3387 = _8406; _3387 < _8407; ++_3387)
        {
          {
            int _3388 = _ptr__3321[safe_add( safe_add( _3314,_3387 ),(int)1 )];
            int _3389 = _ptr__3321[safe_add( _3314,_3387 )];
            int _3390 = _ptr__3321[safe_add( safe_add( _3320,_3387 ),(int)1 )];
            int _3391 = _ptr__3321[safe_add( _3320,_3387 )];
            bool _3392 = false;
            double _3393 = 0.0;
            while ( ((_3391 < _3390) && (_3389 < _3388)) )
            {
              {
                int _3394 = _ptr__3321[safe_add( _3315,_3389 )];
                long long _3395 = (_ptr__3322[safe_add( _3334,_3394 )] / _3328);
                if ((((*msubj)(_3391)) < _3395))
                {
                  {
                    ++ _3391;
                  }
                }
                else if((((*msubj)(_3391)) > _3395))
                {
                  {
                    ++ _3389;
                  }
                }
                else
                {
                  {
                    _3392 = true;
                    int _8408 = _ptr__3321[safe_add( _3333,_3394 )];
                    int _8409 = _ptr__3321[safe_add( safe_add( _3333,_3394 ),(int)1 )];
                    for (int _3396 = _8408; _3396 < _8409; ++_3396)
                    {
                      {
                        _ptr__3383[safe_add( _3378,_3386 )] = _ptr__3322[safe_add( _3335,_3396 )];
                        _ptr__3384[safe_add( _3380,_3386 )] = (_ptr__3323[safe_add( _3337,_3396 )] * ((*mval)(_3391)));
                        ++ _3386;
                      }
                    }
                    _3393 += _ptr__3323[safe_add( _3336,_3394 )];
                    ++ _3391;
                    ++ _3389;
                  }
                }
              }
            }
            if (_3392)
            {
              {
                _ptr__3383[safe_add( _3379,_3385 )] = _3387;
                _ptr__3384[safe_add( _3381,_3385 )] = (_3393 * ((*mval)(_3391)));
                _ptr__3382[safe_add( safe_add( _3377,_3385 ),(int)1 )] = _3386;
                ++ _3385;
              }
            }
            {}
          }
        }
      }
      if ((!_3376))
      {
        {
          _3310->popi64(_3374);
        }
      }
      {}
    }
  }
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _3397,int _3398,std::shared_ptr< monty::ndarray< int,1 > > _3399,std::shared_ptr< monty::ndarray< int,1 > > _3400,std::shared_ptr< monty::ndarray< double,1 > > _3401,monty::rc_ptr< ::mosek::fusion::Expression > _3402){
  _checked_ptr_1<int> _ptr__3399(_3399 ? _3399->raw() : nullptr, _3399 ? _3399->size(0) : 0);
  _checked_ptr_1<int> _ptr__3400(_3400 ? _3400->raw() : nullptr, _3400 ? _3400->size(0) : 0);
  _checked_ptr_1<double> _ptr__3401(_3401 ? _3401->raw() : nullptr, _3401 ? _3401->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3403 = _3402->getShape();
  _checked_ptr_1<int> _ptr__3403(_3403 ? _3403->raw() : nullptr,_3403 ? _3403->size(0) : 0);
  if (((int)((_3403)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3404 = _ptr__3403[(int)0];
  int _3405 = _ptr__3403[(int)1];
  if (((_3397 < (int)0) || (_3398 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3398 != _3404) || (_3397 != _3405)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3399)->size(0)) != (int)((_3400)->size(0))) || ((int)((_3399)->size(0)) != (int)((_3401)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3406 = (int)((_3399)->size(0));
  int _8410 = (int)0;
  int _8411 = _3406;
  for (int _3407 = _8410; _3407 < _8411; ++_3407)
  {
    {
      if (((_ptr__3399[_3407] < (int)0) || ((_ptr__3399[_3407] >= _3397) || ((_ptr__3400[_3407] < (int)0) || (_ptr__3400[_3407] >= _3398)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8412 = (int)0;
  int _8413 = (_3406 - (int)1);
  for (int _3408 = _8412; _3408 < _8413; ++_3408)
  {
    {
      if (((_ptr__3399[_3408] > _ptr__3399[safe_add( _3408,(int)1 )]) || ((_ptr__3399[_3408] == _ptr__3399[safe_add( _3408,(int)1 )]) && (_ptr__3400[_3408] >= _ptr__3400[safe_add( _3408,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8414 = (int)0;
  int _8415 = _3406;
  for (int _3409 = _8414; _3409 < _8415; ++_3409)
  {
    {
      if (((_ptr__3399[_3409] < (int)0) || ((_ptr__3399[_3409] >= _3397) || ((_ptr__3400[_3409] < (int)0) || (_ptr__3400[_3409] >= _3398)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return std::string ("ExprMulDiagLeft()");
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3410,    std::shared_ptr< monty::ndarray< long long,1 > > _3411,    monty::rc_ptr< ::mosek::fusion::Expression > _3412){ return new mosek::fusion::ExprMulElement(_3410,_3411,_3412); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3410,    std::shared_ptr< monty::ndarray< long long,1 > > _3411,    monty::rc_ptr< ::mosek::fusion::Expression > _3412) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3410,_3411,_3412); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3410,    std::shared_ptr< monty::ndarray< long long,1 > > _3411,    monty::rc_ptr< ::mosek::fusion::Expression > _3412){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3410(_3410 ? _3410->raw() : nullptr, _3410 ? _3410->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3411(_3411 ? _3411->raw() : nullptr, _3411 ? _3411->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_3410,_3411,_3412,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3413 = _3412->getShape();
    _checked_ptr_1<int> _ptr__3413(_3413 ? _3413->raw() : nullptr,_3413 ? _3413->size(0) : 0);
    if (((int)((_3410)->size(0)) != (int)((_3411)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _3414 = ::mosek::fusion::p_Set::size(_3413);
    int _8416 = (int)0;
    int _8417 = (int)((_3411)->size(0));
    for (int _3415 = _8416; _3415 < _8417; ++_3415)
    {
      {
        if (((_ptr__3411[_3415] < (int)0) || (_ptr__3411[_3415] >= _3414)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
          }
        }
        {}
      }
    }
    int _8418 = (int)0;
    int _8419 = ((int)((_3411)->size(0)) - (int)1);
    for (int _3416 = _8418; _3416 < _8419; ++_3416)
    {
      {
        if ((_ptr__3411[_3416] >= _ptr__3411[safe_add( _3416,(int)1 )]))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3417,    std::shared_ptr< monty::ndarray< long long,1 > > _3418,    monty::rc_ptr< ::mosek::fusion::Expression > _3419,    int _3420){ return new mosek::fusion::ExprMulElement(_3417,_3418,_3419,_3420); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _3417,    std::shared_ptr< monty::ndarray< long long,1 > > _3418,    monty::rc_ptr< ::mosek::fusion::Expression > _3419,    int _3420) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_3417,_3418,_3419,_3420); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _3417,    std::shared_ptr< monty::ndarray< long long,1 > > _3418,    monty::rc_ptr< ::mosek::fusion::Expression > _3419,    int _3420){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__3417(_3417 ? _3417->raw() : nullptr, _3417 ? _3417->size(0) : 0);
    _checked_ptr_1<long long> _ptr__3418(_3418 ? _3418->raw() : nullptr, _3418 ? _3418->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_3419->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _3419;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _3417;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _3418;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3421,monty::rc_ptr< ::mosek::fusion::WorkStack > _3422,monty::rc_ptr< ::mosek::fusion::WorkStack > _3423) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_3421,_3422,_3423); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3421,monty::rc_ptr< ::mosek::fusion::WorkStack > _3422,monty::rc_ptr< ::mosek::fusion::WorkStack > _3423){
  expr->eval(_3422,_3421,_3423);
  int _3424 = _3422->popi32();
  int _3425 = _3422->popi32(_3424);
  int _3426 = _3422->popi32();
  int _3427 = _3422->popi32();
  bool _3428 = (_3422->popi32() != (int)0);
  int _3429 = _3422->popi32(safe_add( _3426,(int)1 ));
  int _8420;
  bool _8421 = _3428;
  if (_8421)
  {
    _8420 = _3422->popi64(_3426);
  }
  else
  {
    _8420 = (-(int)1);
  }
  int _3430 = _8420;
  int _3431 = _3422->popi64(_3427);
  int _3432 = _3422->popf64(_3426);
  int _3433 = _3422->popf64(_3427);
  std::shared_ptr< monty::ndarray< int,1 > > _3434 = mosek::fusion::p_WorkStack::_get_impl(_3422)->i32;
  _checked_ptr_1<int> _ptr__3434(_3434 ? _3434->raw() : nullptr,_3434 ? _3434->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3435 = mosek::fusion::p_WorkStack::_get_impl(_3422)->i64;
  _checked_ptr_1<long long> _ptr__3435(_3435 ? _3435->raw() : nullptr,_3435 ? _3435->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3436 = mosek::fusion::p_WorkStack::_get_impl(_3422)->f64;
  _checked_ptr_1<double> _ptr__3436(_3436 ? _3436->raw() : nullptr,_3436 ? _3436->size(0) : 0);
  int _3437 = (int)0;
  int _3438 = (int)0;
  if ((!_3428))
  {
    {
      _3438 = (int)((msp)->size(0));
      int _8422 = (int)0;
      int _8423 = (int)((msp)->size(0));
      for (int _3439 = _8422; _3439 < _8423; ++_3439)
      {
        {
          _3437 += (_ptr__3434[safe_add( safe_add( _3429,((*msp)(_3439)) ),(int)1 )] - _ptr__3434[safe_add( _3429,((*msp)(_3439)) )]);
        }
      }
    }
  }
  else
  {
    {
      int _3440 = (int)((msp)->size(0));
      int _3441 = (int)0;
      int _3442 = _3426;
      int _3443 = (int)0;
      while ( ((_3441 < _3440) && (_3443 < _3442)) )
      {
        {
          if ((((*msp)(_3441)) < _ptr__3435[safe_add( _3430,_3443 )]))
          {
            {
              ++ _3441;
            }
          }
          else if((((*msp)(_3441)) > _ptr__3435[safe_add( _3430,_3443 )]))
          {
            {
              ++ _3443;
            }
          }
          else
          {
            {
              _3437 += (_ptr__3434[safe_add( safe_add( _3429,_3443 ),(int)1 )] - _ptr__3434[safe_add( _3429,_3443 )]);
              ++ _3441;
              ++ _3443;
              ++ _3438;
            }
          }
        }
      }
    }
  }
  int _3444 = _3421->alloci32(safe_add( _3438,(int)1 ));
  int _3445 = _3421->alloci64(_3437);
  int _3446 = _3421->alloci64(_3438);
  int _3447 = _3421->allocf64(_3437);
  int _3448 = _3421->allocf64(_3438);
  int _3449 = (int)1;
  int _8424 = (int)0;
  int _8425 = _3424;
  for (int _3450 = _8424; _3450 < _8425; ++_3450)
  {
    {
      _3449 *= _ptr__3434[safe_add( _3425,_3450 )];
    }
  }
  bool _3451 = (_3438 < _3449);
  int _8426;
  bool _8427 = _3451;
  if (_8427)
  {
    _8426 = (int)1;
  }
  else
  {
    _8426 = (int)0;
  }
  _3421->pushi32(_8426);
  _3421->pushi32(_3437);
  _3421->pushi32(_3438);
  int _3452 = _3421->alloci32(_3424);
  _3421->pushi32(_3424);
  std::shared_ptr< monty::ndarray< int,1 > > _3453 = mosek::fusion::p_WorkStack::_get_impl(_3421)->i32;
  _checked_ptr_1<int> _ptr__3453(_3453 ? _3453->raw() : nullptr,_3453 ? _3453->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3454 = mosek::fusion::p_WorkStack::_get_impl(_3421)->i64;
  _checked_ptr_1<long long> _ptr__3454(_3454 ? _3454->raw() : nullptr,_3454 ? _3454->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3455 = mosek::fusion::p_WorkStack::_get_impl(_3421)->f64;
  _checked_ptr_1<double> _ptr__3455(_3455 ? _3455->raw() : nullptr,_3455 ? _3455->size(0) : 0);
  {
    int _3456 = (int)0;
    int _3457 = (int)0;
    _ptr__3453[_3444] = (int)0;
    int _8428 = (int)0;
    int _8429 = _3424;
    for (int _3458 = _8428; _3458 < _8429; ++_3458)
    {
      {
        _ptr__3453[safe_add( _3452,_3458 )] = _ptr__3434[safe_add( _3425,_3458 )];
      }
    }
    if ((!_3428))
    {
      {
        int _8430 = (int)0;
        int _8431 = (int)((msp)->size(0));
        for (int _3459 = _8430; _3459 < _8431; ++_3459)
        {
          {
            int _3460 = _ptr__3434[safe_add( _3429,((*msp)(_3459)) )];
            int _3461 = _ptr__3434[safe_add( safe_add( _3429,((*msp)(_3459)) ),(int)1 )];
            int _8432 = _3460;
            int _8433 = _3461;
            for (int _3462 = _8432; _3462 < _8433; ++_3462)
            {
              {
                _ptr__3454[safe_add( _3445,_3457 )] = _ptr__3435[safe_add( _3431,_3462 )];
                _ptr__3455[safe_add( _3447,_3457 )] = (_ptr__3436[safe_add( _3433,_3462 )] * ((*mcof)(_3459)));
                ++ _3457;
              }
            }
            _ptr__3453[safe_add( safe_add( _3444,_3459 ),(int)1 )] = _3457;
            _ptr__3455[safe_add( _3448,_3459 )] = (_ptr__3436[safe_add( _3432,((*msp)(_3459)) )] * ((*mcof)(_3459)));
            _ptr__3454[safe_add( _3446,_3459 )] = ((*msp)(_3459));
          }
        }
      }
    }
    else
    {
      {
        int _3463 = (int)((msp)->size(0));
        int _3464 = (int)0;
        int _3465 = _3426;
        int _3466 = (int)0;
        while ( ((_3464 < _3463) && (_3466 < _3465)) )
        {
          {
            if ((((*msp)(_3464)) < _ptr__3435[safe_add( _3430,_3466 )]))
            {
              {
                ++ _3464;
              }
            }
            else if((((*msp)(_3464)) > _ptr__3435[safe_add( _3430,_3466 )]))
            {
              {
                ++ _3466;
              }
            }
            else
            {
              {
                int _3467 = _ptr__3434[safe_add( _3429,_3466 )];
                int _3468 = _ptr__3434[safe_add( safe_add( _3429,_3466 ),(int)1 )];
                int _8434 = _3467;
                int _8435 = _3468;
                for (int _3469 = _8434; _3469 < _8435; ++_3469)
                {
                  {
                    _ptr__3454[safe_add( _3445,_3457 )] = _ptr__3435[safe_add( _3431,_3469 )];
                    _ptr__3455[safe_add( _3445,_3457 )] = (_ptr__3436[safe_add( _3431,_3469 )] * ((*mcof)(_3464)));
                    ++ _3457;
                  }
                }
                _ptr__3453[safe_add( safe_add( _3444,_3456 ),(int)1 )] = _3457;
                _ptr__3455[safe_add( _3448,_3456 )] = (_ptr__3436[safe_add( _3432,_3466 )] * ((*mcof)(_3464)));
                _ptr__3454[safe_add( _3446,_3456 )] = ((*msp)(_3464));
                ++ _3456;
                ++ _3464;
                ++ _3466;
              }
            }
          }
        }
      }
    }
  }
  if ((!_3451))
  {
    {
      _3421->popi64(_3438);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return std::string ("ExprMulElement()");
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _3470,    monty::rc_ptr< ::mosek::fusion::Expression > _3471){ return new mosek::fusion::ExprMulScalarConst(_3470,_3471); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _3470,    monty::rc_ptr< ::mosek::fusion::Expression > _3471) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_3470,_3471); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _3470,    monty::rc_ptr< ::mosek::fusion::Expression > _3471){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3471->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _3470;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _3471;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3472,monty::rc_ptr< ::mosek::fusion::WorkStack > _3473,monty::rc_ptr< ::mosek::fusion::WorkStack > _3474) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_3472,_3473,_3474); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3472,monty::rc_ptr< ::mosek::fusion::WorkStack > _3473,monty::rc_ptr< ::mosek::fusion::WorkStack > _3474){
  expr->eval(_3472,_3473,_3474);
  int _3475 = _3472->peeki32((int)0);
  int _3476 = _3472->peeki32(safe_add( _3475,(int)1 ));
  int _3477 = _3472->peeki32(safe_add( _3475,(int)2 ));
  int _3478 = (mosek::fusion::p_WorkStack::_get_impl(_3472)->pf64 - _3476);
  int _3479 = (_3478 - _3477);
  std::shared_ptr< monty::ndarray< double,1 > > _3480 = mosek::fusion::p_WorkStack::_get_impl(_3472)->f64;
  _checked_ptr_1<double> _ptr__3480(_3480 ? _3480->raw() : nullptr,_3480 ? _3480->size(0) : 0);
  int _8436 = (int)0;
  int _8437 = safe_add( _3477,_3476 );
  for (int _3481 = _8436; _3481 < _8437; ++_3481)
  {
    {
      _ptr__3480[safe_add( _3479,_3481 )] *= c;
    }
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3482,    int _3483,    std::shared_ptr< monty::ndarray< int,1 > > _3484,    std::shared_ptr< monty::ndarray< int,1 > > _3485,    std::shared_ptr< monty::ndarray< double,1 > > _3486,    monty::rc_ptr< ::mosek::fusion::Expression > _3487,    int _3488){ return new mosek::fusion::ExprScalarMul(_3482,_3483,_3484,_3485,_3486,_3487,_3488); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3482,    int _3483,    std::shared_ptr< monty::ndarray< int,1 > > _3484,    std::shared_ptr< monty::ndarray< int,1 > > _3485,    std::shared_ptr< monty::ndarray< double,1 > > _3486,    monty::rc_ptr< ::mosek::fusion::Expression > _3487,    int _3488) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3482,_3483,_3484,_3485,_3486,_3487,_3488); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3482,    int _3483,    std::shared_ptr< monty::ndarray< int,1 > > _3484,    std::shared_ptr< monty::ndarray< int,1 > > _3485,    std::shared_ptr< monty::ndarray< double,1 > > _3486,    monty::rc_ptr< ::mosek::fusion::Expression > _3487,    int _3488){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3484(_3484 ? _3484->raw() : nullptr, _3484 ? _3484->size(0) : 0);
    _checked_ptr_1<int> _ptr__3485(_3485 ? _3485->raw() : nullptr, _3485 ? _3485->size(0) : 0);
    _checked_ptr_1<double> _ptr__3486(_3486 ? _3486->raw() : nullptr, _3486 ? _3486->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3482),(int)(_3483)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _3482;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _3483;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _3484;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _3485;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _3486;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _3487;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _3489,    int _3490,    std::shared_ptr< monty::ndarray< int,1 > > _3491,    std::shared_ptr< monty::ndarray< int,1 > > _3492,    std::shared_ptr< monty::ndarray< double,1 > > _3493,    monty::rc_ptr< ::mosek::fusion::Expression > _3494){ return new mosek::fusion::ExprScalarMul(_3489,_3490,_3491,_3492,_3493,_3494); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _3489,    int _3490,    std::shared_ptr< monty::ndarray< int,1 > > _3491,    std::shared_ptr< monty::ndarray< int,1 > > _3492,    std::shared_ptr< monty::ndarray< double,1 > > _3493,    monty::rc_ptr< ::mosek::fusion::Expression > _3494) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_3489,_3490,_3491,_3492,_3493,_3494); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _3489,    int _3490,    std::shared_ptr< monty::ndarray< int,1 > > _3491,    std::shared_ptr< monty::ndarray< int,1 > > _3492,    std::shared_ptr< monty::ndarray< double,1 > > _3493,    monty::rc_ptr< ::mosek::fusion::Expression > _3494){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3491(_3491 ? _3491->raw() : nullptr, _3491 ? _3491->size(0) : 0);
    _checked_ptr_1<int> _ptr__3492(_3492 ? _3492->raw() : nullptr, _3492 ? _3492->size(0) : 0);
    _checked_ptr_1<double> _ptr__3493(_3493 ? _3493->raw() : nullptr, _3493 ? _3493->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_3489,_3490,_3491,_3492,_3493,_3494,::mosek::fusion::p_ExprScalarMul::validate(_3489,_3490,_3491,_3492,_3493,_3494));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3495,monty::rc_ptr< ::mosek::fusion::WorkStack > _3496,monty::rc_ptr< ::mosek::fusion::WorkStack > _3497) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_3495,_3496,_3497); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3495,monty::rc_ptr< ::mosek::fusion::WorkStack > _3496,monty::rc_ptr< ::mosek::fusion::WorkStack > _3497){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_3496,_3495,_3497);
  _3496->pop_expr();
  int _3498 = mosek::fusion::p_WorkStack::_get_impl(_3496)->nd;
  int _3499 = mosek::fusion::p_WorkStack::_get_impl(_3496)->nelem;
  int _3500 = mosek::fusion::p_WorkStack::_get_impl(_3496)->nnz;
  bool _3501 = mosek::fusion::p_WorkStack::_get_impl(_3496)->hassp;
  int _3502 = mosek::fusion::p_WorkStack::_get_impl(_3496)->ptr_base;
  int _3503 = mosek::fusion::p_WorkStack::_get_impl(_3496)->sp_base;
  int _3504 = mosek::fusion::p_WorkStack::_get_impl(_3496)->nidxs_base;
  int _3505 = mosek::fusion::p_WorkStack::_get_impl(_3496)->bfix_base;
  int _3506 = mosek::fusion::p_WorkStack::_get_impl(_3496)->cof_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3507 = mosek::fusion::p_WorkStack::_get_impl(_3496)->i64;
  _checked_ptr_1<long long> _ptr__3507(_3507 ? _3507->raw() : nullptr,_3507 ? _3507->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3508 = mosek::fusion::p_WorkStack::_get_impl(_3496)->f64;
  _checked_ptr_1<double> _ptr__3508(_3508 ? _3508->raw() : nullptr,_3508 ? _3508->size(0) : 0);
  int _3509 = (int)((mval)->size(0));
  if ((_3498 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_3499 == (int)0))
  {
    {
      _3495->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_3495)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3495)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_3495)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_3495)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      _3495->alloc_expr((int)2,_3509,safe_mul( _3509,_3500 ),true);
      int _3510 = mosek::fusion::p_WorkStack::_get_impl(_3495)->ptr_base;
      int _3511 = mosek::fusion::p_WorkStack::_get_impl(_3495)->nidxs_base;
      int _3512 = mosek::fusion::p_WorkStack::_get_impl(_3495)->sp_base;
      int _3513 = mosek::fusion::p_WorkStack::_get_impl(_3495)->cof_base;
      int _3514 = mosek::fusion::p_WorkStack::_get_impl(_3495)->bfix_base;
      int _3515 = mosek::fusion::p_WorkStack::_get_impl(_3495)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _3516 = mosek::fusion::p_WorkStack::_get_impl(_3495)->i32;
      _checked_ptr_1<int> _ptr__3516(_3516 ? _3516->raw() : nullptr,_3516 ? _3516->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3517 = mosek::fusion::p_WorkStack::_get_impl(_3495)->i64;
      _checked_ptr_1<long long> _ptr__3517(_3517 ? _3517->raw() : nullptr,_3517 ? _3517->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3518 = mosek::fusion::p_WorkStack::_get_impl(_3495)->f64;
      _checked_ptr_1<double> _ptr__3518(_3518 ? _3518->raw() : nullptr,_3518 ? _3518->size(0) : 0);
      _ptr__3516[_3515] = mdim0;
      _ptr__3516[safe_add( _3515,(int)1 )] = mdim1;
      int _3519 = (int)0;
      _ptr__3516[_3510] = (int)0;
      int _8438 = (int)0;
      int _8439 = _3509;
      for (int _3520 = _8438; _3520 < _8439; ++_3520)
      {
        {
          int _8440 = (int)0;
          int _8441 = _3500;
          for (int _3521 = _8440; _3521 < _8441; ++_3521)
          {
            {
              _ptr__3517[safe_add( _3511,_3519 )] = _ptr__3507[safe_add( _3504,_3521 )];
              _ptr__3518[safe_add( _3513,_3519 )] = (_ptr__3508[safe_add( _3506,_3521 )] * ((*mval)(_3520)));
              ++ _3519;
            }
          }
          _ptr__3517[safe_add( _3512,_3520 )] = safe_add( safe_mul( ((*msubi)(_3520)),mdim1 ),((*msubj)(_3520)) );
          _ptr__3518[safe_add( _3514,_3520 )] = (((*mval)(_3520)) * _ptr__3508[_3505]);
          _ptr__3516[safe_add( safe_add( _3510,_3520 ),(int)1 )] = _3519;
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _3522,int _3523,std::shared_ptr< monty::ndarray< int,1 > > _3524,std::shared_ptr< monty::ndarray< int,1 > > _3525,std::shared_ptr< monty::ndarray< double,1 > > _3526,monty::rc_ptr< ::mosek::fusion::Expression > _3527){
  _checked_ptr_1<int> _ptr__3524(_3524 ? _3524->raw() : nullptr, _3524 ? _3524->size(0) : 0);
  _checked_ptr_1<int> _ptr__3525(_3525 ? _3525->raw() : nullptr, _3525 ? _3525->size(0) : 0);
  _checked_ptr_1<double> _ptr__3526(_3526 ? _3526->raw() : nullptr, _3526 ? _3526->size(0) : 0);
  int _3528 = _3527->getND();
  if ((_3528 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_3522 < (int)0) || (_3523 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_3524)->size(0)) != (int)((_3525)->size(0))) || ((int)((_3524)->size(0)) != (int)((_3526)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3529 = (int)((_3524)->size(0));
  int _8442 = (int)0;
  int _8443 = _3529;
  for (int _3530 = _8442; _3530 < _8443; ++_3530)
  {
    {
      if (((_ptr__3524[_3530] < (int)0) || ((_ptr__3524[_3530] >= _3522) || ((_ptr__3525[_3530] < (int)0) || (_ptr__3525[_3530] >= _3523)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8444 = (int)0;
  int _8445 = (_3529 - (int)1);
  for (int _3531 = _8444; _3531 < _8445; ++_3531)
  {
    {
      if (((_ptr__3524[_3531] > _ptr__3524[safe_add( _3531,(int)1 )]) || ((_ptr__3524[_3531] == _ptr__3524[safe_add( _3531,(int)1 )]) && (_ptr__3525[_3531] >= _ptr__3525[safe_add( _3531,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8446 = (int)0;
  int _8447 = _3529;
  for (int _3532 = _8446; _3532 < _8447; ++_3532)
  {
    {
      if (((_ptr__3524[_3532] < (int)0) || ((_ptr__3524[_3532] >= _3522) || ((_ptr__3525[_3532] < (int)0) || (_ptr__3525[_3532] >= _3523)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3533,    int _3534,    std::shared_ptr< monty::ndarray< int,1 > > _3535,    std::shared_ptr< monty::ndarray< int,1 > > _3536,    std::shared_ptr< monty::ndarray< double,1 > > _3537,    monty::rc_ptr< ::mosek::fusion::Expression > _3538,    int _3539){ return new mosek::fusion::ExprMulRight(_3533,_3534,_3535,_3536,_3537,_3538,_3539); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3533,    int _3534,    std::shared_ptr< monty::ndarray< int,1 > > _3535,    std::shared_ptr< monty::ndarray< int,1 > > _3536,    std::shared_ptr< monty::ndarray< double,1 > > _3537,    monty::rc_ptr< ::mosek::fusion::Expression > _3538,    int _3539) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3533,_3534,_3535,_3536,_3537,_3538,_3539); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3533,    int _3534,    std::shared_ptr< monty::ndarray< int,1 > > _3535,    std::shared_ptr< monty::ndarray< int,1 > > _3536,    std::shared_ptr< monty::ndarray< double,1 > > _3537,    monty::rc_ptr< ::mosek::fusion::Expression > _3538,    int _3539){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3535(_3535 ? _3535->raw() : nullptr, _3535 ? _3535->size(0) : 0);
    _checked_ptr_1<int> _ptr__3536(_3536 ? _3536->raw() : nullptr, _3536 ? _3536->size(0) : 0);
    _checked_ptr_1<double> _ptr__3537(_3537 ? _3537->raw() : nullptr, _3537 ? _3537->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_3534,_3538->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _3533;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _3534;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _3535;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _3536;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _3537;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _3538;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _3540,    int _3541,    std::shared_ptr< monty::ndarray< int,1 > > _3542,    std::shared_ptr< monty::ndarray< int,1 > > _3543,    std::shared_ptr< monty::ndarray< double,1 > > _3544,    monty::rc_ptr< ::mosek::fusion::Expression > _3545){ return new mosek::fusion::ExprMulRight(_3540,_3541,_3542,_3543,_3544,_3545); }mosek::fusion::ExprMulRight::ExprMulRight  (int _3540,    int _3541,    std::shared_ptr< monty::ndarray< int,1 > > _3542,    std::shared_ptr< monty::ndarray< int,1 > > _3543,    std::shared_ptr< monty::ndarray< double,1 > > _3544,    monty::rc_ptr< ::mosek::fusion::Expression > _3545) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_3540,_3541,_3542,_3543,_3544,_3545); }void mosek::fusion::p_ExprMulRight::_initialize  (int _3540,    int _3541,    std::shared_ptr< monty::ndarray< int,1 > > _3542,    std::shared_ptr< monty::ndarray< int,1 > > _3543,    std::shared_ptr< monty::ndarray< double,1 > > _3544,    monty::rc_ptr< ::mosek::fusion::Expression > _3545){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3542(_3542 ? _3542->raw() : nullptr, _3542 ? _3542->size(0) : 0);
    _checked_ptr_1<int> _ptr__3543(_3543 ? _3543->raw() : nullptr, _3543 ? _3543->size(0) : 0);
    _checked_ptr_1<double> _ptr__3544(_3544 ? _3544->raw() : nullptr, _3544 ? _3544->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_3540,_3541,_3542,_3543,_3544,_3545,::mosek::fusion::p_ExprMulRight::validate(_3540,_3541,_3542,_3543,_3544,_3545));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3546,monty::rc_ptr< ::mosek::fusion::WorkStack > _3547,monty::rc_ptr< ::mosek::fusion::WorkStack > _3548) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_3546,_3547,_3548); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3546,monty::rc_ptr< ::mosek::fusion::WorkStack > _3547,monty::rc_ptr< ::mosek::fusion::WorkStack > _3548){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_3547,_3546,_3548);
  _3547->peek_expr();
  int _3549 = mosek::fusion::p_WorkStack::_get_impl(_3547)->nd;
  bool _3550 = mosek::fusion::p_WorkStack::_get_impl(_3547)->hassp;
  int _3551 = (int)((mval)->size(0));
  bool _3552 = (_3551 < safe_mul( mdim0,mdim1 ));
  int _3553 = ((*mosek::fusion::p_WorkStack::_get_impl(_3547)->i32)(mosek::fusion::p_WorkStack::_get_impl(_3547)->shape_base));
  if (_3552)
  {
    {
      int _3554 = _3547->alloci32(safe_add( mdim1,(int)1 ));
      int _3555 = _3547->alloci32(_3551);
      int _3556 = _3547->alloci32(safe_add( _3553,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3557 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i32;
      _checked_ptr_1<int> _ptr__3557(_3557 ? _3557->raw() : nullptr,_3557 ? _3557->size(0) : 0);
      int _8448 = (int)0;
      int _8449 = safe_add( mdim1,(int)1 );
      for (int _3558 = _8448; _3558 < _8449; ++_3558)
      {
        {
          _ptr__3557[safe_add( _3554,_3558 )] = (int)0;
        }
      }
      int _8450 = (int)0;
      int _8451 = _3551;
      for (int _3559 = _8450; _3559 < _8451; ++_3559)
      {
        {
          ++ _ptr__3557[safe_add( safe_add( _3554,((*msubj)(_3559)) ),(int)1 )];
        }
      }
      int _8452 = (int)0;
      int _8453 = mdim1;
      for (int _3560 = _8452; _3560 < _8453; ++_3560)
      {
        {
          _ptr__3557[safe_add( safe_add( _3554,_3560 ),(int)1 )] += _ptr__3557[safe_add( _3554,_3560 )];
        }
      }
      int _8454 = (int)0;
      int _8455 = _3551;
      for (int _3561 = _8454; _3561 < _8455; ++_3561)
      {
        {
          _ptr__3557[safe_add( _3555,_3561 )] = _ptr__3557[safe_add( _3554,((*msubj)(_3561)) )];
          ++ _ptr__3557[safe_add( _3554,((*msubj)(_3561)) )];
        }
      }
      int _8456 = (int)0;
      int _8457 = mdim1;
      for (int _3562 = _8456; _3562 < _8457; ++_3562)
      {
        {
          _ptr__3557[(safe_add( _3554,mdim1 ) - _3562)] = _ptr__3557[((safe_add( _3554,mdim1 ) - _3562) - (int)1)];
        }
      }
      _ptr__3557[_3554] = (int)0;
      int _8458 = (int)0;
      int _8459 = safe_add( _3553,(int)1 );
      for (int _3563 = _8458; _3563 < _8459; ++_3563)
      {
        {
          _ptr__3557[safe_add( _3556,_3563 )] = (int)0;
        }
      }
      _3547->popi32(safe_add( safe_add( safe_add( _3553,mdim1 ),(int)2 ),_3551 ));
      int _3564 = _3547->popi32();
      if ((_3564 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      int _3565 = _3547->popi32();
      int _3566 = _3547->popi32();
      int _3567 = _3547->popi32();
      int _3568 = _3547->popi32();
      bool _3569 = (_3547->popi32() != (int)0);
      int _3570 = _3547->popi32(safe_add( _3567,(int)1 ));
      int _8460;
      bool _8461 = _3569;
      if (_8461)
      {
        _8460 = _3547->popi64(_3567);
      }
      else
      {
        _8460 = (int)999999;
      }
      int _3571 = _8460;
      int _3572 = _3547->popi64(_3568);
      int _3573 = _3547->popf64(_3567);
      int _3574 = _3547->popf64(_3568);
      std::shared_ptr< monty::ndarray< int,1 > > _3575 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i32;
      _checked_ptr_1<int> _ptr__3575(_3575 ? _3575->raw() : nullptr,_3575 ? _3575->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3576 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i64;
      _checked_ptr_1<long long> _ptr__3576(_3576 ? _3576->raw() : nullptr,_3576 ? _3576->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3577 = mosek::fusion::p_WorkStack::_get_impl(_3547)->f64;
      _checked_ptr_1<double> _ptr__3577(_3577 ? _3577->raw() : nullptr,_3577 ? _3577->size(0) : 0);
      if (_3569)
      {
        {
          int _8462 = (int)0;
          int _8463 = _3567;
          for (int _3578 = _8462; _3578 < _8463; ++_3578)
          {
            {
              ++ _ptr__3575[safe_add( safe_add( _3556,(_ptr__3576[safe_add( _3571,_3578 )] / _3565) ),(int)1 )];
            }
          }
          int _8464 = (int)0;
          int _8465 = _3566;
          for (int _3579 = _8464; _3579 < _8465; ++_3579)
          {
            {
              _ptr__3575[safe_add( safe_add( _3556,_3579 ),(int)1 )] += _ptr__3575[safe_add( _3556,_3579 )];
            }
          }
          int _3580 = (int)0;
          int _3581 = (int)0;
          int _8466 = (int)0;
          int _8467 = _3566;
          for (int _3582 = _8466; _3582 < _8467; ++_3582)
          {
            {
              int _8468 = (int)0;
              int _8469 = mdim1;
              for (int _3583 = _8468; _3583 < _8469; ++_3583)
              {
                {
                  bool _3584 = false;
                  int _3585 = _ptr__3575[safe_add( safe_add( _3556,_3582 ),(int)1 )];
                  int _3586 = _ptr__3575[safe_add( _3556,_3582 )];
                  int _3587 = _ptr__3575[safe_add( safe_add( _3554,_3583 ),(int)1 )];
                  int _3588 = _ptr__3575[safe_add( _3554,_3583 )];
                  while ( ((_3586 < _3585) && (_3588 < _3587)) )
                  {
                    {
                      int _3589 = _ptr__3575[safe_add( _3555,_3588 )];
                      if (((_ptr__3576[safe_add( _3571,_3586 )] % _3565) < ((*msubi)(_3589))))
                      {
                        {
                          ++ _3586;
                        }
                      }
                      else if(((_ptr__3576[safe_add( _3571,_3586 )] % _3565) > ((*msubi)(_3589))))
                      {
                        {
                          ++ _3588;
                        }
                      }
                      else
                      {
                        {
                          _3581 += (_ptr__3575[safe_add( safe_add( _3570,_3586 ),(int)1 )] - _ptr__3575[safe_add( _3570,_3586 )]);
                          ++ _3586;
                          ++ _3588;
                          _3584 = true;
                        }
                      }
                    }
                  }
                  if (_3584)
                  {
                    {
                      ++ _3580;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _3590 = (_3580 < safe_mul( _3566,mdim1 ));
          _3546->alloc_expr((int)2,_3580,_3581,_3590);
          int _3591 = mosek::fusion::p_WorkStack::_get_impl(_3546)->ptr_base;
          int _3592 = mosek::fusion::p_WorkStack::_get_impl(_3546)->nidxs_base;
          int _8470;
          bool _8471 = _3590;
          if (_8471)
          {
            _8470 = mosek::fusion::p_WorkStack::_get_impl(_3546)->sp_base;
          }
          else
          {
            _8470 = _3546->alloci64(_3580);
          }
          int _3593 = _8470;
          int _3594 = mosek::fusion::p_WorkStack::_get_impl(_3546)->cof_base;
          int _3595 = mosek::fusion::p_WorkStack::_get_impl(_3546)->bfix_base;
          int _3596 = mosek::fusion::p_WorkStack::_get_impl(_3546)->shape_base;
          std::shared_ptr< monty::ndarray< int,1 > > _3597 = mosek::fusion::p_WorkStack::_get_impl(_3546)->i32;
          _checked_ptr_1<int> _ptr__3597(_3597 ? _3597->raw() : nullptr,_3597 ? _3597->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3598 = mosek::fusion::p_WorkStack::_get_impl(_3546)->i64;
          _checked_ptr_1<long long> _ptr__3598(_3598 ? _3598->raw() : nullptr,_3598 ? _3598->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3599 = mosek::fusion::p_WorkStack::_get_impl(_3546)->f64;
          _checked_ptr_1<double> _ptr__3599(_3599 ? _3599->raw() : nullptr,_3599 ? _3599->size(0) : 0);
          _ptr__3597[_3596] = _3566;
          _ptr__3597[safe_add( _3596,(int)1 )] = mdim1;
          int _3600 = (int)0;
          int _3601 = (int)0;
          _ptr__3597[_3591] = (int)0;
          int _8472 = (int)0;
          int _8473 = _3566;
          for (int _3602 = _8472; _3602 < _8473; ++_3602)
          {
            {
              int _8474 = (int)0;
              int _8475 = mdim1;
              for (int _3603 = _8474; _3603 < _8475; ++_3603)
              {
                {
                  bool _3604 = false;
                  double _3605 = 0.0;
                  int _3606 = _ptr__3575[safe_add( safe_add( _3556,_3602 ),(int)1 )];
                  int _3607 = _ptr__3575[safe_add( _3556,_3602 )];
                  int _3608 = _ptr__3575[safe_add( safe_add( _3554,_3603 ),(int)1 )];
                  int _3609 = _ptr__3575[safe_add( _3554,_3603 )];
                  while ( ((_3607 < _3606) && (_3609 < _3608)) )
                  {
                    {
                      int _3610 = _ptr__3575[safe_add( _3555,_3609 )];
                      if (((_ptr__3576[safe_add( _3571,_3607 )] % _3565) < ((*msubi)(_3610))))
                      {
                        {
                          ++ _3607;
                        }
                      }
                      else if(((_ptr__3576[safe_add( _3571,_3607 )] % _3565) > ((*msubi)(_3610))))
                      {
                        {
                          ++ _3609;
                        }
                      }
                      else
                      {
                        {
                          int _3611 = (_ptr__3575[safe_add( safe_add( _3570,_3607 ),(int)1 )] - _ptr__3575[safe_add( _3570,_3607 )]);
                          _3605 += (((*mval)(_3610)) * _ptr__3577[safe_add( _3573,_3607 )]);
                          int _8476 = (int)0;
                          int _8477 = _3611;
                          for (int _3612 = _8476; _3612 < _8477; ++_3612)
                          {
                            {
                              _ptr__3598[safe_add( safe_add( _3592,_3601 ),_3612 )] = _ptr__3576[safe_add( safe_add( _3572,_ptr__3575[safe_add( _3570,_3607 )] ),_3612 )];
                            }
                          }
                          int _8478 = (int)0;
                          int _8479 = _3611;
                          for (int _3613 = _8478; _3613 < _8479; ++_3613)
                          {
                            {
                              _ptr__3599[safe_add( safe_add( _3594,_3601 ),_3613 )] = (_ptr__3577[safe_add( safe_add( _3574,_ptr__3575[safe_add( _3570,_3607 )] ),_3613 )] * ((*mval)(_3610)));
                            }
                          }
                          _3601 += _3611;
                          ++ _3607;
                          ++ _3609;
                          _3604 = true;
                        }
                      }
                      if (_3604)
                      {
                        {
                          _ptr__3597[safe_add( safe_add( _3591,_3600 ),(int)1 )] = _3601;
                          _ptr__3599[safe_add( _3595,_3600 )] = _3605;
                          _ptr__3598[safe_add( _3593,_3600 )] = safe_add( safe_mul( _3602,mdim1 ),_3603 );
                          ++ _3600;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          if ((!_3590))
          {
            {
              _3546->popi64(_3580);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _3614 = safe_mul( _3566,mdim1 );
          int _3615 = (int)0;
          int _8480 = (int)0;
          int _8481 = _3566;
          for (int _3616 = _8480; _3616 < _8481; ++_3616)
          {
            {
              int _8482 = (int)0;
              int _8483 = mdim1;
              for (int _3617 = _8482; _3617 < _8483; ++_3617)
              {
                {
                  int _8484 = _ptr__3575[safe_add( _3554,_3617 )];
                  int _8485 = _ptr__3575[safe_add( safe_add( _3554,_3617 ),(int)1 )];
                  for (int _3618 = _8484; _3618 < _8485; ++_3618)
                  {
                    {
                      int _3619 = _ptr__3575[safe_add( _3555,_3618 )];
                      int _3620 = safe_add( safe_mul( _3616,_3565 ),((*msubi)(_3619)) );
                      _3615 += (_ptr__3575[safe_add( safe_add( _3570,_3620 ),(int)1 )] - _ptr__3575[safe_add( _3570,_3620 )]);
                    }
                  }
                }
              }
            }
          }
          bool _3621 = (_3614 < safe_mul( _3566,mdim1 ));
          int _3622 = _3546->alloci32(safe_add( _3614,(int)1 ));
          int _8486;
          bool _8487 = _3621;
          if (_8487)
          {
            _8486 = (int)1;
          }
          else
          {
            _8486 = (int)0;
          }
          _3546->pushi32(_8486);
          _3546->pushi32(_3615);
          _3546->pushi32(_3614);
          _3546->pushi32(_3566);
          _3546->pushi32(mdim1);
          _3546->pushi32((int)2);
          int _3623 = _3546->alloci64(_3615);
          int _3624 = _3546->alloci64(_3614);
          int _3625 = _3546->allocf64(_3615);
          int _3626 = _3546->allocf64(_3614);
          std::shared_ptr< monty::ndarray< int,1 > > _3627 = mosek::fusion::p_WorkStack::_get_impl(_3546)->i32;
          _checked_ptr_1<int> _ptr__3627(_3627 ? _3627->raw() : nullptr,_3627 ? _3627->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3628 = mosek::fusion::p_WorkStack::_get_impl(_3546)->i64;
          _checked_ptr_1<long long> _ptr__3628(_3628 ? _3628->raw() : nullptr,_3628 ? _3628->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3629 = mosek::fusion::p_WorkStack::_get_impl(_3546)->f64;
          _checked_ptr_1<double> _ptr__3629(_3629 ? _3629->raw() : nullptr,_3629 ? _3629->size(0) : 0);
          int _3630 = (int)0;
          int _3631 = (int)0;
          _ptr__3627[_3622] = (int)0;
          int _8488 = (int)0;
          int _8489 = _3566;
          for (int _3632 = _8488; _3632 < _8489; ++_3632)
          {
            {
              int _8490 = (int)0;
              int _8491 = mdim1;
              for (int _3633 = _8490; _3633 < _8491; ++_3633)
              {
                {
                  int _3634 = safe_mul( _3632,_3565 );
                  double _3635 = 0.0;
                  int _8492 = _ptr__3575[safe_add( _3554,_3633 )];
                  int _8493 = _ptr__3575[safe_add( safe_add( _3554,_3633 ),(int)1 )];
                  for (int _3636 = _8492; _3636 < _8493; ++_3636)
                  {
                    {
                      int _3637 = _ptr__3575[safe_add( _3555,_3636 )];
                      int _3638 = safe_add( _3634,((*msubi)(_3637)) );
                      int _3639 = _ptr__3575[safe_add( _3570,_3638 )];
                      int _3640 = (_ptr__3575[safe_add( safe_add( _3570,_3638 ),(int)1 )] - _ptr__3575[safe_add( _3570,_3638 )]);
                      int _8494 = (int)0;
                      int _8495 = _3640;
                      for (int _3641 = _8494; _3641 < _8495; ++_3641)
                      {
                        {
                          _ptr__3628[safe_add( safe_add( _3623,_3631 ),_3641 )] = _ptr__3576[safe_add( safe_add( _3572,_3639 ),_3641 )];
                        }
                      }
                      int _8496 = (int)0;
                      int _8497 = _3640;
                      for (int _3642 = _8496; _3642 < _8497; ++_3642)
                      {
                        {
                          _ptr__3629[safe_add( safe_add( _3625,_3631 ),_3642 )] = (_ptr__3577[safe_add( safe_add( _3574,_3639 ),_3642 )] * ((*mval)(_3637)));
                        }
                      }
                      _3635 += (_ptr__3577[safe_add( safe_add( _3573,_3634 ),((*msubi)(_3637)) )] * ((*mval)(_3637)));
                      _3631 += _3640;
                    }
                  }
                  _ptr__3627[safe_add( safe_add( _3622,_3630 ),(int)1 )] = _3631;
                  _ptr__3629[safe_add( _3626,_3630 )] = _3635;
                  _ptr__3628[safe_add( _3624,_3630 )] = safe_add( safe_mul( _3632,mdim1 ),_3633 );
                  ++ _3630;
                }
              }
            }
          }
          if ((!_3621))
          {
            {
              _3546->popi64(_3614);
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _3643 = _3548->alloci32(safe_add( _3553,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3644 = mosek::fusion::p_WorkStack::_get_impl(_3548)->i32;
      _checked_ptr_1<int> _ptr__3644(_3644 ? _3644->raw() : nullptr,_3644 ? _3644->size(0) : 0);
      int _8498 = (int)0;
      int _8499 = safe_add( _3553,(int)1 );
      for (int _3645 = _8498; _3645 < _8499; ++_3645)
      {
        {
          _ptr__3644[safe_add( _3643,_3645 )] = (int)0;
        }
      }
      _3547->pop_expr();
      std::shared_ptr< monty::ndarray< int,1 > > _3646 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i32;
      _checked_ptr_1<int> _ptr__3646(_3646 ? _3646->raw() : nullptr,_3646 ? _3646->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3647 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i64;
      _checked_ptr_1<long long> _ptr__3647(_3647 ? _3647->raw() : nullptr,_3647 ? _3647->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3648 = mosek::fusion::p_WorkStack::_get_impl(_3547)->f64;
      _checked_ptr_1<double> _ptr__3648(_3648 ? _3648->raw() : nullptr,_3648 ? _3648->size(0) : 0);
      int _3649 = mosek::fusion::p_WorkStack::_get_impl(_3547)->nd;
      int _3650 = mosek::fusion::p_WorkStack::_get_impl(_3547)->nelem;
      int _3651 = mosek::fusion::p_WorkStack::_get_impl(_3547)->nnz;
      bool _3652 = mosek::fusion::p_WorkStack::_get_impl(_3547)->hassp;
      int _3653 = _3651;
      int _3654 = _3650;
      int _3655 = mosek::fusion::p_WorkStack::_get_impl(_3547)->shape_base;
      int _3656 = mosek::fusion::p_WorkStack::_get_impl(_3547)->ptr_base;
      int _3657 = mosek::fusion::p_WorkStack::_get_impl(_3547)->sp_base;
      int _3658 = mosek::fusion::p_WorkStack::_get_impl(_3547)->nidxs_base;
      int _3659 = mosek::fusion::p_WorkStack::_get_impl(_3547)->bfix_base;
      int _3660 = mosek::fusion::p_WorkStack::_get_impl(_3547)->cof_base;
      int _3661 = _ptr__3646[_3655];
      int _3662 = _ptr__3646[safe_add( _3655,(int)1 )];
      if ((_3649 != (int)2))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,1 > > _3663 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i32;
      _checked_ptr_1<int> _ptr__3663(_3663 ? _3663->raw() : nullptr,_3663 ? _3663->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3664 = mosek::fusion::p_WorkStack::_get_impl(_3547)->i64;
      _checked_ptr_1<long long> _ptr__3664(_3664 ? _3664->raw() : nullptr,_3664 ? _3664->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3665 = mosek::fusion::p_WorkStack::_get_impl(_3547)->f64;
      _checked_ptr_1<double> _ptr__3665(_3665 ? _3665->raw() : nullptr,_3665 ? _3665->size(0) : 0);
      int _3666 = safe_mul( _3661,mdim1 );
      int _3667 = safe_mul( _3651,mdim1 );
      bool _3668 = false;
      int _3669 = (int)2;
      _3546->alloc_expr(_3669,_3666,_3667,_3668);
      std::shared_ptr< monty::ndarray< int,1 > > _3670 = mosek::fusion::p_WorkStack::_get_impl(_3546)->i32;
      _checked_ptr_1<int> _ptr__3670(_3670 ? _3670->raw() : nullptr,_3670 ? _3670->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3671 = mosek::fusion::p_WorkStack::_get_impl(_3546)->i64;
      _checked_ptr_1<long long> _ptr__3671(_3671 ? _3671->raw() : nullptr,_3671 ? _3671->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3672 = mosek::fusion::p_WorkStack::_get_impl(_3546)->f64;
      _checked_ptr_1<double> _ptr__3672(_3672 ? _3672->raw() : nullptr,_3672 ? _3672->size(0) : 0);
      int _3673 = mosek::fusion::p_WorkStack::_get_impl(_3546)->shape_base;
      int _3674 = mosek::fusion::p_WorkStack::_get_impl(_3546)->ptr_base;
      int _3675 = mosek::fusion::p_WorkStack::_get_impl(_3546)->nidxs_base;
      int _3676 = mosek::fusion::p_WorkStack::_get_impl(_3546)->sp_base;
      int _3677 = mosek::fusion::p_WorkStack::_get_impl(_3546)->cof_base;
      int _3678 = mosek::fusion::p_WorkStack::_get_impl(_3546)->bfix_base;
      _ptr__3670[_3673] = _3661;
      _ptr__3670[safe_add( _3673,(int)1 )] = mdim1;
      int _3679 = (int)0;
      int _3680 = (int)0;
      _ptr__3670[_3674] = (int)0;
      if (_3652)
      {
        {
          int _8500 = (int)0;
          int _8501 = _3650;
          for (int _3681 = _8500; _3681 < _8501; ++_3681)
          {
            {
              ++ _ptr__3644[safe_add( safe_add( _3643,(_ptr__3664[safe_add( _3657,_3681 )] / _3662) ),(int)1 )];
            }
          }
          int _8502 = (int)0;
          int _8503 = _3661;
          for (int _3682 = _8502; _3682 < _8503; ++_3682)
          {
            {
              _ptr__3644[safe_add( safe_add( _3643,_3682 ),(int)1 )] += _ptr__3644[safe_add( _3643,_3682 )];
            }
          }
          int _8504 = (int)0;
          int _8505 = _3661;
          for (int _3683 = _8504; _3683 < _8505; ++_3683)
          {
            {
              int _8506 = (int)0;
              int _8507 = mdim1;
              for (int _3684 = _8506; _3684 < _8507; ++_3684)
              {
                {
                  double _3685 = 0.0;
                  int _3686 = (int)0;
                  int _8508 = _ptr__3644[safe_add( _3643,_3683 )];
                  int _8509 = _ptr__3644[safe_add( safe_add( _3643,_3683 ),(int)1 )];
                  for (int _3687 = _8508; _3687 < _8509; ++_3687)
                  {
                    {
                      long long _3688 = safe_add( _3684,safe_mul( (_ptr__3664[safe_add( _3657,_3687 )] % _3662),mdim1 ) );
                      _3685 += (_ptr__3665[safe_add( _3659,_3687 )] * ((*mval)(_3688)));
                      int _8510 = _ptr__3663[safe_add( _3656,_3687 )];
                      int _8511 = _ptr__3663[safe_add( safe_add( _3656,_3687 ),(int)1 )];
                      for (int _3689 = _8510; _3689 < _8511; ++_3689)
                      {
                        {
                          _ptr__3671[safe_add( safe_add( _3675,_3679 ),_3686 )] = _ptr__3664[safe_add( _3658,_3689 )];
                          _ptr__3672[safe_add( safe_add( _3677,_3679 ),_3686 )] = (_ptr__3665[safe_add( _3660,_3689 )] * ((*mval)(_3688)));
                          ++ _3686;
                        }
                      }
                    }
                  }
                  _3679 += _3686;
                  _ptr__3670[safe_add( safe_add( _3674,_3680 ),(int)1 )] = _3679;
                  _ptr__3672[safe_add( _3678,_3680 )] = _3685;
                  ++ _3680;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _8512 = (int)0;
          int _8513 = _3661;
          for (int _3690 = _8512; _3690 < _8513; ++_3690)
          {
            {
              int _8514 = (int)0;
              int _8515 = mdim1;
              for (int _3691 = _8514; _3691 < _8515; ++_3691)
              {
                {
                  double _3692 = 0.0;
                  int _3693 = (int)0;
                  int _8516 = (int)0;
                  int _8517 = _3662;
                  for (int _3694 = _8516; _3694 < _8517; ++_3694)
                  {
                    {
                      int _3695 = safe_add( safe_mul( _3690,_3662 ),_3694 );
                      int _3696 = safe_add( _3691,safe_mul( _3694,mdim1 ) );
                      _3692 += (_ptr__3665[safe_add( _3659,_3695 )] * ((*mval)(_3696)));
                      int _8518 = _ptr__3663[safe_add( _3656,_3695 )];
                      int _8519 = _ptr__3663[safe_add( safe_add( _3656,_3695 ),(int)1 )];
                      for (int _3697 = _8518; _3697 < _8519; ++_3697)
                      {
                        {
                          _ptr__3671[safe_add( safe_add( _3675,_3679 ),_3693 )] = _ptr__3664[safe_add( _3658,_3697 )];
                          _ptr__3672[safe_add( safe_add( _3677,_3679 ),_3693 )] = (_ptr__3665[safe_add( _3660,_3697 )] * ((*mval)(_3696)));
                          ++ _3693;
                        }
                      }
                    }
                  }
                  _3679 += _3693;
                  _ptr__3670[safe_add( safe_add( _3674,_3680 ),(int)1 )] = _3679;
                  _ptr__3672[safe_add( _3678,_3680 )] = _3692;
                  ++ _3680;
                }
              }
            }
          }
        }
      }
      _3548->clear();
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _3698,std::shared_ptr< monty::ndarray< int,1 > > _3699){
  _checked_ptr_1<int> _ptr__3699(_3699 ? _3699->raw() : nullptr, _3699 ? _3699->size(0) : 0);
  if (((int)((_3699)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_3698)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__3699[(int)0]),(int)(_3698)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _3700,int _3701,std::shared_ptr< monty::ndarray< int,1 > > _3702,std::shared_ptr< monty::ndarray< int,1 > > _3703,std::shared_ptr< monty::ndarray< double,1 > > _3704,monty::rc_ptr< ::mosek::fusion::Expression > _3705){
  _checked_ptr_1<int> _ptr__3702(_3702 ? _3702->raw() : nullptr, _3702 ? _3702->size(0) : 0);
  _checked_ptr_1<int> _ptr__3703(_3703 ? _3703->raw() : nullptr, _3703 ? _3703->size(0) : 0);
  _checked_ptr_1<double> _ptr__3704(_3704 ? _3704->raw() : nullptr, _3704 ? _3704->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3706 = _3705->getShape();
  _checked_ptr_1<int> _ptr__3706(_3706 ? _3706->raw() : nullptr,_3706 ? _3706->size(0) : 0);
  if (((int)((_3706)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3707 = _ptr__3706[(int)0];
  int _3708 = _ptr__3706[(int)1];
  if (((_3700 < (int)0) || ((_3701 < (int)0) || ((_3707 < (int)0) || (_3708 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3700 != _3708))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3702)->size(0)) != (int)((_3703)->size(0))) || ((int)((_3702)->size(0)) != (int)((_3704)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3709 = (int)((_3702)->size(0));
  int _8520 = (int)0;
  int _8521 = _3709;
  for (int _3710 = _8520; _3710 < _8521; ++_3710)
  {
    {
      if (((_ptr__3702[_3710] < (int)0) || ((_ptr__3702[_3710] >= _3700) || ((_ptr__3703[_3710] < (int)0) || (_ptr__3703[_3710] >= _3701)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8522 = (int)0;
  int _8523 = (_3709 - (int)1);
  for (int _3711 = _8522; _3711 < _8523; ++_3711)
  {
    {
      if (((_ptr__3702[_3711] > _ptr__3702[safe_add( _3711,(int)1 )]) || ((_ptr__3702[_3711] == _ptr__3702[safe_add( _3711,(int)1 )]) && (_ptr__3703[_3711] >= _ptr__3703[safe_add( _3711,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8524 = (int)0;
  int _8525 = _3709;
  for (int _3712 = _8524; _3712 < _8525; ++_3712)
  {
    {
      if (((_ptr__3702[_3712] < (int)0) || ((_ptr__3702[_3712] >= _3700) || ((_ptr__3703[_3712] < (int)0) || (_ptr__3703[_3712] >= _3701)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3713,    int _3714,    std::shared_ptr< monty::ndarray< int,1 > > _3715,    std::shared_ptr< monty::ndarray< int,1 > > _3716,    std::shared_ptr< monty::ndarray< double,1 > > _3717,    monty::rc_ptr< ::mosek::fusion::Expression > _3718,    int _3719){ return new mosek::fusion::ExprMulLeft(_3713,_3714,_3715,_3716,_3717,_3718,_3719); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3713,    int _3714,    std::shared_ptr< monty::ndarray< int,1 > > _3715,    std::shared_ptr< monty::ndarray< int,1 > > _3716,    std::shared_ptr< monty::ndarray< double,1 > > _3717,    monty::rc_ptr< ::mosek::fusion::Expression > _3718,    int _3719) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3713,_3714,_3715,_3716,_3717,_3718,_3719); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3713,    int _3714,    std::shared_ptr< monty::ndarray< int,1 > > _3715,    std::shared_ptr< monty::ndarray< int,1 > > _3716,    std::shared_ptr< monty::ndarray< double,1 > > _3717,    monty::rc_ptr< ::mosek::fusion::Expression > _3718,    int _3719){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3715(_3715 ? _3715->raw() : nullptr, _3715 ? _3715->size(0) : 0);
    _checked_ptr_1<int> _ptr__3716(_3716 ? _3716->raw() : nullptr, _3716 ? _3716->size(0) : 0);
    _checked_ptr_1<double> _ptr__3717(_3717 ? _3717->raw() : nullptr, _3717 ? _3717->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_3713,_3714,_3718->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _3713;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _3714;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _3715;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _3716;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _3717;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _3718;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _3720,    int _3721,    std::shared_ptr< monty::ndarray< int,1 > > _3722,    std::shared_ptr< monty::ndarray< int,1 > > _3723,    std::shared_ptr< monty::ndarray< double,1 > > _3724,    monty::rc_ptr< ::mosek::fusion::Expression > _3725){ return new mosek::fusion::ExprMulLeft(_3720,_3721,_3722,_3723,_3724,_3725); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _3720,    int _3721,    std::shared_ptr< monty::ndarray< int,1 > > _3722,    std::shared_ptr< monty::ndarray< int,1 > > _3723,    std::shared_ptr< monty::ndarray< double,1 > > _3724,    monty::rc_ptr< ::mosek::fusion::Expression > _3725) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_3720,_3721,_3722,_3723,_3724,_3725); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _3720,    int _3721,    std::shared_ptr< monty::ndarray< int,1 > > _3722,    std::shared_ptr< monty::ndarray< int,1 > > _3723,    std::shared_ptr< monty::ndarray< double,1 > > _3724,    monty::rc_ptr< ::mosek::fusion::Expression > _3725){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3722(_3722 ? _3722->raw() : nullptr, _3722 ? _3722->size(0) : 0);
    _checked_ptr_1<int> _ptr__3723(_3723 ? _3723->raw() : nullptr, _3723 ? _3723->size(0) : 0);
    _checked_ptr_1<double> _ptr__3724(_3724 ? _3724->raw() : nullptr, _3724 ? _3724->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_3720,_3721,_3722,_3723,_3724,_3725,::mosek::fusion::p_ExprMulLeft::validate(_3720,_3721,_3722,_3723,_3724,_3725));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3726,monty::rc_ptr< ::mosek::fusion::WorkStack > _3727,monty::rc_ptr< ::mosek::fusion::WorkStack > _3728) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_3726,_3727,_3728); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3726,monty::rc_ptr< ::mosek::fusion::WorkStack > _3727,monty::rc_ptr< ::mosek::fusion::WorkStack > _3728){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_3727,_3726,_3728);
  _3727->pop_expr();
  int _3729 = mosek::fusion::p_WorkStack::_get_impl(_3727)->nd;
  int _3730 = mosek::fusion::p_WorkStack::_get_impl(_3727)->nnz;
  int _3731 = mosek::fusion::p_WorkStack::_get_impl(_3727)->nelem;
  bool _3732 = mosek::fusion::p_WorkStack::_get_impl(_3727)->hassp;
  int _3733 = mosek::fusion::p_WorkStack::_get_impl(_3727)->shape_base;
  int _3734 = mosek::fusion::p_WorkStack::_get_impl(_3727)->ptr_base;
  int _3735 = mosek::fusion::p_WorkStack::_get_impl(_3727)->sp_base;
  int _3736 = mosek::fusion::p_WorkStack::_get_impl(_3727)->nidxs_base;
  int _3737 = mosek::fusion::p_WorkStack::_get_impl(_3727)->bfix_base;
  int _3738 = mosek::fusion::p_WorkStack::_get_impl(_3727)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _3739 = mosek::fusion::p_WorkStack::_get_impl(_3727)->i32;
  _checked_ptr_1<int> _ptr__3739(_3739 ? _3739->raw() : nullptr,_3739 ? _3739->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3740 = mosek::fusion::p_WorkStack::_get_impl(_3727)->i64;
  _checked_ptr_1<long long> _ptr__3740(_3740 ? _3740->raw() : nullptr,_3740 ? _3740->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3741 = mosek::fusion::p_WorkStack::_get_impl(_3727)->f64;
  _checked_ptr_1<double> _ptr__3741(_3741 ? _3741->raw() : nullptr,_3741 ? _3741->size(0) : 0);
  if ((_3729 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3742 = (int)9999;
  int _3743 = (int)9999;
  int _3744 = (int)9999;
  int _3745 = _ptr__3739[_3733];
  int _3746 = _ptr__3739[safe_add( _3733,(int)1 )];
  int _3747 = (int)((msubi)->size(0));
  bool _3748 = (_3747 < safe_mul( mdim0,mdim1 ));
  bool _3749 = false;
  int _3750 = (int)0;
  int _3751 = (int)0;
  if (_3732)
  {
    {
      _3742 = _3728->alloci32(_3731);
      _3743 = _3728->alloci32(_3731);
      _3744 = _3728->alloci32(safe_add( _3746,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3752 = mosek::fusion::p_WorkStack::_get_impl(_3728)->i32;
      _checked_ptr_1<int> _ptr__3752(_3752 ? _3752->raw() : nullptr,_3752 ? _3752->size(0) : 0);
      int _8526 = (int)0;
      int _8527 = safe_add( _3746,(int)1 );
      for (int _3753 = _8526; _3753 < _8527; ++_3753)
      {
        {
          _ptr__3752[safe_add( _3744,_3753 )] = (int)0;
        }
      }
      int _8528 = (int)0;
      int _8529 = _3731;
      for (int _3754 = _8528; _3754 < _8529; ++_3754)
      {
        {
          ++ _ptr__3752[safe_add( safe_add( _3744,(_ptr__3740[safe_add( _3735,_3754 )] % _3746) ),(int)1 )];
        }
      }
      int _8530 = (int)0;
      int _8531 = _3746;
      for (int _3755 = _8530; _3755 < _8531; ++_3755)
      {
        {
          _ptr__3752[safe_add( safe_add( _3744,_3755 ),(int)1 )] += _ptr__3752[safe_add( _3744,_3755 )];
        }
      }
      int _8532 = (int)0;
      int _8533 = _3731;
      for (int _3756 = _8532; _3756 < _8533; ++_3756)
      {
        {
          long long _3757 = (_ptr__3740[safe_add( _3735,_3756 )] % _3746);
          _ptr__3752[safe_add( _3742,_ptr__3752[safe_add( _3744,_3757 )] )] = _3756;
          ++ _ptr__3752[safe_add( _3744,_3757 )];
        }
      }
      int _8534 = (int)0;
      int _8535 = _3746;
      for (int _3758 = _8534; _3758 < _8535; ++_3758)
      {
        {
          _ptr__3752[(safe_add( _3744,_3746 ) - _3758)] = _ptr__3752[((safe_add( _3744,_3746 ) - _3758) - (int)1)];
        }
      }
      _ptr__3752[_3744] = (int)0;
      if (_3748)
      {
        {
          int _3759 = (int)0;
          while ( (_3759 < _3747) )
          {
            {
              int _3760 = ((*msubi)(_3759));
              int _3761 = safe_add( _3759,(int)1 );
              while ( ((_3761 < _3747) && (((*msubi)(_3761)) == ((*msubi)(_3759)))) )
              {
                {
                  ++ _3761;
                }
              }
              int _8536 = (int)0;
              int _8537 = _3746;
              for (int _3762 = _8536; _3762 < _8537; ++_3762)
              {
                {
                  bool _3763 = false;
                  int _3764 = _3761;
                  int _3765 = _3759;
                  int _3766 = _ptr__3752[safe_add( safe_add( _3744,_3762 ),(int)1 )];
                  int _3767 = _ptr__3752[safe_add( _3744,_3762 )];
                  while ( ((_3765 < _3764) && (_3767 < _3766)) )
                  {
                    {
                      int _3768 = _ptr__3752[safe_add( _3742,_3767 )];
                      if ((((*msubj)(_3765)) < (_ptr__3740[safe_add( _3735,_3768 )] / _3746)))
                      {
                        {
                          ++ _3765;
                        }
                      }
                      else if((((*msubj)(_3765)) > (_ptr__3740[safe_add( _3735,_3768 )] / _3746)))
                      {
                        {
                          ++ _3767;
                        }
                      }
                      else
                      {
                        {
                          _3763 = true;
                          _3751 += (_ptr__3739[safe_add( safe_add( _3734,_3768 ),(int)1 )] - _ptr__3739[safe_add( _3734,_3768 )]);
                          ++ _3767;
                          ++ _3765;
                        }
                      }
                    }
                  }
                  if (_3763)
                  {
                    {
                      ++ _3750;
                    }
                  }
                  {}
                }
              }
              _3759 = _3761;
            }
          }
        }
      }
      else
      {
        {
          _3750 = safe_mul( mdim0,_3746 );
          _3751 = safe_mul( _3730,mdim0 );
        }
      }
    }
  }
  else
  {
    {
      if (_3748)
      {
        {
          int _3769 = (int)0;
          while ( (_3769 < _3747) )
          {
            {
              int _3770 = safe_add( _3769,(int)1 );
              while ( ((_3770 < _3747) && (((*msubi)(_3769)) == ((*msubi)(_3770)))) )
              {
                {
                  ++ _3770;
                }
              }
              int _3771 = ((*msubi)(_3769));
              int _8538 = (int)0;
              int _8539 = _3746;
              for (int _3772 = _8538; _3772 < _8539; ++_3772)
              {
                {
                  bool _3773 = false;
                  int _8540 = _3769;
                  int _8541 = _3770;
                  for (int _3774 = _8540; _3774 < _8541; ++_3774)
                  {
                    {
                      int _3775 = safe_add( safe_mul( ((*msubj)(_3774)),_3746 ),_3772 );
                      _3751 += (_ptr__3739[safe_add( safe_add( _3734,_3775 ),(int)1 )] - _ptr__3739[safe_add( _3734,_3775 )]);
                      _3773 = true;
                    }
                  }
                  if (_3773)
                  {
                    {
                      ++ _3750;
                    }
                  }
                  {}
                }
              }
              _3769 = _3770;
            }
          }
        }
      }
      else
      {
        {
          _3751 = safe_mul( _3730,mdim0 );
          _3750 = safe_mul( mdim0,_3746 );
        }
      }
    }
  }
  _3749 = (_3750 < safe_mul( mdim0,_3746 ));
  int _3776 = (int)2;
  _3726->alloc_expr(_3776,_3750,_3751,_3749);
  int _3777 = mosek::fusion::p_WorkStack::_get_impl(_3726)->ptr_base;
  int _3778 = mosek::fusion::p_WorkStack::_get_impl(_3726)->nidxs_base;
  int _8542;
  bool _8543 = _3749;
  if (_8543)
  {
    _8542 = mosek::fusion::p_WorkStack::_get_impl(_3726)->sp_base;
  }
  else
  {
    _8542 = _3726->alloci64(_3750);
  }
  int _3779 = _8542;
  int _3780 = mosek::fusion::p_WorkStack::_get_impl(_3726)->cof_base;
  int _3781 = mosek::fusion::p_WorkStack::_get_impl(_3726)->bfix_base;
  int _3782 = mosek::fusion::p_WorkStack::_get_impl(_3726)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3783 = mosek::fusion::p_WorkStack::_get_impl(_3726)->i64;
  _checked_ptr_1<long long> _ptr__3783(_3783 ? _3783->raw() : nullptr,_3783 ? _3783->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3784 = mosek::fusion::p_WorkStack::_get_impl(_3726)->f64;
  _checked_ptr_1<double> _ptr__3784(_3784 ? _3784->raw() : nullptr,_3784 ? _3784->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3785 = mosek::fusion::p_WorkStack::_get_impl(_3726)->i32;
  _checked_ptr_1<int> _ptr__3785(_3785 ? _3785->raw() : nullptr,_3785 ? _3785->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3786 = mosek::fusion::p_WorkStack::_get_impl(_3728)->i32;
  _checked_ptr_1<int> _ptr__3786(_3786 ? _3786->raw() : nullptr,_3786 ? _3786->size(0) : 0);
  _ptr__3785[_3782] = mdim0;
  _ptr__3785[safe_add( _3782,(int)1 )] = _3746;
  if (_3732)
  {
    {
      _ptr__3785[_3777] = (int)0;
      if (_3748)
      {
        {
          int _3787 = (int)0;
          int _3788 = (int)0;
          int _3789 = (int)0;
          while ( (_3789 < _3747) )
          {
            {
              int _3790 = ((*msubi)(_3789));
              int _3791 = safe_add( _3789,(int)1 );
              while ( ((_3791 < _3747) && (((*msubi)(_3791)) == ((*msubi)(_3789)))) )
              {
                {
                  ++ _3791;
                }
              }
              int _8544 = (int)0;
              int _8545 = _3746;
              for (int _3792 = _8544; _3792 < _8545; ++_3792)
              {
                {
                  bool _3793 = false;
                  double _3794 = 0.0;
                  int _3795 = _3791;
                  int _3796 = _3789;
                  int _3797 = _ptr__3786[safe_add( safe_add( _3744,_3792 ),(int)1 )];
                  int _3798 = _ptr__3786[safe_add( _3744,_3792 )];
                  while ( ((_3796 < _3795) && (_3798 < _3797)) )
                  {
                    {
                      int _3799 = _ptr__3786[safe_add( _3742,_3798 )];
                      if ((((*msubj)(_3796)) < (_ptr__3740[safe_add( _3735,_3799 )] / _3746)))
                      {
                        {
                          ++ _3796;
                        }
                      }
                      else if((((*msubj)(_3796)) > (_ptr__3740[safe_add( _3735,_3799 )] / _3746)))
                      {
                        {
                          ++ _3798;
                        }
                      }
                      else
                      {
                        {
                          _3793 = true;
                          _3794 += (_ptr__3741[safe_add( _3737,_3799 )] * ((*mval)(_3796)));
                          int _3800 = (_ptr__3739[safe_add( safe_add( _3734,_3799 ),(int)1 )] - _ptr__3739[safe_add( _3734,_3799 )]);
                          int _8546 = (int)0;
                          int _8547 = _3800;
                          for (int _3801 = _8546; _3801 < _8547; ++_3801)
                          {
                            {
                              _ptr__3783[safe_add( safe_add( _3778,_3788 ),_3801 )] = _ptr__3740[safe_add( safe_add( _3736,_ptr__3739[safe_add( _3734,_3799 )] ),_3801 )];
                            }
                          }
                          int _8548 = (int)0;
                          int _8549 = _3800;
                          for (int _3802 = _8548; _3802 < _8549; ++_3802)
                          {
                            {
                              _ptr__3784[safe_add( safe_add( _3780,_3788 ),_3802 )] = (_ptr__3741[safe_add( safe_add( _3738,_ptr__3739[safe_add( _3734,_3799 )] ),_3802 )] * ((*mval)(_3796)));
                            }
                          }
                          ++ _3796;
                          ++ _3798;
                          _3788 += _3800;
                        }
                      }
                    }
                  }
                  if (_3793)
                  {
                    {
                      _ptr__3785[safe_add( safe_add( _3777,_3787 ),(int)1 )] = _3788;
                      _ptr__3783[safe_add( _3779,_3787 )] = safe_add( safe_mul( _3790,_3746 ),_3792 );
                      _ptr__3784[safe_add( _3781,_3787 )] = _3794;
                      ++ _3787;
                    }
                  }
                  {}
                }
              }
              _3789 = _3791;
            }
          }
        }
      }
      else
      {
        {
          int _3803 = (int)0;
          int _3804 = (int)0;
          int _8550 = (int)0;
          int _8551 = mdim0;
          for (int _3805 = _8550; _3805 < _8551; ++_3805)
          {
            {
              int _8552 = (int)0;
              int _8553 = _3746;
              for (int _3806 = _8552; _3806 < _8553; ++_3806)
              {
                {
                  double _3807 = 0.0;
                  int _8554 = _ptr__3786[safe_add( _3744,_3806 )];
                  int _8555 = _ptr__3786[safe_add( safe_add( _3744,_3806 ),(int)1 )];
                  for (int _3808 = _8554; _3808 < _8555; ++_3808)
                  {
                    {
                      int _3809 = _ptr__3786[safe_add( _3742,_3808 )];
                      long long _3810 = safe_add( safe_mul( _3805,mdim1 ),(_ptr__3740[safe_add( _3735,_3809 )] / _3746) );
                      _3807 += (_ptr__3741[safe_add( _3737,_3809 )] * ((*mval)(_3810)));
                      int _3811 = (_ptr__3739[safe_add( safe_add( _3734,_3809 ),(int)1 )] - _ptr__3739[safe_add( _3734,_3809 )]);
                      int _8556 = (int)0;
                      int _8557 = _3811;
                      for (int _3812 = _8556; _3812 < _8557; ++_3812)
                      {
                        {
                          _ptr__3783[safe_add( safe_add( _3778,_3804 ),_3812 )] = _ptr__3740[safe_add( safe_add( _3736,_ptr__3739[safe_add( _3734,_3809 )] ),_3812 )];
                          _ptr__3784[safe_add( safe_add( _3780,_3804 ),_3812 )] = (_ptr__3741[safe_add( safe_add( _3738,_ptr__3739[safe_add( _3734,_3809 )] ),_3812 )] * ((*mval)(_3810)));
                        }
                      }
                      _3804 += _3811;
                    }
                  }
                  _ptr__3785[safe_add( safe_add( _3777,_3803 ),(int)1 )] = _3804;
                  _ptr__3784[safe_add( _3781,_3803 )] = _3807;
                  ++ _3803;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _ptr__3785[_3777] = (int)0;
      int _3813 = (int)0;
      int _3814 = (int)0;
      int _3815 = (int)0;
      while ( (_3813 < _3747) )
      {
        {
          int _3816 = safe_add( _3813,(int)1 );
          while ( ((_3816 < _3747) && (((*msubi)(_3813)) == ((*msubi)(_3816)))) )
          {
            {
              ++ _3816;
            }
          }
          int _3817 = ((*msubi)(_3813));
          int _8558 = (int)0;
          int _8559 = _3746;
          for (int _3818 = _8558; _3818 < _8559; ++_3818)
          {
            {
              double _3819 = 0.0;
              bool _3820 = false;
              int _8560 = _3813;
              int _8561 = _3816;
              for (int _3821 = _8560; _3821 < _8561; ++_3821)
              {
                {
                  int _3822 = safe_add( safe_mul( ((*msubj)(_3821)),_3746 ),_3818 );
                  int _3823 = (_ptr__3739[safe_add( safe_add( _3734,_3822 ),(int)1 )] - _ptr__3739[safe_add( _3734,_3822 )]);
                  int _8562 = (int)0;
                  int _8563 = _3823;
                  for (int _3824 = _8562; _3824 < _8563; ++_3824)
                  {
                    {
                      _ptr__3783[safe_add( safe_add( _3778,_3815 ),_3824 )] = _ptr__3740[safe_add( safe_add( _3736,_ptr__3739[safe_add( _3734,_3822 )] ),_3824 )];
                    }
                  }
                  int _8564 = (int)0;
                  int _8565 = _3823;
                  for (int _3825 = _8564; _3825 < _8565; ++_3825)
                  {
                    {
                      _ptr__3784[safe_add( safe_add( _3780,_3815 ),_3825 )] = (_ptr__3741[safe_add( safe_add( _3738,_ptr__3739[safe_add( _3734,_3822 )] ),_3825 )] * ((*mval)(_3821)));
                    }
                  }
                  _3819 += (_ptr__3741[safe_add( _3737,_3822 )] * ((*mval)(_3821)));
                  _3820 = true;
                  _3815 += _3823;
                }
              }
              if (_3820)
              {
                {
                  _ptr__3783[safe_add( _3779,_3814 )] = safe_add( safe_mul( _3817,_3746 ),_3818 );
                  _ptr__3784[safe_add( _3781,_3814 )] = _3819;
                  _ptr__3785[safe_add( safe_add( _3777,_3814 ),(int)1 )] = _3815;
                  ++ _3814;
                }
              }
              {}
            }
          }
          _3813 = _3816;
        }
      }
    }
  }
  _3726->peek_expr();
  if ((!_3749))
  {
    {
      _3726->popi64(_3750);
    }
  }
  {}
  _3728->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _3826,int _3827,std::shared_ptr< monty::ndarray< int,1 > > _3828){
  _checked_ptr_1<int> _ptr__3828(_3828 ? _3828->raw() : nullptr, _3828 ? _3828->size(0) : 0);
  if (((int)((_3828)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_3827 != _ptr__3828[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3826),(int)(_ptr__3828[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _3829,int _3830,std::shared_ptr< monty::ndarray< int,1 > > _3831,std::shared_ptr< monty::ndarray< int,1 > > _3832,std::shared_ptr< monty::ndarray< double,1 > > _3833,monty::rc_ptr< ::mosek::fusion::Expression > _3834){
  _checked_ptr_1<int> _ptr__3831(_3831 ? _3831->raw() : nullptr, _3831 ? _3831->size(0) : 0);
  _checked_ptr_1<int> _ptr__3832(_3832 ? _3832->raw() : nullptr, _3832 ? _3832->size(0) : 0);
  _checked_ptr_1<double> _ptr__3833(_3833 ? _3833->raw() : nullptr, _3833 ? _3833->size(0) : 0);
  if ((_3834->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _3835 = _3834->getDim((int)0);
  int _3836 = _3834->getDim((int)0);
  if (((_3829 < (int)0) || (_3830 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_3830 != _3835))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_3831)->size(0)) != (int)((_3832)->size(0))) || ((int)((_3831)->size(0)) != (int)((_3833)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _3837 = (int)((_3831)->size(0));
  int _8566 = (int)0;
  int _8567 = _3837;
  for (int _3838 = _8566; _3838 < _8567; ++_3838)
  {
    {
      if (((_ptr__3831[_3838] < (int)0) || ((_ptr__3831[_3838] >= _3829) || ((_ptr__3832[_3838] < (int)0) || (_ptr__3832[_3838] >= _3830)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  int _8568 = (int)0;
  int _8569 = (_3837 - (int)1);
  for (int _3839 = _8568; _3839 < _8569; ++_3839)
  {
    {
      if (((_ptr__3831[_3839] > _ptr__3831[safe_add( _3839,(int)1 )]) || ((_ptr__3831[_3839] == _ptr__3831[safe_add( _3839,(int)1 )]) && (_ptr__3832[_3839] >= _ptr__3832[safe_add( _3839,(int)1 )]))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
        }
      }
      {}
    }
  }
  int _8570 = (int)0;
  int _8571 = _3837;
  for (int _3840 = _8570; _3840 < _8571; ++_3840)
  {
    {
      if (((_ptr__3831[_3840] < (int)0) || ((_ptr__3831[_3840] >= _3829) || ((_ptr__3832[_3840] < (int)0) || (_ptr__3832[_3840] >= _3830)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
        }
      }
      {}
    }
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3841,    int _3842,    int _3843,    std::shared_ptr< monty::ndarray< int,1 > > _3844,    std::shared_ptr< monty::ndarray< int,1 > > _3845,    std::shared_ptr< monty::ndarray< double,1 > > _3846,    monty::rc_ptr< ::mosek::fusion::Variable > _3847){ return new mosek::fusion::ExprMulVar(_3841,_3842,_3843,_3844,_3845,_3846,_3847); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3841,    int _3842,    int _3843,    std::shared_ptr< monty::ndarray< int,1 > > _3844,    std::shared_ptr< monty::ndarray< int,1 > > _3845,    std::shared_ptr< monty::ndarray< double,1 > > _3846,    monty::rc_ptr< ::mosek::fusion::Variable > _3847) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3841,_3842,_3843,_3844,_3845,_3846,_3847); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3841,    int _3842,    int _3843,    std::shared_ptr< monty::ndarray< int,1 > > _3844,    std::shared_ptr< monty::ndarray< int,1 > > _3845,    std::shared_ptr< monty::ndarray< double,1 > > _3846,    monty::rc_ptr< ::mosek::fusion::Variable > _3847){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3844(_3844 ? _3844->raw() : nullptr, _3844 ? _3844->size(0) : 0);
    _checked_ptr_1<int> _ptr__3845(_3845 ? _3845->raw() : nullptr, _3845 ? _3845->size(0) : 0);
    _checked_ptr_1<double> _ptr__3846(_3846 ? _3846->raw() : nullptr, _3846 ? _3846->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_3841,_3842,_3843,_3844,_3845,_3846,_3847,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _3848 = _3847->getShape();
    _checked_ptr_1<int> _ptr__3848(_3848 ? _3848->raw() : nullptr,_3848 ? _3848->size(0) : 0);
    int _3849 = (int)((_3848)->size(0));
    if ((_3849 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_3841 && (_ptr__3848[(int)0] != _3843)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_3841) && (_ptr__3848[(int)1] != _3842)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_3844)->size(0)) != (int)((_3845)->size(0))) || ((int)((_3844)->size(0)) != (int)((_3846)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_3842,_3843,_3844,_3845,_3846);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _3850,    int _3851,    int _3852,    std::shared_ptr< monty::ndarray< int,1 > > _3853,    std::shared_ptr< monty::ndarray< int,1 > > _3854,    std::shared_ptr< monty::ndarray< double,1 > > _3855,    monty::rc_ptr< ::mosek::fusion::Variable > _3856,    int _3857){ return new mosek::fusion::ExprMulVar(_3850,_3851,_3852,_3853,_3854,_3855,_3856,_3857); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _3850,    int _3851,    int _3852,    std::shared_ptr< monty::ndarray< int,1 > > _3853,    std::shared_ptr< monty::ndarray< int,1 > > _3854,    std::shared_ptr< monty::ndarray< double,1 > > _3855,    monty::rc_ptr< ::mosek::fusion::Variable > _3856,    int _3857) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_3850,_3851,_3852,_3853,_3854,_3855,_3856,_3857); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _3850,    int _3851,    int _3852,    std::shared_ptr< monty::ndarray< int,1 > > _3853,    std::shared_ptr< monty::ndarray< int,1 > > _3854,    std::shared_ptr< monty::ndarray< double,1 > > _3855,    monty::rc_ptr< ::mosek::fusion::Variable > _3856,    int _3857){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__3853(_3853 ? _3853->raw() : nullptr, _3853 ? _3853->size(0) : 0);
    _checked_ptr_1<int> _ptr__3854(_3854 ? _3854->raw() : nullptr, _3854 ? _3854->size(0) : 0);
    _checked_ptr_1<double> _ptr__3855(_3855 ? _3855->raw() : nullptr, _3855 ? _3855->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_3851,_3852,_3856->getShape(),_3850));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _3850;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _3856;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _3851;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _3852;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_3853);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_3854);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_3855);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3858,monty::rc_ptr< ::mosek::fusion::WorkStack > _3859,monty::rc_ptr< ::mosek::fusion::WorkStack > _3860) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_3858,_3859,_3860); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3858,monty::rc_ptr< ::mosek::fusion::WorkStack > _3859,monty::rc_ptr< ::mosek::fusion::WorkStack > _3860){
  if (left)
  {
    {
      _pubthis->eval_left(_3858,_3859,_3860);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_3858,_3859,_3860);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3861,monty::rc_ptr< ::mosek::fusion::WorkStack > _3862,monty::rc_ptr< ::mosek::fusion::WorkStack > _3863) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_3861,_3862,_3863); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3861,monty::rc_ptr< ::mosek::fusion::WorkStack > _3862,monty::rc_ptr< ::mosek::fusion::WorkStack > _3863){
  int _3864 = mosek::fusion::p_WorkStack::_get_impl(_3862)->pi32;
  int _3865 = mosek::fusion::p_WorkStack::_get_impl(_3862)->pi64;
  int _3866 = x->numInst();
  int _3867 = _3862->alloci64(_3866);
  int _3868 = _3862->alloci64(_3866);
  int _3869 = _3862->alloci32(_3866);
  int _3870 = _3862->alloci32(_3866);
  std::shared_ptr< monty::ndarray< int,1 > > _3871 = x->getShape();
  _checked_ptr_1<int> _ptr__3871(_3871 ? _3871->raw() : nullptr,_3871 ? _3871->size(0) : 0);
  int _3872 = (int)((_3871)->size(0));
  long long _3873 = safe_mul( _ptr__3871[(int)0],_ptr__3871[(int)1] );
  int _3874 = _ptr__3871[(int)1];
  int _3875 = _ptr__3871[(int)0];
  int _3876 = _3862->alloci32(safe_add( _3875,(int)1 ));
  int _3877 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _3878 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3878(_3878 ? _3878->raw() : nullptr,_3878 ? _3878->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3879 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3879(_3879 ? _3879->raw() : nullptr,_3879 ? _3879->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3880 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3880(_3880 ? _3880->raw() : nullptr,_3880 ? _3880->size(0) : 0);
  int _3881 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3882 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _3883 = ((_3877 / _3881) == _3882);
  int _3884 = _3862->alloci32(_3877);
  int _3885 = _3862->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3886 = mosek::fusion::p_WorkStack::_get_impl(_3862)->i32;
  _checked_ptr_1<int> _ptr__3886(_3886 ? _3886->raw() : nullptr,_3886 ? _3886->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3887 = mosek::fusion::p_WorkStack::_get_impl(_3862)->i64;
  _checked_ptr_1<long long> _ptr__3887(_3887 ? _3887->raw() : nullptr,_3887 ? _3887->size(0) : 0);
  int _3888 = (int)0;
  int _3889 = (int)0;
  x->inst(_3868,_3887,_3867,_3887);
  if (_3883)
  {
    {
      int _3890 = (int)0;
      if ((_3866 > (int)0))
      {
        {
          _3890 = (int)1;
          if ((_3875 > (int)1))
          {
            {
              if ((_3874 == (int)1))
              {
                {
                  int _8572 = (int)1;
                  int _8573 = _3866;
                  for (int _3891 = _8572; _3891 < _8573; ++_3891)
                  {
                    {
                      if ((_ptr__3887[safe_add( _3868,_3891 )] > _ptr__3887[(safe_add( _3868,_3891 ) - (int)1)]))
                      {
                        {
                          ++ _3890;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _8574 = (int)1;
                  int _8575 = _3866;
                  for (int _3892 = _8574; _3892 < _8575; ++_3892)
                  {
                    {
                      if (((_ptr__3887[safe_add( _3868,_3892 )] / _3874) > (_ptr__3887[(safe_add( _3868,_3892 ) - (int)1)] / _3874)))
                      {
                        {
                          ++ _3890;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _3889 = safe_mul( _3890,_3882 );
      _3888 = safe_mul( _3866,_3882 );
      bool _3893 = (_3890 < _3875);
      int _3894 = _3861->alloci32(safe_add( _3889,(int)1 ));
      int _8576;
      bool _8577 = _3893;
      if (_8577)
      {
        _8576 = (int)1;
      }
      else
      {
        _8576 = (int)0;
      }
      _3861->pushi32(_8576);
      _3861->pushi32(_3888);
      _3861->pushi32(_3889);
      _3861->pushi32(_3875);
      _3861->pushi32(_3882);
      _3861->pushi32((int)2);
      int _3895 = _3861->alloci64(_3888);
      int _3896 = _3861->alloci64(_3889);
      int _3897 = _3861->allocf64(_3888);
      int _3898 = _3861->allocf64(_3889);
      std::shared_ptr< monty::ndarray< int,1 > > _3899 = mosek::fusion::p_WorkStack::_get_impl(_3861)->i32;
      _checked_ptr_1<int> _ptr__3899(_3899 ? _3899->raw() : nullptr,_3899 ? _3899->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3900 = mosek::fusion::p_WorkStack::_get_impl(_3861)->i64;
      _checked_ptr_1<long long> _ptr__3900(_3900 ? _3900->raw() : nullptr,_3900 ? _3900->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3901 = mosek::fusion::p_WorkStack::_get_impl(_3861)->f64;
      _checked_ptr_1<double> _ptr__3901(_3901 ? _3901->raw() : nullptr,_3901 ? _3901->size(0) : 0);
      {
        int _3902 = (int)0;
        int _3903 = (int)0;
        int _3904 = (int)0;
        _ptr__3899[_3894] = (int)0;
        while ( (_3902 < _3866) )
        {
          {
            int _3905 = _3902;
            ++ _3902;
            while ( ((_3902 < _3866) && ((_ptr__3887[safe_add( _3868,_3902 )] / _3874) == (_ptr__3887[safe_add( _3868,_3905 )] / _3874))) )
            {
              {
                ++ _3902;
              }
            }
            long long _3906 = (_ptr__3887[safe_add( _3868,_3905 )] / _3874);
            int _8578 = (int)0;
            int _8579 = _3882;
            for (int _3907 = _8578; _3907 < _8579; ++_3907)
            {
              {
                int _8580 = _3905;
                int _8581 = _3902;
                for (int _3908 = _8580; _3908 < _8581; ++_3908)
                {
                  {
                    long long _3909 = (_ptr__3887[safe_add( _3868,_3908 )] % _3874);
                    _ptr__3900[safe_add( _3895,_3904 )] = _ptr__3887[safe_add( _3867,_3908 )];
                    _ptr__3901[safe_add( _3897,_3904 )] = _ptr__3880[safe_add( safe_mul( _3909,_3882 ),_3907 )];
                    ++ _3904;
                  }
                }
                _ptr__3899[safe_add( safe_add( _3894,_3903 ),(int)1 )] = _3904;
                _ptr__3901[safe_add( _3898,_3903 )] = 0.0;
                _ptr__3900[safe_add( _3896,_3903 )] = safe_add( safe_mul( _3906,_3882 ),_3907 );
                ++ _3903;
              }
            }
          }
        }
      }
      if ((!_3893))
      {
        {
          _3861->popi64(_3889);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_3882 == (int)1))
        {
          {
            int _8582 = (int)0;
            int _8583 = _3877;
            for (int _3910 = _8582; _3910 < _8583; ++_3910)
            {
              {
                _ptr__3886[safe_add( _3884,_3910 )] = _3910;
              }
            }
            _ptr__3886[_3885] = (int)0;
            _ptr__3886[safe_add( _3885,(int)1 )] = _3877;
          }
        }
        else
        {
          {
            _ptr__3886[_3885] = (int)0;
            int _8584 = (int)0;
            int _8585 = safe_add( _3882,(int)1 );
            for (int _3911 = _8584; _3911 < _8585; ++_3911)
            {
              {
                _ptr__3886[safe_add( _3885,_3911 )] = (int)0;
              }
            }
            int _8586 = (int)0;
            int _8587 = _3877;
            for (int _3912 = _8586; _3912 < _8587; ++_3912)
            {
              {
                ++ _ptr__3886[safe_add( safe_add( _3885,_ptr__3879[_3912] ),(int)1 )];
              }
            }
            int _8588 = (int)0;
            int _8589 = mdimj;
            for (int _3913 = _8588; _3913 < _8589; ++_3913)
            {
              {
                _ptr__3886[safe_add( safe_add( _3885,_3913 ),(int)1 )] += _ptr__3886[safe_add( _3885,_3913 )];
              }
            }
            int _8590 = (int)0;
            int _8591 = _3877;
            for (int _3914 = _8590; _3914 < _8591; ++_3914)
            {
              {
                _ptr__3886[safe_add( _3884,_ptr__3886[safe_add( _3885,_ptr__3879[_3914] )] )] = _3914;
                ++ _ptr__3886[safe_add( _3885,_ptr__3879[_3914] )];
              }
            }
            int _8592 = (int)0;
            int _8593 = _3882;
            for (int _3915 = _8592; _3915 < _8593; ++_3915)
            {
              {
                _ptr__3886[(safe_add( _3885,_3882 ) - _3915)] = _ptr__3886[((safe_add( _3885,_3882 ) - _3915) - (int)1)];
              }
            }
            _ptr__3886[_3885] = (int)0;
          }
        }
      }
      if (((_3866 / _3875) == _3874))
      {
        {
          int _3916 = (int)0;
          {
            int _3917 = (int)0;
            while ( (_3917 < _3877) )
            {
              {
                ++ _3917;
                while ( ((_3917 < _3877) && (_ptr__3879[_ptr__3886[(safe_add( _3884,_3917 ) - (int)1)]] == _ptr__3879[_ptr__3886[safe_add( _3884,_3917 )]])) )
                {
                  {
                    ++ _3917;
                  }
                }
                ++ _3916;
              }
            }
          }
          _3889 = safe_mul( _3916,_3875 );
          _3888 = safe_mul( _3877,_3875 );
          bool _3918 = (_3916 < _3882);
          int _3919 = _3861->alloci32(safe_add( _3889,(int)1 ));
          int _8594;
          bool _8595 = _3918;
          if (_8595)
          {
            _8594 = (int)1;
          }
          else
          {
            _8594 = (int)0;
          }
          _3861->pushi32(_8594);
          _3861->pushi32(_3888);
          _3861->pushi32(_3889);
          _3861->pushi32(_3875);
          _3861->pushi32(_3882);
          _3861->pushi32((int)2);
          int _3920 = _3861->alloci64(_3888);
          int _3921 = _3861->alloci64(_3889);
          int _3922 = _3861->allocf64(_3888);
          int _3923 = _3861->allocf64(_3889);
          std::shared_ptr< monty::ndarray< int,1 > > _3924 = mosek::fusion::p_WorkStack::_get_impl(_3861)->i32;
          _checked_ptr_1<int> _ptr__3924(_3924 ? _3924->raw() : nullptr,_3924 ? _3924->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3925 = mosek::fusion::p_WorkStack::_get_impl(_3861)->i64;
          _checked_ptr_1<long long> _ptr__3925(_3925 ? _3925->raw() : nullptr,_3925 ? _3925->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3926 = mosek::fusion::p_WorkStack::_get_impl(_3861)->f64;
          _checked_ptr_1<double> _ptr__3926(_3926 ? _3926->raw() : nullptr,_3926 ? _3926->size(0) : 0);
          _ptr__3924[_3919] = (int)0;
          int _3927 = (int)0;
          int _3928 = (int)0;
          int _8596 = (int)0;
          int _8597 = _3875;
          for (int _3929 = _8596; _3929 < _8597; ++_3929)
          {
            {
              int _3930 = (int)0;
              while ( (_3930 < _3877) )
              {
                {
                  int _3931 = _3930;
                  ++ _3930;
                  while ( ((_3930 < _3877) && (_ptr__3879[_ptr__3886[safe_add( _3884,_3931 )]] == _ptr__3879[_ptr__3886[safe_add( _3884,_3930 )]])) )
                  {
                    {
                      ++ _3930;
                    }
                  }
                  int _3932 = _ptr__3879[_ptr__3886[safe_add( _3884,_3931 )]];
                  int _8598 = _3931;
                  int _8599 = _3930;
                  for (int _3933 = _8598; _3933 < _8599; ++_3933)
                  {
                    {
                      int _3934 = _ptr__3878[_ptr__3886[safe_add( _3884,_3933 )]];
                      _ptr__3925[safe_add( _3920,_3928 )] = _ptr__3887[safe_add( safe_add( _3867,safe_mul( _3929,_3874 ) ),_3934 )];
                      _ptr__3926[safe_add( _3922,_3928 )] = _ptr__3880[_ptr__3886[safe_add( _3884,_3933 )]];
                      ++ _3928;
                    }
                  }
                  _ptr__3926[safe_add( _3923,_3927 )] = 0.0;
                  _ptr__3925[safe_add( _3921,_3927 )] = safe_add( safe_mul( _3929,_3882 ),_3932 );
                  _ptr__3924[safe_add( safe_add( _3919,_3927 ),(int)1 )] = _3928;
                  ++ _3927;
                }
              }
            }
          }
          if ((!_3918))
          {
            {
              _3861->popi64(_3889);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _8600 = (int)0;
          int _8601 = safe_add( _3875,(int)1 );
          for (int _3935 = _8600; _3935 < _8601; ++_3935)
          {
            {
              _ptr__3886[safe_add( _3876,_3935 )] = (int)0;
            }
          }
          if ((_3872 == (int)1))
          {
            {
              int _8602 = (int)0;
              int _8603 = _3866;
              for (int _3936 = _8602; _3936 < _8603; ++_3936)
              {
                {
                  _ptr__3886[safe_add( _3869,_3936 )] = (int)0;
                }
              }
              int _8604 = (int)0;
              int _8605 = _3866;
              for (int _3937 = _8604; _3937 < _8605; ++_3937)
              {
                {
                  _ptr__3886[safe_add( _3870,_3937 )] = (int)_ptr__3887[safe_add( _3868,_3937 )];
                }
              }
              _ptr__3886[_3876] = (int)0;
              _ptr__3886[safe_add( _3876,(int)1 )] = _3866;
            }
          }
          else
          {
            {
              int _8606 = (int)0;
              int _8607 = _3866;
              for (int _3938 = _8606; _3938 < _8607; ++_3938)
              {
                {
                  _ptr__3886[safe_add( _3869,_3938 )] = (int)(_ptr__3887[safe_add( _3868,_3938 )] / _ptr__3871[(int)1]);
                }
              }
              int _8608 = (int)0;
              int _8609 = _3866;
              for (int _3939 = _8608; _3939 < _8609; ++_3939)
              {
                {
                  _ptr__3886[safe_add( _3870,_3939 )] = (int)(_ptr__3887[safe_add( _3868,_3939 )] % _ptr__3871[(int)1]);
                }
              }
              _ptr__3886[_3876] = (int)0;
              int _8610 = (int)0;
              int _8611 = _3866;
              for (int _3940 = _8610; _3940 < _8611; ++_3940)
              {
                {
                  ++ _ptr__3886[safe_add( safe_add( _3876,_ptr__3886[safe_add( _3869,_3940 )] ),(int)1 )];
                }
              }
              int _8612 = (int)0;
              int _8613 = _3875;
              for (int _3941 = _8612; _3941 < _8613; ++_3941)
              {
                {
                  _ptr__3886[safe_add( safe_add( _3876,_3941 ),(int)1 )] += _ptr__3886[safe_add( _3876,_3941 )];
                }
              }
            }
          }
          int _8614 = (int)0;
          int _8615 = _3875;
          for (int _3942 = _8614; _3942 < _8615; ++_3942)
          {
            {
              int _8616 = (int)0;
              int _8617 = mdimj;
              for (int _3943 = _8616; _3943 < _8617; ++_3943)
              {
                {
                  int _3944 = (int)0;
                  int _3945 = _ptr__3886[safe_add( safe_add( _3876,_3942 ),(int)1 )];
                  int _3946 = _ptr__3886[safe_add( safe_add( _3885,_3943 ),(int)1 )];
                  int _3947 = _ptr__3886[safe_add( _3876,_3942 )];
                  int _3948 = _ptr__3886[safe_add( _3885,_3943 )];
                  while ( ((_3948 < _3946) && (_3947 < _3945)) )
                  {
                    {
                      if ((_ptr__3878[_ptr__3886[safe_add( _3884,_3948 )]] < _ptr__3886[safe_add( _3870,_3947 )]))
                      {
                        {
                          ++ _3948;
                        }
                      }
                      else if((_ptr__3878[_ptr__3886[safe_add( _3884,_3948 )]] > _ptr__3886[safe_add( _3870,_3947 )]))
                      {
                        {
                          ++ _3947;
                        }
                      }
                      else
                      {
                        {
                          ++ _3944;
                          ++ _3948;
                          ++ _3947;
                        }
                      }
                    }
                  }
                  if ((_3944 > (int)0))
                  {
                    {
                      _3888 += _3944;
                      ++ _3889;
                    }
                  }
                  {}
                }
              }
            }
          }
          int _3949 = _3861->alloci32(safe_add( _3889,(int)1 ));
          bool _8618;
          bool _8619 = (_3889 < safe_mul( _3874,mdimi ));
          if (_8619)
          {
            _8618 = true;
          }
          else
          {
            _8618 = false;
          }
          bool _3950 = _8618;
          int _8620;
          bool _8621 = _3950;
          if (_8621)
          {
            _8620 = (int)1;
          }
          else
          {
            _8620 = (int)0;
          }
          _3861->pushi32(_8620);
          _3861->pushi32(_3888);
          _3861->pushi32(_3889);
          _3861->pushi32(_3875);
          _3861->pushi32(mdimj);
          _3861->pushi32((int)2);
          int _3951 = _3861->alloci64(_3888);
          int _3952 = _3861->alloci64(_3889);
          int _3953 = _3861->allocf64(_3888);
          int _3954 = _3861->allocf64(_3889);
          std::shared_ptr< monty::ndarray< int,1 > > _3955 = mosek::fusion::p_WorkStack::_get_impl(_3861)->i32;
          _checked_ptr_1<int> _ptr__3955(_3955 ? _3955->raw() : nullptr,_3955 ? _3955->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _3956 = mosek::fusion::p_WorkStack::_get_impl(_3861)->i64;
          _checked_ptr_1<long long> _ptr__3956(_3956 ? _3956->raw() : nullptr,_3956 ? _3956->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _3957 = mosek::fusion::p_WorkStack::_get_impl(_3861)->f64;
          _checked_ptr_1<double> _ptr__3957(_3957 ? _3957->raw() : nullptr,_3957 ? _3957->size(0) : 0);
          {
            int _3958 = (int)0;
            int _3959 = (int)0;
            int _3960 = (int)0;
            _ptr__3955[_3949] = (int)0;
            int _8622 = (int)0;
            int _8623 = _3889;
            for (int _3961 = _8622; _3961 < _8623; ++_3961)
            {
              {
                _ptr__3957[safe_add( _3954,_3961 )] = 0.0;
              }
            }
            int _8624 = (int)0;
            int _8625 = _3875;
            for (int _3962 = _8624; _3962 < _8625; ++_3962)
            {
              {
                int _8626 = (int)0;
                int _8627 = mdimj;
                for (int _3963 = _8626; _3963 < _8627; ++_3963)
                {
                  {
                    int _3964 = (int)0;
                    int _3965 = _ptr__3886[safe_add( safe_add( _3876,_3962 ),(int)1 )];
                    int _3966 = _ptr__3886[safe_add( safe_add( _3885,_3963 ),(int)1 )];
                    int _3967 = _ptr__3886[safe_add( _3876,_3962 )];
                    int _3968 = _ptr__3886[safe_add( _3885,_3963 )];
                    while ( ((_3968 < _3966) && (_3967 < _3965)) )
                    {
                      {
                        if ((_ptr__3878[_ptr__3886[safe_add( _3884,_3968 )]] < _ptr__3886[safe_add( _3870,_3967 )]))
                        {
                          {
                            ++ _3968;
                          }
                        }
                        else if((_ptr__3878[_ptr__3886[safe_add( _3884,_3968 )]] > _ptr__3886[safe_add( _3870,_3967 )]))
                        {
                          {
                            ++ _3967;
                          }
                        }
                        else
                        {
                          {
                            _ptr__3956[safe_add( _3951,_3960 )] = _ptr__3887[safe_add( _3867,_3967 )];
                            _ptr__3957[safe_add( _3953,_3960 )] = _ptr__3880[_ptr__3886[safe_add( _3884,_3968 )]];
                            ++ _3964;
                            ++ _3960;
                            ++ _3968;
                            ++ _3967;
                          }
                        }
                      }
                    }
                    if ((_3964 > (int)0))
                    {
                      {
                        _ptr__3955[safe_add( safe_add( _3949,_3959 ),(int)1 )] = _3960;
                        _ptr__3956[safe_add( _3952,_3959 )] = _3958;
                        ++ _3959;
                      }
                    }
                    {}
                    ++ _3958;
                  }
                }
              }
            }
          }
          if ((!_3950))
          {
            {
              _3861->popi64(_3889);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_3862)->pi32 = _3864;
  mosek::fusion::p_WorkStack::_get_impl(_3862)->pi64 = _3865;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3969,monty::rc_ptr< ::mosek::fusion::WorkStack > _3970,monty::rc_ptr< ::mosek::fusion::WorkStack > _3971) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_3969,_3970,_3971); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3969,monty::rc_ptr< ::mosek::fusion::WorkStack > _3970,monty::rc_ptr< ::mosek::fusion::WorkStack > _3971){
  int _3972 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _3973 = x->getShape();
  _checked_ptr_1<int> _ptr__3973(_3973 ? _3973->raw() : nullptr,_3973 ? _3973->size(0) : 0);
  int _3974 = (int)((_3973)->size(0));
  int _3975 = _3971->alloci64(_3972);
  int _3976 = _3971->alloci64(_3972);
  int _3977 = _3971->alloci32(_3972);
  int _3978 = _3971->alloci32(_3972);
  int _3979 = _3971->alloci32(_3972);
  int _3980 = _3971->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3981 = x->getShape();
  _checked_ptr_1<int> _ptr__3981(_3981 ? _3981->raw() : nullptr,_3981 ? _3981->size(0) : 0);
  int _3982 = (int)((_3981)->size(0));
  int _8628;
  bool _8629 = (_3982 == (int)1);
  if (_8629)
  {
    _8628 = (int)1;
  }
  else
  {
    _8628 = _ptr__3981[(int)1];
  }
  int _3983 = _8628;
  int _3984 = _ptr__3981[(int)0];
  int _3985 = _3971->alloci32(safe_add( _3983,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3986 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__3986(_3986 ? _3986->raw() : nullptr,_3986 ? _3986->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3987 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__3987(_3987 ? _3987->raw() : nullptr,_3987 ? _3987->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3988 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__3988(_3988 ? _3988->raw() : nullptr,_3988 ? _3988->size(0) : 0);
  int _3989 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _3990 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _3991 = (int)0;
  int _3992 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _3993 = mosek::fusion::p_WorkStack::_get_impl(_3971)->i32;
  _checked_ptr_1<int> _ptr__3993(_3993 ? _3993->raw() : nullptr,_3993 ? _3993->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3994 = mosek::fusion::p_WorkStack::_get_impl(_3971)->i64;
  _checked_ptr_1<long long> _ptr__3994(_3994 ? _3994->raw() : nullptr,_3994 ? _3994->size(0) : 0);
  x->inst(_3976,_3994,_3975,_3994);
  {
    int _8630 = (int)0;
    int _8631 = safe_add( _3989,(int)1 );
    for (int _3995 = _8630; _3995 < _8631; ++_3995)
    {
      {
        _ptr__3993[safe_add( _3980,_3995 )] = (int)0;
      }
    }
    int _8632 = (int)0;
    int _8633 = (int)((_3986)->size(0));
    for (int _3996 = _8632; _3996 < _8633; ++_3996)
    {
      {
        ++ _ptr__3993[safe_add( safe_add( _3980,_ptr__3986[_3996] ),(int)1 )];
      }
    }
    int _8634 = (int)0;
    int _8635 = _3989;
    for (int _3997 = _8634; _3997 < _8635; ++_3997)
    {
      {
        _ptr__3993[safe_add( safe_add( _3980,_3997 ),(int)1 )] += _ptr__3993[safe_add( _3980,_3997 )];
      }
    }
    if ((_3982 == (int)1))
    {
      {
        int _8636 = (int)0;
        int _8637 = _3972;
        for (int _3998 = _8636; _3998 < _8637; ++_3998)
        {
          {
            _ptr__3993[safe_add( _3977,_3998 )] = (int)_ptr__3994[safe_add( _3976,_3998 )];
          }
        }
        int _8638 = (int)0;
        int _8639 = _3972;
        for (int _3999 = _8638; _3999 < _8639; ++_3999)
        {
          {
            _ptr__3993[safe_add( _3978,_3999 )] = (int)0;
          }
        }
      }
    }
    else
    {
      {
        int _8640 = (int)0;
        int _8641 = _3972;
        for (int _4000 = _8640; _4000 < _8641; ++_4000)
        {
          {
            _ptr__3993[safe_add( _3977,_4000 )] = (int)(_ptr__3994[safe_add( _3976,_4000 )] / _3983);
          }
        }
        int _8642 = (int)0;
        int _8643 = _3972;
        for (int _4001 = _8642; _4001 < _8643; ++_4001)
        {
          {
            _ptr__3993[safe_add( _3978,_4001 )] = (int)(_ptr__3994[safe_add( _3976,_4001 )] % _3983);
          }
        }
      }
    }
    if ((_3982 > (int)1))
    {
      {
        int _8644 = (int)0;
        int _8645 = safe_add( _3983,(int)1 );
        for (int _4002 = _8644; _4002 < _8645; ++_4002)
        {
          {
            _ptr__3993[safe_add( _3985,_4002 )] = (int)0;
          }
        }
        int _8646 = (int)0;
        int _8647 = _3972;
        for (int _4003 = _8646; _4003 < _8647; ++_4003)
        {
          {
            ++ _ptr__3993[safe_add( safe_add( _3985,_ptr__3993[safe_add( _3978,_4003 )] ),(int)1 )];
          }
        }
        int _8648 = (int)0;
        int _8649 = _3983;
        for (int _4004 = _8648; _4004 < _8649; ++_4004)
        {
          {
            _ptr__3993[safe_add( safe_add( _3985,_4004 ),(int)1 )] += _ptr__3993[safe_add( _3985,_4004 )];
          }
        }
        int _8650 = (int)0;
        int _8651 = _3972;
        for (int _4005 = _8650; _4005 < _8651; ++_4005)
        {
          {
            _ptr__3993[safe_add( _3979,_ptr__3993[safe_add( _3985,_ptr__3993[safe_add( _3978,_4005 )] )] )] = _4005;
            ++ _ptr__3993[safe_add( _3985,_ptr__3993[safe_add( _3978,_4005 )] )];
          }
        }
        int _8652 = (int)0;
        int _8653 = _3983;
        for (int _4006 = _8652; _4006 < _8653; ++_4006)
        {
          {
            _ptr__3993[(safe_add( _3985,_3983 ) - _4006)] = _ptr__3993[((safe_add( _3985,_3983 ) - _4006) - (int)1)];
          }
        }
        _ptr__3993[_3985] = (int)0;
      }
    }
    else
    {
      {
        _ptr__3993[_3985] = (int)0;
        _ptr__3993[safe_add( _3985,(int)1 )] = _3972;
        int _8654 = (int)0;
        int _8655 = _3972;
        for (int _4007 = _8654; _4007 < _8655; ++_4007)
        {
          {
            _ptr__3993[safe_add( _3979,_4007 )] = _4007;
          }
        }
      }
    }
    int _8656 = (int)0;
    int _8657 = _3989;
    for (int _4008 = _8656; _4008 < _8657; ++_4008)
    {
      {
        int _8658 = (int)0;
        int _8659 = _3983;
        for (int _4009 = _8658; _4009 < _8659; ++_4009)
        {
          {
            int _4010 = (int)0;
            int _4011 = _ptr__3993[safe_add( safe_add( _3985,_4009 ),(int)1 )];
            int _4012 = _ptr__3993[safe_add( safe_add( _3980,_4008 ),(int)1 )];
            int _4013 = _ptr__3993[safe_add( _3985,_4009 )];
            int _4014 = _ptr__3993[safe_add( _3980,_4008 )];
            while ( ((_4014 < _4012) && (_4013 < _4011)) )
            {
              {
                if ((_ptr__3987[_4014] < _ptr__3993[safe_add( _3977,_ptr__3993[safe_add( _3979,_4013 )] )]))
                {
                  {
                    ++ _4014;
                  }
                }
                else if((_ptr__3987[_4014] > _ptr__3993[safe_add( _3977,_ptr__3993[safe_add( _3979,_4013 )] )]))
                {
                  {
                    ++ _4013;
                  }
                }
                else
                {
                  {
                    ++ _4010;
                    ++ _4014;
                    ++ _4013;
                  }
                }
              }
            }
            if ((_4010 > (int)0))
            {
              {
                _3991 += _4010;
                ++ _3992;
              }
            }
            {}
          }
        }
      }
    }
  }
  bool _8660;
  bool _8661 = (_3992 < safe_mul( _3983,_3989 ));
  if (_8661)
  {
    _8660 = true;
  }
  else
  {
    _8660 = false;
  }
  bool _4015 = _8660;
  int _4016 = _3982;
  _3969->alloc_expr(_4016,_3992,_3991,_4015);
  int _4017 = mosek::fusion::p_WorkStack::_get_impl(_3969)->ptr_base;
  int _4018 = mosek::fusion::p_WorkStack::_get_impl(_3969)->shape_base;
  int _4019 = mosek::fusion::p_WorkStack::_get_impl(_3969)->nidxs_base;
  int _8662;
  bool _8663 = _4015;
  if (_8663)
  {
    _8662 = mosek::fusion::p_WorkStack::_get_impl(_3969)->sp_base;
  }
  else
  {
    _8662 = _3969->alloci64(_3992);
  }
  int _4020 = _8662;
  int _4021 = mosek::fusion::p_WorkStack::_get_impl(_3969)->cof_base;
  int _4022 = mosek::fusion::p_WorkStack::_get_impl(_3969)->bfix_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4023 = mosek::fusion::p_WorkStack::_get_impl(_3969)->i32;
  _checked_ptr_1<int> _ptr__4023(_4023 ? _4023->raw() : nullptr,_4023 ? _4023->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4024 = mosek::fusion::p_WorkStack::_get_impl(_3969)->i64;
  _checked_ptr_1<long long> _ptr__4024(_4024 ? _4024->raw() : nullptr,_4024 ? _4024->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4025 = mosek::fusion::p_WorkStack::_get_impl(_3969)->f64;
  _checked_ptr_1<double> _ptr__4025(_4025 ? _4025->raw() : nullptr,_4025 ? _4025->size(0) : 0);
  _ptr__4023[_4018] = _3989;
  if ((_3982 > (int)1))
  {
    {
      _ptr__4023[safe_add( _4018,(int)1 )] = _3983;
    }
  }
  {}
  {
    int _4026 = (int)0;
    int _4027 = (int)0;
    int _4028 = (int)0;
    _ptr__4023[_4017] = (int)0;
    int _8664 = (int)0;
    int _8665 = _3992;
    for (int _4029 = _8664; _4029 < _8665; ++_4029)
    {
      {
        _ptr__4025[safe_add( _4022,_4029 )] = 0.0;
      }
    }
    int _8666 = (int)0;
    int _8667 = _3989;
    for (int _4030 = _8666; _4030 < _8667; ++_4030)
    {
      {
        int _8668 = (int)0;
        int _8669 = _3983;
        for (int _4031 = _8668; _4031 < _8669; ++_4031)
        {
          {
            int _4032 = (int)0;
            int _4033 = _ptr__3993[safe_add( safe_add( _3985,_4031 ),(int)1 )];
            int _4034 = _ptr__3993[safe_add( safe_add( _3980,_4030 ),(int)1 )];
            int _4035 = _ptr__3993[safe_add( _3985,_4031 )];
            int _4036 = _ptr__3993[safe_add( _3980,_4030 )];
            while ( ((_4036 < _4034) && (_4035 < _4033)) )
            {
              {
                if ((_ptr__3987[_4036] < _ptr__3993[safe_add( _3977,_ptr__3993[safe_add( _3979,_4035 )] )]))
                {
                  {
                    ++ _4036;
                  }
                }
                else if((_ptr__3987[_4036] > _ptr__3993[safe_add( _3977,_ptr__3993[safe_add( _3979,_4035 )] )]))
                {
                  {
                    ++ _4035;
                  }
                }
                else
                {
                  {
                    _ptr__4024[safe_add( _4019,_4028 )] = _ptr__3994[safe_add( _3975,_ptr__3993[safe_add( _3979,_4035 )] )];
                    _ptr__4025[safe_add( _4021,_4028 )] = _ptr__3988[_4036];
                    ++ _4032;
                    ++ _4028;
                    ++ _4036;
                    ++ _4035;
                  }
                }
              }
            }
            if ((_4032 > (int)0))
            {
              {
                _ptr__4023[safe_add( safe_add( _4017,_4027 ),(int)1 )] = _4028;
                _ptr__4024[safe_add( _4020,_4027 )] = _4026;
                ++ _4027;
              }
            }
            {}
            ++ _4026;
          }
        }
      }
    }
  }
  if ((!_4015))
  {
    {
      _3969->popi64(_3992);
    }
  }
  {}
  _3971->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _4037,int _4038,std::shared_ptr< monty::ndarray< int,1 > > _4039,std::shared_ptr< monty::ndarray< int,1 > > _4040,std::shared_ptr< monty::ndarray< double,1 > > _4041){
  _checked_ptr_1<int> _ptr__4039(_4039 ? _4039->raw() : nullptr, _4039 ? _4039->size(0) : 0);
  _checked_ptr_1<int> _ptr__4040(_4040 ? _4040->raw() : nullptr, _4040 ? _4040->size(0) : 0);
  _checked_ptr_1<double> _ptr__4041(_4041 ? _4041->raw() : nullptr, _4041 ? _4041->size(0) : 0);
  bool _4042 = true;
  {
    int _8670 = (int)0;
    int _8671 = (int)((_4039)->size(0));
    for (int _4043 = _8670; _4043 < _8671; ++_4043)
    {
      {
        if (((_ptr__4039[_4043] < (int)0) || ((_ptr__4039[_4043] >= _4037) || ((_ptr__4040[_4043] < (int)0) || (_ptr__4040[_4043] >= _4038)))))
        {
          {
            _4042 = false;
          }
        }
        {}
      }
    }
    int _8672 = (int)1;
    int _8673 = (int)((_4039)->size(0));
    for (int _4044 = _8672; _4044 < _8673; ++_4044)
    {
      {
        if (((_ptr__4039[(_4044 - (int)1)] > _ptr__4039[_4044]) || ((_ptr__4039[(_4044 - (int)1)] == _ptr__4039[_4044]) && (_ptr__4040[(_4044 - (int)1)] >= _ptr__4040[_4044]))))
        {
          {
            _4042 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_4042))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _4045,int _4046,std::shared_ptr< monty::ndarray< int,1 > > _4047,bool _4048){
  _checked_ptr_1<int> _ptr__4047(_4047 ? _4047->raw() : nullptr, _4047 ? _4047->size(0) : 0);
  if (_4048)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4045),(int)(_ptr__4047[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4047[(int)0]),(int)(_4046)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4049,    int _4050,    std::shared_ptr< monty::ndarray< int,1 > > _4051,    std::shared_ptr< monty::ndarray< int,1 > > _4052,    std::shared_ptr< monty::ndarray< double,1 > > _4053,    monty::rc_ptr< ::mosek::fusion::Variable > _4054){ return new mosek::fusion::ExprMulScalarVar(_4049,_4050,_4051,_4052,_4053,_4054); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4049,    int _4050,    std::shared_ptr< monty::ndarray< int,1 > > _4051,    std::shared_ptr< monty::ndarray< int,1 > > _4052,    std::shared_ptr< monty::ndarray< double,1 > > _4053,    monty::rc_ptr< ::mosek::fusion::Variable > _4054) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4049,_4050,_4051,_4052,_4053,_4054); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4049,    int _4050,    std::shared_ptr< monty::ndarray< int,1 > > _4051,    std::shared_ptr< monty::ndarray< int,1 > > _4052,    std::shared_ptr< monty::ndarray< double,1 > > _4053,    monty::rc_ptr< ::mosek::fusion::Variable > _4054){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4051(_4051 ? _4051->raw() : nullptr, _4051 ? _4051->size(0) : 0);
    _checked_ptr_1<int> _ptr__4052(_4052 ? _4052->raw() : nullptr, _4052 ? _4052->size(0) : 0);
    _checked_ptr_1<double> _ptr__4053(_4053 ? _4053->raw() : nullptr, _4053 ? _4053->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_4049,_4050,::mosek::fusion::Utils::Tools::arraycopy(_4051),::mosek::fusion::Utils::Tools::arraycopy(_4052),::mosek::fusion::Utils::Tools::arraycopy(_4053),_4054,(int)1);
    if ((_4054->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_4049 < (int)0) || ((_4050 < (int)0) || (((int)((_4051)->size(0)) != (int)((_4052)->size(0))) || ((int)((_4051)->size(0)) != (int)((_4053)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    int _8674 = (int)0;
    int _8675 = (int)((_4051)->size(0));
    for (int _4055 = _8674; _4055 < _8675; ++_4055)
    {
      {
        if (((_ptr__4051[_4055] < (int)0) || ((_ptr__4051[_4055] >= _4049) || ((_ptr__4052[_4055] < (int)0) || (_ptr__4052[_4055] >= _4050)))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
          }
        }
        {}
      }
    }
    int _8676 = (int)1;
    int _8677 = (int)((_4051)->size(0));
    for (int _4056 = _8676; _4056 < _8677; ++_4056)
    {
      {
        if (((_ptr__4051[_4056] < _ptr__4051[(_4056 - (int)1)]) || ((_ptr__4051[_4056] == _ptr__4051[(_4056 - (int)1)]) && (_ptr__4052[_4056] <= _ptr__4052[(_4056 - (int)1)]))))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _4057,    int _4058,    std::shared_ptr< monty::ndarray< int,1 > > _4059,    std::shared_ptr< monty::ndarray< int,1 > > _4060,    std::shared_ptr< monty::ndarray< double,1 > > _4061,    monty::rc_ptr< ::mosek::fusion::Variable > _4062,    int _4063){ return new mosek::fusion::ExprMulScalarVar(_4057,_4058,_4059,_4060,_4061,_4062,_4063); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _4057,    int _4058,    std::shared_ptr< monty::ndarray< int,1 > > _4059,    std::shared_ptr< monty::ndarray< int,1 > > _4060,    std::shared_ptr< monty::ndarray< double,1 > > _4061,    monty::rc_ptr< ::mosek::fusion::Variable > _4062,    int _4063) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_4057,_4058,_4059,_4060,_4061,_4062,_4063); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _4057,    int _4058,    std::shared_ptr< monty::ndarray< int,1 > > _4059,    std::shared_ptr< monty::ndarray< int,1 > > _4060,    std::shared_ptr< monty::ndarray< double,1 > > _4061,    monty::rc_ptr< ::mosek::fusion::Variable > _4062,    int _4063){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4059(_4059 ? _4059->raw() : nullptr, _4059 ? _4059->size(0) : 0);
    _checked_ptr_1<int> _ptr__4060(_4060 ? _4060->raw() : nullptr, _4060 ? _4060->size(0) : 0);
    _checked_ptr_1<double> _ptr__4061(_4061 ? _4061->raw() : nullptr, _4061 ? _4061->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4057),(int)(_4058)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _4057;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _4058;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _4059;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _4060;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _4061;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _4062;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4064,monty::rc_ptr< ::mosek::fusion::WorkStack > _4065,monty::rc_ptr< ::mosek::fusion::WorkStack > _4066) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_4064,_4065,_4066); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4064,monty::rc_ptr< ::mosek::fusion::WorkStack > _4065,monty::rc_ptr< ::mosek::fusion::WorkStack > _4066){
  if ((x->numInst() == (int)0))
  {
    {
      _4064->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_4064)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4064)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4064)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4064)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4067 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__4067(_4067 ? _4067->raw() : nullptr,_4067 ? _4067->size(0) : 0);
      x->inst((int)0,_4067);
      long long _4068 = _ptr__4067[(int)0];
      int _4069 = (int)((msubi)->size(0));
      int _4070 = _4069;
      bool _4071 = (_4069 < safe_mul( mdimi,mdimj ));
      _4064->alloc_expr((int)2,_4069,_4070,_4071);
      int _4072 = mosek::fusion::p_WorkStack::_get_impl(_4064)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4064)->i32)(mosek::fusion::p_WorkStack::_get_impl(_4064)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_4064)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4064)->shape_base,(int)1 ))) = mdimj;
      int _4073 = mosek::fusion::p_WorkStack::_get_impl(_4064)->nidxs_base;
      int _4074 = mosek::fusion::p_WorkStack::_get_impl(_4064)->sp_base;
      int _4075 = mosek::fusion::p_WorkStack::_get_impl(_4064)->cof_base;
      int _4076 = mosek::fusion::p_WorkStack::_get_impl(_4064)->bfix_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4077 = mosek::fusion::p_WorkStack::_get_impl(_4064)->i32;
      _checked_ptr_1<int> _ptr__4077(_4077 ? _4077->raw() : nullptr,_4077 ? _4077->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4078 = mosek::fusion::p_WorkStack::_get_impl(_4064)->i64;
      _checked_ptr_1<long long> _ptr__4078(_4078 ? _4078->raw() : nullptr,_4078 ? _4078->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4079 = mosek::fusion::p_WorkStack::_get_impl(_4064)->f64;
      _checked_ptr_1<double> _ptr__4079(_4079 ? _4079->raw() : nullptr,_4079 ? _4079->size(0) : 0);
      {
        int _8678 = (int)0;
        int _8679 = _4069;
        for (int _4080 = _8678; _4080 < _8679; ++_4080)
        {
          {
            _ptr__4079[safe_add( _4076,_4080 )] = (int)0;
          }
        }
        int _8680 = (int)0;
        int _8681 = _4070;
        for (int _4081 = _8680; _4081 < _8681; ++_4081)
        {
          {
            _ptr__4079[safe_add( _4075,_4081 )] = ((*mcof)(_4081));
          }
        }
        int _8682 = (int)0;
        int _8683 = _4070;
        for (int _4082 = _8682; _4082 < _8683; ++_4082)
        {
          {
            _ptr__4078[safe_add( _4073,_4082 )] = _4068;
          }
        }
        if (_4071)
        {
          {
            int _8684 = (int)0;
            int _8685 = _4069;
            for (int _4083 = _8684; _4083 < _8685; ++_4083)
            {
              {
                _ptr__4078[safe_add( _4074,_4083 )] = safe_add( safe_mul( ((*msubi)(_4083)),mdimj ),((*msubj)(_4083)) );
              }
            }
          }
        }
        {}
        int _8686 = (int)0;
        int _8687 = safe_add( _4069,(int)1 );
        for (int _4084 = _8686; _4084 < _8687; ++_4084)
        {
          {
            _ptr__4077[safe_add( _4072,_4084 )] = _4084;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4085,    double _4086){ return new mosek::fusion::ExprMulVarScalarConst(_4085,_4086); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _4085,    double _4086) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_4085,_4086); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4085,    double _4086){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4085->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _4085;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _4086;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4087,monty::rc_ptr< ::mosek::fusion::WorkStack > _4088,monty::rc_ptr< ::mosek::fusion::WorkStack > _4089) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_4087,_4088,_4089); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4087,monty::rc_ptr< ::mosek::fusion::WorkStack > _4088,monty::rc_ptr< ::mosek::fusion::WorkStack > _4089){
  int _4090 = x->numInst();
  int _4091 = _4090;
  std::shared_ptr< monty::ndarray< int,1 > > _4092 = x->getShape();
  _checked_ptr_1<int> _ptr__4092(_4092 ? _4092->raw() : nullptr,_4092 ? _4092->size(0) : 0);
  int _4093 = (int)((_4092)->size(0));
  int _4094 = _4087->alloci32(safe_add( _4091,(int)1 ));
  int _4095 = _4087->alloci64(_4090);
  bool _4096 = (::mosek::fusion::p_Set::size(_4092) > _4091);
  int _8688;
  bool _8689 = _4096;
  if (_8689)
  {
    _8688 = _4087->alloci64(_4091);
  }
  else
  {
    _8688 = (int)0;
  }
  int _4097 = _8688;
  int _4098 = _4087->allocf64(_4090);
  int _4099 = _4087->allocf64(_4091);
  if (_4096)
  {
    {
      x->inst(_4097,mosek::fusion::p_WorkStack::_get_impl(_4087)->i64,_4095,mosek::fusion::p_WorkStack::_get_impl(_4087)->i64);
    }
  }
  else
  {
    {
      x->inst(_4095,mosek::fusion::p_WorkStack::_get_impl(_4087)->i64);
    }
  }
  int _8690;
  bool _8691 = _4096;
  if (_8691)
  {
    _8690 = (int)1;
  }
  else
  {
    _8690 = (int)0;
  }
  _4087->pushi32(_8690);
  _4087->pushi32(_4091);
  _4087->pushi32(_4090);
  int _8692 = (int)0;
  int _8693 = _4093;
  for (int _4100 = _8692; _4100 < _8693; ++_4100)
  {
    {
      _4087->pushi32(_ptr__4092[_4100]);
    }
  }
  _4087->pushi32(_4093);
  std::shared_ptr< monty::ndarray< int,1 > > _4101 = mosek::fusion::p_WorkStack::_get_impl(_4087)->i32;
  _checked_ptr_1<int> _ptr__4101(_4101 ? _4101->raw() : nullptr,_4101 ? _4101->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4102 = mosek::fusion::p_WorkStack::_get_impl(_4087)->i64;
  _checked_ptr_1<long long> _ptr__4102(_4102 ? _4102->raw() : nullptr,_4102 ? _4102->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4103 = mosek::fusion::p_WorkStack::_get_impl(_4087)->f64;
  _checked_ptr_1<double> _ptr__4103(_4103 ? _4103->raw() : nullptr,_4103 ? _4103->size(0) : 0);
  {
    int _8694 = (int)0;
    int _8695 = safe_add( _4091,(int)1 );
    for (int _4104 = _8694; _4104 < _8695; ++_4104)
    {
      {
        _ptr__4101[safe_add( _4094,_4104 )] = _4104;
      }
    }
    int _8696 = (int)0;
    int _8697 = _4090;
    for (int _4105 = _8696; _4105 < _8697; ++_4105)
    {
      {
        _ptr__4103[safe_add( _4098,_4105 )] = 1.0;
      }
    }
    int _8698 = (int)0;
    int _8699 = _4091;
    for (int _4106 = _8698; _4106 < _8699; ++_4106)
    {
      {
        _ptr__4103[safe_add( _4099,_4106 )] = 0.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4107,    monty::rc_ptr< ::mosek::fusion::Expression > _4108,    double _4109,    double _4110){ return new mosek::fusion::ExprAdd(_4107,_4108,_4109,_4110); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _4107,    monty::rc_ptr< ::mosek::fusion::Expression > _4108,    double _4109,    double _4110) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_4107,_4108,_4109,_4110); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4107,    monty::rc_ptr< ::mosek::fusion::Expression > _4108,    double _4109,    double _4110){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4107->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _4107;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _4108;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _4109;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _4110;
    if ((_4107->getND() != _4108->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _8700 = (int)0;
    int _8701 = _4107->getND();
    for (int _4111 = _8700; _4111 < _8701; ++_4111)
    {
      {
        if ((_4107->getDim(_4111) != _4108->getDim(_4111)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4112,monty::rc_ptr< ::mosek::fusion::WorkStack > _4113,monty::rc_ptr< ::mosek::fusion::WorkStack > _4114) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_4112,_4113,_4114); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4112,monty::rc_ptr< ::mosek::fusion::WorkStack > _4113,monty::rc_ptr< ::mosek::fusion::WorkStack > _4114){
  e1->eval(_4113,_4112,_4114);
  e2->eval(_4113,_4112,_4114);
  _4113->pop_expr();
  int _4115 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nd;
  int _4116 = mosek::fusion::p_WorkStack::_get_impl(_4113)->shape_base;
  int _4117 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nelem;
  int _4118 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nnz;
  bool _4119 = mosek::fusion::p_WorkStack::_get_impl(_4113)->hassp;
  int _4120 = mosek::fusion::p_WorkStack::_get_impl(_4113)->ptr_base;
  int _4121 = mosek::fusion::p_WorkStack::_get_impl(_4113)->sp_base;
  int _4122 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nidxs_base;
  int _4123 = mosek::fusion::p_WorkStack::_get_impl(_4113)->bfix_base;
  int _4124 = mosek::fusion::p_WorkStack::_get_impl(_4113)->cof_base;
  _4113->pop_expr();
  int _4125 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nd;
  int _4126 = mosek::fusion::p_WorkStack::_get_impl(_4113)->shape_base;
  int _4127 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nelem;
  int _4128 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nnz;
  bool _4129 = mosek::fusion::p_WorkStack::_get_impl(_4113)->hassp;
  int _4130 = mosek::fusion::p_WorkStack::_get_impl(_4113)->ptr_base;
  int _4131 = mosek::fusion::p_WorkStack::_get_impl(_4113)->sp_base;
  int _4132 = mosek::fusion::p_WorkStack::_get_impl(_4113)->nidxs_base;
  int _4133 = mosek::fusion::p_WorkStack::_get_impl(_4113)->bfix_base;
  int _4134 = mosek::fusion::p_WorkStack::_get_impl(_4113)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4135 = mosek::fusion::p_WorkStack::_get_impl(_4113)->i32;
  _checked_ptr_1<int> _ptr__4135(_4135 ? _4135->raw() : nullptr,_4135 ? _4135->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4136 = mosek::fusion::p_WorkStack::_get_impl(_4113)->i64;
  _checked_ptr_1<long long> _ptr__4136(_4136 ? _4136->raw() : nullptr,_4136 ? _4136->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4137 = mosek::fusion::p_WorkStack::_get_impl(_4113)->f64;
  _checked_ptr_1<double> _ptr__4137(_4137 ? _4137->raw() : nullptr,_4137 ? _4137->size(0) : 0);
  if ((_4125 != _4115))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _8702 = (int)0;
  int _8703 = _4125;
  for (int _4138 = _8702; _4138 < _8703; ++_4138)
  {
    {
      if ((_ptr__4135[safe_add( _4126,_4138 )] != _ptr__4135[safe_add( _4116,_4138 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_4129) && (!_4119)))
  {
    {
      int _4139 = _4127;
      int _4140 = safe_add( _4128,_4118 );
      int _4141 = _4125;
      _4112->alloc_expr(_4141,_4139,_4140,false);
      int _4142 = mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base;
      int _4143 = mosek::fusion::p_WorkStack::_get_impl(_4112)->ptr_base;
      int _4144 = mosek::fusion::p_WorkStack::_get_impl(_4112)->sp_base;
      int _4145 = mosek::fusion::p_WorkStack::_get_impl(_4112)->nidxs_base;
      int _4146 = mosek::fusion::p_WorkStack::_get_impl(_4112)->bfix_base;
      int _4147 = mosek::fusion::p_WorkStack::_get_impl(_4112)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4148 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i32;
      _checked_ptr_1<int> _ptr__4148(_4148 ? _4148->raw() : nullptr,_4148 ? _4148->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4149 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i64;
      _checked_ptr_1<long long> _ptr__4149(_4149 ? _4149->raw() : nullptr,_4149 ? _4149->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4150 = mosek::fusion::p_WorkStack::_get_impl(_4112)->f64;
      _checked_ptr_1<double> _ptr__4150(_4150 ? _4150->raw() : nullptr,_4150 ? _4150->size(0) : 0);
      int _8704 = (int)0;
      int _8705 = _4141;
      for (int _4151 = _8704; _4151 < _8705; ++_4151)
      {
        {
          _ptr__4148[safe_add( _4142,_4151 )] = _ptr__4135[safe_add( _4126,_4151 )];
        }
      }
      int _4152 = (int)0;
      _ptr__4148[_4143] = (int)0;
      int _8706 = (int)0;
      int _8707 = _4139;
      for (int _4153 = _8706; _4153 < _8707; ++_4153)
      {
        {
          int _8708 = _ptr__4135[safe_add( _4130,_4153 )];
          int _8709 = _ptr__4135[safe_add( safe_add( _4130,_4153 ),(int)1 )];
          for (int _4154 = _8708; _4154 < _8709; ++_4154)
          {
            {
              _ptr__4149[safe_add( _4145,_4152 )] = _ptr__4136[safe_add( _4132,_4154 )];
              _ptr__4150[safe_add( _4147,_4152 )] = (_ptr__4137[safe_add( _4134,_4154 )] * m1);
              ++ _4152;
            }
          }
          int _8710 = _ptr__4135[safe_add( _4120,_4153 )];
          int _8711 = _ptr__4135[safe_add( safe_add( _4120,_4153 ),(int)1 )];
          for (int _4155 = _8710; _4155 < _8711; ++_4155)
          {
            {
              _ptr__4149[safe_add( _4145,_4152 )] = _ptr__4136[safe_add( _4122,_4155 )];
              _ptr__4150[safe_add( _4147,_4152 )] = (_ptr__4137[safe_add( _4124,_4155 )] * m2);
              ++ _4152;
            }
          }
          _ptr__4148[safe_add( safe_add( _4143,_4153 ),(int)1 )] = _4152;
          _ptr__4150[safe_add( _4146,_4153 )] = ((_ptr__4137[safe_add( _4133,_4153 )] * m1) + (_ptr__4137[safe_add( _4123,_4153 )] * m2));
        }
      }
    }
  }
  else if(((!_4129) || (!_4119)))
  {
    {
      if ((!_4119))
      {
        {
          int _4156 = _4117;
          int _4157 = _4118;
          int _4158 = _4120;
          int _4159 = _4121;
          int _4160 = _4122;
          int _4161 = _4123;
          int _4162 = _4124;
          _4117 = _4127;
          _4118 = _4128;
          _4120 = _4130;
          _4121 = _4131;
          _4122 = _4132;
          _4123 = _4133;
          _4124 = _4134;
          _4127 = _4156;
          _4128 = _4157;
          _4130 = _4158;
          _4131 = _4159;
          _4132 = _4160;
          _4133 = _4161;
          _4134 = _4162;
        }
      }
      {}
      double _8712;
      bool _8713 = (!_4129);
      if (_8713)
      {
        _8712 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      else
      {
        _8712 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      double _4163 = _8712;
      double _8714;
      bool _8715 = (!_4129);
      if (_8715)
      {
        _8714 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      else
      {
        _8714 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      double _4164 = _8714;
      int _4165 = _4127;
      int _4166 = safe_add( _4128,_4118 );
      int _4167 = _4125;
      _4112->alloc_expr(_4167,_4165,_4166,false);
      int _4168 = mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base;
      int _4169 = mosek::fusion::p_WorkStack::_get_impl(_4112)->ptr_base;
      int _4170 = mosek::fusion::p_WorkStack::_get_impl(_4112)->sp_base;
      int _4171 = mosek::fusion::p_WorkStack::_get_impl(_4112)->nidxs_base;
      int _4172 = mosek::fusion::p_WorkStack::_get_impl(_4112)->bfix_base;
      int _4173 = mosek::fusion::p_WorkStack::_get_impl(_4112)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4174 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i32;
      _checked_ptr_1<int> _ptr__4174(_4174 ? _4174->raw() : nullptr,_4174 ? _4174->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4175 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i64;
      _checked_ptr_1<long long> _ptr__4175(_4175 ? _4175->raw() : nullptr,_4175 ? _4175->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4176 = mosek::fusion::p_WorkStack::_get_impl(_4112)->f64;
      _checked_ptr_1<double> _ptr__4176(_4176 ? _4176->raw() : nullptr,_4176 ? _4176->size(0) : 0);
      {
        int _4177 = (int)0;
        int _8716 = (int)0;
        int _8717 = _4167;
        for (int _4178 = _8716; _4178 < _8717; ++_4178)
        {
          {
            _ptr__4174[safe_add( _4168,_4178 )] = _ptr__4135[safe_add( _4126,_4178 )];
          }
        }
        int _8718 = (int)0;
        int _8719 = safe_add( _4165,(int)1 );
        for (int _4179 = _8718; _4179 < _8719; ++_4179)
        {
          {
            _ptr__4174[safe_add( _4169,_4179 )] = (int)0;
          }
        }
        int _8720 = (int)0;
        int _8721 = _4127;
        for (int _4180 = _8720; _4180 < _8721; ++_4180)
        {
          {
            _ptr__4174[safe_add( safe_add( _4169,_4180 ),(int)1 )] += (_ptr__4135[safe_add( safe_add( _4130,_4180 ),(int)1 )] - _ptr__4135[safe_add( _4130,_4180 )]);
          }
        }
        int _8722 = (int)0;
        int _8723 = _4117;
        for (int _4181 = _8722; _4181 < _8723; ++_4181)
        {
          {
            long long _4182 = _ptr__4136[safe_add( _4121,_4181 )];
            _ptr__4174[safe_add( safe_add( _4169,_4182 ),(int)1 )] += (_ptr__4135[safe_add( safe_add( _4120,_4181 ),(int)1 )] - _ptr__4135[safe_add( _4120,_4181 )]);
          }
        }
        int _8724 = (int)0;
        int _8725 = _4165;
        for (int _4183 = _8724; _4183 < _8725; ++_4183)
        {
          {
            _ptr__4174[safe_add( safe_add( _4169,_4183 ),(int)1 )] += _ptr__4174[safe_add( _4169,_4183 )];
          }
        }
        int _8726 = (int)0;
        int _8727 = _4127;
        for (int _4184 = _8726; _4184 < _8727; ++_4184)
        {
          {
            int _4185 = _ptr__4174[safe_add( _4169,_4184 )];
            int _4186 = _ptr__4135[safe_add( _4130,_4184 )];
            int _4187 = (_ptr__4135[safe_add( safe_add( _4130,_4184 ),(int)1 )] - _ptr__4135[safe_add( _4130,_4184 )]);
            int _8728 = (int)0;
            int _8729 = _4187;
            for (int _4188 = _8728; _4188 < _8729; ++_4188)
            {
              {
                _ptr__4175[safe_add( safe_add( _4171,_4185 ),_4188 )] = _ptr__4136[safe_add( safe_add( _4132,_4186 ),_4188 )];
                _ptr__4176[safe_add( safe_add( _4173,_4185 ),_4188 )] = (_ptr__4137[safe_add( safe_add( _4134,_4186 ),_4188 )] * _4163);
              }
            }
            _ptr__4174[safe_add( _4169,_4184 )] += _4187;
            _ptr__4176[safe_add( _4172,_4184 )] = (_ptr__4137[safe_add( _4133,_4184 )] * _4163);
          }
        }
        int _8730 = (int)0;
        int _8731 = _4117;
        for (int _4189 = _8730; _4189 < _8731; ++_4189)
        {
          {
            long long _4190 = _ptr__4136[safe_add( _4121,_4189 )];
            int _4191 = _ptr__4174[safe_add( _4169,_4190 )];
            int _4192 = _ptr__4135[safe_add( _4120,_4189 )];
            int _4193 = (_ptr__4135[safe_add( safe_add( _4120,_4189 ),(int)1 )] - _ptr__4135[safe_add( _4120,_4189 )]);
            int _8732 = (int)0;
            int _8733 = _4193;
            for (int _4194 = _8732; _4194 < _8733; ++_4194)
            {
              {
                _ptr__4175[safe_add( safe_add( _4171,_4191 ),_4194 )] = _ptr__4136[safe_add( safe_add( _4122,_4192 ),_4194 )];
                _ptr__4176[safe_add( safe_add( _4173,_4191 ),_4194 )] = (_ptr__4137[safe_add( safe_add( _4124,_4192 ),_4194 )] * _4164);
              }
            }
            _ptr__4174[safe_add( _4169,_4190 )] += _4193;
            _ptr__4176[safe_add( _4172,_4190 )] += (_ptr__4137[safe_add( _4123,_4189 )] * _4164);
          }
        }
        int _8734 = (int)0;
        int _8735 = _4165;
        for (int _4195 = _8734; _4195 < _8735; ++_4195)
        {
          {
            _ptr__4174[(safe_add( _4169,_4165 ) - _4195)] = _ptr__4174[((safe_add( _4169,_4165 ) - _4195) - (int)1)];
          }
        }
        _ptr__4174[_4169] = (int)0;
      }
    }
  }
  else
  {
    {
      int _4196 = safe_add( _4128,_4118 );
      int _4197 = (int)0;
      int _4198 = _4125;
      long long _4199 = (long long)1;
      int _8736 = (int)0;
      int _8737 = _4198;
      for (int _4200 = _8736; _4200 < _8737; ++_4200)
      {
        {
          _4199 *= _ptr__4135[safe_add( _4126,_4200 )];
        }
      }
      {
        int _4201 = (int)0;
        int _4202 = (int)0;
        while ( ((_4202 < _4127) && (_4201 < _4117)) )
        {
          {
            if ((_ptr__4136[safe_add( _4131,_4202 )] < _ptr__4136[safe_add( _4121,_4201 )]))
            {
              {
                ++ _4197;
                ++ _4202;
              }
            }
            else if((_ptr__4136[safe_add( _4131,_4202 )] > _ptr__4136[safe_add( _4121,_4201 )]))
            {
              {
                ++ _4197;
                ++ _4201;
              }
            }
            else
            {
              {
                ++ _4197;
                ++ _4202;
                ++ _4201;
              }
            }
          }
        }
        _4197 += (safe_add( (_4127 - _4202),_4117 ) - _4201);
      }
      bool _4203 = (_4197 < _4199);
      _4112->alloc_expr(_4198,_4197,_4196,_4203);
      int _4204 = mosek::fusion::p_WorkStack::_get_impl(_4112)->shape_base;
      int _4205 = mosek::fusion::p_WorkStack::_get_impl(_4112)->ptr_base;
      int _8738;
      bool _8739 = _4203;
      if (_8739)
      {
        _8738 = mosek::fusion::p_WorkStack::_get_impl(_4112)->sp_base;
      }
      else
      {
        _8738 = _4112->alloci64(_4197);
      }
      int _4206 = _8738;
      int _4207 = mosek::fusion::p_WorkStack::_get_impl(_4112)->nidxs_base;
      int _4208 = mosek::fusion::p_WorkStack::_get_impl(_4112)->bfix_base;
      int _4209 = mosek::fusion::p_WorkStack::_get_impl(_4112)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4210 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i32;
      _checked_ptr_1<int> _ptr__4210(_4210 ? _4210->raw() : nullptr,_4210 ? _4210->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4211 = mosek::fusion::p_WorkStack::_get_impl(_4112)->i64;
      _checked_ptr_1<long long> _ptr__4211(_4211 ? _4211->raw() : nullptr,_4211 ? _4211->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4212 = mosek::fusion::p_WorkStack::_get_impl(_4112)->f64;
      _checked_ptr_1<double> _ptr__4212(_4212 ? _4212->raw() : nullptr,_4212 ? _4212->size(0) : 0);
      int _8740 = (int)0;
      int _8741 = _4198;
      for (int _4213 = _8740; _4213 < _8741; ++_4213)
      {
        {
          _ptr__4210[safe_add( _4204,_4213 )] = _ptr__4135[safe_add( _4126,_4213 )];
        }
      }
      {
        _ptr__4210[_4205] = (int)0;
        int _4214 = (int)0;
        int _4215 = (int)0;
        int _4216 = (int)0;
        int _4217 = (int)0;
        while ( ((_4217 < _4127) && (_4216 < _4117)) )
        {
          {
            if ((_ptr__4136[safe_add( _4131,_4217 )] < _ptr__4136[safe_add( _4121,_4216 )]))
            {
              {
                int _8742 = _ptr__4135[safe_add( _4130,_4217 )];
                int _8743 = _ptr__4135[safe_add( safe_add( _4130,_4217 ),(int)1 )];
                for (int _4218 = _8742; _4218 < _8743; ++_4218)
                {
                  {
                    _ptr__4211[safe_add( _4207,_4215 )] = _ptr__4136[safe_add( _4132,_4218 )];
                    _ptr__4212[safe_add( _4209,_4215 )] = (m1 * _ptr__4137[safe_add( _4134,_4218 )]);
                    ++ _4215;
                  }
                }
                _ptr__4212[safe_add( _4208,_4214 )] = (m1 * _ptr__4137[safe_add( _4133,_4217 )]);
                _ptr__4211[safe_add( _4206,_4214 )] = _ptr__4136[safe_add( _4131,_4217 )];
                _ptr__4210[safe_add( safe_add( _4205,_4214 ),(int)1 )] = _4215;
                ++ _4214;
                ++ _4217;
              }
            }
            else if((_ptr__4136[safe_add( _4121,_4216 )] < _ptr__4136[safe_add( _4131,_4217 )]))
            {
              {
                int _8744 = _ptr__4135[safe_add( _4120,_4216 )];
                int _8745 = _ptr__4135[safe_add( safe_add( _4120,_4216 ),(int)1 )];
                for (int _4219 = _8744; _4219 < _8745; ++_4219)
                {
                  {
                    _ptr__4211[safe_add( _4207,_4215 )] = _ptr__4136[safe_add( _4122,_4219 )];
                    _ptr__4212[safe_add( _4209,_4215 )] = (m2 * _ptr__4137[safe_add( _4124,_4219 )]);
                    ++ _4215;
                  }
                }
                _ptr__4212[safe_add( _4208,_4214 )] = (m1 * _ptr__4137[safe_add( _4123,_4217 )]);
                _ptr__4211[safe_add( _4206,_4214 )] = _ptr__4136[safe_add( _4121,_4216 )];
                _ptr__4210[safe_add( safe_add( _4205,_4214 ),(int)1 )] = _4215;
                ++ _4214;
                ++ _4216;
              }
            }
            else
            {
              {
                int _8746 = _ptr__4135[safe_add( _4130,_4217 )];
                int _8747 = _ptr__4135[safe_add( safe_add( _4130,_4217 ),(int)1 )];
                for (int _4220 = _8746; _4220 < _8747; ++_4220)
                {
                  {
                    _ptr__4211[safe_add( _4207,_4215 )] = _ptr__4136[safe_add( _4132,_4220 )];
                    _ptr__4212[safe_add( _4209,_4215 )] = (m1 * _ptr__4137[safe_add( _4134,_4220 )]);
                    ++ _4215;
                  }
                }
                int _8748 = _ptr__4135[safe_add( _4120,_4216 )];
                int _8749 = _ptr__4135[safe_add( safe_add( _4120,_4216 ),(int)1 )];
                for (int _4221 = _8748; _4221 < _8749; ++_4221)
                {
                  {
                    _ptr__4211[safe_add( _4207,_4215 )] = _ptr__4136[safe_add( _4122,_4221 )];
                    _ptr__4212[safe_add( _4209,_4215 )] = (m2 * _ptr__4137[safe_add( _4124,_4221 )]);
                    ++ _4215;
                  }
                }
                _ptr__4212[safe_add( _4208,_4214 )] = ((m1 * _ptr__4137[safe_add( _4133,_4217 )]) + (m2 * _ptr__4137[safe_add( _4123,_4216 )]));
                _ptr__4211[safe_add( _4206,_4214 )] = _ptr__4136[safe_add( _4131,_4217 )];
                _ptr__4210[safe_add( safe_add( _4205,_4214 ),(int)1 )] = _4215;
                ++ _4214;
                ++ _4217;
                ++ _4216;
              }
            }
          }
        }
        while ( (_4217 < _4127) )
        {
          {
            int _8750 = _ptr__4135[safe_add( _4130,_4217 )];
            int _8751 = _ptr__4135[safe_add( safe_add( _4130,_4217 ),(int)1 )];
            for (int _4222 = _8750; _4222 < _8751; ++_4222)
            {
              {
                _ptr__4211[safe_add( _4207,_4215 )] = _ptr__4136[safe_add( _4132,_4222 )];
                _ptr__4212[safe_add( _4209,_4215 )] = (m1 * _ptr__4137[safe_add( _4134,_4222 )]);
                ++ _4215;
              }
            }
            _ptr__4212[safe_add( _4208,_4214 )] = (m1 * _ptr__4137[safe_add( _4133,_4217 )]);
            _ptr__4211[safe_add( _4206,_4214 )] = _ptr__4136[safe_add( _4131,_4217 )];
            _ptr__4210[safe_add( safe_add( _4205,_4214 ),(int)1 )] = _4215;
            ++ _4214;
            ++ _4217;
          }
        }
        while ( (_4216 < _4117) )
        {
          {
            int _8752 = _ptr__4135[safe_add( _4120,_4216 )];
            int _8753 = _ptr__4135[safe_add( safe_add( _4120,_4216 ),(int)1 )];
            for (int _4223 = _8752; _4223 < _8753; ++_4223)
            {
              {
                _ptr__4211[safe_add( _4207,_4215 )] = _ptr__4136[safe_add( _4122,_4223 )];
                _ptr__4212[safe_add( _4209,_4215 )] = (m2 * _ptr__4137[safe_add( _4124,_4223 )]);
                ++ _4215;
              }
            }
            _ptr__4212[safe_add( _4208,_4214 )] = (m1 * _ptr__4137[safe_add( _4123,_4216 )]);
            _ptr__4211[safe_add( _4206,_4214 )] = _ptr__4136[safe_add( _4121,_4216 )];
            _ptr__4210[safe_add( safe_add( _4205,_4214 ),(int)1 )] = _4215;
            ++ _4214;
            ++ _4216;
          }
        }
      }
      if ((!_4203))
      {
        {
          _4112->popi64(_4197);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4224,    std::shared_ptr< monty::ndarray< double,1 > > _4225){ return new mosek::fusion::ExprWSum(_4224,_4225); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4224,    std::shared_ptr< monty::ndarray< double,1 > > _4225) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_4224,_4225); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4224,    std::shared_ptr< monty::ndarray< double,1 > > _4225){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__4225(_4225 ? _4225->raw() : nullptr, _4225 ? _4225->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_4224)((int)0))->getShape());
    if (((int)((_4225)->size(0)) != (int)((_4224)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_4225);
    std::shared_ptr< monty::ndarray< int,1 > > _4226 = ((*_4224)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__4226(_4226 ? _4226->raw() : nullptr,_4226 ? _4226->size(0) : 0);
    int _4227 = (int)((_4226)->size(0));
    int _8754 = (int)1;
    int _8755 = (int)((_4224)->size(0));
    for (int _4228 = _8754; _4228 < _8755; ++_4228)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4229 = ((*_4224)(_4228))->getShape();
        _checked_ptr_1<int> _ptr__4229(_4229 ? _4229->raw() : nullptr,_4229 ? _4229->size(0) : 0);
        if ((_4227 != (int)((_4229)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _8756 = (int)0;
            int _8757 = _4227;
            for (int _4230 = _8756; _4230 < _8757; ++_4230)
            {
              {
                if ((_ptr__4226[_4230] != _ptr__4229[_4230]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _8758;
    for (int _4231 = (int)0, _8759 = (int)((_4224)->size(0)); _4231 < _8759 ; ++_4231)
    {
      _8758.push_back(((*_4224)(_4231)));
    }
    auto _8760 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_8758.size()),_8758.begin(),_8758.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _8760;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4232,monty::rc_ptr< ::mosek::fusion::WorkStack > _4233,monty::rc_ptr< ::mosek::fusion::WorkStack > _4234) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_4232,_4233,_4234); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4232,monty::rc_ptr< ::mosek::fusion::WorkStack > _4233,monty::rc_ptr< ::mosek::fusion::WorkStack > _4234){
  int _4235 = (int)((es)->size(0));
  int _8761 = (int)0;
  int _8762 = _4235;
  for (int _4236 = _8761; _4236 < _8762; ++_4236)
  {
    {
      ((*es)(_4236))->eval(_4233,_4232,_4234);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4237 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4237(_4237 ? _4237->raw() : nullptr,_4237 ? _4237->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4238 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4238(_4238 ? _4238->raw() : nullptr,_4238 ? _4238->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4239 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4239(_4239 ? _4239->raw() : nullptr,_4239 ? _4239->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4240 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4240(_4240 ? _4240->raw() : nullptr,_4240 ? _4240->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4241 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4241(_4241 ? _4241->raw() : nullptr,_4241 ? _4241->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4242 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4242(_4242 ? _4242->raw() : nullptr,_4242 ? _4242->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4243 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
  _checked_ptr_1<int> _ptr__4243(_4243 ? _4243->raw() : nullptr,_4243 ? _4243->size(0) : 0);
  int _4244 = _4233->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4245 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4244)));
  _checked_ptr_1<int> _ptr__4245(_4245 ? _4245->raw() : nullptr,_4245 ? _4245->size(0) : 0);
  _4233->popi32(_4244,_4245,(int)0);
  {
    _ptr__4237[(_4235 - (int)1)] = _4233->popi32();
    _ptr__4238[(_4235 - (int)1)] = _4233->popi32();
    bool _4246 = (_4233->popi32() != (int)0);
    _ptr__4239[(_4235 - (int)1)] = _4233->popi32(safe_add( _ptr__4237[(_4235 - (int)1)],(int)1 ));
    int _8763;
    bool _8764 = _4246;
    if (_8764)
    {
      _8763 = _4233->popi64(_ptr__4237[(_4235 - (int)1)]);
    }
    else
    {
      _8763 = (-(int)1);
    }
    _ptr__4241[(_4235 - (int)1)] = _8763;
    _ptr__4240[(_4235 - (int)1)] = _4233->popi64(_ptr__4238[(_4235 - (int)1)]);
    _ptr__4243[(_4235 - (int)1)] = _4233->popf64(_ptr__4237[(_4235 - (int)1)]);
    _ptr__4242[(_4235 - (int)1)] = _4233->popf64(_ptr__4238[(_4235 - (int)1)]);
  }
  int _8765 = (int)1;
  int _8766 = _4235;
  for (int _4247 = _8765; _4247 < _8766; ++_4247)
  {
    {
      int _4248 = ((_4235 - _4247) - (int)1);
      _4233->popi32();
      _4233->popi32(_4244);
      _ptr__4237[_4248] = _4233->popi32();
      _ptr__4238[_4248] = _4233->popi32();
      bool _4249 = (_4233->popi32() != (int)0);
      _ptr__4239[_4248] = _4233->popi32(safe_add( _ptr__4237[_4248],(int)1 ));
      int _8767;
      bool _8768 = _4249;
      if (_8768)
      {
        _8767 = _4233->popi64(_ptr__4237[_4248]);
      }
      else
      {
        _8767 = (-(int)1);
      }
      _ptr__4241[_4248] = _8767;
      _ptr__4240[_4248] = _4233->popi64(_ptr__4238[_4248]);
      _ptr__4243[_4248] = _4233->popf64(_ptr__4237[_4248]);
      _ptr__4242[_4248] = _4233->popf64(_ptr__4238[_4248]);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4250 = mosek::fusion::p_WorkStack::_get_impl(_4233)->i32;
  _checked_ptr_1<int> _ptr__4250(_4250 ? _4250->raw() : nullptr,_4250 ? _4250->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4251 = mosek::fusion::p_WorkStack::_get_impl(_4233)->i64;
  _checked_ptr_1<long long> _ptr__4251(_4251 ? _4251->raw() : nullptr,_4251 ? _4251->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4252 = mosek::fusion::p_WorkStack::_get_impl(_4233)->f64;
  _checked_ptr_1<double> _ptr__4252(_4252 ? _4252->raw() : nullptr,_4252 ? _4252->size(0) : 0);
  bool _4253 = false;
  int _8769 = (int)0;
  int _8770 = _4235;
  for (int _4254 = _8769; _4254 < _8770; ++_4254)
  {
    {
      if ((_ptr__4241[_4254] < (int)0))
      {
        {
          _4253 = true;
        }
      }
      {}
    }
  }
  int _4255 = (int)0;
  int _4256 = (int)0;
  if (_4253)
  {
    {
      _4255 = (int)::mosek::fusion::p_Set::size(_4245);
      int _8771 = (int)0;
      int _8772 = _4235;
      for (int _4257 = _8771; _4257 < _8772; ++_4257)
      {
        {
          _4256 += _ptr__4238[_4257];
        }
      }
    }
  }
  else
  {
    {
      bool _4258 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4259 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
      _checked_ptr_1<int> _ptr__4259(_4259 ? _4259->raw() : nullptr,_4259 ? _4259->size(0) : 0);
      int _8773 = (int)0;
      int _8774 = _4235;
      for (int _4260 = _8773; _4260 < _8774; ++_4260)
      {
        {
          _4256 += _ptr__4238[_4260];
        }
      }
      while ( (!_4258) )
      {
        {
          long long _4261 = (-(int)1);
          int _8775 = (int)0;
          int _8776 = _4235;
          for (int _4262 = _8775; _4262 < _8776; ++_4262)
          {
            {
              if (((_ptr__4259[_4262] < _ptr__4237[_4262]) && ((_4261 < (int)0) || (_ptr__4251[safe_add( _ptr__4241[_4262],_ptr__4259[_4262] )] < _4261))))
              {
                {
                  _4261 = _ptr__4251[safe_add( _ptr__4241[_4262],_ptr__4259[_4262] )];
                }
              }
              {}
            }
          }
          if ((_4261 < (int)0))
          {
            {
              _4258 = true;
            }
          }
          else
          {
            {
              int _8777 = (int)0;
              int _8778 = _4235;
              for (int _4263 = _8777; _4263 < _8778; ++_4263)
              {
                {
                  if (((_ptr__4259[_4263] < _ptr__4237[_4263]) && (_4261 == _ptr__4251[safe_add( _ptr__4241[_4263],_ptr__4259[_4263] )])))
                  {
                    {
                      ++ _ptr__4259[_4263];
                    }
                  }
                  {}
                }
              }
              ++ _4255;
            }
          }
        }
      }
    }
  }
  int _4264 = _4232->alloci32(safe_add( _4255,(int)1 ));
  int _4265 = _4232->alloci64(_4256);
  int _8779;
  bool _8780 = (!_4253);
  if (_8780)
  {
    _8779 = _4232->alloci64(_4255);
  }
  else
  {
    _8779 = (-(int)1);
  }
  int _4266 = _8779;
  int _4267 = _4232->allocf64(_4256);
  int _4268 = _4232->allocf64(_4255);
  int _8781;
  bool _8782 = _4253;
  if (_8782)
  {
    _8781 = (int)0;
  }
  else
  {
    _8781 = (int)1;
  }
  _4232->pushi32(_8781);
  _4232->pushi32(_4256);
  _4232->pushi32(_4255);
  int _8783 = (int)0;
  int _8784 = _4244;
  for (int _4269 = _8783; _4269 < _8784; ++_4269)
  {
    {
      _4232->pushi32(_ptr__4245[_4269]);
    }
  }
  _4232->pushi32(_4244);
  std::shared_ptr< monty::ndarray< int,1 > > _4270 = mosek::fusion::p_WorkStack::_get_impl(_4232)->i32;
  _checked_ptr_1<int> _ptr__4270(_4270 ? _4270->raw() : nullptr,_4270 ? _4270->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4271 = mosek::fusion::p_WorkStack::_get_impl(_4232)->i64;
  _checked_ptr_1<long long> _ptr__4271(_4271 ? _4271->raw() : nullptr,_4271 ? _4271->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4272 = mosek::fusion::p_WorkStack::_get_impl(_4232)->f64;
  _checked_ptr_1<double> _ptr__4272(_4272 ? _4272->raw() : nullptr,_4272 ? _4272->size(0) : 0);
  _ptr__4270[_4264] = (int)0;
  int _8785 = (int)0;
  int _8786 = _4255;
  for (int _4273 = _8785; _4273 < _8786; ++_4273)
  {
    {
      _ptr__4272[safe_add( _4268,_4273 )] = 0.0;
    }
  }
  int _8787 = (int)0;
  int _8788 = safe_add( _4255,(int)1 );
  for (int _4274 = _8787; _4274 < _8788; ++_4274)
  {
    {
      _ptr__4270[safe_add( _4264,_4274 )] = (int)0;
    }
  }
  if (_4253)
  {
    {
      int _8789 = (int)0;
      int _8790 = _4235;
      for (int _4275 = _8789; _4275 < _8790; ++_4275)
      {
        {
          if ((_ptr__4241[_4275] >= (int)0))
          {
            {
              int _8791 = (int)0;
              int _8792 = _ptr__4237[_4275];
              for (int _4276 = _8791; _4276 < _8792; ++_4276)
              {
                {
                  _ptr__4270[safe_add( safe_add( _4264,_ptr__4251[safe_add( _ptr__4241[_4275],_4276 )] ),(int)1 )] += (_ptr__4250[safe_add( safe_add( _ptr__4239[_4275],_4276 ),(int)1 )] - _ptr__4250[safe_add( _ptr__4239[_4275],_4276 )]);
                }
              }
            }
          }
          else
          {
            {
              int _8793 = (int)0;
              int _8794 = _ptr__4237[_4275];
              for (int _4277 = _8793; _4277 < _8794; ++_4277)
              {
                {
                  _ptr__4270[safe_add( safe_add( _4264,_4277 ),(int)1 )] += (_ptr__4250[safe_add( safe_add( _ptr__4239[_4275],_4277 ),(int)1 )] - _ptr__4250[safe_add( _ptr__4239[_4275],_4277 )]);
                }
              }
            }
          }
        }
      }
      int _8795 = (int)0;
      int _8796 = _4255;
      for (int _4278 = _8795; _4278 < _8796; ++_4278)
      {
        {
          _ptr__4270[safe_add( safe_add( _4264,_4278 ),(int)1 )] += _ptr__4270[safe_add( _4264,_4278 )];
        }
      }
      int _8797 = (int)0;
      int _8798 = _4235;
      for (int _4279 = _8797; _4279 < _8798; ++_4279)
      {
        {
          if ((_ptr__4241[_4279] >= (int)0))
          {
            {
              int _8799 = (int)0;
              int _8800 = _ptr__4237[_4279];
              for (int _4280 = _8799; _4280 < _8800; ++_4280)
              {
                {
                  int _4281 = _ptr__4250[safe_add( _ptr__4239[_4279],_4280 )];
                  int _4282 = _ptr__4250[safe_add( safe_add( _ptr__4239[_4279],_4280 ),(int)1 )];
                  long long _4283 = _ptr__4251[safe_add( _ptr__4241[_4279],_4280 )];
                  int _4284 = _ptr__4270[safe_add( _4264,_4283 )];
                  int _8801 = _4281;
                  int _8802 = _4282;
                  for (int _4285 = _8801; _4285 < _8802; ++_4285)
                  {
                    {
                      _ptr__4271[safe_add( _4265,_4284 )] = _ptr__4251[safe_add( _ptr__4240[_4279],_4285 )];
                      _ptr__4272[safe_add( _4267,_4284 )] = (((*w)(_4279)) * _ptr__4252[safe_add( _ptr__4242[_4279],_4285 )]);
                      ++ _4284;
                    }
                  }
                  _ptr__4272[safe_add( _4268,_4283 )] += (((*w)(_4279)) * _ptr__4252[safe_add( _ptr__4243[_4279],_4280 )]);
                  _ptr__4270[safe_add( _4264,_4283 )] += (_4282 - _4281);
                }
              }
            }
          }
          else
          {
            {
              int _8803 = (int)0;
              int _8804 = _ptr__4237[_4279];
              for (int _4286 = _8803; _4286 < _8804; ++_4286)
              {
                {
                  int _4287 = _ptr__4250[safe_add( _ptr__4239[_4279],_4286 )];
                  int _4288 = _ptr__4250[safe_add( safe_add( _ptr__4239[_4279],_4286 ),(int)1 )];
                  int _4289 = _4286;
                  int _4290 = _ptr__4270[safe_add( _4264,_4289 )];
                  int _8805 = _4287;
                  int _8806 = _4288;
                  for (int _4291 = _8805; _4291 < _8806; ++_4291)
                  {
                    {
                      _ptr__4271[safe_add( _4265,_4290 )] = _ptr__4251[safe_add( _ptr__4240[_4279],_4291 )];
                      _ptr__4272[safe_add( _4267,_4290 )] = (((*w)(_4279)) * _ptr__4252[safe_add( _ptr__4242[_4279],_4291 )]);
                      ++ _4290;
                    }
                  }
                  _ptr__4272[safe_add( _4268,_4289 )] += (((*w)(_4279)) * _ptr__4252[safe_add( _ptr__4243[_4279],_4286 )]);
                  _ptr__4270[safe_add( _4264,_4289 )] += (_4288 - _4287);
                }
              }
            }
          }
        }
      }
      int _8807 = (int)0;
      int _8808 = _4255;
      for (int _4292 = _8807; _4292 < _8808; ++_4292)
      {
        {
          _ptr__4270[(safe_add( _4264,_4255 ) - _4292)] = _ptr__4270[((safe_add( _4264,_4255 ) - _4292) - (int)1)];
        }
      }
      _ptr__4270[_4264] = (int)0;
    }
  }
  else
  {
    {
      bool _4293 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _4294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4235)));
      _checked_ptr_1<int> _ptr__4294(_4294 ? _4294->raw() : nullptr,_4294 ? _4294->size(0) : 0);
      int _4295 = (int)0;
      int _4296 = (int)0;
      while ( (!_4293) )
      {
        {
          long long _4297 = (-(int)1);
          int _8809 = (int)0;
          int _8810 = _4235;
          for (int _4298 = _8809; _4298 < _8810; ++_4298)
          {
            {
              if (((_ptr__4294[_4298] < _ptr__4237[_4298]) && ((_4297 < (int)0) || (_ptr__4251[safe_add( _ptr__4241[_4298],_ptr__4294[_4298] )] < _4297))))
              {
                {
                  _4297 = _ptr__4251[safe_add( _ptr__4241[_4298],_ptr__4294[_4298] )];
                }
              }
              {}
            }
          }
          if ((_4297 < (int)0))
          {
            {
              _4293 = true;
            }
          }
          else
          {
            {
              int _8811 = (int)0;
              int _8812 = _4235;
              for (int _4299 = _8811; _4299 < _8812; ++_4299)
              {
                {
                  if (((_ptr__4294[_4299] < _ptr__4237[_4299]) && (_4297 == _ptr__4251[safe_add( _ptr__4241[_4299],_ptr__4294[_4299] )])))
                  {
                    {
                      int _8813 = _ptr__4250[safe_add( _ptr__4239[_4299],_ptr__4294[_4299] )];
                      int _8814 = _ptr__4250[safe_add( safe_add( _ptr__4239[_4299],_ptr__4294[_4299] ),(int)1 )];
                      for (int _4300 = _8813; _4300 < _8814; ++_4300)
                      {
                        {
                          _ptr__4271[safe_add( _4265,_4296 )] = _ptr__4251[safe_add( _ptr__4240[_4299],_4300 )];
                          _ptr__4272[safe_add( _4267,_4296 )] = (((*w)(_4299)) * _ptr__4252[safe_add( _ptr__4242[_4299],_4300 )]);
                          ++ _4296;
                        }
                      }
                      _ptr__4272[safe_add( _4268,_4295 )] += (((*w)(_4299)) * _ptr__4252[safe_add( _ptr__4243[_4299],_ptr__4294[_4299] )]);
                      ++ _ptr__4294[_4299];
                    }
                  }
                  {}
                }
              }
              _ptr__4270[safe_add( safe_add( _4264,_4295 ),(int)1 )] = _4296;
              _ptr__4271[safe_add( _4266,_4295 )] = _4297;
            }
          }
          ++ _4295;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  return std::string ("ExprWSum()");
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _4301,    monty::rc_ptr< ::mosek::fusion::Expression > _4302){ return new mosek::fusion::ExprSumReduce(_4301,_4302); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _4301,    monty::rc_ptr< ::mosek::fusion::Expression > _4302) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_4301,_4302); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _4301,    monty::rc_ptr< ::mosek::fusion::Expression > _4302){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_4301,_4302->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _4302;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _4301;
    std::shared_ptr< monty::ndarray< int,1 > > _4303 = _4302->getShape();
    _checked_ptr_1<int> _ptr__4303(_4303 ? _4303->raw() : nullptr,_4303 ? _4303->size(0) : 0);
    if (((int)((_4303)->size(0)) <= _4301))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4304,monty::rc_ptr< ::mosek::fusion::WorkStack > _4305,monty::rc_ptr< ::mosek::fusion::WorkStack > _4306) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_4304,_4305,_4306); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4304,monty::rc_ptr< ::mosek::fusion::WorkStack > _4305,monty::rc_ptr< ::mosek::fusion::WorkStack > _4306){
  expr->eval(_4305,_4304,_4306);
  _4305->pop_expr();
  int _4307 = mosek::fusion::p_WorkStack::_get_impl(_4305)->nd;
  int _4308 = mosek::fusion::p_WorkStack::_get_impl(_4305)->shape_base;
  int _4309 = mosek::fusion::p_WorkStack::_get_impl(_4305)->nelem;
  int _4310 = mosek::fusion::p_WorkStack::_get_impl(_4305)->nnz;
  bool _4311 = mosek::fusion::p_WorkStack::_get_impl(_4305)->hassp;
  int _4312 = mosek::fusion::p_WorkStack::_get_impl(_4305)->ptr_base;
  int _4313 = mosek::fusion::p_WorkStack::_get_impl(_4305)->sp_base;
  int _4314 = mosek::fusion::p_WorkStack::_get_impl(_4305)->nidxs_base;
  int _4315 = mosek::fusion::p_WorkStack::_get_impl(_4305)->bfix_base;
  int _4316 = mosek::fusion::p_WorkStack::_get_impl(_4305)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4317 = mosek::fusion::p_WorkStack::_get_impl(_4305)->i32;
  _checked_ptr_1<int> _ptr__4317(_4317 ? _4317->raw() : nullptr,_4317 ? _4317->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4318 = mosek::fusion::p_WorkStack::_get_impl(_4305)->i64;
  _checked_ptr_1<long long> _ptr__4318(_4318 ? _4318->raw() : nullptr,_4318 ? _4318->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4319 = mosek::fusion::p_WorkStack::_get_impl(_4305)->f64;
  _checked_ptr_1<double> _ptr__4319(_4319 ? _4319->raw() : nullptr,_4319 ? _4319->size(0) : 0);
  int _4320 = (int)99999;
  int _4321 = (int)99999;
  int _4322 = (int)99999;
  if (_4311)
  {
    {
      int _4323 = (int)0;
      int _8815 = (int)0;
      int _8816 = _4307;
      for (int _4324 = _8815; _4324 < _8816; ++_4324)
      {
        {
          if ((_4323 < _ptr__4317[safe_add( _4308,_4324 )]))
          {
            {
              _4323 = _ptr__4317[safe_add( _4308,_4324 )];
            }
          }
          {}
        }
      }
      _4320 = _4306->alloci32(safe_add( _4323,(int)1 ));
      _4321 = _4306->alloci32(_4309);
      _4322 = _4306->alloci32(_4309);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _4325 = mosek::fusion::p_WorkStack::_get_impl(_4306)->i32;
  _checked_ptr_1<int> _ptr__4325(_4325 ? _4325->raw() : nullptr,_4325 ? _4325->size(0) : 0);
  if (_4311)
  {
    {
      int _4326 = _4321;
      int _4327 = _4322;
      int _8817 = (int)0;
      int _8818 = _4309;
      for (int _4328 = _8817; _4328 < _8818; ++_4328)
      {
        {
          _ptr__4325[safe_add( _4326,_4328 )] = _4328;
        }
      }
      if ((dim < (_4307 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _4329 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4307)));
          _checked_ptr_1<long long> _ptr__4329(_4329 ? _4329->raw() : nullptr,_4329 ? _4329->size(0) : 0);
          _ptr__4329[(_4307 - (int)1)] = (int)1;
          int _8819 = (int)1;
          int _8820 = _4307;
          for (int _4330 = _8819; _4330 < _8820; ++_4330)
          {
            {
              _ptr__4329[((_4307 - _4330) - (int)1)] = safe_mul( _ptr__4329[(_4307 - _4330)],_ptr__4317[(safe_add( _4308,_4307 ) - _4330)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _4331 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_4307 - (int)1))));
          _checked_ptr_1<int> _ptr__4331(_4331 ? _4331->raw() : nullptr,_4331 ? _4331->size(0) : 0);
          int _8821 = (int)0;
          int _8822 = dim;
          for (int _4332 = _8821; _4332 < _8822; ++_4332)
          {
            {
              _ptr__4331[((_4307 - _4332) - (int)2)] = _4332;
            }
          }
          int _8823 = safe_add( dim,(int)1 );
          int _8824 = _4307;
          for (int _4333 = _8823; _4333 < _8824; ++_4333)
          {
            {
              _ptr__4331[((_4307 - _4333) - (int)1)] = _4333;
            }
          }
          int _8825 = (int)0;
          int _8826 = (_4307 - (int)1);
          for (int _4334 = _8825; _4334 < _8826; ++_4334)
          {
            {
              int _4335 = _ptr__4331[_4334];
              int _4336 = _ptr__4317[safe_add( _4308,_4335 )];
              int _8827 = (int)0;
              int _8828 = safe_add( _4336,(int)1 );
              for (int _4337 = _8827; _4337 < _8828; ++_4337)
              {
                {
                  _ptr__4325[safe_add( _4320,_4337 )] = (int)0;
                }
              }
              int _8829 = (int)0;
              int _8830 = _4309;
              for (int _4338 = _8829; _4338 < _8830; ++_4338)
              {
                {
                  ++ _ptr__4325[safe_add( safe_add( _4320,(int)1 ),((_ptr__4318[safe_add( _4313,_4338 )] / _ptr__4329[_4335]) % _4336) )];
                }
              }
              int _8831 = (int)0;
              int _8832 = _4336;
              for (int _4339 = _8831; _4339 < _8832; ++_4339)
              {
                {
                  _ptr__4325[safe_add( safe_add( _4320,_4339 ),(int)1 )] += _ptr__4325[safe_add( _4320,_4339 )];
                }
              }
              int _8833 = (int)0;
              int _8834 = _4309;
              for (int _4340 = _8833; _4340 < _8834; ++_4340)
              {
                {
                  int _4341 = _ptr__4325[safe_add( _4326,_4340 )];
                  long long _4342 = ((_ptr__4318[safe_add( _4313,_4341 )] / _ptr__4329[_4335]) % _4336);
                  _ptr__4325[safe_add( _4327,_ptr__4325[safe_add( _4320,_4342 )] )] = _4341;
                  ++ _ptr__4325[safe_add( _4320,_4342 )];
                }
              }
              int _4343 = _4327;
              _4327 = _4326;
              _4326 = _4343;
            }
          }
        }
      }
      {}
      int _4344 = (int)1;
      int _8835 = (int)0;
      int _8836 = dim;
      for (int _4345 = _8835; _4345 < _8836; ++_4345)
      {
        {
          _4344 *= _ptr__4317[safe_add( _4308,_4345 )];
        }
      }
      int _4346 = _ptr__4317[safe_add( _4308,dim )];
      int _4347 = (int)1;
      int _8837 = safe_add( dim,(int)1 );
      int _8838 = _4307;
      for (int _4348 = _8837; _4348 < _8838; ++_4348)
      {
        {
          _4347 *= _ptr__4317[safe_add( _4308,_4348 )];
        }
      }
      int _4349 = safe_mul( _4347,_4346 );
      int _4350 = _4347;
      int _4351 = (int)1;
      int _4352 = (int)0;
      long long _4353 = (-(int)1);
      long long _4354 = (-(int)1);
      int _8839 = (int)0;
      int _8840 = _4309;
      for (int _4355 = _8839; _4355 < _8840; ++_4355)
      {
        {
          int _4356 = _ptr__4325[safe_add( _4326,_4355 )];
          long long _4357 = ((_ptr__4318[safe_add( _4313,_4356 )] / _4349) % _4344);
          long long _4358 = (_ptr__4318[safe_add( _4313,_4356 )] % _4347);
          if (((_4354 != _4357) || (_4353 != _4358)))
          {
            {
              _4354 = _4357;
              _4353 = _4358;
              ++ _4352;
            }
          }
          {}
        }
      }
      int _4359 = (_4307 - (int)1);
      bool _4360 = (_4352 < safe_mul( _4344,_4347 ));
      int _4361 = _4310;
      _4304->alloc_expr(_4359,_4352,_4361,_4360);
      int _4362 = mosek::fusion::p_WorkStack::_get_impl(_4304)->ptr_base;
      int _4363 = mosek::fusion::p_WorkStack::_get_impl(_4304)->nidxs_base;
      int _8841;
      bool _8842 = _4360;
      if (_8842)
      {
        _8841 = mosek::fusion::p_WorkStack::_get_impl(_4304)->sp_base;
      }
      else
      {
        _8841 = _4304->alloci64(_4352);
      }
      int _4364 = _8841;
      int _4365 = mosek::fusion::p_WorkStack::_get_impl(_4304)->cof_base;
      int _4366 = mosek::fusion::p_WorkStack::_get_impl(_4304)->bfix_base;
      int _4367 = mosek::fusion::p_WorkStack::_get_impl(_4304)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4368 = mosek::fusion::p_WorkStack::_get_impl(_4304)->i32;
      _checked_ptr_1<int> _ptr__4368(_4368 ? _4368->raw() : nullptr,_4368 ? _4368->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4369 = mosek::fusion::p_WorkStack::_get_impl(_4304)->i64;
      _checked_ptr_1<long long> _ptr__4369(_4369 ? _4369->raw() : nullptr,_4369 ? _4369->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4370 = mosek::fusion::p_WorkStack::_get_impl(_4304)->f64;
      _checked_ptr_1<double> _ptr__4370(_4370 ? _4370->raw() : nullptr,_4370 ? _4370->size(0) : 0);
      int _8843 = (int)0;
      int _8844 = dim;
      for (int _4371 = _8843; _4371 < _8844; ++_4371)
      {
        {
          _ptr__4368[safe_add( _4367,_4371 )] = _ptr__4317[safe_add( _4308,_4371 )];
        }
      }
      int _8845 = safe_add( dim,(int)1 );
      int _8846 = _4307;
      for (int _4372 = _8845; _4372 < _8846; ++_4372)
      {
        {
          _ptr__4368[(safe_add( _4367,_4372 ) - (int)1)] = _ptr__4317[safe_add( _4308,_4372 )];
        }
      }
      _ptr__4368[_4362] = (int)0;
      int _4373 = (int)0;
      int _4374 = (int)0;
      int _4375 = (int)0;
      while ( (_4375 < _4309) )
      {
        {
          int _4376 = _4375;
          long long _4377 = ((_ptr__4318[safe_add( _4313,_ptr__4325[safe_add( _4326,_4376 )] )] / _4349) % _4344);
          long long _4378 = (_ptr__4318[safe_add( _4313,_ptr__4325[safe_add( _4326,_4376 )] )] % _4347);
          ++ _4375;
          while ( ((_4375 < _4309) && ((_4377 == ((_ptr__4318[safe_add( _4313,_ptr__4325[safe_add( _4326,_4375 )] )] / _4349) % _4344)) && (_4378 == (_ptr__4318[safe_add( _4313,_ptr__4325[safe_add( _4326,_4375 )] )] % _4347)))) )
          {
            {
              ++ _4375;
            }
          }
          double _4379 = 0.0;
          int _8847 = _4376;
          int _8848 = _4375;
          for (int _4380 = _8847; _4380 < _8848; ++_4380)
          {
            {
              int _4381 = _ptr__4325[safe_add( _4326,_4380 )];
              int _8849 = _ptr__4317[safe_add( _4312,_4381 )];
              int _8850 = _ptr__4317[safe_add( safe_add( _4312,_4381 ),(int)1 )];
              for (int _4382 = _8849; _4382 < _8850; ++_4382)
              {
                {
                  _ptr__4369[safe_add( _4363,_4374 )] = _ptr__4318[safe_add( _4314,_4382 )];
                  _ptr__4370[safe_add( _4365,_4374 )] = _ptr__4319[safe_add( _4316,_4382 )];
                  ++ _4374;
                }
              }
              _4379 += _ptr__4319[safe_add( _4315,_4381 )];
            }
          }
          _ptr__4369[safe_add( _4364,_4373 )] = safe_add( safe_mul( _4377,_4347 ),_4378 );
          _ptr__4368[safe_add( safe_add( _4362,_4373 ),(int)1 )] = _4374;
          _ptr__4370[safe_add( _4366,_4373 )] = _4379;
          ++ _4373;
        }
      }
      if ((!_4360))
      {
        {
          _4304->popi64(_4352);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4383 = (int)1;
      int _8851 = (int)0;
      int _8852 = dim;
      for (int _4384 = _8851; _4384 < _8852; ++_4384)
      {
        {
          _4383 *= _ptr__4317[safe_add( _4308,_4384 )];
        }
      }
      int _4385 = _ptr__4317[safe_add( _4308,dim )];
      int _4386 = (int)1;
      int _8853 = safe_add( dim,(int)1 );
      int _8854 = _4307;
      for (int _4387 = _8853; _4387 < _8854; ++_4387)
      {
        {
          _4386 *= _ptr__4317[safe_add( _4308,_4387 )];
        }
      }
      int _4388 = safe_mul( _4386,_4385 );
      int _4389 = _4386;
      int _4390 = (int)1;
      int _4391 = safe_mul( _4383,_4386 );
      int _4392 = _4304->alloci32(safe_add( _4391,(int)1 ));
      int _4393 = _4304->alloci64(_4310);
      int _4394 = _4304->allocf64(_4310);
      int _4395 = _4304->allocf64(_4391);
      _4304->pushi32((int)0);
      _4304->pushi32(_4310);
      _4304->pushi32(_4391);
      int _4396 = _4304->alloci32((_4307 - (int)1));
      _4304->pushi32((_4307 - (int)1));
      std::shared_ptr< monty::ndarray< int,1 > > _4397 = mosek::fusion::p_WorkStack::_get_impl(_4304)->i32;
      _checked_ptr_1<int> _ptr__4397(_4397 ? _4397->raw() : nullptr,_4397 ? _4397->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4398 = mosek::fusion::p_WorkStack::_get_impl(_4304)->i64;
      _checked_ptr_1<long long> _ptr__4398(_4398 ? _4398->raw() : nullptr,_4398 ? _4398->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4399 = mosek::fusion::p_WorkStack::_get_impl(_4304)->f64;
      _checked_ptr_1<double> _ptr__4399(_4399 ? _4399->raw() : nullptr,_4399 ? _4399->size(0) : 0);
      int _8855 = (int)0;
      int _8856 = dim;
      for (int _4400 = _8855; _4400 < _8856; ++_4400)
      {
        {
          _ptr__4397[safe_add( _4396,_4400 )] = _ptr__4317[safe_add( _4308,_4400 )];
        }
      }
      int _8857 = safe_add( dim,(int)1 );
      int _8858 = _4307;
      for (int _4401 = _8857; _4401 < _8858; ++_4401)
      {
        {
          _ptr__4397[(safe_add( _4396,_4401 ) - (int)1)] = _ptr__4317[safe_add( _4308,_4401 )];
        }
      }
      int _4402 = (int)0;
      int _4403 = (int)0;
      _ptr__4397[_4392] = (int)0;
      int _8859 = (int)0;
      int _8860 = _4383;
      for (int _4404 = _8859; _4404 < _8860; ++_4404)
      {
        {
          int _8861 = (int)0;
          int _8862 = _4386;
          for (int _4405 = _8861; _4405 < _8862; ++_4405)
          {
            {
              double _4406 = 0.0;
              int _8863 = (int)0;
              int _8864 = _4385;
              for (int _4407 = _8863; _4407 < _8864; ++_4407)
              {
                {
                  int _4408 = safe_add( safe_add( safe_mul( _4404,_4388 ),safe_mul( _4407,_4389 ) ),_4405 );
                  int _8865 = _ptr__4317[safe_add( _4312,_4408 )];
                  int _8866 = _ptr__4317[safe_add( safe_add( _4312,_4408 ),(int)1 )];
                  for (int _4409 = _8865; _4409 < _8866; ++_4409)
                  {
                    {
                      _ptr__4398[safe_add( _4393,_4403 )] = _ptr__4318[safe_add( _4314,_4409 )];
                      _ptr__4399[safe_add( _4394,_4403 )] = _ptr__4319[safe_add( _4316,_4409 )];
                      ++ _4403;
                    }
                  }
                  _4406 += _ptr__4319[safe_add( _4315,_4408 )];
                }
              }
              _ptr__4397[safe_add( safe_add( _4392,_4402 ),(int)1 )] = _4403;
              _ptr__4399[safe_add( _4395,_4402 )] = _4406;
              ++ _4402;
            }
          }
        }
      }
    }
  }
  _4306->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _4410,std::shared_ptr< monty::ndarray< int,1 > > _4411){
  _checked_ptr_1<int> _ptr__4411(_4411 ? _4411->raw() : nullptr, _4411 ? _4411->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4412 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_4411)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__4412(_4412 ? _4412->raw() : nullptr,_4412 ? _4412->size(0) : 0);
  int _8867 = (int)0;
  int _8868 = _4410;
  for (int _4413 = _8867; _4413 < _8868; ++_4413)
  {
    {
      _ptr__4412[_4413] = _ptr__4411[_4413];
    }
  }
  int _8869 = safe_add( _4410,(int)1 );
  int _8870 = (int)((_4411)->size(0));
  for (int _4414 = _8869; _4414 < _8870; ++_4414)
  {
    {
      _ptr__4412[(_4414 - (int)1)] = _ptr__4411[_4414];
    }
  }
  return _4412;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return std::string ("ExprSumReduce()");
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4415,    int _4416,    monty::rc_ptr< ::mosek::fusion::Expression > _4417,    int _4418){ return new mosek::fusion::ExprDenseTril(_4415,_4416,_4417,_4418); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4415,    int _4416,    monty::rc_ptr< ::mosek::fusion::Expression > _4417,    int _4418) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4415,_4416,_4417,_4418); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4415,    int _4416,    monty::rc_ptr< ::mosek::fusion::Expression > _4417,    int _4418){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4417->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _4417;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _4415;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _4416;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _4419,    int _4420,    monty::rc_ptr< ::mosek::fusion::Expression > _4421){ return new mosek::fusion::ExprDenseTril(_4419,_4420,_4421); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _4419,    int _4420,    monty::rc_ptr< ::mosek::fusion::Expression > _4421) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_4419,_4420,_4421); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _4419,    int _4420,    monty::rc_ptr< ::mosek::fusion::Expression > _4421){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_4419,_4420,_4421,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4422 = _4421->getShape();
    _checked_ptr_1<int> _ptr__4422(_4422 ? _4422->raw() : nullptr,_4422 ? _4422->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_4422)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_4422)->size(0))) || (_ptr__4422[dim0] != _ptr__4422[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4423,monty::rc_ptr< ::mosek::fusion::WorkStack > _4424,monty::rc_ptr< ::mosek::fusion::WorkStack > _4425) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_4423,_4424,_4425); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4423,monty::rc_ptr< ::mosek::fusion::WorkStack > _4424,monty::rc_ptr< ::mosek::fusion::WorkStack > _4425){
  expr->eval(_4424,_4423,_4425);
  std::shared_ptr< monty::ndarray< int,1 > > _4426 = mosek::fusion::p_WorkStack::_get_impl(_4424)->i32;
  _checked_ptr_1<int> _ptr__4426(_4426 ? _4426->raw() : nullptr,_4426 ? _4426->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4427 = mosek::fusion::p_WorkStack::_get_impl(_4424)->i64;
  _checked_ptr_1<long long> _ptr__4427(_4427 ? _4427->raw() : nullptr,_4427 ? _4427->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4428 = mosek::fusion::p_WorkStack::_get_impl(_4424)->f64;
  _checked_ptr_1<double> _ptr__4428(_4428 ? _4428->raw() : nullptr,_4428 ? _4428->size(0) : 0);
  int _8871;
  bool _8872 = (dim0 < dim1);
  if (_8872)
  {
    _8871 = dim0;
  }
  else
  {
    _8871 = dim1;
  }
  int _4429 = _8871;
  int _8873;
  bool _8874 = (dim0 > dim1);
  if (_8874)
  {
    _8873 = dim0;
  }
  else
  {
    _8873 = dim1;
  }
  int _4430 = _8873;
  bool _4431 = (dim0 < dim1);
  int _4432 = _4424->popi32();
  int _4433 = _4424->popi32(_4432);
  int _4434 = _4424->popi32();
  int _4435 = _4424->popi32();
  bool _4436 = (_4424->popi32() != (int)0);
  int _4437 = _4424->popi32(safe_add( _4434,(int)1 ));
  int _8875;
  bool _8876 = _4436;
  if (_8876)
  {
    _8875 = _4424->popi64(_4434);
  }
  else
  {
    _8875 = (-(int)1);
  }
  int _4438 = _8875;
  int _4439 = _4424->popi64(_4435);
  int _4440 = _4424->popf64(_4434);
  int _4441 = _4424->popf64(_4435);
  std::vector<int> _8877;
  for (int _4443 = (int)0, _8878 = (int)5; _4443 < _8878 ; ++_4443)
  {
    _8877.push_back((int)1);
  }
  auto _8879 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8877.size()),_8877.begin(),_8877.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4442 = _8879;
  _checked_ptr_1<int> _ptr__4442(_4442 ? _4442->raw() : nullptr,_4442 ? _4442->size(0) : 0);
  int _8880 = (int)0;
  int _8881 = _4429;
  for (int _4444 = _8880; _4444 < _8881; ++_4444)
  {
    {
      _ptr__4442[(int)0] *= _ptr__4426[safe_add( _4433,_4444 )];
    }
  }
  _ptr__4442[(int)1] = _ptr__4426[safe_add( _4433,_4429 )];
  int _8882 = safe_add( _4429,(int)1 );
  int _8883 = _4430;
  for (int _4445 = _8882; _4445 < _8883; ++_4445)
  {
    {
      _ptr__4442[(int)2] *= _ptr__4426[safe_add( _4433,_4445 )];
    }
  }
  _ptr__4442[(int)3] = _ptr__4426[safe_add( _4433,_4430 )];
  int _8884 = safe_add( _4430,(int)1 );
  int _8885 = _4432;
  for (int _4446 = _8884; _4446 < _8885; ++_4446)
  {
    {
      _ptr__4442[(int)4] *= _ptr__4426[safe_add( _4433,_4446 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4447 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__4447(_4447 ? _4447->raw() : nullptr,_4447 ? _4447->size(0) : 0);
  _ptr__4447[(int)4] = (int)1;
  int _8886 = (int)1;
  int _8887 = (int)5;
  for (int _4448 = _8886; _4448 < _8887; ++_4448)
  {
    {
      _ptr__4447[(((int)5 - _4448) - (int)1)] = safe_mul( _ptr__4447[((int)5 - _4448)],_ptr__4442[((int)5 - _4448)] );
    }
  }
  int _4449 = (int)0;
  int _4450 = (int)0;
  {
    if (_4436)
    {
      {
        if (_4431)
        {
          {
            int _8888 = (int)0;
            int _8889 = _4434;
            for (int _4451 = _8888; _4451 < _8889; ++_4451)
            {
              {
                long long _4452 = ((_ptr__4427[safe_add( _4438,_4451 )] / _ptr__4447[(int)1]) % _ptr__4442[(int)1]);
                long long _4453 = ((_ptr__4427[safe_add( _4438,_4451 )] / _ptr__4447[(int)3]) % _ptr__4442[(int)3]);
                if ((_4452 >= _4453))
                {
                  {
                    _4449 += (_ptr__4426[safe_add( safe_add( _4437,_4451 ),(int)1 )] - _ptr__4426[safe_add( _4437,_4451 )]);
                    ++ _4450;
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _8890 = (int)0;
            int _8891 = _4434;
            for (int _4454 = _8890; _4454 < _8891; ++_4454)
            {
              {
                long long _4455 = ((_ptr__4427[safe_add( _4438,_4454 )] / _ptr__4447[(int)1]) % _ptr__4442[(int)1]);
                long long _4456 = ((_ptr__4427[safe_add( _4438,_4454 )] / _ptr__4447[(int)3]) % _ptr__4442[(int)3]);
                if ((_4455 <= _4456))
                {
                  {
                    _4449 += (_ptr__4426[safe_add( safe_add( _4437,_4454 ),(int)1 )] - _ptr__4426[safe_add( _4437,_4454 )]);
                    ++ _4450;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        _4450 = safe_mul( safe_mul( safe_mul( _ptr__4442[(int)0],_ptr__4442[(int)2] ),_ptr__4442[(int)4] ),(safe_mul( _ptr__4442[(int)1],safe_add( _ptr__4442[(int)1],(int)1 ) ) / (int)2) );
        if (_4431)
        {
          {
            int _8892 = (int)0;
            int _8893 = _ptr__4442[(int)0];
            for (int _4457 = _8892; _4457 < _8893; ++_4457)
            {
              {
                int _8894 = (int)0;
                int _8895 = _ptr__4442[(int)1];
                for (int _4458 = _8894; _4458 < _8895; ++_4458)
                {
                  {
                    int _8896 = (int)0;
                    int _8897 = _ptr__4442[(int)2];
                    for (int _4459 = _8896; _4459 < _8897; ++_4459)
                    {
                      {
                        int _8898 = (int)0;
                        int _8899 = safe_add( _4458,(int)1 );
                        for (int _4460 = _8898; _4460 < _8899; ++_4460)
                        {
                          {
                            int _8900 = (int)0;
                            int _8901 = _ptr__4442[(int)4];
                            for (int _4461 = _8900; _4461 < _8901; ++_4461)
                            {
                              {
                                int _4462 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4457,_ptr__4447[(int)0] ),safe_mul( _4458,_ptr__4447[(int)1] ) ),safe_mul( _4459,_ptr__4447[(int)2] ) ),safe_mul( _4460,_ptr__4447[(int)3] ) ),safe_mul( _4461,_ptr__4447[(int)4] ) );
                                _4449 += (_ptr__4426[safe_add( safe_add( _4437,_4462 ),(int)1 )] - _ptr__4426[safe_add( _4437,_4462 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _8902 = (int)0;
            int _8903 = _ptr__4442[(int)0];
            for (int _4463 = _8902; _4463 < _8903; ++_4463)
            {
              {
                int _8904 = (int)0;
                int _8905 = _ptr__4442[(int)1];
                for (int _4464 = _8904; _4464 < _8905; ++_4464)
                {
                  {
                    int _8906 = (int)0;
                    int _8907 = _ptr__4442[(int)2];
                    for (int _4465 = _8906; _4465 < _8907; ++_4465)
                    {
                      {
                        int _8908 = _4464;
                        int _8909 = _ptr__4442[(int)3];
                        for (int _4466 = _8908; _4466 < _8909; ++_4466)
                        {
                          {
                            int _8910 = (int)0;
                            int _8911 = _ptr__4442[(int)4];
                            for (int _4467 = _8910; _4467 < _8911; ++_4467)
                            {
                              {
                                int _4468 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4463,_ptr__4447[(int)0] ),safe_mul( _4464,_ptr__4447[(int)1] ) ),safe_mul( _4465,_ptr__4447[(int)2] ) ),safe_mul( _4466,_ptr__4447[(int)3] ) ),safe_mul( _4467,_ptr__4447[(int)4] ) );
                                _4449 += (_ptr__4426[safe_add( safe_add( _4437,_4468 ),(int)1 )] - _ptr__4426[safe_add( _4437,_4468 )]);
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _4469 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__4442[(int)0],_ptr__4442[(int)2] ),_ptr__4442[(int)4] ),_ptr__4442[(int)1] ),safe_add( _ptr__4442[(int)1],(int)1 ) ) / (int)2);
  int _4470 = _4423->alloci32(safe_add( _4469,(int)1 ));
  _4423->pushi32((int)1);
  _4423->pushi32(_4449);
  _4423->pushi32(_4469);
  int _8912 = (int)0;
  int _8913 = _4432;
  for (int _4471 = _8912; _4471 < _8913; ++_4471)
  {
    {
      _4423->pushi32(_ptr__4426[safe_add( _4433,_4471 )]);
    }
  }
  _4423->pushi32(_4432);
  int _4472 = _4423->alloci64(_4449);
  int _4473 = _4423->alloci64(_4469);
  int _4474 = _4423->allocf64(_4449);
  int _4475 = _4423->allocf64(_4469);
  std::shared_ptr< monty::ndarray< int,1 > > _4476 = mosek::fusion::p_WorkStack::_get_impl(_4423)->i32;
  _checked_ptr_1<int> _ptr__4476(_4476 ? _4476->raw() : nullptr,_4476 ? _4476->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4477 = mosek::fusion::p_WorkStack::_get_impl(_4423)->i64;
  _checked_ptr_1<long long> _ptr__4477(_4477 ? _4477->raw() : nullptr,_4477 ? _4477->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4478 = mosek::fusion::p_WorkStack::_get_impl(_4423)->f64;
  _checked_ptr_1<double> _ptr__4478(_4478 ? _4478->raw() : nullptr,_4478 ? _4478->size(0) : 0);
  _ptr__4476[_4470] = (int)0;
  if (_4431)
  {
    {
      int _4479 = (int)0;
      int _8914 = (int)0;
      int _8915 = _ptr__4442[(int)0];
      for (int _4480 = _8914; _4480 < _8915; ++_4480)
      {
        {
          int _8916 = (int)0;
          int _8917 = _ptr__4442[(int)1];
          for (int _4481 = _8916; _4481 < _8917; ++_4481)
          {
            {
              int _8918 = (int)0;
              int _8919 = _ptr__4442[(int)2];
              for (int _4482 = _8918; _4482 < _8919; ++_4482)
              {
                {
                  int _8920 = (int)0;
                  int _8921 = safe_add( _4481,(int)1 );
                  for (int _4483 = _8920; _4483 < _8921; ++_4483)
                  {
                    {
                      int _8922 = (int)0;
                      int _8923 = _ptr__4442[(int)4];
                      for (int _4484 = _8922; _4484 < _8923; ++_4484)
                      {
                        {
                          _ptr__4477[safe_add( _4473,_4479 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4480,_ptr__4447[(int)0] ),safe_mul( _4481,_ptr__4447[(int)1] ) ),safe_mul( _4482,_ptr__4447[(int)2] ) ),safe_mul( _4483,_ptr__4447[(int)3] ) ),safe_mul( _4484,_ptr__4447[(int)4] ) );
                          ++ _4479;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _4485 = (int)0;
      int _8924 = (int)0;
      int _8925 = _ptr__4442[(int)0];
      for (int _4486 = _8924; _4486 < _8925; ++_4486)
      {
        {
          int _8926 = (int)0;
          int _8927 = _ptr__4442[(int)1];
          for (int _4487 = _8926; _4487 < _8927; ++_4487)
          {
            {
              int _8928 = (int)0;
              int _8929 = _ptr__4442[(int)2];
              for (int _4488 = _8928; _4488 < _8929; ++_4488)
              {
                {
                  int _8930 = _4487;
                  int _8931 = _ptr__4442[(int)3];
                  for (int _4489 = _8930; _4489 < _8931; ++_4489)
                  {
                    {
                      int _8932 = (int)0;
                      int _8933 = _ptr__4442[(int)4];
                      for (int _4490 = _8932; _4490 < _8933; ++_4490)
                      {
                        {
                          _ptr__4477[safe_add( _4473,_4485 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _4486,_ptr__4447[(int)0] ),safe_mul( _4487,_ptr__4447[(int)1] ) ),safe_mul( _4488,_ptr__4447[(int)2] ) ),safe_mul( _4489,_ptr__4447[(int)3] ) ),safe_mul( _4490,_ptr__4447[(int)4] ) );
                          ++ _4485;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  {
    int _4491 = (int)0;
    if (_4436)
    {
      {
        int _4492 = (int)0;
        int _4493 = (int)0;
        while ( ((_4493 < _4434) && (_4492 < _4469)) )
        {
          {
            if ((_ptr__4427[safe_add( _4438,_4493 )] < _ptr__4477[safe_add( _4473,_4492 )]))
            {
              {
                ++ _4493;
              }
            }
            else if((_ptr__4427[safe_add( _4438,_4493 )] > _ptr__4477[safe_add( _4473,_4492 )]))
            {
              {
                _ptr__4478[safe_add( _4475,_4492 )] = 0.0;
                _ptr__4476[safe_add( safe_add( _4470,_4492 ),(int)1 )] = _4491;
                ++ _4492;
              }
            }
            else
            {
              {
                int _8934 = _ptr__4426[safe_add( _4437,_4493 )];
                int _8935 = _ptr__4426[safe_add( safe_add( _4437,_4493 ),(int)1 )];
                for (int _4494 = _8934; _4494 < _8935; ++_4494)
                {
                  {
                    _ptr__4477[safe_add( _4472,_4491 )] = _ptr__4427[safe_add( _4439,_4494 )];
                    _ptr__4478[safe_add( _4474,_4491 )] = _ptr__4428[safe_add( _4441,_4494 )];
                    ++ _4491;
                  }
                }
                _ptr__4478[safe_add( _4475,_4492 )] = _ptr__4428[safe_add( _4440,_4493 )];
                _ptr__4476[safe_add( safe_add( _4470,_4492 ),(int)1 )] = _4491;
                ++ _4493;
                ++ _4492;
              }
            }
          }
        }
        while ( (_4492 < _4469) )
        {
          {
            _ptr__4476[safe_add( safe_add( _4470,_4492 ),(int)1 )] = _4491;
            _ptr__4478[safe_add( _4475,_4492 )] = 0.0;
            ++ _4492;
          }
        }
      }
    }
    else
    {
      {
        int _8936 = (int)0;
        int _8937 = _4469;
        for (int _4495 = _8936; _4495 < _8937; ++_4495)
        {
          {
            long long _4496 = _ptr__4477[safe_add( _4473,_4495 )];
            _ptr__4478[safe_add( _4475,_4495 )] = _ptr__4428[safe_add( _4440,_4496 )];
            int _8938 = _ptr__4426[safe_add( _4437,_4496 )];
            int _8939 = _ptr__4426[safe_add( safe_add( _4437,_4496 ),(int)1 )];
            for (int _4497 = _8938; _4497 < _8939; ++_4497)
            {
              {
                _ptr__4477[safe_add( _4472,_4491 )] = _ptr__4427[safe_add( _4439,_4497 )];
                _ptr__4478[safe_add( _4474,_4491 )] = _ptr__4428[safe_add( _4441,_4497 )];
                ++ _4491;
              }
            }
            _ptr__4476[safe_add( safe_add( _4470,_4495 ),(int)1 )] = _4491;
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4498){ return new mosek::fusion::ExprDense(_4498); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _4498) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_4498); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4498){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4498->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _4498;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_4499,_4500,_4501); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501){
  expr->eval(_4499,_4500,_4501);
  _4499->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_4499)->hassp)
  {
    {
      int _4502 = mosek::fusion::p_WorkStack::_get_impl(_4499)->nd;
      int _4503 = mosek::fusion::p_WorkStack::_get_impl(_4499)->nnz;
      int _4504 = mosek::fusion::p_WorkStack::_get_impl(_4499)->nelem;
      int _4505 = mosek::fusion::p_WorkStack::_get_impl(_4499)->sp_base;
      std::vector<int> _8940;
      for (int _4507 = (int)0, _8941 = _4502; _4507 < _8941 ; ++_4507)
      {
        _8940.push_back(((*mosek::fusion::p_WorkStack::_get_impl(_4499)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_4499)->shape_base,_4507 ))));
      }
      auto _8942 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8940.size()),_8940.begin(),_8940.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _4506 = _8942;
      _checked_ptr_1<int> _ptr__4506(_4506 ? _4506->raw() : nullptr,_4506 ? _4506->size(0) : 0);
      int _4508 = (int)::mosek::fusion::p_Set::size(_4506);
      _4499->popi32(safe_add( (int)4,_4502 ));
      if ((_4508 == _4504))
      {
        {
          _4499->popi64(_4504);
          _4499->pushi32((int)0);
          _4499->pushi32(_4503);
          _4499->pushi32(_4504);
          int _4509 = _4499->alloci32(_4502);
          int _8943 = (int)0;
          int _8944 = _4502;
          for (int _4510 = _8943; _4510 < _8944; ++_4510)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4499)->i32)(safe_add( _4509,_4510 ))) = _ptr__4506[_4510];
            }
          }
          _4499->pushi32(_4502);
          _4499->peek_expr();
        }
      }
      else
      {
        {
          int _4511 = _4501->alloci32(safe_add( _4508,(int)1 ));
          int _4512 = _4501->allocf64(_4508);
          std::shared_ptr< monty::ndarray< int,1 > > _4513 = mosek::fusion::p_WorkStack::_get_impl(_4501)->i32;
          _checked_ptr_1<int> _ptr__4513(_4513 ? _4513->raw() : nullptr,_4513 ? _4513->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4514 = mosek::fusion::p_WorkStack::_get_impl(_4501)->f64;
          _checked_ptr_1<double> _ptr__4514(_4514 ? _4514->raw() : nullptr,_4514 ? _4514->size(0) : 0);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4499)->f64,mosek::fusion::p_WorkStack::_get_impl(_4499)->bfix_base,_4514,_4512,_4504);
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_WorkStack::_get_impl(_4499)->i32,mosek::fusion::p_WorkStack::_get_impl(_4499)->ptr_base,_4513,_4511,safe_add( _4504,(int)1 ));
          _4499->popi32(safe_add( _4504,(int)1 ));
          _4499->popf64(_4504);
          int _4515 = _4499->alloci32(safe_add( _4508,(int)1 ));
          int _4516 = _4499->allocf64(_4508);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _4517 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i32;
            _checked_ptr_1<int> _ptr__4517(_4517 ? _4517->raw() : nullptr,_4517 ? _4517->size(0) : 0);
            std::shared_ptr< monty::ndarray< long long,1 > > _4518 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i64;
            _checked_ptr_1<long long> _ptr__4518(_4518 ? _4518->raw() : nullptr,_4518 ? _4518->size(0) : 0);
            std::shared_ptr< monty::ndarray< double,1 > > _4519 = mosek::fusion::p_WorkStack::_get_impl(_4499)->f64;
            _checked_ptr_1<double> _ptr__4519(_4519 ? _4519->raw() : nullptr,_4519 ? _4519->size(0) : 0);
            _ptr__4517[_4515] = (int)0;
            int _4520 = (int)0;
            if ((_4504 > (int)0))
            {
              {
                int _8945 = (int)0;
                int _8946 = _4508;
                for (int _4521 = _8945; _4521 < _8946; ++_4521)
                {
                  {
                    if ((_ptr__4518[safe_add( _4505,_4520 )] == _4521))
                    {
                      {
                        _ptr__4519[safe_add( _4516,_4521 )] = _ptr__4514[safe_add( _4512,_4520 )];
                        ++ _4520;
                      }
                    }
                    else
                    {
                      {
                        _ptr__4519[safe_add( _4516,_4521 )] = (int)0;
                      }
                    }
                    _ptr__4517[safe_add( safe_add( _4515,_4521 ),(int)1 )] = _ptr__4513[safe_add( _4511,_4520 )];
                  }
                }
              }
            }
            else
            {
              {
                int _8947 = (int)0;
                int _8948 = _4508;
                for (int _4522 = _8947; _4522 < _8948; ++_4522)
                {
                  {
                    _ptr__4519[safe_add( _4516,_4522 )] = (int)0;
                    _ptr__4517[safe_add( safe_add( _4515,_4522 ),(int)1 )] = (int)0;
                  }
                }
              }
            }
          }
          _4499->popi64(_4504);
          _4499->pushi32((int)0);
          _4499->pushi32(_4503);
          _4499->pushi32(_4508);
          int _8949 = (int)0;
          int _8950 = _4502;
          for (int _4523 = _8949; _4523 < _8950; ++_4523)
          {
            {
              _4499->pushi32(_ptr__4506[_4523]);
            }
          }
          _4499->pushi32(_4502);
        }
      }
      _4499->peek_expr();
    }
  }
  {}
  _4501->clear();
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4524,    int _4525,    monty::rc_ptr< ::mosek::fusion::Expression > _4526,    int _4527){ return new mosek::fusion::ExprSymmetrize(_4524,_4525,_4526,_4527); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4524,    int _4525,    monty::rc_ptr< ::mosek::fusion::Expression > _4526,    int _4527) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4524,_4525,_4526,_4527); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4524,    int _4525,    monty::rc_ptr< ::mosek::fusion::Expression > _4526,    int _4527){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4526->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _4526;
    if ((_4524 < _4525))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4524;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4525;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _4525;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _4524;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _4528,    int _4529,    monty::rc_ptr< ::mosek::fusion::Expression > _4530){ return new mosek::fusion::ExprSymmetrize(_4528,_4529,_4530); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _4528,    int _4529,    monty::rc_ptr< ::mosek::fusion::Expression > _4530) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_4528,_4529,_4530); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _4528,    int _4529,    monty::rc_ptr< ::mosek::fusion::Expression > _4530){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_4528,_4529,_4530,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4531 = _4530->getShape();
    _checked_ptr_1<int> _ptr__4531(_4531 ? _4531->raw() : nullptr,_4531 ? _4531->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_4531)->size(0))) || (_ptr__4531[dim0] != _ptr__4531[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4532,monty::rc_ptr< ::mosek::fusion::WorkStack > _4533,monty::rc_ptr< ::mosek::fusion::WorkStack > _4534) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_4532,_4533,_4534); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4532,monty::rc_ptr< ::mosek::fusion::WorkStack > _4533,monty::rc_ptr< ::mosek::fusion::WorkStack > _4534){
  expr->eval(_4533,_4532,_4534);
  int _4535 = (int)0;
  int _4536 = _4533->peeki32();
  int _4537 = _4533->peeki32(safe_add( _4536,(int)3 ));
  int _4538 = _4533->peeki32(safe_add( _4536,(int)2 ));
  int _8951 = (int)0;
  int _8952 = _4536;
  for (int _4539 = _8951; _4539 < _8952; ++_4539)
  {
    {
      int _4540 = _4533->peeki32(safe_add( _4539,(int)1 ));
      if ((_4540 > _4535))
      {
        {
          _4540 = _4535;
        }
      }
      {}
    }
  }
  int _4541 = _4533->alloci32(_4538);
  int _4542 = _4533->alloci32(_4538);
  int _4543 = _4533->alloci32(safe_add( _4535,(int)1 ));
  int _4544 = _4533->alloci64(_4538);
  _4533->popi32(safe_add( safe_add( safe_mul( (int)2,_4538 ),_4535 ),(int)1 ));
  _4533->popi64(_4538);
  int _4545 = _4533->popi32();
  int _4546 = _4533->popi32(_4545);
  int _4547 = _4533->popi32();
  int _4548 = _4533->popi32();
  bool _4549 = (_4533->popi32() != (int)0);
  int _4550 = _4533->popi32(safe_add( _4547,(int)1 ));
  int _8953;
  bool _8954 = _4549;
  if (_8954)
  {
    _8953 = _4533->popi64(_4547);
  }
  else
  {
    _8953 = (-(int)1);
  }
  int _4551 = _8953;
  int _4552 = _4533->popi64(_4548);
  int _4553 = _4533->popf64(_4547);
  int _4554 = _4533->popf64(_4548);
  int _4555 = (int)0;
  int _4556 = (int)0;
  std::vector<int> _8955;
  for (int _4558 = (int)0, _8956 = (int)5; _4558 < _8956 ; ++_4558)
  {
    _8955.push_back((int)1);
  }
  auto _8957 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8955.size()),_8955.begin(),_8955.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4557 = _8957;
  _checked_ptr_1<int> _ptr__4557(_4557 ? _4557->raw() : nullptr,_4557 ? _4557->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4559 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__4559(_4559 ? _4559->raw() : nullptr,_4559 ? _4559->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4560 = mosek::fusion::p_WorkStack::_get_impl(_4533)->i32;
  _checked_ptr_1<int> _ptr__4560(_4560 ? _4560->raw() : nullptr,_4560 ? _4560->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4561 = mosek::fusion::p_WorkStack::_get_impl(_4533)->i64;
  _checked_ptr_1<long long> _ptr__4561(_4561 ? _4561->raw() : nullptr,_4561 ? _4561->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4562 = mosek::fusion::p_WorkStack::_get_impl(_4533)->f64;
  _checked_ptr_1<double> _ptr__4562(_4562 ? _4562->raw() : nullptr,_4562 ? _4562->size(0) : 0);
  int _8958 = (int)0;
  int _8959 = dim0;
  for (int _4563 = _8958; _4563 < _8959; ++_4563)
  {
    {
      _ptr__4557[(int)0] *= _ptr__4560[safe_add( _4546,_4563 )];
    }
  }
  _ptr__4557[(int)1] = _ptr__4560[safe_add( _4546,dim0 )];
  int _8960 = safe_add( dim0,(int)1 );
  int _8961 = dim1;
  for (int _4564 = _8960; _4564 < _8961; ++_4564)
  {
    {
      _ptr__4557[(int)2] *= _ptr__4560[safe_add( _4546,_4564 )];
    }
  }
  _ptr__4557[(int)3] = _ptr__4560[safe_add( _4546,dim1 )];
  int _8962 = safe_add( dim1,(int)1 );
  int _8963 = _4545;
  for (int _4565 = _8962; _4565 < _8963; ++_4565)
  {
    {
      _ptr__4557[(int)4] *= _ptr__4560[safe_add( _4546,_4565 )];
    }
  }
  _ptr__4559[(int)4] = (int)1;
  int _8964 = (int)1;
  int _8965 = (int)5;
  for (int _4566 = _8964; _4566 < _8965; ++_4566)
  {
    {
      _ptr__4559[(((int)5 - _4566) - (int)1)] = safe_mul( _ptr__4559[((int)5 - _4566)],_ptr__4557[((int)5 - _4566)] );
    }
  }
  if (_4549)
  {
    {
      int _4567 = _4541;
      int _8966 = (int)0;
      int _8967 = _4547;
      for (int _4568 = _8966; _4568 < _8967; ++_4568)
      {
        {
          _ptr__4560[safe_add( _4567,_4568 )] = _4568;
        }
      }
      int _4569 = _4542;
      std::shared_ptr< monty::ndarray< int,1 > > _4570 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__4570(_4570 ? _4570->raw() : nullptr,_4570 ? _4570->size(0) : 0);
      int _8968 = (int)0;
      int _8969 = (int)4;
      for (int _4571 = _8968; _4571 < _8969; ++_4571)
      {
        {
          long long _4572 = _ptr__4559[_ptr__4570[_4571]];
          int _4573 = _ptr__4557[_ptr__4570[_4571]];
          if ((_4573 > (int)1))
          {
            {
              int _8970 = (int)0;
              int _8971 = safe_add( _4573,(int)1 );
              for (int _4574 = _8970; _4574 < _8971; ++_4574)
              {
                {
                  _ptr__4560[safe_add( _4543,_4574 )] = (int)0;
                }
              }
              int _8972 = (int)0;
              int _8973 = _4547;
              for (int _4575 = _8972; _4575 < _8973; ++_4575)
              {
                {
                  ++ _ptr__4560[safe_add( safe_add( _4543,((_ptr__4561[safe_add( _4551,_ptr__4560[safe_add( _4567,_4575 )] )] / _4572) % _4573) ),(int)1 )];
                }
              }
              int _8974 = (int)0;
              int _8975 = _ptr__4557[(int)3];
              for (int _4576 = _8974; _4576 < _8975; ++_4576)
              {
                {
                  _ptr__4560[safe_add( safe_add( _4543,_4576 ),(int)1 )] += _ptr__4560[safe_add( _4543,_4576 )];
                }
              }
              int _8976 = (int)0;
              int _8977 = _4547;
              for (int _4577 = _8976; _4577 < _8977; ++_4577)
              {
                {
                  int _4578 = _ptr__4560[safe_add( _4567,_4577 )];
                  long long _4579 = ((_ptr__4561[safe_add( _4551,_4578 )] / _4572) % _4573);
                  _ptr__4560[safe_add( _4569,_ptr__4560[safe_add( _4543,_4579 )] )] = _4578;
                  ++ _ptr__4560[safe_add( _4543,_4579 )];
                }
              }
              int _4580 = _4567;
              _4567 = _4569;
              _4569 = _4580;
            }
          }
          {}
        }
      }
      int _8978 = (int)0;
      int _8979 = _4547;
      for (int _4581 = _8978; _4581 < _8979; ++_4581)
      {
        {
          _ptr__4561[safe_add( _4544,_4581 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__4561[safe_add( _4551,_4581 )] / _ptr__4559[(int)0]) % _ptr__4557[(int)0]),_ptr__4559[(int)0] ),safe_mul( ((_ptr__4561[safe_add( _4551,_4581 )] / _ptr__4559[(int)1]) % _ptr__4557[(int)1]),_ptr__4559[(int)3] ) ),safe_mul( ((_ptr__4561[safe_add( _4551,_4581 )] / _ptr__4559[(int)2]) % _ptr__4557[(int)2]),_ptr__4559[(int)2] ) ),safe_mul( ((_ptr__4561[safe_add( _4551,_4581 )] / _ptr__4559[(int)3]) % _ptr__4557[(int)3]),_ptr__4559[(int)1] ) ),safe_mul( ((_ptr__4561[safe_add( _4551,_4581 )] / _ptr__4559[(int)4]) % _ptr__4557[(int)4]),_ptr__4559[(int)4] ) );
        }
      }
      {
        int _4582 = (int)0;
        int _4583 = (int)0;
        while ( ((_4583 < _4547) && (_4582 < _4547)) )
        {
          {
            int _4584 = _ptr__4560[safe_add( _4567,_4582 )];
            if ((_ptr__4561[safe_add( _4551,_4583 )] < _ptr__4561[safe_add( _4544,_4584 )]))
            {
              {
                _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4583 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4583 )]);
                ++ _4555;
                ++ _4583;
              }
            }
            else if((_ptr__4561[safe_add( _4551,_4583 )] > _ptr__4561[safe_add( _4544,_4584 )]))
            {
              {
                _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4584 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4584 )]);
                ++ _4555;
                ++ _4582;
              }
            }
            else if((_ptr__4561[safe_add( _4551,_4583 )] != _ptr__4561[safe_add( _4551,_4584 )]))
            {
              {
                _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4583 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4583 )]);
                _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4584 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4584 )]);
                ++ _4555;
                ++ _4582;
                ++ _4583;
              }
            }
            else
            {
              {
                _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4583 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4583 )]);
                ++ _4555;
                ++ _4582;
                ++ _4583;
              }
            }
          }
        }
        while ( (_4583 < _4547) )
        {
          {
            _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4583 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4583 )]);
            ++ _4555;
            ++ _4583;
          }
        }
        while ( (_4582 < _4547) )
        {
          {
            int _4585 = _ptr__4560[safe_add( _4567,_4582 )];
            _4556 += (_ptr__4560[safe_add( safe_add( _4550,_4585 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4585 )]);
            ++ _4555;
            ++ _4582;
          }
        }
      }
      int _4586 = _4532->alloci32(safe_add( _4555,(int)1 ));
      _4532->pushi32((int)1);
      _4532->pushi32(_4556);
      _4532->pushi32(_4555);
      int _8980 = (int)0;
      int _8981 = _4545;
      for (int _4587 = _8980; _4587 < _8981; ++_4587)
      {
        {
          _4532->pushi32(_ptr__4560[safe_add( _4546,_4587 )]);
        }
      }
      _4532->pushi32(_4545);
      int _4588 = _4532->alloci64(_4556);
      int _4589 = _4532->alloci64(_4555);
      int _4590 = _4532->allocf64(_4556);
      int _4591 = _4532->allocf64(_4555);
      std::shared_ptr< monty::ndarray< int,1 > > _4592 = mosek::fusion::p_WorkStack::_get_impl(_4532)->i32;
      _checked_ptr_1<int> _ptr__4592(_4592 ? _4592->raw() : nullptr,_4592 ? _4592->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4593 = mosek::fusion::p_WorkStack::_get_impl(_4532)->i64;
      _checked_ptr_1<long long> _ptr__4593(_4593 ? _4593->raw() : nullptr,_4593 ? _4593->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4594 = mosek::fusion::p_WorkStack::_get_impl(_4532)->f64;
      _checked_ptr_1<double> _ptr__4594(_4594 ? _4594->raw() : nullptr,_4594 ? _4594->size(0) : 0);
      _ptr__4592[_4586] = (int)0;
      {
        int _4595 = (int)0;
        int _4596 = (int)0;
        int _4597 = (int)0;
        int _4598 = (int)0;
        _ptr__4560[_4586] = (int)0;
        while ( ((_4598 < _4547) && (_4597 < _4547)) )
        {
          {
            int _4599 = _ptr__4560[safe_add( _4567,_4597 )];
            if ((_ptr__4561[safe_add( _4551,_4598 )] < _ptr__4561[safe_add( _4544,_4599 )]))
            {
              {
                int _8982 = _ptr__4560[safe_add( _4550,_4598 )];
                int _8983 = _ptr__4560[safe_add( safe_add( _4550,_4598 ),(int)1 )];
                for (int _4600 = _8982; _4600 < _8983; ++_4600)
                {
                  {
                    _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4600 )];
                    _ptr__4594[safe_add( _4590,_4595 )] = (_ptr__4562[safe_add( _4554,_4600 )] * 0.5);
                    ++ _4595;
                  }
                }
                _ptr__4594[safe_add( _4591,_4596 )] = (_ptr__4562[safe_add( _4553,_4598 )] * 0.5);
                _ptr__4593[safe_add( _4589,_4596 )] = _ptr__4561[safe_add( _4551,_4598 )];
                _ptr__4592[safe_add( safe_add( _4586,_4596 ),(int)1 )] = _4595;
                ++ _4596;
                ++ _4598;
              }
            }
            else if((_ptr__4561[safe_add( _4551,_4598 )] > _ptr__4561[safe_add( _4544,_4599 )]))
            {
              {
                int _8984 = _ptr__4560[safe_add( _4550,_4599 )];
                int _8985 = _ptr__4560[safe_add( safe_add( _4550,_4599 ),(int)1 )];
                for (int _4601 = _8984; _4601 < _8985; ++_4601)
                {
                  {
                    _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4601 )];
                    _ptr__4594[safe_add( _4590,_4595 )] = (_ptr__4562[safe_add( _4554,_4601 )] * 0.5);
                    ++ _4595;
                  }
                }
                _ptr__4594[safe_add( _4591,_4596 )] = (_ptr__4562[safe_add( _4553,_4599 )] * 0.5);
                _ptr__4593[safe_add( _4589,_4596 )] = _ptr__4561[safe_add( _4544,_4599 )];
                _ptr__4592[safe_add( safe_add( _4586,_4596 ),(int)1 )] = _4595;
                ++ _4596;
                ++ _4597;
              }
            }
            else if((_ptr__4561[safe_add( _4551,_4598 )] != _ptr__4561[safe_add( _4551,_4599 )]))
            {
              {
                int _8986 = _ptr__4560[safe_add( _4550,_4598 )];
                int _8987 = _ptr__4560[safe_add( safe_add( _4550,_4598 ),(int)1 )];
                for (int _4602 = _8986; _4602 < _8987; ++_4602)
                {
                  {
                    _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4602 )];
                    _ptr__4594[safe_add( _4590,_4595 )] = (_ptr__4562[safe_add( _4554,_4602 )] * 0.5);
                    ++ _4595;
                  }
                }
                int _8988 = _ptr__4560[safe_add( _4550,_4599 )];
                int _8989 = _ptr__4560[safe_add( safe_add( _4550,_4599 ),(int)1 )];
                for (int _4603 = _8988; _4603 < _8989; ++_4603)
                {
                  {
                    _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4603 )];
                    _ptr__4594[safe_add( _4590,_4595 )] = (_ptr__4562[safe_add( _4554,_4603 )] * 0.5);
                    ++ _4595;
                  }
                }
                _ptr__4594[safe_add( _4591,_4596 )] = (0.5 * (_ptr__4562[safe_add( _4553,_4598 )] + _ptr__4562[safe_add( _4553,_4599 )]));
                _ptr__4593[safe_add( _4589,_4596 )] = _ptr__4561[safe_add( _4551,_4598 )];
                _ptr__4592[safe_add( safe_add( _4586,_4596 ),(int)1 )] = _4595;
                ++ _4596;
                ++ _4597;
                ++ _4598;
              }
            }
            else
            {
              {
                int _8990 = _ptr__4560[safe_add( _4550,_4598 )];
                int _8991 = _ptr__4560[safe_add( safe_add( _4550,_4598 ),(int)1 )];
                for (int _4604 = _8990; _4604 < _8991; ++_4604)
                {
                  {
                    _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4604 )];
                    _ptr__4594[safe_add( _4590,_4595 )] = _ptr__4562[safe_add( _4554,_4604 )];
                    ++ _4595;
                  }
                }
                _ptr__4594[safe_add( _4591,_4596 )] = _ptr__4562[safe_add( _4553,_4598 )];
                _ptr__4593[safe_add( _4589,_4596 )] = _ptr__4561[safe_add( _4551,_4598 )];
                _ptr__4592[safe_add( safe_add( _4586,_4596 ),(int)1 )] = _4595;
                ++ _4596;
                ++ _4597;
                ++ _4598;
              }
            }
          }
        }
        while ( (_4598 < _4547) )
        {
          {
            int _8992 = _ptr__4560[safe_add( _4550,_4598 )];
            int _8993 = _ptr__4560[safe_add( safe_add( _4550,_4598 ),(int)1 )];
            for (int _4605 = _8992; _4605 < _8993; ++_4605)
            {
              {
                _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4605 )];
                _ptr__4594[safe_add( _4590,_4595 )] = (_ptr__4562[safe_add( _4554,_4605 )] * 0.5);
                ++ _4595;
              }
            }
            _ptr__4594[safe_add( _4591,_4596 )] = (_ptr__4562[safe_add( _4553,_4598 )] * 0.5);
            _ptr__4593[safe_add( _4589,_4596 )] = _ptr__4561[safe_add( _4551,_4598 )];
            _ptr__4592[safe_add( safe_add( _4586,_4596 ),(int)1 )] = _4595;
            ++ _4596;
            ++ _4598;
          }
        }
        while ( (_4597 < _4547) )
        {
          {
            int _4606 = _ptr__4560[safe_add( _4567,_4597 )];
            int _8994 = _ptr__4560[safe_add( _4550,_4606 )];
            int _8995 = _ptr__4560[safe_add( safe_add( _4550,_4606 ),(int)1 )];
            for (int _4607 = _8994; _4607 < _8995; ++_4607)
            {
              {
                _ptr__4593[safe_add( _4588,_4595 )] = _ptr__4561[safe_add( _4552,_4607 )];
                _ptr__4594[safe_add( _4590,_4595 )] = (_ptr__4562[safe_add( _4554,_4607 )] * 0.5);
                ++ _4595;
              }
            }
            _ptr__4594[safe_add( _4591,_4596 )] = (_ptr__4562[safe_add( _4553,_4606 )] * 0.5);
            _ptr__4593[safe_add( _4589,_4596 )] = _ptr__4561[safe_add( _4544,_4606 )];
            _ptr__4592[safe_add( safe_add( _4586,_4596 ),(int)1 )] = _4595;
            ++ _4596;
            ++ _4597;
          }
        }
      }
    }
  }
  else
  {
    {
      _4555 = _4547;
      _4556 = safe_mul( _4548,(int)2 );
      int _8996 = (int)0;
      int _8997 = _ptr__4557[(int)0];
      for (int _4608 = _8996; _4608 < _8997; ++_4608)
      {
        {
          int _8998 = (int)0;
          int _8999 = _ptr__4557[(int)2];
          for (int _4609 = _8998; _4609 < _8999; ++_4609)
          {
            {
              int _9000 = (int)0;
              int _9001 = _ptr__4557[(int)4];
              for (int _4610 = _9000; _4610 < _9001; ++_4610)
              {
                {
                  int _9002 = (int)0;
                  int _9003 = _ptr__4557[(int)1];
                  for (int _4611 = _9002; _4611 < _9003; ++_4611)
                  {
                    {
                      long long _4612 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__4559[(int)0],_4608 ),safe_mul( _ptr__4559[(int)1],_4611 ) ),safe_mul( _ptr__4559[(int)2],_4609 ) ),safe_mul( _ptr__4559[(int)3],_4611 ) ),safe_mul( _ptr__4559[(int)4],_4610 ) );
                      _4556 -= (_ptr__4560[safe_add( safe_add( _4550,_4612 ),(int)1 )] - _ptr__4560[safe_add( _4550,_4612 )]);
                    }
                  }
                }
              }
            }
          }
        }
      }
      int _4613 = _4532->alloci32(safe_add( _4555,(int)1 ));
      _4532->pushi32((int)0);
      _4532->pushi32(_4556);
      _4532->pushi32(_4555);
      int _9004 = (int)0;
      int _9005 = _4545;
      for (int _4614 = _9004; _4614 < _9005; ++_4614)
      {
        {
          _4532->pushi32(_ptr__4560[safe_add( _4546,_4614 )]);
        }
      }
      _4532->pushi32(_4545);
      int _4615 = _4532->alloci64(_4556);
      int _4616 = _4532->allocf64(_4556);
      int _4617 = _4532->allocf64(_4555);
      std::shared_ptr< monty::ndarray< int,1 > > _4618 = mosek::fusion::p_WorkStack::_get_impl(_4532)->i32;
      _checked_ptr_1<int> _ptr__4618(_4618 ? _4618->raw() : nullptr,_4618 ? _4618->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4619 = mosek::fusion::p_WorkStack::_get_impl(_4532)->i64;
      _checked_ptr_1<long long> _ptr__4619(_4619 ? _4619->raw() : nullptr,_4619 ? _4619->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4620 = mosek::fusion::p_WorkStack::_get_impl(_4532)->f64;
      _checked_ptr_1<double> _ptr__4620(_4620 ? _4620->raw() : nullptr,_4620 ? _4620->size(0) : 0);
      int _4621 = (int)0;
      int _4622 = (int)0;
      _ptr__4618[_4613] = (int)0;
      int _4623 = (int)0;
      int _9006 = (int)0;
      int _9007 = _ptr__4557[(int)0];
      for (int _4624 = _9006; _4624 < _9007; ++_4624)
      {
        {
          int _9008 = (int)0;
          int _9009 = _ptr__4557[(int)1];
          for (int _4625 = _9008; _4625 < _9009; ++_4625)
          {
            {
              int _9010 = (int)0;
              int _9011 = _ptr__4557[(int)2];
              for (int _4626 = _9010; _4626 < _9011; ++_4626)
              {
                {
                  int _9012 = (int)0;
                  int _9013 = _ptr__4557[(int)3];
                  for (int _4627 = _9012; _4627 < _9013; ++_4627)
                  {
                    {
                      int _9014 = (int)0;
                      int _9015 = _ptr__4557[(int)4];
                      for (int _4628 = _9014; _4628 < _9015; ++_4628)
                      {
                        {
                          if ((_4625 == _4627))
                          {
                            {
                              int _9016 = _ptr__4560[safe_add( _4550,_4623 )];
                              int _9017 = _ptr__4560[safe_add( safe_add( _4550,_4623 ),(int)1 )];
                              for (int _4629 = _9016; _4629 < _9017; ++_4629)
                              {
                                {
                                  _ptr__4619[safe_add( _4615,_4621 )] = _ptr__4561[safe_add( _4552,_4629 )];
                                  _ptr__4620[safe_add( _4616,_4621 )] = _ptr__4562[safe_add( _4554,_4629 )];
                                  ++ _4621;
                                }
                              }
                              _ptr__4620[safe_add( _4617,_4622 )] = _ptr__4562[safe_add( _4553,_4624 )];
                              _ptr__4618[safe_add( safe_add( _4613,_4622 ),(int)1 )] = _4621;
                              ++ _4623;
                            }
                          }
                          else
                          {
                            {
                              long long _4630 = safe_add( safe_add( safe_add( safe_add( safe_mul( _4624,_ptr__4559[(int)0] ),safe_mul( _4627,_ptr__4559[(int)1] ) ),safe_mul( _4626,_ptr__4559[(int)2] ) ),safe_mul( _4625,_ptr__4559[(int)3] ) ),_4628 );
                              int _9018 = _ptr__4560[safe_add( _4550,_4623 )];
                              int _9019 = _ptr__4560[safe_add( safe_add( _4550,_4623 ),(int)1 )];
                              for (int _4631 = _9018; _4631 < _9019; ++_4631)
                              {
                                {
                                  _ptr__4619[safe_add( _4615,_4621 )] = _ptr__4561[safe_add( _4552,_4631 )];
                                  _ptr__4620[safe_add( _4616,_4621 )] = (_ptr__4562[safe_add( _4554,_4631 )] * 0.5);
                                  ++ _4621;
                                }
                              }
                              int _9020 = _ptr__4560[safe_add( _4550,_4630 )];
                              int _9021 = _ptr__4560[safe_add( safe_add( _4550,_4630 ),(int)1 )];
                              for (int _4632 = _9020; _4632 < _9021; ++_4632)
                              {
                                {
                                  _ptr__4619[safe_add( _4615,_4621 )] = _ptr__4561[safe_add( _4552,_4632 )];
                                  _ptr__4620[safe_add( _4616,_4621 )] = (_ptr__4562[safe_add( _4554,_4632 )] * 0.5);
                                  ++ _4621;
                                }
                              }
                              _ptr__4620[safe_add( _4617,_4622 )] = (0.5 * (_ptr__4562[safe_add( _4553,_4623 )] + _ptr__4562[safe_add( _4553,_4630 )]));
                              _ptr__4618[safe_add( safe_add( _4613,_4622 ),(int)1 )] = _4621;
                              ++ _4623;
                            }
                          }
                          ++ _4622;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4633){ return new mosek::fusion::ExprCompress(_4633); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4633) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4633); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4633){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4633->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4633;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4634,    double _4635){ return new mosek::fusion::ExprCompress(_4634,_4635); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4634,    double _4635) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4634,_4635); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4634,    double _4635){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4634->getShape());
    eps = _4635;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4634;
  }
}void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4636,monty::rc_ptr< ::mosek::fusion::WorkStack > _4637,monty::rc_ptr< ::mosek::fusion::WorkStack > _4638) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4636,_4637,_4638); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4636,monty::rc_ptr< ::mosek::fusion::WorkStack > _4637,monty::rc_ptr< ::mosek::fusion::WorkStack > _4638){
  expr->eval(_4637,_4636,_4638);
  _4637->pop_expr();
  int _4639 = mosek::fusion::p_WorkStack::_get_impl(_4637)->nd;
  int _4640 = mosek::fusion::p_WorkStack::_get_impl(_4637)->shape_base;
  int _4641 = mosek::fusion::p_WorkStack::_get_impl(_4637)->nelem;
  int _4642 = mosek::fusion::p_WorkStack::_get_impl(_4637)->nnz;
  bool _4643 = mosek::fusion::p_WorkStack::_get_impl(_4637)->hassp;
  int _4644 = mosek::fusion::p_WorkStack::_get_impl(_4637)->ptr_base;
  int _4645 = mosek::fusion::p_WorkStack::_get_impl(_4637)->sp_base;
  int _4646 = mosek::fusion::p_WorkStack::_get_impl(_4637)->nidxs_base;
  int _4647 = mosek::fusion::p_WorkStack::_get_impl(_4637)->bfix_base;
  int _4648 = mosek::fusion::p_WorkStack::_get_impl(_4637)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4649 = mosek::fusion::p_WorkStack::_get_impl(_4637)->i32;
  _checked_ptr_1<int> _ptr__4649(_4649 ? _4649->raw() : nullptr,_4649 ? _4649->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4650 = mosek::fusion::p_WorkStack::_get_impl(_4637)->i64;
  _checked_ptr_1<long long> _ptr__4650(_4650 ? _4650->raw() : nullptr,_4650 ? _4650->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4651 = mosek::fusion::p_WorkStack::_get_impl(_4637)->f64;
  _checked_ptr_1<double> _ptr__4651(_4651 ? _4651->raw() : nullptr,_4651 ? _4651->size(0) : 0);
  std::vector<int> _9022;
  for (int _4653 = (int)0, _9023 = _4639; _4653 < _9023 ; ++_4653)
  {
    _9022.push_back(_ptr__4649[safe_add( _4640,_4653 )]);
  }
  auto _9024 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9022.size()),_9022.begin(),_9022.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4652 = _9024;
  _checked_ptr_1<int> _ptr__4652(_4652 ? _4652->raw() : nullptr,_4652 ? _4652->size(0) : 0);
  bool _4654 = true;
  int _9025 = (int)0;
  int _9026 = _4641;
  for (int _4655 = _9025; _4655 < _9026; ++_4655)
  {
    {
      int _9027 = safe_add( _ptr__4649[safe_add( _4644,_4655 )],(int)1 );
      int _9028 = _ptr__4649[safe_add( safe_add( _4644,_4655 ),(int)1 )];
      for (int _4656 = _9027; _4656 < _9028; ++_4656)
      {
        {
          _4654 = (_4654 && (_ptr__4650[(safe_add( _4646,_4656 ) - (int)1)] < _ptr__4650[safe_add( _4646,_4656 )]));
        }
      }
    }
  }
  if (_4654)
  {
    {
      int _9029 = (int)0;
      int _9030 = _4642;
      for (int _4657 = _9029; _4657 < _9030; ++_4657)
      {
        {
          _4654 = (_4654 && ((_ptr__4651[safe_add( _4648,_4657 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4651[safe_add( _4648,_4657 )])));
        }
      }
    }
  }
  {}
  if (_4654)
  {
    {
      _4636->alloc_expr(_4639,_4641,_4642,_4643);
      int _4658 = mosek::fusion::p_WorkStack::_get_impl(_4636)->ptr_base;
      int _4659 = mosek::fusion::p_WorkStack::_get_impl(_4636)->nidxs_base;
      int _4660 = mosek::fusion::p_WorkStack::_get_impl(_4636)->sp_base;
      int _4661 = mosek::fusion::p_WorkStack::_get_impl(_4636)->cof_base;
      int _4662 = mosek::fusion::p_WorkStack::_get_impl(_4636)->bfix_base;
      int _4663 = mosek::fusion::p_WorkStack::_get_impl(_4636)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4664 = mosek::fusion::p_WorkStack::_get_impl(_4636)->i32;
      _checked_ptr_1<int> _ptr__4664(_4664 ? _4664->raw() : nullptr,_4664 ? _4664->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4665 = mosek::fusion::p_WorkStack::_get_impl(_4636)->i64;
      _checked_ptr_1<long long> _ptr__4665(_4665 ? _4665->raw() : nullptr,_4665 ? _4665->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4666 = mosek::fusion::p_WorkStack::_get_impl(_4636)->f64;
      _checked_ptr_1<double> _ptr__4666(_4666 ? _4666->raw() : nullptr,_4666 ? _4666->size(0) : 0);
      {
        int _9031 = (int)0;
        int _9032 = _4639;
        for (int _4667 = _9031; _4667 < _9032; ++_4667)
        {
          {
            _ptr__4664[safe_add( _4663,_4667 )] = _ptr__4652[_4667];
          }
        }
        int _9033 = (int)0;
        int _9034 = safe_add( _4641,(int)1 );
        for (int _4668 = _9033; _4668 < _9034; ++_4668)
        {
          {
            _ptr__4664[safe_add( _4658,_4668 )] = _ptr__4649[safe_add( _4644,_4668 )];
          }
        }
        if (_4643)
        {
          {
            int _9035 = (int)0;
            int _9036 = _4641;
            for (int _4669 = _9035; _4669 < _9036; ++_4669)
            {
              {
                _ptr__4665[safe_add( _4660,_4669 )] = _ptr__4650[safe_add( _4645,_4669 )];
              }
            }
          }
        }
        {}
        int _9037 = (int)0;
        int _9038 = _4641;
        for (int _4670 = _9037; _4670 < _9038; ++_4670)
        {
          {
            _ptr__4666[safe_add( _4662,_4670 )] = _ptr__4651[safe_add( _4647,_4670 )];
          }
        }
        int _9039 = (int)0;
        int _9040 = _4642;
        for (int _4671 = _9039; _4671 < _9040; ++_4671)
        {
          {
            _ptr__4665[safe_add( _4659,_4671 )] = _ptr__4650[safe_add( _4646,_4671 )];
          }
        }
        int _9041 = (int)0;
        int _9042 = _4642;
        for (int _4672 = _9041; _4672 < _9042; ++_4672)
        {
          {
            _ptr__4666[safe_add( _4661,_4672 )] = _ptr__4651[safe_add( _4648,_4672 )];
          }
        }
      }
    }
  }
  else
  {
    {
      int _4673 = _4638->alloci32(_4642);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4637,_4638,_4673,_4641,_4642,_4644,_4646);
      std::shared_ptr< monty::ndarray< int,1 > > _4674 = mosek::fusion::p_WorkStack::_get_impl(_4638)->i32;
      _checked_ptr_1<int> _ptr__4674(_4674 ? _4674->raw() : nullptr,_4674 ? _4674->size(0) : 0);
      int _4675 = (int)0;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4676 = mosek::fusion::p_WorkStack::_get_impl(_4636)->i32;
        _checked_ptr_1<int> _ptr__4676(_4676 ? _4676->raw() : nullptr,_4676 ? _4676->size(0) : 0);
        {
          int _9043 = (int)0;
          int _9044 = _4641;
          for (int _4677 = _9043; _4677 < _9044; ++_4677)
          {
            {
              int _4678 = _ptr__4649[safe_add( safe_add( _4644,_4677 ),(int)1 )];
              int _4679 = _ptr__4649[safe_add( _4644,_4677 )];
              if ((_4679 < _4678))
              {
                {
                  int _4680 = _4679;
                  while ( (_4680 < _4678) )
                  {
                    {
                      double _4681 = 0.0;
                      long long _4682 = _ptr__4650[safe_add( _4646,_ptr__4674[safe_add( _4673,_4680 )] )];
                      while ( ((_4680 < _4678) && (_ptr__4650[safe_add( _4646,_ptr__4674[safe_add( _4673,_4680 )] )] == _4682)) )
                      {
                        {
                          _4681 += _ptr__4651[safe_add( _4648,_ptr__4674[safe_add( _4673,_4680 )] )];
                          ++ _4680;
                        }
                      }
                      {
                      }
                      if (((_4682 != (int)0) && ((_4681 < (-eps)) || (eps < _4681))))
                      {
                        {
                          ++ _4675;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
            }
          }
        }
      }
      _4636->alloc_expr(_4639,_4641,_4675,_4643);
      int _4683 = mosek::fusion::p_WorkStack::_get_impl(_4636)->nidxs_base;
      int _4684 = mosek::fusion::p_WorkStack::_get_impl(_4636)->shape_base;
      int _4685 = mosek::fusion::p_WorkStack::_get_impl(_4636)->sp_base;
      int _4686 = mosek::fusion::p_WorkStack::_get_impl(_4636)->cof_base;
      int _4687 = mosek::fusion::p_WorkStack::_get_impl(_4636)->bfix_base;
      int _4688 = mosek::fusion::p_WorkStack::_get_impl(_4636)->ptr_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4689 = mosek::fusion::p_WorkStack::_get_impl(_4636)->i32;
      _checked_ptr_1<int> _ptr__4689(_4689 ? _4689->raw() : nullptr,_4689 ? _4689->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4690 = mosek::fusion::p_WorkStack::_get_impl(_4636)->i64;
      _checked_ptr_1<long long> _ptr__4690(_4690 ? _4690->raw() : nullptr,_4690 ? _4690->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4691 = mosek::fusion::p_WorkStack::_get_impl(_4636)->f64;
      _checked_ptr_1<double> _ptr__4691(_4691 ? _4691->raw() : nullptr,_4691 ? _4691->size(0) : 0);
      int _9045 = (int)0;
      int _9046 = _4639;
      for (int _4692 = _9045; _4692 < _9046; ++_4692)
      {
        {
          _ptr__4689[safe_add( _4684,_4692 )] = _ptr__4652[_4692];
        }
      }
      {
        int _9047 = (int)0;
        int _9048 = _4641;
        for (int _4693 = _9047; _4693 < _9048; ++_4693)
        {
          {
            _ptr__4691[safe_add( _4686,_4693 )] = 0.0;
          }
        }
        int _9049 = (int)0;
        int _9050 = _4641;
        for (int _4694 = _9049; _4694 < _9050; ++_4694)
        {
          {
            _ptr__4691[safe_add( _4687,_4694 )] = _ptr__4651[safe_add( _4647,_4694 )];
          }
        }
        if (_4643)
        {
          {
            int _9051 = (int)0;
            int _9052 = _4641;
            for (int _4695 = _9051; _4695 < _9052; ++_4695)
            {
              {
                _ptr__4690[safe_add( _4685,_4695 )] = _ptr__4650[safe_add( _4685,_4695 )];
              }
            }
          }
        }
        {}
        int _4696 = (int)0;
        {
          int _4697 = (_4686 - _4683);
          _ptr__4689[_4688] = (int)0;
          int _9053 = (int)0;
          int _9054 = _4641;
          for (int _4698 = _9053; _4698 < _9054; ++_4698)
          {
            {
              int _4699 = _ptr__4649[safe_add( safe_add( _4644,_4698 ),(int)1 )];
              int _4700 = _ptr__4649[safe_add( _4644,_4698 )];
              if ((_4700 < _4699))
              {
                {
                  int _4701 = _4700;
                  while ( (_4701 < _4699) )
                  {
                    {
                      double _4702 = 0.0;
                      long long _4703 = _ptr__4650[safe_add( _4646,_ptr__4674[safe_add( _4673,_4701 )] )];
                      while ( ((_4701 < _4699) && (_ptr__4650[safe_add( _4646,_ptr__4674[safe_add( _4673,_4701 )] )] == _4703)) )
                      {
                        {
                          _4702 += _ptr__4651[safe_add( _4648,_ptr__4674[safe_add( _4673,_4701 )] )];
                          ++ _4701;
                        }
                      }
                      {
                      }
                      if (((_4703 != (int)0) && ((_4702 < (-eps)) || (eps < _4702))))
                      {
                        {
                          _ptr__4690[safe_add( _4683,_4696 )] = _4703;
                          _ptr__4691[safe_add( _4686,_4696 )] = _4702;
                          ++ _4696;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              {}
              _ptr__4689[safe_add( safe_add( _4688,_4698 ),(int)1 )] = _4696;
            }
          }
        }
      }
    }
  }
  _4638->clear();
}
void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4704,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4705,    int _4706,    int _4707,    int _4708,    int _4709,    int _4710) { mosek::fusion::p_ExprCompress::arg_sort(_4704,_4705,_4706,_4707,_4708,_4709,_4710); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4704,monty::rc_ptr< ::mosek::fusion::WorkStack > _4705,int _4706,int _4707,int _4708,int _4709,int _4710){
  int _4711 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4712 = mosek::fusion::p_WorkStack::_get_impl(_4704)->i32;
  _checked_ptr_1<int> _ptr__4712(_4712 ? _4712->raw() : nullptr,_4712 ? _4712->size(0) : 0);
  int _9055 = (int)0;
  int _9056 = _4707;
  for (int _4713 = _9055; _4713 < _9056; ++_4713)
  {
    {
      if (((_ptr__4712[safe_add( safe_add( _4709,_4713 ),(int)1 )] - _ptr__4712[safe_add( _4709,_4713 )]) > _4711))
      {
        {
          _4711 = (_ptr__4712[safe_add( safe_add( _4709,_4713 ),(int)1 )] - _ptr__4712[safe_add( _4709,_4713 )]);
        }
      }
      {}
    }
  }
  int _9057;
  bool _9058 = (_4711 > (int)2);
  if (_9058)
  {
    _9057 = _4705->alloci32(safe_mul( _4711,(int)2 ));
  }
  else
  {
    _9057 = (int)99999;
  }
  int _4714 = _9057;
  std::shared_ptr< monty::ndarray< int,1 > > _4715 = mosek::fusion::p_WorkStack::_get_impl(_4705)->i32;
  _checked_ptr_1<int> _ptr__4715(_4715 ? _4715->raw() : nullptr,_4715 ? _4715->size(0) : 0);
  _4712 = mosek::fusion::p_WorkStack::_get_impl(_4704)->i32;
  _ptr__4712.update(_4712 ? _4712->raw() : nullptr, _4712 ? _4712->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4716 = mosek::fusion::p_WorkStack::_get_impl(_4704)->i64;
  _checked_ptr_1<long long> _ptr__4716(_4716 ? _4716->raw() : nullptr,_4716 ? _4716->size(0) : 0);
  int _9059 = (int)0;
  int _9060 = _4707;
  for (int _4717 = _9059; _4717 < _9060; ++_4717)
  {
    {
      int _4718 = _ptr__4712[safe_add( _4709,_4717 )];
      int _4719 = _ptr__4712[safe_add( safe_add( _4709,_4717 ),(int)1 )];
      int _4720 = (_4719 - _4718);
      if ((_4720 == (int)0))
      {
        {
        }
      }
      else if((_4720 == (int)1))
      {
        {
          _ptr__4715[safe_add( _4706,_4718 )] = _4718;
        }
      }
      else if((_4720 == (int)2))
      {
        {
          if ((_ptr__4716[safe_add( _4710,_4718 )] <= _ptr__4716[safe_add( safe_add( _4710,_4718 ),(int)1 )]))
          {
            {
              _ptr__4715[safe_add( _4706,_4718 )] = _4718;
              _ptr__4715[safe_add( safe_add( _4706,_4718 ),(int)1 )] = safe_add( _4718,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4715[safe_add( _4706,_4718 )] = safe_add( _4718,(int)1 );
              _ptr__4715[safe_add( safe_add( _4706,_4718 ),(int)1 )] = _4718;
            }
          }
        }
      }
      else
      {
        {
          long long _4721 = _ptr__4716[safe_add( _4710,_4718 )];
          long long _4722 = _ptr__4716[safe_add( _4710,_4718 )];
          bool _4723 = false;
          int _9061 = safe_add( _4718,(int)1 );
          int _9062 = _4719;
          for (int _4724 = _9061; _4724 < _9062; ++_4724)
          {
            {
              _4723 = (_4723 && (_ptr__4716[(safe_add( _4710,_4724 ) - (int)1)] <= _ptr__4716[safe_add( _4710,_4724 )]));
              if ((_4721 > _ptr__4716[safe_add( _4710,_4724 )]))
              {
                {
                  _4721 = _ptr__4716[safe_add( _4710,_4724 )];
                }
              }
              {}
              if ((_4722 < _ptr__4716[safe_add( _4710,_4724 )]))
              {
                {
                  _4722 = _ptr__4716[safe_add( _4710,_4724 )];
                }
              }
              {}
            }
          }
          if (_4723)
          {
            {
              int _9063 = _4718;
              int _9064 = _4719;
              for (int _4725 = _9063; _4725 < _9064; ++_4725)
              {
                {
                  _ptr__4715[safe_add( _4706,_4725 )] = _4725;
                }
              }
            }
          }
          else if((safe_add( (_4722 - _4721),(int)1 ) <= _4720))
          {
            {
              long long _4726 = safe_add( (_4722 - _4721),(int)1 );
              int _9065 = (int)0;
              long long _9066 = safe_add( _4726,(int)1 );
              for (long long _4727 = _9065; _4727 < _9066; ++_4727)
              {
                {
                  _ptr__4715[safe_add( _4714,_4727 )] = (int)0;
                }
              }
              int _9067 = _4718;
              int _9068 = _4719;
              for (int _4728 = _9067; _4728 < _9068; ++_4728)
              {
                {
                  ++ _ptr__4715[safe_add( (safe_add( _4714,_ptr__4716[safe_add( _4710,_4728 )] ) - _4721),(int)1 )];
                }
              }
              int _9069 = (int)0;
              long long _9070 = _4726;
              for (long long _4729 = _9069; _4729 < _9070; ++_4729)
              {
                {
                  _ptr__4715[safe_add( safe_add( _4714,_4729 ),(int)1 )] += _ptr__4715[safe_add( _4714,_4729 )];
                }
              }
              int _9071 = _4718;
              int _9072 = _4719;
              for (int _4730 = _9071; _4730 < _9072; ++_4730)
              {
                {
                  _ptr__4715[safe_add( safe_add( _4706,_4718 ),_ptr__4715[(safe_add( _4714,_ptr__4716[safe_add( _4710,_4730 )] ) - _4721)] )] = _4730;
                  ++ _ptr__4715[(safe_add( _4714,_ptr__4716[safe_add( _4710,_4730 )] ) - _4721)];
                }
              }
            }
          }
          else
          {
            {
              int _4731 = (int)1;
              int _4732 = _4714;
              int _4733 = safe_add( _4714,_4720 );
              int _9073 = (int)0;
              int _9074 = _4720;
              for (int _4734 = _9073; _4734 < _9074; ++_4734)
              {
                {
                  _ptr__4715[safe_add( _4732,_4734 )] = _4734;
                }
              }
              while ( (_4731 < _4720) )
              {
                {
                  int _4735 = safe_mul( _4731,(int)2 );
                  int _4736 = (_4720 / _4735);
                  if ((safe_add( safe_mul( _4736,_4735 ),_4731 ) < _4720))
                  {
                    {
                      ++ _4736;
                    }
                  }
                  {}
                  int _4737 = (int)0;
                  int _9075 = (int)0;
                  int _9076 = _4736;
                  for (int _4738 = _9075; _4738 < _9076; ++_4738)
                  {
                    {
                      int _4739 = safe_mul( _4738,_4735 );
                      int _4740 = safe_add( _4739,_4731 );
                      int _4741 = _4740;
                      int _4742 = safe_add( _4741,_4731 );
                      if ((_4742 > _4720))
                      {
                        {
                          _4742 = _4720;
                        }
                      }
                      {}
                      while ( ((_4739 < _4740) && (_4741 < _4742)) )
                      {
                        {
                          if ((_ptr__4716[safe_add( safe_add( _4710,_ptr__4715[safe_add( _4732,_4739 )] ),_4718 )] <= _ptr__4716[safe_add( safe_add( _4710,_ptr__4715[safe_add( _4732,_4741 )] ),_4718 )]))
                          {
                            {
                              _ptr__4715[safe_add( _4733,_4737 )] = _ptr__4715[safe_add( _4732,_4739 )];
                              ++ _4737;
                              ++ _4739;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4715[safe_add( _4733,_4737 )] = _ptr__4715[safe_add( _4732,_4741 )];
                              ++ _4737;
                              ++ _4741;
                            }
                          }
                        }
                      }
                      while ( (_4739 < _4740) )
                      {
                        {
                          _ptr__4715[safe_add( _4733,_4737 )] = _ptr__4715[safe_add( _4732,_4739 )];
                          ++ _4737;
                          ++ _4739;
                        }
                      }
                      while ( (_4741 < _4742) )
                      {
                        {
                          _ptr__4715[safe_add( _4733,_4737 )] = _ptr__4715[safe_add( _4732,_4741 )];
                          ++ _4737;
                          ++ _4741;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4736,_4735 ) < _4720))
                  {
                    {
                      int _4743 = safe_mul( _4736,_4735 );
                      while ( (_4743 < _4720) )
                      {
                        {
                          _ptr__4715[safe_add( _4733,_4737 )] = _ptr__4715[safe_add( _4732,_4743 )];
                          ++ _4743;
                          ++ _4737;
                        }
                      }
                    }
                  }
                  {}
                  int _4744 = _4732;
                  _4732 = _4733;
                  _4733 = _4744;
                  _4731 *= (int)2;
                }
              }
              int _9077 = (int)0;
              int _9078 = _4720;
              for (int _4745 = _9077; _4745 < _9078; ++_4745)
              {
                {
                  _ptr__4715[safe_add( safe_add( _4706,_4718 ),_4745 )] = safe_add( _ptr__4715[safe_add( _4732,_4745 )],_4718 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4746,    int _4747,    int _4748,    int _4749,    int _4750,    int _4751,    std::shared_ptr< monty::ndarray< int,1 > > _4752,    std::shared_ptr< monty::ndarray< long long,1 > > _4753) { mosek::fusion::p_ExprCompress::merge_sort(_4746,_4747,_4748,_4749,_4750,_4751,_4752,_4753); }void mosek::fusion::p_ExprCompress::merge_sort(int _4746,int _4747,int _4748,int _4749,int _4750,int _4751,std::shared_ptr< monty::ndarray< int,1 > > _4752,std::shared_ptr< monty::ndarray< long long,1 > > _4753){
  _checked_ptr_1<int> _ptr__4752(_4752 ? _4752->raw() : nullptr, _4752 ? _4752->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4753(_4753 ? _4753->raw() : nullptr, _4753 ? _4753->size(0) : 0);
  int _4754 = _4746;
  int _4755 = _4747;
  int _9079 = (int)0;
  int _9080 = _4749;
  for (int _4756 = _9079; _4756 < _9080; ++_4756)
  {
    {
      _ptr__4752[safe_add( _4754,_4756 )] = _4756;
    }
  }
  int _9081 = (int)0;
  int _9082 = _4748;
  for (int _4757 = _9081; _4757 < _9082; ++_4757)
  {
    {
      _4754 = _4746;
      _4755 = _4747;
      int _4758 = _ptr__4752[safe_add( safe_add( _4750,_4757 ),(int)1 )];
      int _4759 = _ptr__4752[safe_add( _4750,_4757 )];
      if ((safe_add( _4759,(int)1 ) < _4758))
      {
        {
          int _4760 = (_4758 - _4759);
          int _4761 = (int)0;
          while ( (_4760 > (int)1) )
          {
            {
              ++ _4761;
              _4760 /= (int)2;
            }
          }
          _4760 = (_4758 - _4759);
          int _4762 = (int)1;
          int _9083 = (int)0;
          int _9084 = safe_add( _4761,(int)1 );
          for (int _4763 = _9083; _4763 < _9084; ++_4763)
          {
            {
              int _4764 = ((safe_add( _4760,_4762 ) - (int)1) / _4762);
              int _4765 = (_4764 / (int)2);
              int _4766 = _4759;
              int _9085 = (int)0;
              int _9086 = _4765;
              for (int _4767 = _9085; _4767 < _9086; ++_4767)
              {
                {
                  int _4768 = safe_mul( safe_mul( _4767,_4762 ),(int)2 );
                  int _9087;
                  bool _9088 = (safe_add( safe_add( _4759,_4768 ),safe_mul( (int)2,_4762 ) ) < _4758);
                  if (_9088)
                  {
                    _9087 = safe_add( safe_add( _4759,_4768 ),safe_mul( (int)2,_4762 ) );
                  }
                  else
                  {
                    _9087 = _4758;
                  }
                  int _4769 = _9087;
                  int _4770 = safe_add( safe_add( _4759,_4768 ),_4762 );
                  int _4771 = safe_add( safe_add( _4759,_4768 ),_4762 );
                  int _4772 = safe_add( _4759,_4768 );
                  while ( ((_4772 < _4771) && (_4770 < _4769)) )
                  {
                    {
                      if ((_ptr__4753[safe_add( _4751,_ptr__4752[safe_add( _4754,_4772 )] )] <= _ptr__4753[safe_add( _4751,_ptr__4752[safe_add( _4754,_4770 )] )]))
                      {
                        {
                          _ptr__4752[safe_add( _4755,_4766 )] = _ptr__4752[safe_add( _4754,_4772 )];
                          ++ _4766;
                          ++ _4772;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4752[safe_add( _4755,_4766 )] = _ptr__4752[safe_add( _4754,_4770 )];
                          ++ _4766;
                          ++ _4770;
                        }
                      }
                    }
                  }
                  while ( (_4772 < _4771) )
                  {
                    {
                      _ptr__4752[safe_add( _4755,_4766 )] = _ptr__4752[safe_add( _4754,_4772 )];
                      ++ _4766;
                      ++ _4772;
                    }
                  }
                  while ( (_4770 < _4769) )
                  {
                    {
                      _ptr__4752[safe_add( _4755,_4766 )] = _ptr__4752[safe_add( _4754,_4770 )];
                      ++ _4766;
                      ++ _4770;
                    }
                  }
                }
              }
              int _9089 = _4766;
              int _9090 = _4758;
              for (int _4773 = _9089; _4773 < _9090; ++_4773)
              {
                {
                  _ptr__4752[safe_add( _4755,_4773 )] = _ptr__4752[safe_add( _4754,_4773 )];
                }
              }
              int _4774 = _4754;
              _4754 = _4755;
              _4755 = _4774;
              _4762 *= (int)2;
            }
          }
        }
      }
      {}
      int _9091 = _4759;
      int _9092 = _4758;
      for (int _4775 = _9091; _4775 < _9092; ++_4775)
      {
        {
          _ptr__4752[safe_add( _4746,_4775 )] = _ptr__4752[safe_add( _4754,_4775 )];
        }
      }
    }
  }
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4776){ return new mosek::fusion::ExprCondense(_4776); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _4776) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_4776); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4776){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4776->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _4776;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4777,monty::rc_ptr< ::mosek::fusion::WorkStack > _4778,monty::rc_ptr< ::mosek::fusion::WorkStack > _4779) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_4777,_4778,_4779); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4777,monty::rc_ptr< ::mosek::fusion::WorkStack > _4778,monty::rc_ptr< ::mosek::fusion::WorkStack > _4779){
  expr->eval(_4777,_4778,_4779);
  int _4780 = _4777->popi32();
  long long _4781 = (int)1;
  int _9093 = (int)0;
  int _9094 = _4780;
  for (int _4782 = _9093; _4782 < _9094; ++_4782)
  {
    {
      _4781 *= _4777->popi32();
    }
  }
  int _4783 = _4777->popi32();
  int _4784 = _4777->popi32();
  bool _4785 = (_4777->popi32() != (int)0);
  if (_4785)
  {
    {
      _4777->popi64(_4783);
    }
  }
  {}
  _4777->pushi32((int)0);
  _4777->pushi32(_4784);
  _4777->pushi32(_4783);
  _4777->pushi32(_4783);
  _4777->pushi32((int)1);
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4786){ return new mosek::fusion::ExprFromVar(_4786); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _4786) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_4786); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _4786){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4786->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _4786;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4787,monty::rc_ptr< ::mosek::fusion::WorkStack > _4788,monty::rc_ptr< ::mosek::fusion::WorkStack > _4789) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_4787,_4788,_4789); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4787,monty::rc_ptr< ::mosek::fusion::WorkStack > _4788,monty::rc_ptr< ::mosek::fusion::WorkStack > _4789){
  std::shared_ptr< monty::ndarray< int,1 > > _4790 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4790(_4790 ? _4790->raw() : nullptr,_4790 ? _4790->size(0) : 0);
  long long _4791 = ::mosek::fusion::p_Set::size(_4790);
  int _4792 = x->numInst();
  int _4793 = _4792;
  bool _4794 = (_4791 > _4792);
  int _4795 = _4787->alloci32(safe_add( _4792,(int)1 ));
  int _4796 = _4787->alloci64(_4793);
  int _9095;
  bool _9096 = _4794;
  if (_9096)
  {
    _9095 = _4787->alloci64(_4792);
  }
  else
  {
    _9095 = (-(int)1);
  }
  int _4797 = _9095;
  int _4798 = _4787->allocf64(_4793);
  int _4799 = _4787->allocf64(_4792);
  int _9097;
  bool _9098 = _4794;
  if (_9098)
  {
    _9097 = (int)1;
  }
  else
  {
    _9097 = (int)0;
  }
  _4787->pushi32(_9097);
  _4787->pushi32(_4793);
  _4787->pushi32(_4792);
  int _9099 = (int)0;
  int _9100 = (int)((_4790)->size(0));
  for (int _4800 = _9099; _4800 < _9100; ++_4800)
  {
    {
      _4787->pushi32(_ptr__4790[_4800]);
    }
  }
  _4787->pushi32((int)((_4790)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4801 = mosek::fusion::p_WorkStack::_get_impl(_4787)->i32;
  _checked_ptr_1<int> _ptr__4801(_4801 ? _4801->raw() : nullptr,_4801 ? _4801->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4802 = mosek::fusion::p_WorkStack::_get_impl(_4787)->i64;
  _checked_ptr_1<long long> _ptr__4802(_4802 ? _4802->raw() : nullptr,_4802 ? _4802->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4803 = mosek::fusion::p_WorkStack::_get_impl(_4787)->f64;
  _checked_ptr_1<double> _ptr__4803(_4803 ? _4803->raw() : nullptr,_4803 ? _4803->size(0) : 0);
  int _9101 = (int)0;
  int _9102 = safe_add( _4792,(int)1 );
  for (int _4804 = _9101; _4804 < _9102; ++_4804)
  {
    {
      _ptr__4801[safe_add( _4795,_4804 )] = _4804;
    }
  }
  int _9103 = (int)0;
  int _9104 = _4792;
  for (int _4805 = _9103; _4805 < _9104; ++_4805)
  {
    {
      _ptr__4803[safe_add( _4799,_4805 )] = 0.0;
    }
  }
  int _9105 = (int)0;
  int _9106 = _4793;
  for (int _4806 = _9105; _4806 < _9106; ++_4806)
  {
    {
      _ptr__4803[safe_add( _4798,_4806 )] = 1.0;
    }
  }
  if (_4794)
  {
    {
      x->inst(_4797,_4802,_4796,_4802);
    }
  }
  else
  {
    {
      x->inst(_4796,_4802);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4807,    monty::rc_ptr< ::mosek::fusion::Expression > _4808){ return new mosek::fusion::ExprReshape(_4807,_4808); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _4807,    monty::rc_ptr< ::mosek::fusion::Expression > _4808) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_4807,_4808); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4807,    monty::rc_ptr< ::mosek::fusion::Expression > _4808){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4807(_4807 ? _4807->raw() : nullptr, _4807 ? _4807->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4807));
    long long _4809 = _4808->getSize();
    if ((::mosek::fusion::p_Set::size(_4807) != _4808->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _4808;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4810,monty::rc_ptr< ::mosek::fusion::WorkStack > _4811,monty::rc_ptr< ::mosek::fusion::WorkStack > _4812) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_4810,_4811,_4812); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4810,monty::rc_ptr< ::mosek::fusion::WorkStack > _4811,monty::rc_ptr< ::mosek::fusion::WorkStack > _4812){
  std::shared_ptr< monty::ndarray< int,1 > > _4813 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4813(_4813 ? _4813->raw() : nullptr,_4813 ? _4813->size(0) : 0);
  e->eval(_4810,_4811,_4812);
  _4810->peek_expr();
  int _4814 = _4810->popi32();
  long long _4815 = (int)1;
  int _9107 = (int)0;
  int _9108 = _4814;
  for (int _4816 = _9107; _4816 < _9108; ++_4816)
  {
    {
      _4815 *= _4810->popi32();
    }
  }
  if ((_4815 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _9109 = (int)0;
  int _9110 = (int)((_4813)->size(0));
  for (int _4817 = _9109; _4817 < _9110; ++_4817)
  {
    {
      _4810->pushi32(_ptr__4813[_4817]);
    }
  }
  _4810->pushi32((int)((_4813)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4818 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _4818->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _9111 = (int)1;
      int _9112 = _pubthis->getND();
      for (int _4819 = _9111; _4819 < _9112; ++_4819)
      {
        {
          _4818->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_4819));
        }
      }
    }
  }
  {}
  _4818->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4818->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4820){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4820(_4820 ? _4820->raw() : nullptr, _4820 ? _4820->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _4820;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__eval() { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::eval() { return __mosek_2fusion_2BaseExpression__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__eval(){
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4821 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4822 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _4823 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  _pubthis->eval(_4821,_4822,_4823);
  int _4824 = _4821->popi32();
  std::shared_ptr< monty::ndarray< int,1 > > _4825 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4824)));
  _checked_ptr_1<int> _ptr__4825(_4825 ? _4825->raw() : nullptr,_4825 ? _4825->size(0) : 0);
  _4821->popi32(_4824,_4825,(int)0);
  int _4826 = _4821->popi32();
  int _4827 = _4821->popi32();
  int _4828 = (int)1;
  int _9113 = (int)0;
  int _9114 = _4824;
  for (int _4829 = _9113; _4829 < _9114; ++_4829)
  {
    {
      _4828 *= _ptr__4825[_4829];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4830 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4827)));
  _checked_ptr_1<long long> _ptr__4830(_4830 ? _4830->raw() : nullptr,_4830 ? _4830->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4831 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4826,(int)1 ))));
  _checked_ptr_1<int> _ptr__4831(_4831 ? _4831->raw() : nullptr,_4831 ? _4831->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4832 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4826)));
  _checked_ptr_1<double> _ptr__4832(_4832 ? _4832->raw() : nullptr,_4832 ? _4832->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4833 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4827)));
  _checked_ptr_1<double> _ptr__4833(_4833 ? _4833->raw() : nullptr,_4833 ? _4833->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4834 = nullptr;
  _checked_ptr_1<long long> _ptr__4834(_4834 ? _4834->raw() : nullptr,_4834 ? _4834->size(0) : 0);
  if ((_4828 < _4826))
  {
    {
      _4834 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4826)));
      _ptr__4834.update(_4834 ? _4834->raw() : nullptr, _4834 ? _4834->size(0) : 0);
      _4821->popi64(_4826,_4834,(int)0);
    }
  }
  {}
  _4821->popi32(_4826,_4831,(int)1);
  _4821->popi64(_4827,_4830,(int)0);
  _4821->popf64(_4826,_4832,(int)0);
  _4821->popf64(_4827,_4833,(int)0);
  std::vector<long long> _9115;
  for (int _4835 = (int)0, _9116 = safe_add( _4826,(int)1 ); _4835 < _9116 ; ++_4835)
  {
    _9115.push_back(_ptr__4831[_4835]);
  }
  auto _9117 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9115.size()),_9115.begin(),_9115.end()));
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_4832,_9117,_4830,_4833,_4825,_4834);
}
void mosek::fusion::BaseExpression::storeexpr  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4836,    std::shared_ptr< monty::ndarray< int,1 > > _4837,    std::shared_ptr< monty::ndarray< int,1 > > _4838,    std::shared_ptr< monty::ndarray< long long,1 > > _4839,    std::shared_ptr< monty::ndarray< long long,1 > > _4840,    std::shared_ptr< monty::ndarray< double,1 > > _4841,    std::shared_ptr< monty::ndarray< double,1 > > _4842) { mosek::fusion::p_BaseExpression::storeexpr(_4836,_4837,_4838,_4839,_4840,_4841,_4842); }void mosek::fusion::p_BaseExpression::storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4836,std::shared_ptr< monty::ndarray< int,1 > > _4837,std::shared_ptr< monty::ndarray< int,1 > > _4838,std::shared_ptr< monty::ndarray< long long,1 > > _4839,std::shared_ptr< monty::ndarray< long long,1 > > _4840,std::shared_ptr< monty::ndarray< double,1 > > _4841,std::shared_ptr< monty::ndarray< double,1 > > _4842){
  _checked_ptr_1<int> _ptr__4837(_4837 ? _4837->raw() : nullptr, _4837 ? _4837->size(0) : 0);
  _checked_ptr_1<int> _ptr__4838(_4838 ? _4838->raw() : nullptr, _4838 ? _4838->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4839(_4839 ? _4839->raw() : nullptr, _4839 ? _4839->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4840(_4840 ? _4840->raw() : nullptr, _4840 ? _4840->size(0) : 0);
  _checked_ptr_1<double> _ptr__4841(_4841 ? _4841->raw() : nullptr, _4841 ? _4841->size(0) : 0);
  _checked_ptr_1<double> _ptr__4842(_4842 ? _4842->raw() : nullptr, _4842 ? _4842->size(0) : 0);
  int _4843 = _ptr__4838[((int)((_4838)->size(0)) - (int)1)];
  int _4844 = ((int)((_4838)->size(0)) - (int)1);
  int _4845 = (int)((_4837)->size(0));
  {
    int _4846 = _4836->alloci32(safe_add( _4844,(int)1 ));
    ::mosek::fusion::Utils::Tools::arraycopy(_4838,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4836)->i32,_4846,safe_add( _4844,(int)1 ));
  }
  int _9118;
  bool _9119 = (NULL != _4839.get());
  if (_9119)
  {
    _9118 = (int)1;
  }
  else
  {
    _9118 = (int)0;
  }
  _4836->pushi32(_9118);
  _4836->pushi32(_4843);
  _4836->pushi32(_4844);
  {
    int _4847 = _4836->alloci32(_4845);
    ::mosek::fusion::Utils::Tools::arraycopy(_4837,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4836)->i32,_4847,_4845);
  }
  _4836->pushi32(_4845);
  {
    int _4848 = _4836->alloci64(_4843);
    ::mosek::fusion::Utils::Tools::arraycopy(_4840,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4836)->i64,_4848,_4843);
  }
  if ((NULL != _4839.get()))
  {
    {
      int _4849 = _4836->alloci64(_4844);
      ::mosek::fusion::Utils::Tools::arraycopy(_4839,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4836)->i64,_4849,_4844);
    }
  }
  {}
  {
    int _4850 = _4836->allocf64(_4843);
    ::mosek::fusion::Utils::Tools::arraycopy(_4841,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4836)->f64,_4850,_4843);
  }
  {
    int _4851 = _4836->allocf64(_4844);
    if ((NULL != _4842.get()))
    {
      {
        ::mosek::fusion::Utils::Tools::arraycopy(_4842,(int)0,mosek::fusion::p_WorkStack::_get_impl(_4836)->f64,_4851,_4844);
      }
    }
    else
    {
      {
        int _9120 = (int)0;
        int _9121 = _4844;
        for (int _4852 = _9120; _4852 < _9121; ++_4852)
        {
          {
            ((*mosek::fusion::p_WorkStack::_get_impl(_4836)->f64)(safe_add( _4851,_4852 ))) = (int)0;
          }
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4856) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4856); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _4856) { return __mosek_2fusion_2BaseExpression__pick(_4856); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4856) { return __mosek_2fusion_2BaseExpression__pick(_4856); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4856){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4856)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4857) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_4857); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _4857) { return __mosek_2fusion_2BaseExpression__pick(_4857); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4857) { return __mosek_2fusion_2BaseExpression__pick(_4857); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4857){
  _checked_ptr_1<int> _ptr__4857(_4857 ? _4857->raw() : nullptr, _4857 ? _4857->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4858 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_4857)->size(0)),(int)1)));
  int _9122 = (int)0;
  int _9123 = (int)((_4857)->size(0));
  for (int _4859 = _9122; _4859 < _9123; ++_4859)
  {
    {
      ((*_4858)(_4859,(int)0)) = _ptr__4857[_4859];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4858)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4860) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4860); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _4860) { return __mosek_2fusion_2BaseExpression__index(_4860); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4860) { return __mosek_2fusion_2BaseExpression__index(_4860); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4860){
  _checked_ptr_1<int> _ptr__4860(_4860 ? _4860->raw() : nullptr, _4860 ? _4860->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _4861 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_4860)->size(0)))));
  int _9124 = (int)0;
  int _9125 = (int)((_4860)->size(0));
  for (int _4862 = _9124; _4862 < _9125; ++_4862)
  {
    {
      ((*_4861)((int)0,_4862)) = _ptr__4860[_4862];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4861)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _4863) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_4863); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _4863) { return __mosek_2fusion_2BaseExpression__index(_4863); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _4863) { return __mosek_2fusion_2BaseExpression__index(_4863); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _4863){
  std::shared_ptr< monty::ndarray< int,2 > > _4864 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_4864)((int)0,(int)0)) = _4863;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4864)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4865,std::shared_ptr< monty::ndarray< int,1 > > _4866) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4865,_4866); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _4865,std::shared_ptr< monty::ndarray< int,1 > > _4866) { return __mosek_2fusion_2BaseExpression__slice(_4865,_4866); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4865,std::shared_ptr< monty::ndarray< int,1 > > _4866) { return __mosek_2fusion_2BaseExpression__slice(_4865,_4866); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4865,std::shared_ptr< monty::ndarray< int,1 > > _4866){
  _checked_ptr_1<int> _ptr__4865(_4865 ? _4865->raw() : nullptr, _4865 ? _4865->size(0) : 0);
  _checked_ptr_1<int> _ptr__4866(_4866 ? _4866->raw() : nullptr, _4866 ? _4866->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_4865,_4866)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _4867,int _4868) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_4867,_4868); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _4867,int _4868) { return __mosek_2fusion_2BaseExpression__slice(_4867,_4868); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _4867,int _4868) { return __mosek_2fusion_2BaseExpression__slice(_4867,_4868); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _4867,int _4868){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4867)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_4868)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _4869) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_4869); }int mosek::fusion::p_BaseExpression::getDim(int _4869){
  return ((*shape)(_4869));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_bfix_base() { return _impl->bfix_base; }
void mosek::fusion::WorkStack::set_bfix_base(int _val) { _impl->bfix_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    bfix_base = (int)0;
    cof_base = (int)0;
  }
}bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _4870) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_4870); }int mosek::fusion::p_WorkStack::peek_dim(int _4870){
  return _pubthis->peeki32(safe_add( _4870,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _4871,int _4872,int _4873,bool _4874) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_4871,_4872,_4873,_4874); }void mosek::fusion::p_WorkStack::alloc_expr(int _4871,int _4872,int _4873,bool _4874){
  cof_base = _pubthis->allocf64(_4873);
  bfix_base = _pubthis->allocf64(_4872);
  nidxs_base = _pubthis->alloci64(_4873);
  int _9126;
  bool _9127 = _4874;
  if (_9127)
  {
    _9126 = _pubthis->alloci64(_4872);
  }
  else
  {
    _9126 = (-(int)9999);
  }
  sp_base = _9126;
  ptr_base = _pubthis->alloci32(safe_add( _4872,(int)1 ));
  int _9128;
  bool _9129 = _4874;
  if (_9129)
  {
    _9128 = (int)1;
  }
  else
  {
    _9128 = (int)0;
  }
  _pubthis->pushi32(_9128);
  _pubthis->pushi32(_4873);
  _pubthis->pushi32(_4872);
  shape_base = _pubthis->alloci32(_4871);
  _pubthis->pushi32(_4871);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _4871;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _4872;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _4873;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _4874;
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4875) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_4875); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4875){
  int _4876 = pi32;
  int _4877 = pi64;
  int _4878 = pf64;
  _pubthis->pop_expr();
  int _4879 = _4875->alloci32((_4876 - pi32));
  int _4880 = _4875->alloci64((_4877 - pi64));
  int _4881 = _4875->allocf64((_4878 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_4875)->i32,_4879,(_4876 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_4875)->i64,_4880,(_4877 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_4875)->f64,_4881,(_4878 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _4882 = pi32;
  int _4883 = pi64;
  int _4884 = pf64;
  _pubthis->pop_expr();
  pi32 = _4882;
  pi64 = _4883;
  pf64 = _4884;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _9130;
  bool _9131 = hassp;
  if (_9131)
  {
    _9130 = _pubthis->popi64(nelem);
  }
  else
  {
    _9130 = (-(int)9999);
  }
  sp_base = _9130;
  nidxs_base = _pubthis->popi64(nnz);
  bfix_base = _pubthis->popf64(nelem);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _4885 = ((*i32)((pi32 - (int)1)));
  bool _4886 = (((*i32)(((pi32 - _4885) - (int)3))) != (int)0);
  int _4887 = ((*i32)(((pi32 - _4885) - (int)1)));
  if ((!_4886))
  {
    {
      ((*i32)(((pi32 - _4885) - (int)3))) = (int)1;
      int _4888 = _pubthis->alloci64(_4887);
      int _9132 = (int)0;
      int _9133 = _4887;
      for (int _4889 = _9132; _4889 < _9133; ++_4889)
      {
        {
          ((*i64)(_4888)) = _4889;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _4890) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_4890); }int mosek::fusion::p_WorkStack::allocf64(int _4890){
  _pubthis->ensuref64(_4890);
  int _4891 = pf64;
  int _9134 = pf64;
  int _9135 = safe_add( pf64,_4890 );
  for (int _4892 = _9134; _4892 < _9135; ++_4892)
  {
    {
      ((*f64)(_4892)) = (int)99997;
    }
  }
  pf64 += _4890;
  return _4891;
}
int mosek::fusion::WorkStack :: alloci64(int _4893) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_4893); }int mosek::fusion::p_WorkStack::alloci64(int _4893){
  _pubthis->ensurei64(_4893);
  int _4894 = pi64;
  int _9136 = pi64;
  int _9137 = safe_add( pi64,_4893 );
  for (int _4895 = _9136; _4895 < _9137; ++_4895)
  {
    {
      ((*i64)(_4895)) = (int)99998;
    }
  }
  pi64 += _4893;
  return _4894;
}
int mosek::fusion::WorkStack :: alloci32(int _4896) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_4896); }int mosek::fusion::p_WorkStack::alloci32(int _4896){
  if ((_4896 > (int)0))
  {
    {
      _pubthis->ensurei32(_4896);
      int _4897 = pi32;
      int _9138 = pi32;
      int _9139 = safe_add( pi32,_4896 );
      for (int _4898 = _9138; _4898 < _9139; ++_4898)
      {
        {
          ((*i32)(_4898)) = (int)99999;
        }
      }
      pi32 += _4896;
      return _4897;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _4899) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_4899); }void mosek::fusion::p_WorkStack::pushf64(double _4899){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _4899;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _4900) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_4900); }void mosek::fusion::p_WorkStack::pushi64(long long _4900){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _4900;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _4901) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_4901); }void mosek::fusion::p_WorkStack::pushi32(int _4901){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _4901;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _4902) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_4902); }void mosek::fusion::p_WorkStack::ensuref64(int _4902){
  if ((safe_add( pf64,_4902 ) > (int)((f64)->size(0))))
  {
    {
      int _9140;
      bool _9141 = (_4902 < (int)((f64)->size(0)));
      if (_9141)
      {
        _9140 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _9140 = safe_add( (int)((f64)->size(0)),_4902 );
      }
      int _4903 = _9140;
      std::shared_ptr< monty::ndarray< double,1 > > _4904 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_4903)));
      _checked_ptr_1<double> _ptr__4904(_4904 ? _4904->raw() : nullptr,_4904 ? _4904->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_4904,(int)0,pf64);
      f64 = _4904;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _4905) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_4905); }void mosek::fusion::p_WorkStack::ensurei64(int _4905){
  if ((safe_add( pi64,_4905 ) > (int)((i64)->size(0))))
  {
    {
      int _9142;
      bool _9143 = (_4905 < (int)((i64)->size(0)));
      if (_9143)
      {
        _9142 = (int)((i64)->size(0));
      }
      else
      {
        _9142 = _4905;
      }
      int _4906 = safe_add( (int)((i64)->size(0)),_9142 );
      std::shared_ptr< monty::ndarray< long long,1 > > _4907 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4906)));
      _checked_ptr_1<long long> _ptr__4907(_4907 ? _4907->raw() : nullptr,_4907 ? _4907->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_4907,(int)0,pi64);
      i64 = _4907;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _4908) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_4908); }void mosek::fusion::p_WorkStack::ensurei32(int _4908){
  if ((safe_add( pi32,_4908 ) > (int)((i32)->size(0))))
  {
    {
      int _9144;
      bool _9145 = (_4908 < (int)((i32)->size(0)));
      if (_9145)
      {
        _9144 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _9144 = safe_add( (int)((i32)->size(0)),_4908 );
      }
      int _4909 = _9144;
      std::shared_ptr< monty::ndarray< int,1 > > _4910 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4909)));
      _checked_ptr_1<int> _ptr__4910(_4910 ? _4910->raw() : nullptr,_4910 ? _4910->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_4910,(int)0,pi32);
      i32 = _4910;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _4911) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4911); }int mosek::fusion::p_WorkStack::popf64(int _4911){
  pf64 -= _4911;
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _4912) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4912); }int mosek::fusion::p_WorkStack::popi64(int _4912){
  pi64 -= _4912;
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _4913) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4913); }int mosek::fusion::p_WorkStack::popi32(int _4913){
  pi32 -= _4913;
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _4914,std::shared_ptr< monty::ndarray< double,1 > > _4915,int _4916) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_4914,_4915,_4916); }void mosek::fusion::p_WorkStack::popf64(int _4914,std::shared_ptr< monty::ndarray< double,1 > > _4915,int _4916){
  _checked_ptr_1<double> _ptr__4915(_4915 ? _4915->raw() : nullptr, _4915 ? _4915->size(0) : 0);
  pf64 -= _4914;
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_4915,_4916,_4914);
}
void mosek::fusion::WorkStack :: popi64(int _4917,std::shared_ptr< monty::ndarray< long long,1 > > _4918,int _4919) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_4917,_4918,_4919); }void mosek::fusion::p_WorkStack::popi64(int _4917,std::shared_ptr< monty::ndarray< long long,1 > > _4918,int _4919){
  _checked_ptr_1<long long> _ptr__4918(_4918 ? _4918->raw() : nullptr, _4918 ? _4918->size(0) : 0);
  pi64 -= _4917;
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_4918,_4919,_4917);
}
void mosek::fusion::WorkStack :: popi32(int _4920,std::shared_ptr< monty::ndarray< int,1 > > _4921,int _4922) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_4920,_4921,_4922); }void mosek::fusion::p_WorkStack::popi32(int _4920,std::shared_ptr< monty::ndarray< int,1 > > _4921,int _4922){
  _checked_ptr_1<int> _ptr__4921(_4921 ? _4921->raw() : nullptr, _4921 ? _4921->size(0) : 0);
  pi32 -= _4920;
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_4921,_4922,_4920);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _4923) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_4923); }double mosek::fusion::p_WorkStack::peekf64(int _4923){
  return ((*f64)(((pf64 - _4923) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _4924) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_4924); }long long mosek::fusion::p_WorkStack::peeki64(int _4924){
  return ((*i64)(((pi64 - _4924) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _4925) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_4925); }int mosek::fusion::p_WorkStack::peeki32(int _4925){
  return ((*i32)(((pi32 - _4925) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _4926,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4927,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4928,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4929){ return new mosek::fusion::SymmetricExpr(_4926,_4927,_4928,_4929); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _4926,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4927,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4928,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4929) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_4926,_4927,_4928,_4929); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _4926,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4927,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4928,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4929){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _4926;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _4927;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _4928;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _4929;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4930,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4931){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4930)->n != _4931->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9146;
  bool _9147 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4930)->b.get());
  if (_9147)
  {
    _9146 = mosek::fusion::p_SymmetricExpr::_get_impl(_4930)->b->__mosek_2fusion_2SymmetricMatrix__add(_4931);
  }
  else
  {
    _9146 = _4931;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4930)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_4930)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_4930)->xs,_9146);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4932,double _4933){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _9148;
  for (int _4934 = (int)0, _9149 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4932)->Ms)->size(0)); _4934 < _9149 ; ++_4934)
  {
    _9148.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_4932)->Ms)(_4934))->__mosek_2fusion_2SymmetricMatrix__mul(_4933));
  }
  auto _9150 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_9148.size()),_9148.begin(),_9148.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9151;
  bool _9152 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4932)->b.get());
  if (_9152)
  {
    _9151 = mosek::fusion::p_SymmetricExpr::_get_impl(_4932)->b->__mosek_2fusion_2SymmetricMatrix__mul(_4933);
  }
  else
  {
    _9151 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4932)->n,_9150,mosek::fusion::p_SymmetricExpr::_get_impl(_4932)->xs,_9151);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4935,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4936){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4937 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4938 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->xs)->size(0)) ))));
  int _4939 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->Ms)->size(0));
  int _9153 = (int)0;
  int _9154 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->Ms)->size(0));
  for (int _4940 = _9153; _4940 < _9154; ++_4940)
  {
    {
      ((*_4937)(_4940)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->Ms)(_4940));
    }
  }
  int _9155 = (int)0;
  int _9156 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->Ms)->size(0));
  for (int _4941 = _9155; _4941 < _9156; ++_4941)
  {
    {
      ((*_4937)(safe_add( _4941,_4939 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->Ms)(_4941));
    }
  }
  int _4942 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->xs)->size(0));
  int _9157 = (int)0;
  int _9158 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->xs)->size(0));
  for (int _4943 = _9157; _4943 < _9158; ++_4943)
  {
    {
      ((*_4938)(_4943)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->xs)(_4943));
    }
  }
  int _9159 = (int)0;
  int _9160 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->xs)->size(0));
  for (int _4944 = _9159; _4944 < _9160; ++_4944)
  {
    {
      ((*_4938)(safe_add( _4944,_4942 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->xs)(_4944));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9161;
  bool _9162 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->b.get()));
  if (_9162)
  {
    _9161 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9163;
    bool _9164 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->b.get()));
    if (_9164)
    {
      _9163 = mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _9165;
      bool _9166 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->b.get());
      if (_9166)
      {
        _9165 = mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->b;
      }
      else
      {
        _9165 = mosek::fusion::p_SymmetricExpr::_get_impl(_4936)->b;
      }
      _9163 = _9165;
    }
    _9161 = _9163;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4945 = _9161;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_4935)->n,_4937,_4938,_4945);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4946 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _4946->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _4946->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4947,    std::shared_ptr< monty::ndarray< long long,1 > > _4948,    std::shared_ptr< monty::ndarray< double,1 > > _4949,    std::shared_ptr< monty::ndarray< double,1 > > _4950,    std::shared_ptr< monty::ndarray< int,1 > > _4951,    std::shared_ptr< monty::ndarray< long long,1 > > _4952){ return new mosek::fusion::Expr(_4947,_4948,_4949,_4950,_4951,_4952); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4947,    std::shared_ptr< monty::ndarray< long long,1 > > _4948,    std::shared_ptr< monty::ndarray< double,1 > > _4949,    std::shared_ptr< monty::ndarray< double,1 > > _4950,    std::shared_ptr< monty::ndarray< int,1 > > _4951,    std::shared_ptr< monty::ndarray< long long,1 > > _4952) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4947,_4948,_4949,_4950,_4951,_4952); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4947,    std::shared_ptr< monty::ndarray< long long,1 > > _4948,    std::shared_ptr< monty::ndarray< double,1 > > _4949,    std::shared_ptr< monty::ndarray< double,1 > > _4950,    std::shared_ptr< monty::ndarray< int,1 > > _4951,    std::shared_ptr< monty::ndarray< long long,1 > > _4952){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4947(_4947 ? _4947->raw() : nullptr, _4947 ? _4947->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4948(_4948 ? _4948->raw() : nullptr, _4948 ? _4948->size(0) : 0);
    _checked_ptr_1<double> _ptr__4949(_4949 ? _4949->raw() : nullptr, _4949 ? _4949->size(0) : 0);
    _checked_ptr_1<double> _ptr__4950(_4950 ? _4950->raw() : nullptr, _4950 ? _4950->size(0) : 0);
    _checked_ptr_1<int> _ptr__4951(_4951 ? _4951->raw() : nullptr, _4951 ? _4951->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4952(_4952 ? _4952->raw() : nullptr, _4952 ? _4952->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _9167;
    bool _9168 = (NULL != _4951.get());
    if (_9168)
    {
      _9167 = ::mosek::fusion::Utils::Tools::arraycopy(_4951);
    }
    else
    {
      _9167 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_4947)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _9169;
    bool _9170 = (NULL != _4952.get());
    if (_9170)
    {
      _9169 = ::mosek::fusion::Utils::Tools::arraycopy(_4952);
    }
    else
    {
      _9169 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_4947),::mosek::fusion::Utils::Tools::arraycopy(_4948),::mosek::fusion::Utils::Tools::arraycopy(_4949),::mosek::fusion::Utils::Tools::arraycopy(_4950),_9167,_9169,(int)1);
    int _4953 = ((int)((_4947)->size(0)) - (int)1);
    if ((_4953 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _4954 = _ptr__4947[_4953];
    if (((_4954 < (int)0) || ((_4954 != (int)((_4949)->size(0))) || (_4954 != (int)((_4948)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _4955 = true;
    bool _4956 = true;
    bool _4957 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _4958 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__4958(_4958 ? _4958->raw() : nullptr,_4958 ? _4958->size(0) : 0);
    long long _4959 = ::mosek::fusion::p_Set::size(_4958);
    {
      int _9171 = (int)0;
      int _9172 = (int)((_4958)->size(0));
      for (int _4960 = _9171; _4960 < _9172; ++_4960)
      {
        {
          _4956 = (_4956 && (_ptr__4958[_4960] >= (int)0));
        }
      }
      int _9173 = (int)0;
      int _9174 = _4953;
      for (int _4961 = _9173; _4961 < _9174; ++_4961)
      {
        {
          _4955 = (_4955 && (_ptr__4947[_4961] <= _ptr__4947[safe_add( _4961,(int)1 )]));
        }
      }
      if (((NULL != _4952.get()) && ((int)((_4952)->size(0)) > (int)0)))
      {
        {
          _4957 = ((_ptr__4952[(int)0] >= (int)0) && (_ptr__4952[(_4953 - (int)1)] < _4959));
          int _9175 = (int)0;
          int _9176 = (_4953 - (int)1);
          for (int _4962 = _9175; _4962 < _9176; ++_4962)
          {
            {
              _4957 = (_4957 && (_ptr__4952[_4962] < _ptr__4952[safe_add( _4962,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_4956))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_4955))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_4957))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4963,    std::shared_ptr< monty::ndarray< long long,1 > > _4964,    std::shared_ptr< monty::ndarray< double,1 > > _4965,    std::shared_ptr< monty::ndarray< double,1 > > _4966,    std::shared_ptr< monty::ndarray< int,1 > > _4967,    std::shared_ptr< monty::ndarray< long long,1 > > _4968,    int _4969){ return new mosek::fusion::Expr(_4963,_4964,_4965,_4966,_4967,_4968,_4969); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _4963,    std::shared_ptr< monty::ndarray< long long,1 > > _4964,    std::shared_ptr< monty::ndarray< double,1 > > _4965,    std::shared_ptr< monty::ndarray< double,1 > > _4966,    std::shared_ptr< monty::ndarray< int,1 > > _4967,    std::shared_ptr< monty::ndarray< long long,1 > > _4968,    int _4969) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4963,_4964,_4965,_4966,_4967,_4968,_4969); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _4963,    std::shared_ptr< monty::ndarray< long long,1 > > _4964,    std::shared_ptr< monty::ndarray< double,1 > > _4965,    std::shared_ptr< monty::ndarray< double,1 > > _4966,    std::shared_ptr< monty::ndarray< int,1 > > _4967,    std::shared_ptr< monty::ndarray< long long,1 > > _4968,    int _4969){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4963(_4963 ? _4963->raw() : nullptr, _4963 ? _4963->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4964(_4964 ? _4964->raw() : nullptr, _4964 ? _4964->size(0) : 0);
    _checked_ptr_1<double> _ptr__4965(_4965 ? _4965->raw() : nullptr, _4965 ? _4965->size(0) : 0);
    _checked_ptr_1<double> _ptr__4966(_4966 ? _4966->raw() : nullptr, _4966 ? _4966->size(0) : 0);
    _checked_ptr_1<int> _ptr__4967(_4967 ? _4967->raw() : nullptr, _4967 ? _4967->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4968(_4968 ? _4968->raw() : nullptr, _4968 ? _4968->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_4967);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _4967;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _4963;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _4964;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _4965;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _4966;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _4968;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4970){ return new mosek::fusion::Expr(_4970); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _4970) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_4970); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4970){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4970->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _9177 = _4970;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_9177.get()))
    {
      ::mosek::fusion::Expr::t _4971 (dynamic_cast<::mosek::fusion::Expr*>(_9177.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_4971)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_4971)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_4971)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_4971)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_4971)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_4971)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _4972 = _9177;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4973 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4974 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _4975 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _4972->eval(_4975,_4974,_4973);
        int _4976 = _4975->popi32();
        int _4977 = _4975->popi32(_4976);
        int _4978 = _4975->popi32();
        int _4979 = _4975->popi32();
        bool _4980 = (_4975->popi32() != (int)0);
        int _4981 = _4975->popi32(safe_add( _4978,(int)1 ));
        int _9178;
        bool _9179 = _4980;
        if (_9179)
        {
          _9178 = _4975->popi64(_4978);
        }
        else
        {
          _9178 = (int)0;
        }
        int _4982 = _9178;
        int _4983 = _4975->popi64(_4979);
        int _4984 = _4975->popf64(_4978);
        int _4985 = _4975->popf64(_4979);
        std::shared_ptr< monty::ndarray< int,1 > > _4986 = mosek::fusion::p_WorkStack::_get_impl(_4975)->i32;
        _checked_ptr_1<int> _ptr__4986(_4986 ? _4986->raw() : nullptr,_4986 ? _4986->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _4987 = mosek::fusion::p_WorkStack::_get_impl(_4975)->i64;
        _checked_ptr_1<long long> _ptr__4987(_4987 ? _4987->raw() : nullptr,_4987 ? _4987->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _4988 = mosek::fusion::p_WorkStack::_get_impl(_4975)->f64;
        _checked_ptr_1<double> _ptr__4988(_4988 ? _4988->raw() : nullptr,_4988 ? _4988->size(0) : 0);
        std::vector<int> _9180;
        for (int _4989 = (int)0, _9181 = _4976; _4989 < _9181 ; ++_4989)
        {
          _9180.push_back(_ptr__4986[safe_add( _4977,_4989 )]);
        }
        auto _9182 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9180.size()),_9180.begin(),_9180.end()));
        shape = _9182;
        std::vector<long long> _9183;
        for (int _4990 = (int)0, _9184 = safe_add( _4978,(int)1 ); _4990 < _9184 ; ++_4990)
        {
          _9183.push_back(_ptr__4986[safe_add( _4981,_4990 )]);
        }
        auto _9185 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9183.size()),_9183.begin(),_9183.end()));
        ptrb = _9185;
        std::vector<long long> _9186;
        for (int _4991 = (int)0, _9187 = _4979; _4991 < _9187 ; ++_4991)
        {
          _9186.push_back(_ptr__4987[safe_add( _4983,_4991 )]);
        }
        auto _9188 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9186.size()),_9186.begin(),_9186.end()));
        subj = _9188;
        std::vector<double> _9189;
        for (int _4992 = (int)0, _9190 = _4979; _4992 < _9190 ; ++_4992)
        {
          _9189.push_back(_ptr__4988[safe_add( _4985,_4992 )]);
        }
        auto _9191 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9189.size()),_9189.begin(),_9189.end()));
        cof_v = _9191;
        std::vector<double> _9192;
        for (int _4993 = (int)0, _9193 = _4979; _4993 < _9193 ; ++_4993)
        {
          _9192.push_back(_ptr__4988[safe_add( _4984,_4993 )]);
        }
        auto _9194 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9192.size()),_9192.begin(),_9192.end()));
        bfix = _9194;
        std::shared_ptr< monty::ndarray< long long,1 > > _9195;
        bool _9196 = _4980;
        if (_9196)
        {
          std::vector<long long> _9197;
          for (int _4994 = (int)0, _9198 = _4979; _4994 < _9198 ; ++_4994)
          {
            _9197.push_back(_ptr__4987[safe_add( _4982,_4994 )]);
          }
          auto _9199 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9197.size()),_9197.begin(),_9197.end()));
          _9195 = _9199;
        }
        else
        {
          _9195 = nullptr;
        }
        inst = _9195;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _4995){
  _checked_ptr_1<int> _ptr__4995(_4995 ? _4995->raw() : nullptr, _4995 ? _4995->size(0) : 0);
  int _4996 = (int)1;
  int _9200 = (int)0;
  int _9201 = (int)((_4995)->size(0));
  for (int _4997 = _9200; _4997 < _9201; ++_4997)
  {
    {
      _4996 *= _ptr__4995[_4997];
    }
  }
  return _4996;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _4998){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9202;
  for (int _4999 = (int)0, _9203 = (int)((_4998)->size(0)); _4999 < _9203 ; ++_4999)
  {
    for (int _5000 = (int)0, _9204 = (int)((((*_4998)(_4999)))->size(0)); _5000 < _9204 ; ++_5000)
    {
      _9202.push_back(((*((*_4998)(_4999)))(_5000)));
    }
  }
  auto _9205 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9202.size()),_9202.begin(),_9202.end()));
  return _9205;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5001,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5002){
  if ((NULL == _5001.get()))
  {
    {
      return _5002;
    }
  }
  else if((NULL == _5002.get()))
  {
    {
      return _5001;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5003 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_5001)->size(0)),(int)((_5002)->size(0)) ))));
      int _9206 = (int)0;
      int _9207 = (int)((_5001)->size(0));
      for (int _5004 = _9206; _5004 < _9207; ++_5004)
      {
        {
          ((*_5003)(_5004)) = ((*_5001)(_5004));
        }
      }
      int _9208 = (int)0;
      int _9209 = (int)((_5002)->size(0));
      for (int _5005 = _9208; _5005 < _9209; ++_5005)
      {
        {
          ((*_5003)(safe_add( _5005,(int)((_5001)->size(0)) ))) = ((*_5002)(_5005));
        }
      }
      return _5003;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _5006) { return mosek::fusion::p_Expr::condense(_5006); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _5006){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_5006)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _5007) { return mosek::fusion::p_Expr::flatten(_5007); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5007){
  if ((NULL == _5007.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5007,(int)_5007->getSize());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5008,    int _5009,    int _5010) { return mosek::fusion::p_Expr::reshape(_5008,_5009,_5010); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5008,int _5009,int _5010){
  if ((NULL == _5008.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5008,::mosek::fusion::p_Set::make(_5009,_5010));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5011,    int _5012) { return mosek::fusion::p_Expr::reshape(_5011,_5012); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5011,int _5012){
  if ((NULL == _5011.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_5011,::mosek::fusion::p_Set::make(_5012));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _5013,    std::shared_ptr< monty::ndarray< int,1 > > _5014) { return mosek::fusion::p_Expr::reshape(_5013,_5014); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5013,std::shared_ptr< monty::ndarray< int,1 > > _5014){
  _checked_ptr_1<int> _ptr__5014(_5014 ? _5014->raw() : nullptr, _5014 ? _5014->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5014,_5013)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr :: __mosek_2fusion_2Expr__eval() { return mosek::fusion::p_Expr::_get_impl(this)->__mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::eval() { return __mosek_2fusion_2Expr__eval(); }
monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::Expr::__mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }monty::rc_ptr< ::mosek::fusion::FlatExpr > mosek::fusion::p_Expr::__mosek_2fusion_2Expr__eval(){
  std::shared_ptr< monty::ndarray< double,1 > > _9210;
  bool _9211 = (NULL == bfix.get());
  if (_9211)
  {
    _9210 = nullptr;
  }
  else
  {
    _9210 = ::mosek::fusion::Utils::Tools::arraycopy(bfix);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5015 = _9210;
  _checked_ptr_1<double> _ptr__5015(_5015 ? _5015->raw() : nullptr,_5015 ? _5015->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9212;
  bool _9213 = (NULL == inst.get());
  if (_9213)
  {
    _9212 = nullptr;
  }
  else
  {
    _9212 = ::mosek::fusion::Utils::Tools::arraycopy(inst);
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5016 = _9212;
  _checked_ptr_1<long long> _ptr__5016(_5016 ? _5016->raw() : nullptr,_5016 ? _5016->size(0) : 0);
  return ::mosek::fusion::p_FlatExpr::_new_FlatExpr(_5015,::mosek::fusion::Utils::Tools::arraycopy(ptrb),::mosek::fusion::Utils::Tools::arraycopy(subj),::mosek::fusion::Utils::Tools::arraycopy(cof_v),shape,inst);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _5017) { return mosek::fusion::p_Expr::zeros(_5017); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _5017){
  _checked_ptr_1<int> _ptr__5017(_5017 ? _5017->raw() : nullptr, _5017 ? _5017->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5017,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _5018) { return mosek::fusion::p_Expr::zeros(_5018); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _5018){
  return ::mosek::fusion::p_Expr::constTerm(_5018,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5019,    std::shared_ptr< monty::ndarray< int,2 > > _5020) { return mosek::fusion::p_Expr::ones(_5019,_5020); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5019,std::shared_ptr< monty::ndarray< int,2 > > _5020){
  _checked_ptr_1<int> _ptr__5019(_5019 ? _5019->raw() : nullptr, _5019 ? _5019->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5019,_5020,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _5021) { return mosek::fusion::p_Expr::ones(_5021); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _5021){
  _checked_ptr_1<int> _ptr__5021(_5021 ? _5021->raw() : nullptr, _5021 ? _5021->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_5021,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _5022) { return mosek::fusion::p_Expr::ones(_5022); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _5022){
  return ::mosek::fusion::p_Expr::constTerm(_5022,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5023) { return mosek::fusion::p_Expr::constTerm(_5023); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5023){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_5023)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_5023)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5023)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5024) { return mosek::fusion::p_Expr::constTerm(_5024); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5024){
  int _5025 = _5024->numRows();
  int _5026 = _5024->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _5027 = ::mosek::fusion::p_Set::make(_5025,_5026);
  _checked_ptr_1<int> _ptr__5027(_5027 ? _5027->raw() : nullptr,_5027 ? _5027->size(0) : 0);
  if (_5024->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5028 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5024->numNonzeros())));
      _checked_ptr_1<double> _ptr__5028(_5028 ? _5028->raw() : nullptr,_5028 ? _5028->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5029 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5024->numNonzeros())));
      _checked_ptr_1<int> _ptr__5029(_5029 ? _5029->raw() : nullptr,_5029 ? _5029->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5030 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5024->numNonzeros())));
      _checked_ptr_1<int> _ptr__5030(_5030 ? _5030->raw() : nullptr,_5030 ? _5030->size(0) : 0);
      _5024->getDataAsTriplets(_5030,_5029,_5028);
      std::vector<long long> _9214;
      for (int _5032 = (int)0, _9215 = (int)((_5029)->size(0)); _5032 < _9215 ; ++_5032)
      {
        _9214.push_back(safe_add( safe_mul( _ptr__5030[_5032],_5026 ),_ptr__5029[_5032] ));
      }
      auto _9216 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9214.size()),_9214.begin(),_9214.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _5031 = _9216;
      _checked_ptr_1<long long> _ptr__5031(_5031 ? _5031->raw() : nullptr,_5031 ? _5031->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5027,_5031,_5028)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5027,nullptr,_5024->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _5033) { return mosek::fusion::p_Expr::constTerm(_5033); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _5033){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_5033)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5034,    std::shared_ptr< monty::ndarray< int,2 > > _5035,    double _5036) { return mosek::fusion::p_Expr::constTerm(_5034,_5035,_5036); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5034,std::shared_ptr< monty::ndarray< int,2 > > _5035,double _5036){
  _checked_ptr_1<int> _ptr__5034(_5034 ? _5034->raw() : nullptr, _5034 ? _5034->size(0) : 0);
  int _5037 = (int)((_5035)->size(0));
  int _5038 = (int)((_5034)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5039 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5037)));
  _checked_ptr_1<long long> _ptr__5039(_5039 ? _5039->raw() : nullptr,_5039 ? _5039->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5040 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5038)));
  _checked_ptr_1<long long> _ptr__5040(_5040 ? _5040->raw() : nullptr,_5040 ? _5040->size(0) : 0);
  _ptr__5040[(_5038 - (int)1)] = (int)1;
  int _9217 = (int)1;
  int _9218 = _5038;
  for (int _5041 = _9217; _5041 < _9218; ++_5041)
  {
    {
      _ptr__5040[((_5038 - _5041) - (int)1)] = safe_mul( _ptr__5040[(_5038 - _5041)],_ptr__5034[(_5038 - _5041)] );
    }
  }
  int _9219 = (int)0;
  int _9220 = _5037;
  for (int _5042 = _9219; _5042 < _9220; ++_5042)
  {
    {
      int _9221 = (int)0;
      int _9222 = _5038;
      for (int _5043 = _9221; _5043 < _9222; ++_5043)
      {
        {
          _ptr__5039[_5042] += safe_mul( _ptr__5040[_5043],((*_5035)(_5042,_5043)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5034,_5039,_5036)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5044,    std::shared_ptr< monty::ndarray< int,2 > > _5045,    std::shared_ptr< monty::ndarray< double,1 > > _5046) { return mosek::fusion::p_Expr::constTerm(_5044,_5045,_5046); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5044,std::shared_ptr< monty::ndarray< int,2 > > _5045,std::shared_ptr< monty::ndarray< double,1 > > _5046){
  _checked_ptr_1<int> _ptr__5044(_5044 ? _5044->raw() : nullptr, _5044 ? _5044->size(0) : 0);
  _checked_ptr_1<double> _ptr__5046(_5046 ? _5046->raw() : nullptr, _5046 ? _5046->size(0) : 0);
  int _5047 = (int)((_5045)->size(0));
  int _5048 = (int)((_5044)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5049 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5047)));
  _checked_ptr_1<long long> _ptr__5049(_5049 ? _5049->raw() : nullptr,_5049 ? _5049->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5050 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5048)));
  _checked_ptr_1<long long> _ptr__5050(_5050 ? _5050->raw() : nullptr,_5050 ? _5050->size(0) : 0);
  _ptr__5050[(_5048 - (int)1)] = (int)1;
  int _9223 = (int)1;
  int _9224 = _5048;
  for (int _5051 = _9223; _5051 < _9224; ++_5051)
  {
    {
      _ptr__5050[((_5048 - _5051) - (int)1)] = safe_mul( _ptr__5050[(_5048 - _5051)],_ptr__5044[(_5048 - _5051)] );
    }
  }
  int _9225 = (int)0;
  int _9226 = _5047;
  for (int _5052 = _9225; _5052 < _9226; ++_5052)
  {
    {
      int _9227 = (int)0;
      int _9228 = _5048;
      for (int _5053 = _9227; _5053 < _9228; ++_5053)
      {
        {
          _ptr__5049[_5052] += safe_mul( _ptr__5050[_5053],((*_5045)(_5052,_5053)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5044,_5049,_5046)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _5054,    double _5055) { return mosek::fusion::p_Expr::constTerm(_5054,_5055); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5054,double _5055){
  _checked_ptr_1<int> _ptr__5054(_5054 ? _5054->raw() : nullptr, _5054 ? _5054->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_5054,nullptr,_5055)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _5056,    double _5057) { return mosek::fusion::p_Expr::constTerm(_5056,_5057); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _5056,double _5057){
  std::vector<double> _9229;
  for (int _5058 = (int)0, _9230 = _5056; _5058 < _9230 ; ++_5058)
  {
    _9229.push_back(_5057);
  }
  auto _9231 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9229.size()),_9229.begin(),_9229.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5056)}),nullptr,_9231)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _5059) { return mosek::fusion::p_Expr::constTerm(_5059); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5059){
  std::vector<double> _9232;
  for (int _5060 = (int)0, _9233 = (int)((_5059)->size(0)); _5060 < _9233 ; ++_5060)
  {
    for (int _5061 = (int)0, _9234 = (int)((_5059)->size(1)); _5061 < _9234 ; ++_5061)
    {
      _9232.push_back(((*_5059)(_5060,_5061)));
    }
  }
  auto _9235 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9232.size()),_9232.begin(),_9232.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5059)->size(0))),(int)((int)((_5059)->size(1)))}),nullptr,_9235)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _5062) { return mosek::fusion::p_Expr::constTerm(_5062); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5062){
  _checked_ptr_1<double> _ptr__5062(_5062 ? _5062->raw() : nullptr, _5062 ? _5062->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5062)->size(0)))}),nullptr,_5062)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5063,    int _5064) { return mosek::fusion::p_Expr::sum(_5063,_5064); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5063,int _5064){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_5064,_5063)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _5065) { return mosek::fusion::p_Expr::sum(_5065); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _5065){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_5065))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _5066) { return mosek::fusion::p_Expr::neg(_5066); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _5066){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_5066)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _5067,monty::rc_ptr< ::mosek::fusion::Matrix > _5068,monty::rc_ptr< ::mosek::fusion::Expression > _5069){
  long long _5070 = _5068->numNonzeros();
  int _5071 = _5068->numRows();
  int _5072 = _5068->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5073 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5070)));
  _checked_ptr_1<double> _ptr__5073(_5073 ? _5073->raw() : nullptr,_5073 ? _5073->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5074 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5070)));
  _checked_ptr_1<int> _ptr__5074(_5074 ? _5074->raw() : nullptr,_5074 ? _5074->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5075 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5070)));
  _checked_ptr_1<int> _ptr__5075(_5075 ? _5075->raw() : nullptr,_5075 ? _5075->size(0) : 0);
  _5068->getDataAsTriplets(_5075,_5074,_5073);
  if (_5067)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_5071,_5072,_5075,_5074,_5073,_5069)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_5071,_5072,_5075,_5074,_5073,_5069)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5076,    monty::rc_ptr< ::mosek::fusion::Matrix > _5077) { return mosek::fusion::p_Expr::mulDiag(_5076,_5077); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5076,monty::rc_ptr< ::mosek::fusion::Matrix > _5077){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5077,_5076->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5078,    monty::rc_ptr< ::mosek::fusion::Variable > _5079) { return mosek::fusion::p_Expr::mulDiag(_5078,_5079); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5078,monty::rc_ptr< ::mosek::fusion::Variable > _5079){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5078,_5079->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5080,    monty::rc_ptr< ::mosek::fusion::Matrix > _5081) { return mosek::fusion::p_Expr::mulDiag(_5080,_5081); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5080,monty::rc_ptr< ::mosek::fusion::Matrix > _5081){
  return ::mosek::fusion::p_Expr::mulDiag(false,_5081,_5080);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5082,    monty::rc_ptr< ::mosek::fusion::Expression > _5083) { return mosek::fusion::p_Expr::mulDiag(_5082,_5083); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5082,monty::rc_ptr< ::mosek::fusion::Expression > _5083){
  return ::mosek::fusion::p_Expr::mulDiag(true,_5082,_5083);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _5084,    std::shared_ptr< monty::ndarray< double,2 > > _5085) { return mosek::fusion::p_Expr::mulDiag(_5084,_5085); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5084,std::shared_ptr< monty::ndarray< double,2 > > _5085){
  std::vector<int> _9236;
  for (int _5086 = (int)0, _9237 = (int)((_5085)->size(0)); _5086 < _9237 ; ++_5086)
  {
    for (int _5087 = (int)0, _9238 = (int)((_5085)->size(1)); _5087 < _9238 ; ++_5087)
    {
      _9236.push_back(_5086);
    }
  }
  auto _9239 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9236.size()),_9236.begin(),_9236.end()));
  std::vector<int> _9240;
  for (int _5088 = (int)0, _9241 = (int)((_5085)->size(0)); _5088 < _9241 ; ++_5088)
  {
    for (int _5089 = (int)0, _9242 = (int)((_5085)->size(1)); _5089 < _9242 ; ++_5089)
    {
      _9240.push_back(_5089);
    }
  }
  auto _9243 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9240.size()),_9240.begin(),_9240.end()));
  std::vector<double> _9244;
  for (int _5090 = (int)0, _9245 = (int)((_5085)->size(0)); _5090 < _9245 ; ++_5090)
  {
    for (int _5091 = (int)0, _9246 = (int)((_5085)->size(1)); _5091 < _9246 ; ++_5091)
    {
      _9244.push_back(((*_5085)(_5090,_5091)));
    }
  }
  auto _9247 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9244.size()),_9244.begin(),_9244.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5085)->size(0)),(int)((_5085)->size(1)),_9239,_9243,_9247,_5084->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _5092,    std::shared_ptr< monty::ndarray< double,2 > > _5093) { return mosek::fusion::p_Expr::mulDiag(_5092,_5093); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5092,std::shared_ptr< monty::ndarray< double,2 > > _5093){
  std::vector<int> _9248;
  for (int _5094 = (int)0, _9249 = (int)((_5093)->size(0)); _5094 < _9249 ; ++_5094)
  {
    for (int _5095 = (int)0, _9250 = (int)((_5093)->size(1)); _5095 < _9250 ; ++_5095)
    {
      _9248.push_back(_5094);
    }
  }
  auto _9251 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9248.size()),_9248.begin(),_9248.end()));
  std::vector<int> _9252;
  for (int _5096 = (int)0, _9253 = (int)((_5093)->size(0)); _5096 < _9253 ; ++_5096)
  {
    for (int _5097 = (int)0, _9254 = (int)((_5093)->size(1)); _5097 < _9254 ; ++_5097)
    {
      _9252.push_back(_5097);
    }
  }
  auto _9255 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9252.size()),_9252.begin(),_9252.end()));
  std::vector<double> _9256;
  for (int _5098 = (int)0, _9257 = (int)((_5093)->size(0)); _5098 < _9257 ; ++_5098)
  {
    for (int _5099 = (int)0, _9258 = (int)((_5093)->size(1)); _5099 < _9258 ; ++_5099)
    {
      _9256.push_back(((*_5093)(_5098,_5099)));
    }
  }
  auto _9259 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9256.size()),_9256.begin(),_9256.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_5093)->size(0)),(int)((_5093)->size(1)),_9251,_9255,_9259,_5092)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5100,    monty::rc_ptr< ::mosek::fusion::Variable > _5101) { return mosek::fusion::p_Expr::mulDiag(_5100,_5101); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5100,monty::rc_ptr< ::mosek::fusion::Variable > _5101){
  std::vector<int> _9260;
  for (int _5102 = (int)0, _9261 = (int)((_5100)->size(0)); _5102 < _9261 ; ++_5102)
  {
    for (int _5103 = (int)0, _9262 = (int)((_5100)->size(1)); _5103 < _9262 ; ++_5103)
    {
      _9260.push_back(_5102);
    }
  }
  auto _9263 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9260.size()),_9260.begin(),_9260.end()));
  std::vector<int> _9264;
  for (int _5104 = (int)0, _9265 = (int)((_5100)->size(0)); _5104 < _9265 ; ++_5104)
  {
    for (int _5105 = (int)0, _9266 = (int)((_5100)->size(1)); _5105 < _9266 ; ++_5105)
    {
      _9264.push_back(_5105);
    }
  }
  auto _9267 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9264.size()),_9264.begin(),_9264.end()));
  std::vector<double> _9268;
  for (int _5106 = (int)0, _9269 = (int)((_5100)->size(0)); _5106 < _9269 ; ++_5106)
  {
    for (int _5107 = (int)0, _9270 = (int)((_5100)->size(1)); _5107 < _9270 ; ++_5107)
    {
      _9268.push_back(((*_5100)(_5106,_5107)));
    }
  }
  auto _9271 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9268.size()),_9268.begin(),_9268.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5100)->size(0)),(int)((_5100)->size(1)),_9263,_9267,_9271,_5101->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _5108,    monty::rc_ptr< ::mosek::fusion::Expression > _5109) { return mosek::fusion::p_Expr::mulDiag(_5108,_5109); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5108,monty::rc_ptr< ::mosek::fusion::Expression > _5109){
  std::vector<int> _9272;
  for (int _5110 = (int)0, _9273 = (int)((_5108)->size(0)); _5110 < _9273 ; ++_5110)
  {
    for (int _5111 = (int)0, _9274 = (int)((_5108)->size(1)); _5111 < _9274 ; ++_5111)
    {
      _9272.push_back(_5110);
    }
  }
  auto _9275 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9272.size()),_9272.begin(),_9272.end()));
  std::vector<int> _9276;
  for (int _5112 = (int)0, _9277 = (int)((_5108)->size(0)); _5112 < _9277 ; ++_5112)
  {
    for (int _5113 = (int)0, _9278 = (int)((_5108)->size(1)); _5113 < _9278 ; ++_5113)
    {
      _9276.push_back(_5113);
    }
  }
  auto _9279 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9276.size()),_9276.begin(),_9276.end()));
  std::vector<double> _9280;
  for (int _5114 = (int)0, _9281 = (int)((_5108)->size(0)); _5114 < _9281 ; ++_5114)
  {
    for (int _5115 = (int)0, _9282 = (int)((_5108)->size(1)); _5115 < _9282 ; ++_5115)
    {
      _9280.push_back(((*_5108)(_5114,_5115)));
    }
  }
  auto _9283 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9280.size()),_9280.begin(),_9280.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_5108)->size(0)),(int)((_5108)->size(1)),_9275,_9279,_9283,_5109)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5116,monty::rc_ptr< ::mosek::fusion::Expression > _5117){
  std::shared_ptr< monty::ndarray< int,1 > > _5118 = _5117->getShape();
  _checked_ptr_1<int> _ptr__5118(_5118 ? _5118->raw() : nullptr,_5118 ? _5118->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _5119 = _5117;
  if (((int)((_5118)->size(0)) == (int)1))
  {
    {
      _5118 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5118[(int)0]),(int)((int)1)});
      _ptr__5118.update(_5118 ? _5118->raw() : nullptr, _5118 ? _5118->size(0) : 0);
      _5119 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5118,_5117)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5118)->size(0)) != (int)2) || ((_5116->numRows() != _ptr__5118[(int)0]) || (_5116->numColumns() != _ptr__5118[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _5120 = _5116->numColumns();
  long long _5121 = _5116->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5122 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5121)));
  _checked_ptr_1<int> _ptr__5122(_5122 ? _5122->raw() : nullptr,_5122 ? _5122->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5123 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5121)));
  _checked_ptr_1<int> _ptr__5123(_5123 ? _5123->raw() : nullptr,_5123 ? _5123->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5124 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5121)));
  _checked_ptr_1<double> _ptr__5124(_5124 ? _5124->raw() : nullptr,_5124 ? _5124->size(0) : 0);
  _5116->getDataAsTriplets(_5122,_5123,_5124);
  std::vector<long long> _9284;
  for (long long _5125 = (int)0, _9285 = _5121; _5125 < _9285 ; ++_5125)
  {
    _9284.push_back(safe_add( safe_mul( _ptr__5122[_5125],_5120 ),_ptr__5123[_5125] ));
  }
  auto _9286 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9284.size()),_9284.begin(),_9284.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5124,_9286,_5119,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5126,monty::rc_ptr< ::mosek::fusion::Expression > _5127){
  _checked_ptr_1<double> _ptr__5126(_5126 ? _5126->raw() : nullptr, _5126 ? _5126->size(0) : 0);
  if (((NULL == _5126.get()) || (NULL == _5127.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_5127->getND() == (int)0) && ((int)((_5126)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__5126[(int)0],_5127)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_5127->getND() != (int)1) || (_5127->getDim((int)0) != (int)((_5126)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _9287;
      for (int _5128 = (int)0, _9288 = (int)((_5126)->size(0)); _5128 < _9288 ; ++_5128)
      {
        _9287.push_back(_5128);
      }
      auto _9289 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9287.size()),_9287.begin(),_9287.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_5126,_9289,_5127)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5129,monty::rc_ptr< ::mosek::fusion::Expression > _5130){
  if (((NULL == _5129.get()) || (NULL == _5130.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _5131 = _5130->getShape();
  _checked_ptr_1<int> _ptr__5131(_5131 ? _5131->raw() : nullptr,_5131 ? _5131->size(0) : 0);
  if (((int)((_5131)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5129)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _9290 = (int)0;
  int _9291 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_5129)->dims)->size(0));
  for (int _5132 = _9290; _5132 < _9291; ++_5132)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_5129)->dims)(_5132)) != _ptr__5131[_5132]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_5129)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_5129)->inst,_5130)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5133,    double _5134) { return mosek::fusion::p_Expr::mul(_5133,_5134); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5133,double _5134){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5134,_5133)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _5135,    monty::rc_ptr< ::mosek::fusion::Expression > _5136) { return mosek::fusion::p_Expr::mul(_5135,_5136); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _5135,monty::rc_ptr< ::mosek::fusion::Expression > _5136){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_5135,_5136)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5137,    std::shared_ptr< monty::ndarray< double,1 > > _5138) { return mosek::fusion::p_Expr::mul(_5137,_5138); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5137,std::shared_ptr< monty::ndarray< double,1 > > _5138){
  _checked_ptr_1<double> _ptr__5138(_5138 ? _5138->raw() : nullptr, _5138 ? _5138->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_5138,_5137);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _5139,    monty::rc_ptr< ::mosek::fusion::Expression > _5140) { return mosek::fusion::p_Expr::mul(_5139,_5140); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _5139,monty::rc_ptr< ::mosek::fusion::Expression > _5140){
  _checked_ptr_1<double> _ptr__5139(_5139 ? _5139->raw() : nullptr, _5139 ? _5139->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_5139,_5140);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5141,    std::shared_ptr< monty::ndarray< double,2 > > _5142) { return mosek::fusion::p_Expr::mul(_5141,_5142); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5141,std::shared_ptr< monty::ndarray< double,2 > > _5142){
  return ::mosek::fusion::p_Expr::mul(false,_5142,_5141);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _5143,    monty::rc_ptr< ::mosek::fusion::Expression > _5144) { return mosek::fusion::p_Expr::mul(_5143,_5144); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _5143,monty::rc_ptr< ::mosek::fusion::Expression > _5144){
  return ::mosek::fusion::p_Expr::mul(true,_5143,_5144);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _5145,    monty::rc_ptr< ::mosek::fusion::Matrix > _5146) { return mosek::fusion::p_Expr::mul(_5145,_5146); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _5145,monty::rc_ptr< ::mosek::fusion::Matrix > _5146){
  return ::mosek::fusion::p_Expr::mul(false,_5146,_5145);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5147,    monty::rc_ptr< ::mosek::fusion::Expression > _5148) { return mosek::fusion::p_Expr::mul(_5147,_5148); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5147,monty::rc_ptr< ::mosek::fusion::Expression > _5148){
  return ::mosek::fusion::p_Expr::mul(true,_5147,_5148);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5149,std::shared_ptr< monty::ndarray< double,1 > > _5150,monty::rc_ptr< ::mosek::fusion::Expression > _5151){
  _checked_ptr_1<double> _ptr__5150(_5150 ? _5150->raw() : nullptr, _5150 ? _5150->size(0) : 0);
  int _5152 = (int)((_5150)->size(0));
  int _5153 = _5152;
  std::shared_ptr< monty::ndarray< double,1 > > _5154 = ::mosek::fusion::Utils::Tools::arraycopy(_5150);
  _checked_ptr_1<double> _ptr__5154(_5154 ? _5154->raw() : nullptr,_5154 ? _5154->size(0) : 0);
  int _5155 = _5151->getND();
  if ((_5155 == (int)0))
  {
    {
      std::vector<int> _9292;
      for (int _5156 = (int)0, _9293 = _5152; _5156 < _9293 ; ++_5156)
      {
        _9292.push_back(_5156);
      }
      auto _9294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9292.size()),_9292.begin(),_9292.end()));
      std::vector<int> _9295;
      for (int _5157 = (int)0, _9296 = _5152; _5157 < _9296 ; ++_5157)
      {
        _9295.push_back((int)0);
      }
      auto _9297 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9295.size()),_9295.begin(),_9295.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5152)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5152,(int)1,_9294,_9297,_5154,_5151,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5155 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_5149 && (_5151->getDim((int)0) == (int)((_5150)->size(0)))))
  {
    {
      std::vector<int> _9298;
      for (int _5158 = (int)0, _9299 = _5152; _5158 < _9299 ; ++_5158)
      {
        _9298.push_back((int)0);
      }
      auto _9300 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9298.size()),_9298.begin(),_9298.end()));
      std::vector<int> _9301;
      for (int _5159 = (int)0, _9302 = _5152; _5159 < _9302 ; ++_5159)
      {
        _9301.push_back(_5159);
      }
      auto _9303 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9301.size()),_9301.begin(),_9301.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5151->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_5152,_9300,_9303,_5154,_5151)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5149 && (_5151->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _9304;
      for (int _5160 = (int)0, _9305 = _5152; _5160 < _9305 ; ++_5160)
      {
        _9304.push_back(_5160);
      }
      auto _9306 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9304.size()),_9304.begin(),_9304.end()));
      std::vector<int> _9307;
      for (int _5161 = (int)0, _9308 = _5152; _5161 < _9308 ; ++_5161)
      {
        _9307.push_back((int)0);
      }
      auto _9309 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9307.size()),_9307.begin(),_9307.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5152,(int)1,_9306,_9309,_5154,_5151,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5149) && (_5151->getDim((int)1) == _5152)))
  {
    {
      std::vector<int> _9310;
      for (int _5162 = (int)0, _9311 = _5152; _5162 < _9311 ; ++_5162)
      {
        _9310.push_back(_5162);
      }
      auto _9312 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9310.size()),_9310.begin(),_9310.end()));
      std::vector<int> _9313;
      for (int _5163 = (int)0, _9314 = _5152; _5163 < _9314 ; ++_5163)
      {
        _9313.push_back((int)0);
      }
      auto _9315 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9313.size()),_9313.begin(),_9313.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5151->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5152,(int)1,_9312,_9315,_5154,_5151)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_5149) && (_5151->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _9316;
      for (int _5164 = (int)0, _9317 = _5152; _5164 < _9317 ; ++_5164)
      {
        _9316.push_back((int)0);
      }
      auto _9318 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9316.size()),_9316.begin(),_9316.end()));
      std::vector<int> _9319;
      for (int _5165 = (int)0, _9320 = _5152; _5165 < _9320 ; ++_5165)
      {
        _9319.push_back(_5165);
      }
      auto _9321 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9319.size()),_9319.begin(),_9319.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_5152,_9318,_9321,_5154,_5151,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5166,std::shared_ptr< monty::ndarray< double,2 > > _5167,monty::rc_ptr< ::mosek::fusion::Expression > _5168){
  int _5169 = (int)((_5167)->size(0));
  int _5170 = (int)((_5167)->size(1));
  int _5171 = safe_mul( _5169,_5170 );
  std::vector<int> _9322;
  for (int _5173 = (int)0, _9323 = _5169; _5173 < _9323 ; ++_5173)
  {
    for (int _5174 = (int)0, _9324 = _5170; _5174 < _9324 ; ++_5174)
    {
      _9322.push_back(_5173);
    }
  }
  auto _9325 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9322.size()),_9322.begin(),_9322.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5172 = _9325;
  _checked_ptr_1<int> _ptr__5172(_5172 ? _5172->raw() : nullptr,_5172 ? _5172->size(0) : 0);
  std::vector<int> _9326;
  for (int _5176 = (int)0, _9327 = _5169; _5176 < _9327 ; ++_5176)
  {
    for (int _5177 = (int)0, _9328 = _5170; _5177 < _9328 ; ++_5177)
    {
      _9326.push_back(_5177);
    }
  }
  auto _9329 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9326.size()),_9326.begin(),_9326.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5175 = _9329;
  _checked_ptr_1<int> _ptr__5175(_5175 ? _5175->raw() : nullptr,_5175 ? _5175->size(0) : 0);
  std::vector<double> _9330;
  for (int _5179 = (int)0, _9331 = _5169; _5179 < _9331 ; ++_5179)
  {
    for (int _5180 = (int)0, _9332 = _5170; _5180 < _9332 ; ++_5180)
    {
      _9330.push_back(((*_5167)(_5179,_5180)));
    }
  }
  auto _9333 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9330.size()),_9330.begin(),_9330.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5178 = _9333;
  _checked_ptr_1<double> _ptr__5178(_5178 ? _5178->raw() : nullptr,_5178 ? _5178->size(0) : 0);
  long long _5181 = _5168->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _5182 = _5168->getShape();
  _checked_ptr_1<int> _ptr__5182(_5182 ? _5182->raw() : nullptr,_5182 ? _5182->size(0) : 0);
  if (((int)((_5182)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5169,_5170,_5172,_5175,_5178,_5168,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_5166)
  {
    {
      if (((int)((_5182)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5167)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5169,_5170,_5172,_5175,_5178,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5182[(int)0]),(int)((int)1)}),_5168)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5182)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5169,_5170,_5172,_5175,_5178,_5168)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_5182)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_5167)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5169,_5170,_5172,_5175,_5178,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5182[(int)0])}),_5168)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_5182)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5169,_5170,_5172,_5175,_5178,_5168)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5183,monty::rc_ptr< ::mosek::fusion::Matrix > _5184,monty::rc_ptr< ::mosek::fusion::Expression > _5185){
  long long _5186 = _5184->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _5187 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5186)));
  _checked_ptr_1<int> _ptr__5187(_5187 ? _5187->raw() : nullptr,_5187 ? _5187->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5188 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5186)));
  _checked_ptr_1<int> _ptr__5188(_5188 ? _5188->raw() : nullptr,_5188 ? _5188->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5189 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5186)));
  _checked_ptr_1<double> _ptr__5189(_5189 ? _5189->raw() : nullptr,_5189 ? _5189->size(0) : 0);
  int _5190 = _5184->numRows();
  int _5191 = _5184->numColumns();
  _5184->getDataAsTriplets(_5187,_5188,_5189);
  int _5192 = _5185->getND();
  if ((_5192 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_5190,_5191,_5187,_5188,_5189,_5185)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5192 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5193 = _5185->getShape();
      _checked_ptr_1<int> _ptr__5193(_5193 ? _5193->raw() : nullptr,_5193 ? _5193->size(0) : 0);
      if (_5183)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5190)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5190,_5191,_5187,_5188,_5189,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5193[(int)0]),(int)((int)1)}),_5185)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5191)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5190,_5191,_5187,_5188,_5189,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5193[(int)0])}),_5185)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_5192 == (int)2))
  {
    {
      if (_5183)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_5190,_5191,_5187,_5188,_5189,_5185)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_5190,_5191,_5187,_5188,_5189,_5185)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _5194,    monty::rc_ptr< ::mosek::fusion::Matrix > _5195) { return mosek::fusion::p_Expr::mul(_5194,_5195); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _5194,monty::rc_ptr< ::mosek::fusion::Matrix > _5195){
  int _5196 = _5195->numRows();
  int _5197 = _5195->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5198 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5195->numNonzeros())));
  _checked_ptr_1<double> _ptr__5198(_5198 ? _5198->raw() : nullptr,_5198 ? _5198->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5199 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5195->numNonzeros())));
  _checked_ptr_1<int> _ptr__5199(_5199 ? _5199->raw() : nullptr,_5199 ? _5199->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5200 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5195->numNonzeros())));
  _checked_ptr_1<int> _ptr__5200(_5200 ? _5200->raw() : nullptr,_5200 ? _5200->size(0) : 0);
  _5195->getDataAsTriplets(_5200,_5199,_5198);
  return ::mosek::fusion::p_Expr::mul(false,_5196,_5197,_5200,_5199,_5198,_5194);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5201,    monty::rc_ptr< ::mosek::fusion::Variable > _5202) { return mosek::fusion::p_Expr::mul(_5201,_5202); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5201,monty::rc_ptr< ::mosek::fusion::Variable > _5202){
  int _5203 = _5201->numRows();
  int _5204 = _5201->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _5205 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5201->numNonzeros())));
  _checked_ptr_1<double> _ptr__5205(_5205 ? _5205->raw() : nullptr,_5205 ? _5205->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5206 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5201->numNonzeros())));
  _checked_ptr_1<int> _ptr__5206(_5206 ? _5206->raw() : nullptr,_5206 ? _5206->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5207 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5201->numNonzeros())));
  _checked_ptr_1<int> _ptr__5207(_5207 ? _5207->raw() : nullptr,_5207 ? _5207->size(0) : 0);
  _5201->getDataAsTriplets(_5207,_5206,_5205);
  return ::mosek::fusion::p_Expr::mul(true,_5203,_5204,_5207,_5206,_5205,_5202);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _5208,int _5209,int _5210,std::shared_ptr< monty::ndarray< int,1 > > _5211,std::shared_ptr< monty::ndarray< int,1 > > _5212,std::shared_ptr< monty::ndarray< double,1 > > _5213,monty::rc_ptr< ::mosek::fusion::Variable > _5214){
  _checked_ptr_1<int> _ptr__5211(_5211 ? _5211->raw() : nullptr, _5211 ? _5211->size(0) : 0);
  _checked_ptr_1<int> _ptr__5212(_5212 ? _5212->raw() : nullptr, _5212 ? _5212->size(0) : 0);
  _checked_ptr_1<double> _ptr__5213(_5213 ? _5213->raw() : nullptr, _5213 ? _5213->size(0) : 0);
  if ((_5214->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_5209,_5210,_5211,_5212,_5213,_5214)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5214->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5215 = _5214->getShape();
      _checked_ptr_1<int> _ptr__5215(_5215 ? _5215->raw() : nullptr,_5215 ? _5215->size(0) : 0);
      int _9334;
      bool _9335 = _5208;
      if (_9335)
      {
        _9334 = _5209;
      }
      else
      {
        _9334 = _5210;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _9336;
      bool _9337 = _5208;
      if (_9337)
      {
        _9336 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5215[(int)0]),(int)((int)1)});
      }
      else
      {
        _9336 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__5215[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_9334)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5208,_5209,_5210,_5211,_5212,_5213,::mosek::fusion::p_Var::reshape(_5214,_9336))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_5208,_5209,_5210,_5211,_5212,_5213,_5214)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5216,    monty::rc_ptr< ::mosek::fusion::Matrix > _5217) { return mosek::fusion::p_Expr::dot(_5216,_5217); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5216,monty::rc_ptr< ::mosek::fusion::Matrix > _5217){
  long long _5218 = _5217->numNonzeros();
  if ((!_5217->isSparse()))
  {
    {
      std::vector<long long> _9338;
      for (long long _5219 = (int)0, _9339 = _5218; _5219 < _9339 ; ++_5219)
      {
        _9338.push_back(_5219);
      }
      auto _9340 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9338.size()),_9338.begin(),_9338.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5216,_9340,_5217->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5220 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5218)));
      _checked_ptr_1<int> _ptr__5220(_5220 ? _5220->raw() : nullptr,_5220 ? _5220->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5221 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5218)));
      _checked_ptr_1<int> _ptr__5221(_5221 ? _5221->raw() : nullptr,_5221 ? _5221->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5222 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5218)));
      _checked_ptr_1<double> _ptr__5222(_5222 ? _5222->raw() : nullptr,_5222 ? _5222->size(0) : 0);
      int _5223 = _5217->numColumns();
      _5217->getDataAsTriplets(_5220,_5221,_5222);
      std::vector<long long> _9341;
      for (int _5224 = (int)0, _9342 = (int)((_5220)->size(0)); _5224 < _9342 ; ++_5224)
      {
        _9341.push_back(safe_add( safe_mul( _ptr__5220[_5224],_5223 ),_ptr__5221[_5224] ));
      }
      auto _9343 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9341.size()),_9341.begin(),_9341.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5216,_9343,_5222)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5225,    std::shared_ptr< monty::ndarray< double,2 > > _5226) { return mosek::fusion::p_Expr::dot(_5225,_5226); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5225,std::shared_ptr< monty::ndarray< double,2 > > _5226){
  std::vector<long long> _9344;
  for (int _5227 = (int)0, _9345 = safe_mul( (int)((_5226)->size(0)),(int)((_5226)->size(1)) ); _5227 < _9345 ; ++_5227)
  {
    _9344.push_back(_5227);
  }
  auto _9346 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9344.size()),_9344.begin(),_9344.end()));
  std::vector<double> _9347;
  for (int _5228 = (int)0, _9348 = (int)((_5226)->size(0)); _5228 < _9348 ; ++_5228)
  {
    for (int _5229 = (int)0, _9349 = (int)((_5226)->size(1)); _5229 < _9349 ; ++_5229)
    {
      _9347.push_back(((*_5226)(_5228,_5229)));
    }
  }
  auto _9350 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9347.size()),_9347.begin(),_9347.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5225,_9346,_9350)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5230,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5231) { return mosek::fusion::p_Expr::dot(_5230,_5231); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5230,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5231){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5230,mosek::fusion::p_NDSparseArray::_get_impl(_5231)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_5231)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _5232,    std::shared_ptr< monty::ndarray< double,1 > > _5233) { return mosek::fusion::p_Expr::dot(_5232,_5233); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _5232,std::shared_ptr< monty::ndarray< double,1 > > _5233){
  _checked_ptr_1<double> _ptr__5233(_5233 ? _5233->raw() : nullptr, _5233 ? _5233->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5234 = _5232->getShape();
  _checked_ptr_1<int> _ptr__5234(_5234 ? _5234->raw() : nullptr,_5234 ? _5234->size(0) : 0);
  if (((_5232->getSize() == (int)((_5233)->size(0))) && ((int)((_5234)->size(0)) > (int)1)))
  {
    {
      int _5235 = (int)0;
      int _9351 = (int)0;
      int _9352 = (int)((_5234)->size(0));
      for (int _5236 = _9351; _5236 < _9352; ++_5236)
      {
        {
          if ((_ptr__5234[_5236] > (int)1))
          {
            {
              ++ _5235;
            }
          }
          {}
        }
      }
      if ((_5235 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5237 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_5232->getSize())});
          _checked_ptr_1<int> _ptr__5237(_5237 ? _5237->raw() : nullptr,_5237 ? _5237->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5237,_5232)).as<::mosek::fusion::Expression>(),_5233)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_5232,_5233)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5238,    monty::rc_ptr< ::mosek::fusion::Expression > _5239) { return mosek::fusion::p_Expr::dot(_5238,_5239); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5238,monty::rc_ptr< ::mosek::fusion::Expression > _5239){
  return ::mosek::fusion::p_Expr::dot(_5239,_5238);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5240,    monty::rc_ptr< ::mosek::fusion::Expression > _5241) { return mosek::fusion::p_Expr::dot(_5240,_5241); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5240,monty::rc_ptr< ::mosek::fusion::Expression > _5241){
  return ::mosek::fusion::p_Expr::dot(_5241,_5240);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _5242,    monty::rc_ptr< ::mosek::fusion::Expression > _5243) { return mosek::fusion::p_Expr::dot(_5242,_5243); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _5242,monty::rc_ptr< ::mosek::fusion::Expression > _5243){
  return ::mosek::fusion::p_Expr::dot(_5243,_5242);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _5244,    monty::rc_ptr< ::mosek::fusion::Expression > _5245) { return mosek::fusion::p_Expr::dot(_5244,_5245); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _5244,monty::rc_ptr< ::mosek::fusion::Expression > _5245){
  _checked_ptr_1<double> _ptr__5244(_5244 ? _5244->raw() : nullptr, _5244 ? _5244->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_5245,_5244);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5246,    monty::rc_ptr< ::mosek::fusion::Expression > _5247) { return mosek::fusion::p_Expr::outer(_5246,_5247); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5246,monty::rc_ptr< ::mosek::fusion::Expression > _5247){
  _checked_ptr_1<double> _ptr__5246(_5246 ? _5246->raw() : nullptr, _5246 ? _5246->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5248 = _5247->getShape();
  _checked_ptr_1<int> _ptr__5248(_5248 ? _5248->raw() : nullptr,_5248 ? _5248->size(0) : 0);
  if (((int)((_5248)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  if ((_ptr__5248[(int)0] != (int)((_5246)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Argument lengths do not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5249 = _5247->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9353;
  for (int _5250 = (int)0, _9354 = (int)((_5246)->size(0)); _5250 < _9354 ; ++_5250)
  {
    _9353.push_back(_5250);
  }
  auto _9355 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9353.size()),_9353.begin(),_9353.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5249)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5249)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5249)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5249)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5249)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5249)->inst,_5246,_9355,(int)((_5246)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Expression > _5251,    std::shared_ptr< monty::ndarray< double,1 > > _5252) { return mosek::fusion::p_Expr::outer(_5251,_5252); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Expression > _5251,std::shared_ptr< monty::ndarray< double,1 > > _5252){
  _checked_ptr_1<double> _ptr__5252(_5252 ? _5252->raw() : nullptr, _5252 ? _5252->size(0) : 0);
  if (((_5251->getND() != (int)1) || (_5251->getND() != (int)1)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Arguments must be one-dimensional"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::FlatExpr > _5253 = _5251->__mosek_2fusion_2Expression__eval();
  std::vector<int> _9356;
  for (int _5254 = (int)0, _9357 = (int)((_5252)->size(0)); _5254 < _9357 ; ++_5254)
  {
    _9356.push_back(_5254);
  }
  auto _9358 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9356.size()),_9356.begin(),_9356.end()));
  return ::mosek::fusion::p_Expr::outer_(((*mosek::fusion::p_FlatExpr::_get_impl(_5253)->shape)((int)0)),mosek::fusion::p_FlatExpr::_get_impl(_5253)->ptrb,mosek::fusion::p_FlatExpr::_get_impl(_5253)->subj,mosek::fusion::p_FlatExpr::_get_impl(_5253)->cof,mosek::fusion::p_FlatExpr::_get_impl(_5253)->bfix,mosek::fusion::p_FlatExpr::_get_impl(_5253)->inst,_5252,_9358,(int)((_5252)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5255,    monty::rc_ptr< ::mosek::fusion::Variable > _5256) { return mosek::fusion::p_Expr::outer(_5255,_5256); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5255,monty::rc_ptr< ::mosek::fusion::Variable > _5256){
  std::shared_ptr< monty::ndarray< int,1 > > _5257 = _5256->getShape();
  _checked_ptr_1<int> _ptr__5257(_5257 ? _5257->raw() : nullptr,_5257 ? _5257->size(0) : 0);
  if ((!(((int)((_5257)->size(0)) == (int)1) || (((int)((_5257)->size(0)) == (int)2) && (_ptr__5257[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5255)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9359 = _5255;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9359.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5258 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9359.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5256,_ptr__5257[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5258)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5258)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5259 = _9359;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5260 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5259->numNonzeros())));
      _checked_ptr_1<double> _ptr__5260(_5260 ? _5260->raw() : nullptr,_5260 ? _5260->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5261 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5259->numNonzeros())));
      _checked_ptr_1<int> _ptr__5261(_5261 ? _5261->raw() : nullptr,_5261 ? _5261->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5262 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5259->numNonzeros())));
      _checked_ptr_1<int> _ptr__5262(_5262 ? _5262->raw() : nullptr,_5262 ? _5262->size(0) : 0);
      _5259->getDataAsTriplets(_5262,_5261,_5260);
      return ::mosek::fusion::p_Expr::outer_(_5256,_ptr__5257[(int)0],_5260,_5262,mosek::fusion::p_Matrix::_get_impl(_5259)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5263,    monty::rc_ptr< ::mosek::fusion::Matrix > _5264) { return mosek::fusion::p_Expr::outer(_5263,_5264); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5263,monty::rc_ptr< ::mosek::fusion::Matrix > _5264){
  std::shared_ptr< monty::ndarray< int,1 > > _5265 = _5263->getShape();
  _checked_ptr_1<int> _ptr__5265(_5265 ? _5265->raw() : nullptr,_5265 ? _5265->size(0) : 0);
  if ((!((_5263->getND() == (int)1) || ((_5263->getND() == (int)2) && (_ptr__5265[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_5264)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _9360 = _5264;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9360.get()))
  {
    ::mosek::fusion::DenseMatrix::t _5266 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9360.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_5263,_ptr__5265[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_5266)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_5266)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _5267 = _9360;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _5268 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5267->numNonzeros())));
      _checked_ptr_1<double> _ptr__5268(_5268 ? _5268->raw() : nullptr,_5268 ? _5268->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5269 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5267->numNonzeros())));
      _checked_ptr_1<int> _ptr__5269(_5269 ? _5269->raw() : nullptr,_5269 ? _5269->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5270 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5264->numNonzeros())));
      _checked_ptr_1<int> _ptr__5270(_5270 ? _5270->raw() : nullptr,_5270 ? _5270->size(0) : 0);
      _5267->getDataAsTriplets(_5270,_5269,_5268);
      return ::mosek::fusion::p_Expr::outer_(_5263,((*_5263->getShape())((int)0)),_5268,_5270,mosek::fusion::p_Matrix::_get_impl(_5267)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _5271,    monty::rc_ptr< ::mosek::fusion::Variable > _5272) { return mosek::fusion::p_Expr::outer(_5271,_5272); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _5271,monty::rc_ptr< ::mosek::fusion::Variable > _5272){
  _checked_ptr_1<double> _ptr__5271(_5271 ? _5271->raw() : nullptr, _5271 ? _5271->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5273 = _5272->getShape();
  _checked_ptr_1<int> _ptr__5273(_5273 ? _5273->raw() : nullptr,_5273 ? _5273->size(0) : 0);
  if ((!((_5272->getND() == (int)1) || ((_5272->getND() == (int)2) && (_ptr__5273[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5272,_ptr__5273[(int)0],_5271,nullptr,(int)((_5271)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _5274,    std::shared_ptr< monty::ndarray< double,1 > > _5275) { return mosek::fusion::p_Expr::outer(_5274,_5275); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _5274,std::shared_ptr< monty::ndarray< double,1 > > _5275){
  _checked_ptr_1<double> _ptr__5275(_5275 ? _5275->raw() : nullptr, _5275 ? _5275->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5276 = _5274->getShape();
  _checked_ptr_1<int> _ptr__5276(_5276 ? _5276->raw() : nullptr,_5276 ? _5276->size(0) : 0);
  if ((!((_5274->getND() == (int)1) || ((_5274->getND() == (int)2) && (_ptr__5276[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_5274,_ptr__5276[(int)0],_5275,nullptr,(int)((_5275)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _5277,std::shared_ptr< monty::ndarray< long long,1 > > _5278,std::shared_ptr< monty::ndarray< long long,1 > > _5279,std::shared_ptr< monty::ndarray< double,1 > > _5280,std::shared_ptr< monty::ndarray< double,1 > > _5281,std::shared_ptr< monty::ndarray< long long,1 > > _5282,std::shared_ptr< monty::ndarray< double,1 > > _5283,std::shared_ptr< monty::ndarray< int,1 > > _5284,int _5285,bool _5286){
  _checked_ptr_1<long long> _ptr__5278(_5278 ? _5278->raw() : nullptr, _5278 ? _5278->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5279(_5279 ? _5279->raw() : nullptr, _5279 ? _5279->size(0) : 0);
  _checked_ptr_1<double> _ptr__5280(_5280 ? _5280->raw() : nullptr, _5280 ? _5280->size(0) : 0);
  _checked_ptr_1<double> _ptr__5281(_5281 ? _5281->raw() : nullptr, _5281 ? _5281->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5282(_5282 ? _5282->raw() : nullptr, _5282 ? _5282->size(0) : 0);
  _checked_ptr_1<double> _ptr__5283(_5283 ? _5283->raw() : nullptr, _5283 ? _5283->size(0) : 0);
  _checked_ptr_1<int> _ptr__5284(_5284 ? _5284->raw() : nullptr, _5284 ? _5284->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9361;
  bool _9362 = (!_5286);
  if (_9362)
  {
    _9361 = ::mosek::fusion::p_Set::make(_5277,_5285);
  }
  else
  {
    _9361 = ::mosek::fusion::p_Set::make(_5285,_5277);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5287 = _9361;
  _checked_ptr_1<int> _ptr__5287(_5287 ? _5287->raw() : nullptr,_5287 ? _5287->size(0) : 0);
  int _5288 = safe_mul( (int)((_5283)->size(0)),(int)((_5282)->size(0)) );
  int _5289 = safe_mul( (int)((_5283)->size(0)),(int)((_5279)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _5290 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5288)));
  _checked_ptr_1<long long> _ptr__5290(_5290 ? _5290->raw() : nullptr,_5290 ? _5290->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9363;
  bool _9364 = (NULL != _5281.get());
  if (_9364)
  {
    _9363 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5288)));
  }
  else
  {
    _9363 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5291 = _9363;
  _checked_ptr_1<double> _ptr__5291(_5291 ? _5291->raw() : nullptr,_5291 ? _5291->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5292 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5289)));
  _checked_ptr_1<double> _ptr__5292(_5292 ? _5292->raw() : nullptr,_5292 ? _5292->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5293 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5289)));
  _checked_ptr_1<long long> _ptr__5293(_5293 ? _5293->raw() : nullptr,_5293 ? _5293->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5294 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5288,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5294(_5294 ? _5294->raw() : nullptr,_5294 ? _5294->size(0) : 0);
  int _5295 = (int)_ptr__5294[((int)((_5294)->size(0)) - (int)1)];
  if ((!_5286))
  {
    {
      long long _5296 = (long long)0;
      long long _5297 = (long long)0;
      int _9365 = (int)0;
      int _9366 = (int)((_5282)->size(0));
      for (int _5298 = _9365; _5298 < _9366; ++_5298)
      {
        {
          long long _5299 = (_ptr__5278[safe_add( _5298,(int)1 )] - _ptr__5278[_5298]);
          int _9367 = (int)0;
          int _9368 = (int)((_5283)->size(0));
          for (int _5300 = _9367; _5300 < _9368; ++_5300)
          {
            {
              _ptr__5282[_5296] = safe_add( safe_mul( _ptr__5282[_5298],_5285 ),_ptr__5284[_5300] );
              _ptr__5294[safe_add( _5296,(int)1 )] = safe_add( _ptr__5294[_5296],_5299 );
              ++ _5296;
              long long _9369 = _ptr__5278[_5298];
              long long _9370 = _ptr__5278[safe_add( _5298,(int)1 )];
              for (long long _5301 = _9369; _5301 < _9370; ++_5301)
              {
                {
                  _ptr__5293[_5297] = _ptr__5279[_5301];
                  _ptr__5292[_5297] = (_ptr__5280[_5301] * _ptr__5283[_5300]);
                  ++ _5297;
                }
              }
            }
          }
        }
      }
      if ((NULL != _5291.get()))
      {
        {
          int _5302 = (int)0;
          int _9371 = (int)0;
          int _9372 = (int)((_5282)->size(0));
          for (int _5303 = _9371; _5303 < _9372; ++_5303)
          {
            {
              int _9373 = (int)0;
              int _9374 = (int)((_5283)->size(0));
              for (int _5304 = _9373; _5304 < _9374; ++_5304)
              {
                {
                  _ptr__5291[_5302] = (_ptr__5283[_5304] * _ptr__5281[_5303]);
                  ++ _5302;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _5305 = (long long)0;
      long long _5306 = (long long)0;
      int _9375 = (int)0;
      int _9376 = (int)((_5283)->size(0));
      for (int _5307 = _9375; _5307 < _9376; ++_5307)
      {
        {
          double _5308 = _ptr__5283[_5307];
          ::mosek::fusion::Utils::Tools::arraycopy(_5279,(long long)((int)0),_5293,_5306,(long long)(_5295));
          int _9377 = (int)0;
          int _9378 = _5295;
          for (int _5309 = _9377; _5309 < _9378; ++_5309)
          {
            {
              _ptr__5292[safe_add( _5306,_5309 )] = (_ptr__5280[_5309] * _ptr__5283[_5307]);
            }
          }
          int _9379 = (int)0;
          int _9380 = (int)((_5282)->size(0));
          for (int _5310 = _9379; _5310 < _9380; ++_5310)
          {
            {
              long long _5311 = (_ptr__5278[safe_add( _5310,(int)1 )] - _ptr__5278[_5310]);
              _ptr__5282[_5305] = safe_add( safe_mul( _ptr__5282[_5310],_5285 ),_ptr__5284[_5307] );
              _ptr__5294[safe_add( _5305,(int)1 )] = safe_add( _ptr__5294[_5305],_5311 );
              ++ _5305;
            }
          }
          _5306 += _5295;
        }
      }
      if ((NULL != _5291.get()))
      {
        {
          int _5312 = (int)0;
          int _9381 = (int)0;
          int _9382 = (int)((_5283)->size(0));
          for (int _5313 = _9381; _5313 < _9382; ++_5313)
          {
            {
              double _5314 = _ptr__5283[_5313];
              int _9383 = (int)0;
              int _9384 = (int)((_5282)->size(0));
              for (int _5315 = _9383; _5315 < _9384; ++_5315)
              {
                {
                  _ptr__5291[_5312] = (_ptr__5281[_5315] * _5314);
                  ++ _5312;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5294,_5293,_5292,_5291,_5287,_5290)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5316,int _5317,std::shared_ptr< monty::ndarray< double,1 > > _5318,std::shared_ptr< monty::ndarray< int,1 > > _5319,int _5320,bool _5321){
  _checked_ptr_1<double> _ptr__5318(_5318 ? _5318->raw() : nullptr, _5318 ? _5318->size(0) : 0);
  _checked_ptr_1<int> _ptr__5319(_5319 ? _5319->raw() : nullptr, _5319 ? _5319->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9385;
  bool _9386 = (!_5321);
  if (_9386)
  {
    _9385 = ::mosek::fusion::p_Set::make(_5317,_5320);
  }
  else
  {
    _9385 = ::mosek::fusion::p_Set::make(_5320,_5317);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5322 = _9385;
  _checked_ptr_1<int> _ptr__5322(_5322 ? _5322->raw() : nullptr,_5322 ? _5322->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _9387;
  bool _9388 = (_5320 == (int)((_5318)->size(0)));
  if (_9388)
  {
    _9387 = nullptr;
  }
  else
  {
    _9387 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5318)->size(0)),_5317 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5323 = _9387;
  _checked_ptr_1<long long> _ptr__5323(_5323 ? _5323->raw() : nullptr,_5323 ? _5323->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5324 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5318)->size(0)),_5317 ))));
  _checked_ptr_1<double> _ptr__5324(_5324 ? _5324->raw() : nullptr,_5324 ? _5324->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5325 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_5318)->size(0)),_5317 ))));
  _checked_ptr_1<double> _ptr__5325(_5325 ? _5325->raw() : nullptr,_5325 ? _5325->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5326 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_5318)->size(0)),_5317 ))));
  _checked_ptr_1<long long> _ptr__5326(_5326 ? _5326->raw() : nullptr,_5326 ? _5326->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5327 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_5318)->size(0)),_5317 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__5327(_5327 ? _5327->raw() : nullptr,_5327 ? _5327->size(0) : 0);
  if ((_5320 == (int)((_5318)->size(0))))
  {
    {
      long long _5328 = (long long)0;
      if ((!_5321))
      {
        {
          int _9389 = (int)0;
          int _9390 = _5317;
          for (int _5329 = _9389; _5329 < _9390; ++_5329)
          {
            {
              int _9391 = (int)0;
              int _9392 = _5320;
              for (int _5330 = _9391; _5330 < _9392; ++_5330)
              {
                {
                  _ptr__5327[safe_add( _5328,(int)1 )] = safe_add( _5328,(int)1 );
                  _ptr__5326[_5328] = (long long)_5329;
                  _ptr__5325[_5328] = _ptr__5318[_5330];
                  ++ _5328;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9393 = (int)0;
          int _9394 = _5320;
          for (int _5331 = _9393; _5331 < _9394; ++_5331)
          {
            {
              int _9395 = (int)0;
              int _9396 = _5317;
              for (int _5332 = _9395; _5332 < _9396; ++_5332)
              {
                {
                  _ptr__5327[safe_add( _5328,(int)1 )] = safe_add( _5328,(int)1 );
                  _ptr__5326[_5328] = (long long)_5332;
                  _ptr__5325[_5328] = _ptr__5318[_5331];
                  ++ _5328;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _5333 = (long long)0;
      if ((!_5321))
      {
        {
          int _9397 = (int)0;
          int _9398 = _5317;
          for (int _5334 = _9397; _5334 < _9398; ++_5334)
          {
            {
              int _9399 = (int)0;
              int _9400 = (int)((_5318)->size(0));
              for (int _5335 = _9399; _5335 < _9400; ++_5335)
              {
                {
                  _ptr__5327[safe_add( _5333,(int)1 )] = safe_add( _5333,(int)1 );
                  _ptr__5326[_5333] = (long long)_5334;
                  _ptr__5325[_5333] = _ptr__5318[_5335];
                  _ptr__5323[_5333] = safe_add( safe_mul( _5334,_5320 ),_ptr__5319[_5335] );
                  ++ _5333;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _9401 = (int)0;
          int _9402 = (int)((_5318)->size(0));
          for (int _5336 = _9401; _5336 < _9402; ++_5336)
          {
            {
              int _9403 = (int)0;
              int _9404 = _5317;
              for (int _5337 = _9403; _5337 < _9404; ++_5337)
              {
                {
                  _ptr__5327[safe_add( _5333,(int)1 )] = safe_add( _5333,(int)1 );
                  _ptr__5326[_5333] = (long long)_5337;
                  _ptr__5325[_5333] = _ptr__5318[_5336];
                  _ptr__5323[_5333] = safe_add( safe_mul( _ptr__5319[_5336],_5317 ),_5337 );
                  ++ _5333;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_5327,_5326,_5325,_5324,_5322,_5323)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5338) { return mosek::fusion::p_Expr::stack(_5338); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5338){
  if ((NULL == _5338.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9405 = (int)0;
  int _9406 = (int)((_5338)->size(0));
  for (int _5339 = _9405; _5339 < _9406; ++_5339)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5340 = ((*_5338)(_5339));
      if ((NULL == _5340.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _9407 = (int)0;
      int _9408 = (int)((_5340)->size(0));
      for (int _5341 = _9407; _5341 < _9408; ++_5341)
      {
        {
          if ((NULL == ((*_5340)(_5341)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9409;
  for (int _5343 = (int)0, _9410 = (int)((_5338)->size(0)); _5343 < _9410 ; ++_5343)
  {
    _9409.push_back(::mosek::fusion::p_Expr::stack_(((*_5338)(_5343)),(int)1));
  }
  auto _9411 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9409.size()),_9409.begin(),_9409.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5342 = _9411;
  return ::mosek::fusion::p_Expr::stack_(_5342,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5344,    double _5345,    double _5346) { return mosek::fusion::p_Expr::vstack(_5344,_5345,_5346); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5344,double _5345,double _5346){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5344).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5345).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5346).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5347,    double _5348,    monty::rc_ptr< ::mosek::fusion::Expression > _5349) { return mosek::fusion::p_Expr::vstack(_5347,_5348,_5349); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5347,double _5348,monty::rc_ptr< ::mosek::fusion::Expression > _5349){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5347).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5348).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5349.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5350,    monty::rc_ptr< ::mosek::fusion::Expression > _5351,    double _5352) { return mosek::fusion::p_Expr::vstack(_5350,_5351,_5352); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5350,monty::rc_ptr< ::mosek::fusion::Expression > _5351,double _5352){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5350).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5351.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5352).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5353,    monty::rc_ptr< ::mosek::fusion::Expression > _5354,    monty::rc_ptr< ::mosek::fusion::Expression > _5355) { return mosek::fusion::p_Expr::vstack(_5353,_5354,_5355); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5353,monty::rc_ptr< ::mosek::fusion::Expression > _5354,monty::rc_ptr< ::mosek::fusion::Expression > _5355){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5353).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5354.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5355.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5356,    double _5357,    double _5358) { return mosek::fusion::p_Expr::vstack(_5356,_5357,_5358); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5356,double _5357,double _5358){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5356.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5357).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5358).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5359,    double _5360,    monty::rc_ptr< ::mosek::fusion::Expression > _5361) { return mosek::fusion::p_Expr::vstack(_5359,_5360,_5361); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5359,double _5360,monty::rc_ptr< ::mosek::fusion::Expression > _5361){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5359.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5360).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5361.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5362,    monty::rc_ptr< ::mosek::fusion::Expression > _5363,    double _5364) { return mosek::fusion::p_Expr::vstack(_5362,_5363,_5364); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5362,monty::rc_ptr< ::mosek::fusion::Expression > _5363,double _5364){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5362.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5363.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5364).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5365,    monty::rc_ptr< ::mosek::fusion::Expression > _5366,    monty::rc_ptr< ::mosek::fusion::Expression > _5367) { return mosek::fusion::p_Expr::vstack(_5365,_5366,_5367); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5365,monty::rc_ptr< ::mosek::fusion::Expression > _5366,monty::rc_ptr< ::mosek::fusion::Expression > _5367){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5365.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5366.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5367.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _5368,    monty::rc_ptr< ::mosek::fusion::Expression > _5369) { return mosek::fusion::p_Expr::vstack(_5368,_5369); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _5368,monty::rc_ptr< ::mosek::fusion::Expression > _5369){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5368).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5369.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5370,    double _5371) { return mosek::fusion::p_Expr::vstack(_5370,_5371); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5370,double _5371){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5370.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5371).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5372,    monty::rc_ptr< ::mosek::fusion::Expression > _5373) { return mosek::fusion::p_Expr::vstack(_5372,_5373); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5372.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5373.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5374) { return mosek::fusion::p_Expr::vstack(_5374); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5374){
  if ((NULL == _5374.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9412 = (int)0;
  int _9413 = (int)((_5374)->size(0));
  for (int _5375 = _9412; _5375 < _9413; ++_5375)
  {
    {
      if ((NULL == ((*_5374)(_5375)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5374,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5376,    monty::rc_ptr< ::mosek::fusion::Expression > _5377,    monty::rc_ptr< ::mosek::fusion::Expression > _5378) { return mosek::fusion::p_Expr::hstack(_5376,_5377,_5378); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377,monty::rc_ptr< ::mosek::fusion::Expression > _5378){
  if (((NULL == _5376.get()) || ((NULL == _5377.get()) || (NULL == _5378.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5376.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5377.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5378.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5379,    monty::rc_ptr< ::mosek::fusion::Expression > _5380,    double _5381) { return mosek::fusion::p_Expr::hstack(_5379,_5380,_5381); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5379,monty::rc_ptr< ::mosek::fusion::Expression > _5380,double _5381){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5379.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5380.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5381).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5382,    double _5383,    monty::rc_ptr< ::mosek::fusion::Expression > _5384) { return mosek::fusion::p_Expr::hstack(_5382,_5383,_5384); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5382,double _5383,monty::rc_ptr< ::mosek::fusion::Expression > _5384){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5382.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5383).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5384.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5385,    double _5386,    double _5387) { return mosek::fusion::p_Expr::hstack(_5385,_5386,_5387); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5385,double _5386,double _5387){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5385.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5386).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5387).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5388,    monty::rc_ptr< ::mosek::fusion::Expression > _5389,    monty::rc_ptr< ::mosek::fusion::Expression > _5390) { return mosek::fusion::p_Expr::hstack(_5388,_5389,_5390); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5388,monty::rc_ptr< ::mosek::fusion::Expression > _5389,monty::rc_ptr< ::mosek::fusion::Expression > _5390){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5388).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5389.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5390.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5391,    monty::rc_ptr< ::mosek::fusion::Expression > _5392,    double _5393) { return mosek::fusion::p_Expr::hstack(_5391,_5392,_5393); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5391,monty::rc_ptr< ::mosek::fusion::Expression > _5392,double _5393){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5391).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5392.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5393).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5394,    double _5395,    monty::rc_ptr< ::mosek::fusion::Expression > _5396) { return mosek::fusion::p_Expr::hstack(_5394,_5395,_5396); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5394,double _5395,monty::rc_ptr< ::mosek::fusion::Expression > _5396){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5394).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5395).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5396.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _5397,    monty::rc_ptr< ::mosek::fusion::Expression > _5398) { return mosek::fusion::p_Expr::hstack(_5397,_5398); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _5397,monty::rc_ptr< ::mosek::fusion::Expression > _5398){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5397).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5398.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5399,    double _5400) { return mosek::fusion::p_Expr::hstack(_5399,_5400); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5399,double _5400){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5399.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5400).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _5401,    monty::rc_ptr< ::mosek::fusion::Expression > _5402) { return mosek::fusion::p_Expr::hstack(_5401,_5402); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5401,monty::rc_ptr< ::mosek::fusion::Expression > _5402){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5401.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5402.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5403) { return mosek::fusion::p_Expr::hstack(_5403); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5403){
  if ((NULL == _5403.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _9414 = (int)0;
  int _9415 = (int)((_5403)->size(0));
  for (int _5404 = _9414; _5404 < _9415; ++_5404)
  {
    {
      if ((NULL == ((*_5403)(_5404)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_5403,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5405,    monty::rc_ptr< ::mosek::fusion::Expression > _5406,    monty::rc_ptr< ::mosek::fusion::Expression > _5407,    monty::rc_ptr< ::mosek::fusion::Expression > _5408) { return mosek::fusion::p_Expr::stack(_5405,_5406,_5407,_5408); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5405,monty::rc_ptr< ::mosek::fusion::Expression > _5406,monty::rc_ptr< ::mosek::fusion::Expression > _5407,monty::rc_ptr< ::mosek::fusion::Expression > _5408){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5406.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5407.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5408.get())}),_5405);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5409,    monty::rc_ptr< ::mosek::fusion::Expression > _5410,    monty::rc_ptr< ::mosek::fusion::Expression > _5411,    double _5412) { return mosek::fusion::p_Expr::stack(_5409,_5410,_5411,_5412); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5409,monty::rc_ptr< ::mosek::fusion::Expression > _5410,monty::rc_ptr< ::mosek::fusion::Expression > _5411,double _5412){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5410.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5411.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5412).get())}),_5409);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5413,    monty::rc_ptr< ::mosek::fusion::Expression > _5414,    double _5415,    monty::rc_ptr< ::mosek::fusion::Expression > _5416) { return mosek::fusion::p_Expr::stack(_5413,_5414,_5415,_5416); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5413,monty::rc_ptr< ::mosek::fusion::Expression > _5414,double _5415,monty::rc_ptr< ::mosek::fusion::Expression > _5416){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5414.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5415).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5416.get())}),_5413);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5417,    monty::rc_ptr< ::mosek::fusion::Expression > _5418,    double _5419,    double _5420) { return mosek::fusion::p_Expr::stack(_5417,_5418,_5419,_5420); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5417,monty::rc_ptr< ::mosek::fusion::Expression > _5418,double _5419,double _5420){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5418.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5419).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5420).get())}),_5417);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5421,    double _5422,    monty::rc_ptr< ::mosek::fusion::Expression > _5423,    monty::rc_ptr< ::mosek::fusion::Expression > _5424) { return mosek::fusion::p_Expr::stack(_5421,_5422,_5423,_5424); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5421,double _5422,monty::rc_ptr< ::mosek::fusion::Expression > _5423,monty::rc_ptr< ::mosek::fusion::Expression > _5424){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5422).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5423.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5424.get())}),_5421);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5425,    double _5426,    monty::rc_ptr< ::mosek::fusion::Expression > _5427,    double _5428) { return mosek::fusion::p_Expr::stack(_5425,_5426,_5427,_5428); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5425,double _5426,monty::rc_ptr< ::mosek::fusion::Expression > _5427,double _5428){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5426).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5427.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5428).get())}),_5425);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5429,    double _5430,    double _5431,    monty::rc_ptr< ::mosek::fusion::Expression > _5432) { return mosek::fusion::p_Expr::stack(_5429,_5430,_5431,_5432); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5429,double _5430,double _5431,monty::rc_ptr< ::mosek::fusion::Expression > _5432){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5430).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5431).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5432.get())}),_5429);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5433,    double _5434,    monty::rc_ptr< ::mosek::fusion::Expression > _5435) { return mosek::fusion::p_Expr::stack(_5433,_5434,_5435); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5433,double _5434,monty::rc_ptr< ::mosek::fusion::Expression > _5435){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5434).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5435.get())}),_5433);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5436,    monty::rc_ptr< ::mosek::fusion::Expression > _5437,    double _5438) { return mosek::fusion::p_Expr::stack(_5436,_5437,_5438); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5436,monty::rc_ptr< ::mosek::fusion::Expression > _5437,double _5438){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5437.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_5438).get())}),_5436);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5439,    monty::rc_ptr< ::mosek::fusion::Expression > _5440,    monty::rc_ptr< ::mosek::fusion::Expression > _5441) { return mosek::fusion::p_Expr::stack(_5439,_5440,_5441); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5439,monty::rc_ptr< ::mosek::fusion::Expression > _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_5440.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_5441.get())}),_5439);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _5442,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5443) { return mosek::fusion::p_Expr::stack(_5442,_5443); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _5442,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5443){
  return ::mosek::fusion::p_Expr::stack_(_5443,_5442);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5444,int _5445){
  if (((int)((_5444)->size(0)) == (int)1))
  {
    {
      return ((*_5444)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_5444,_5445),_5445)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5446,int _5447){
  int _5448 = (int)((_5446)->size(0));
  std::vector<int> _9416;
  for (int _5450 = (int)0, _9417 = _5448; _5450 < _9417 ; ++_5450)
  {
    _9416.push_back(((*_5446)(_5450))->getND());
  }
  auto _9418 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9416.size()),_9416.begin(),_9416.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5449 = _9418;
  _checked_ptr_1<int> _ptr__5449(_5449 ? _5449->raw() : nullptr,_5449 ? _5449->size(0) : 0);
  int _5451 = _ptr__5449[(int)0];
  int _5452 = _ptr__5449[(int)0];
  int _9419 = (int)1;
  int _9420 = _5448;
  for (int _5453 = _9419; _5453 < _9420; ++_5453)
  {
    {
      if ((_ptr__5449[_5453] < _5452))
      {
        {
          _5452 = _ptr__5449[_5453];
        }
      }
      {}
      if ((_ptr__5449[_5453] > _5451))
      {
        {
          _5451 = _ptr__5449[_5453];
        }
      }
      {}
    }
  }
  if ((_5451 < _5447))
  {
    {
      _5451 = _5447;
    }
  }
  {}
  if ((_5452 < _5451))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5454 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_5448)));
      std::shared_ptr< monty::ndarray< int,1 > > _5455 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5451)));
      _checked_ptr_1<int> _ptr__5455(_5455 ? _5455->raw() : nullptr,_5455 ? _5455->size(0) : 0);
      int _9421 = (int)0;
      int _9422 = _5448;
      for (int _5456 = _9421; _5456 < _9422; ++_5456)
      {
        {
          if ((((*_5446)(_5456))->getND() == _5451))
          {
            {
              ((*_5454)(_5456)) = ((*_5446)(_5456));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _5457 = ((*_5446)(_5456))->getShape();
              _checked_ptr_1<int> _ptr__5457(_5457 ? _5457->raw() : nullptr,_5457 ? _5457->size(0) : 0);
              int _9423 = (int)0;
              int _9424 = (int)((_5457)->size(0));
              for (int _5458 = _9423; _5458 < _9424; ++_5458)
              {
                {
                  _ptr__5455[_5458] = _ptr__5457[_5458];
                }
              }
              int _9425 = (int)((_5457)->size(0));
              int _9426 = _5451;
              for (int _5459 = _9425; _5459 < _9426; ++_5459)
              {
                {
                  _ptr__5455[_5459] = (int)1;
                }
              }
              ((*_5454)(_5456)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5455,((*_5446)(_5456)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _5454;
    }
  }
  else
  {
    {
      return _5446;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _5460,    int _5461,    int _5462) { return mosek::fusion::p_Expr::repeat(_5460,_5461,_5462); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5460,int _5461,int _5462){
  if ((_5461 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _9427;
  for (int _5463 = (int)0, _9428 = _5461; _5463 < _9428 ; ++_5463)
  {
    _9427.push_back(_5460);
  }
  auto _9429 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_9427.size()),_9427.begin(),_9427.end()));
  return ::mosek::fusion::p_Expr::stack_(_9429,_5462);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5464) { return mosek::fusion::p_Expr::add(_5464); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5464){
  std::vector<double> _9430;
  for (int _5465 = (int)0, _9431 = (int)((_5464)->size(0)); _5465 < _9431 ; ++_5465)
  {
    _9430.push_back(1.0);
  }
  auto _9432 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9430.size()),_9430.begin(),_9430.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_5464,_9432)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5466) { return mosek::fusion::p_Expr::add(_5466); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5466){
  if ((NULL == _5466.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_5466)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_5466)->size(0)) > (int)0) && (NULL == ((*_5466)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _5467 = ((*_5466)((int)0))->getND();
  int _9433 = (int)1;
  int _9434 = (int)((_5466)->size(0));
  for (int _5468 = _9433; _5468 < _9434; ++_5468)
  {
    {
      if ((_5467 < ((*_5466)(_5468))->getND()))
      {
        {
          _5467 = ((*_5466)(_5468))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _5469 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_5466)->size(0)),_5467)));
  int _9435 = (int)0;
  int _9436 = (int)((_5466)->size(0));
  for (int _5470 = _9435; _5470 < _9436; ++_5470)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5471 = ((*_5466)(_5470))->getShape();
      _checked_ptr_1<int> _ptr__5471(_5471 ? _5471->raw() : nullptr,_5471 ? _5471->size(0) : 0);
      int _9437 = (int)0;
      int _9438 = (int)((_5471)->size(0));
      for (int _5472 = _9437; _5472 < _9438; ++_5472)
      {
        {
          ((*_5469)(_5470,_5472)) = _ptr__5471[_5472];
        }
      }
      int _9439 = (int)((_5471)->size(0));
      int _9440 = _5467;
      for (int _5473 = _9439; _5473 < _9440; ++_5473)
      {
        {
          ((*_5469)(_5470,_5473)) = (int)1;
        }
      }
    }
  }
  int _9441 = (int)1;
  int _9442 = (int)((_5466)->size(0));
  for (int _5474 = _9441; _5474 < _9442; ++_5474)
  {
    {
      int _9443 = (int)0;
      int _9444 = _5467;
      for (int _5475 = _9443; _5475 < _9444; ++_5475)
      {
        {
          if ((((*_5469)((int)0,_5475)) != ((*_5469)(_5474,_5475))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _9445;
  for (int _5477 = (int)0, _9446 = _5467; _5477 < _9446 ; ++_5477)
  {
    _9445.push_back(((*_5469)((int)0,_5477)));
  }
  auto _9447 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9445.size()),_9445.begin(),_9445.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5476 = _9447;
  _checked_ptr_1<int> _ptr__5476(_5476 ? _5476->raw() : nullptr,_5476 ? _5476->size(0) : 0);
  int _5478 = (int)1;
  int _9448 = (int)0;
  int _9449 = _5467;
  for (int _5479 = _9448; _5479 < _9449; ++_5479)
  {
    {
      _5478 *= _ptr__5476[_5479];
    }
  }
  int _5480 = (int)0;
  int _5481 = (int)0;
  int _9450 = (int)0;
  int _9451 = (int)((_5466)->size(0));
  for (int _5482 = _9450; _5482 < _9451; ++_5482)
  {
    {
      int _5483 = ((*_5466)(_5482))->numInst();
      _5480 += _5483;
      int _9452;
      bool _9453 = (_5481 > _5483);
      if (_9453)
      {
        _9452 = _5481;
      }
      else
      {
        _9452 = _5483;
      }
      _5481 = _9452;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5484 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _5478,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5484(_5484 ? _5484->raw() : nullptr,_5484 ? _5484->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5485 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5480)));
  _checked_ptr_1<long long> _ptr__5485(_5485 ? _5485->raw() : nullptr,_5485 ? _5485->size(0) : 0);
  std::vector<double> _9454;
  for (int _5487 = (int)0, _9455 = _5480; _5487 < _9455 ; ++_5487)
  {
    _9454.push_back(1.0);
  }
  auto _9456 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9454.size()),_9454.begin(),_9454.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5486 = _9456;
  _checked_ptr_1<double> _ptr__5486(_5486 ? _5486->raw() : nullptr,_5486 ? _5486->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _5488 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5481)));
    _checked_ptr_1<long long> _ptr__5488(_5488 ? _5488->raw() : nullptr,_5488 ? _5488->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5489 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5481)));
    _checked_ptr_1<long long> _ptr__5489(_5489 ? _5489->raw() : nullptr,_5489 ? _5489->size(0) : 0);
    int _9457 = (int)0;
    int _9458 = (int)((_5466)->size(0));
    for (int _5490 = _9457; _5490 < _9458; ++_5490)
    {
      {
        int _5491 = ((*_5466)(_5490))->inst((int)0,_5488,(int)0,_5489);
        int _9459 = (int)0;
        int _9460 = _5491;
        for (int _5492 = _9459; _5492 < _9460; ++_5492)
        {
          {
            _ptr__5484[safe_add( _ptr__5488[_5492],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _9461 = (int)0;
    int _9462 = _5478;
    for (int _5493 = _9461; _5493 < _9462; ++_5493)
    {
      {
        _ptr__5484[safe_add( _5493,(int)1 )] += _ptr__5484[_5493];
      }
    }
    int _9463 = (int)0;
    int _9464 = (int)((_5466)->size(0));
    for (int _5494 = _9463; _5494 < _9464; ++_5494)
    {
      {
        int _5495 = ((*_5466)(_5494))->inst((int)0,_5488,(int)0,_5489);
        int _9465 = (int)0;
        int _9466 = _5495;
        for (int _5496 = _9465; _5496 < _9466; ++_5496)
        {
          {
            _ptr__5485[_ptr__5484[_ptr__5488[_5496]]] = _ptr__5489[_5496];
            ++ _ptr__5484[_ptr__5488[_5496]];
          }
        }
      }
    }
    int _9467 = (int)0;
    int _9468 = _5478;
    for (int _5497 = _9467; _5497 < _9468; ++_5497)
    {
      {
        _ptr__5484[(_5478 - _5497)] = _ptr__5484[((_5478 - _5497) - (int)1)];
      }
    }
    _ptr__5484[(int)0] = (int)0;
  }
  std::vector<double> _9469;
  for (int _5498 = (int)0, _9470 = _5478; _5498 < _9470 ; ++_5498)
  {
    _9469.push_back(0.0);
  }
  auto _9471 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9469.size()),_9469.begin(),_9469.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_5484,_5485,_5486,_9471,_5476,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _5499,double _5500,monty::rc_ptr< ::mosek::fusion::Expression > _5501,double _5502){
  int _5503 = _5499->getND();
  int _5504 = _5501->getND();
  if ((_5503 == _5504))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5499,_5501,_5500,_5502)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _9472;
      bool _9473 = (_5503 > _5504);
      if (_9473)
      {
        _9472 = _5503;
      }
      else
      {
        _9472 = _5504;
      }
      int _5505 = _9472;
      std::shared_ptr< monty::ndarray< int,1 > > _5506 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5505)));
      _checked_ptr_1<int> _ptr__5506(_5506 ? _5506->raw() : nullptr,_5506 ? _5506->size(0) : 0);
      if ((_5503 < _5504))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5507 = _5499->getShape();
          _checked_ptr_1<int> _ptr__5507(_5507 ? _5507->raw() : nullptr,_5507 ? _5507->size(0) : 0);
          int _9474 = (int)0;
          int _9475 = _5503;
          for (int _5508 = _9474; _5508 < _9475; ++_5508)
          {
            {
              _ptr__5506[_5508] = _ptr__5507[_5508];
            }
          }
          int _9476 = _5503;
          int _9477 = _5505;
          for (int _5509 = _9476; _5509 < _9477; ++_5509)
          {
            {
              _ptr__5506[_5509] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5506,_5499)).as<::mosek::fusion::Expression>(),_5501,_5500,_5502)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5510 = _5501->getShape();
          _checked_ptr_1<int> _ptr__5510(_5510 ? _5510->raw() : nullptr,_5510 ? _5510->size(0) : 0);
          int _9478 = (int)0;
          int _9479 = _5504;
          for (int _5511 = _9478; _5511 < _9479; ++_5511)
          {
            {
              _ptr__5506[_5511] = _ptr__5510[_5511];
            }
          }
          int _9480 = _5504;
          int _9481 = _5505;
          for (int _5512 = _9480; _5512 < _9481; ++_5512)
          {
            {
              _ptr__5506[_5512] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_5499,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_5506,_5501)).as<::mosek::fusion::Expression>(),_5500,_5502)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _5513) { return mosek::fusion::p_Expr::transpose(_5513); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5513){
  if ((_5513->getND() == (int)0))
  {
    {
      return _5513;
    }
  }
  else if((_5513->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5513->getDim((int)0))}),_5513)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_5513->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_5513)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5514,    monty::rc_ptr< ::mosek::fusion::Expression > _5515) { return mosek::fusion::p_Expr::mulElm(_5514,_5515); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5514,monty::rc_ptr< ::mosek::fusion::Expression > _5515){
  return ::mosek::fusion::p_Expr::mulElm_(_5514,_5515);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5516,    monty::rc_ptr< ::mosek::fusion::Expression > _5517) { return mosek::fusion::p_Expr::mulElm(_5516,_5517); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5516,monty::rc_ptr< ::mosek::fusion::Expression > _5517){
  return ::mosek::fusion::p_Expr::mulElm_(_5516,_5517);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _5518,    monty::rc_ptr< ::mosek::fusion::Expression > _5519) { return mosek::fusion::p_Expr::mulElm(_5518,_5519); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5518,monty::rc_ptr< ::mosek::fusion::Expression > _5519){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5518),_5519);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _5520,    monty::rc_ptr< ::mosek::fusion::Expression > _5521) { return mosek::fusion::p_Expr::mulElm(_5520,_5521); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5520,monty::rc_ptr< ::mosek::fusion::Expression > _5521){
  _checked_ptr_1<double> _ptr__5520(_5520 ? _5520->raw() : nullptr, _5520 ? _5520->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5520,_5521);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5522,    monty::rc_ptr< ::mosek::fusion::Matrix > _5523) { return mosek::fusion::p_Expr::mulElm(_5522,_5523); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5522,monty::rc_ptr< ::mosek::fusion::Matrix > _5523){
  return ::mosek::fusion::p_Expr::mulElm_(_5523,_5522);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5524,    std::shared_ptr< monty::ndarray< double,2 > > _5525) { return mosek::fusion::p_Expr::mulElm(_5524,_5525); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5524,std::shared_ptr< monty::ndarray< double,2 > > _5525){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_5525),_5524);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5526,    std::shared_ptr< monty::ndarray< double,1 > > _5527) { return mosek::fusion::p_Expr::mulElm(_5526,_5527); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5526,std::shared_ptr< monty::ndarray< double,1 > > _5527){
  _checked_ptr_1<double> _ptr__5527(_5527 ? _5527->raw() : nullptr, _5527 ? _5527->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_5527,_5526);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _5528,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5529) { return mosek::fusion::p_Expr::mulElm(_5528,_5529); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5528,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5529){
  return ::mosek::fusion::p_Expr::mulElm_(_5529,_5528);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5530,    monty::rc_ptr< ::mosek::fusion::Expression > _5531) { return mosek::fusion::p_Expr::sub(_5530,_5531); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5530,monty::rc_ptr< ::mosek::fusion::Expression > _5531){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5530),1.0,_5531,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5532,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5533) { return mosek::fusion::p_Expr::sub(_5532,_5533); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5532,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5533){
  return ::mosek::fusion::p_Expr::add_(_5532,1.0,::mosek::fusion::p_Expr::constTerm(_5533),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5534,    monty::rc_ptr< ::mosek::fusion::Expression > _5535) { return mosek::fusion::p_Expr::sub(_5534,_5535); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5534,monty::rc_ptr< ::mosek::fusion::Expression > _5535){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5534),1.0,_5535,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5536,    monty::rc_ptr< ::mosek::fusion::Matrix > _5537) { return mosek::fusion::p_Expr::sub(_5536,_5537); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5536,monty::rc_ptr< ::mosek::fusion::Matrix > _5537){
  return ::mosek::fusion::p_Expr::add_(_5536,1.0,::mosek::fusion::p_Expr::constTerm(_5537),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _5538,    monty::rc_ptr< ::mosek::fusion::Expression > _5539) { return mosek::fusion::p_Expr::sub(_5538,_5539); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _5538,monty::rc_ptr< ::mosek::fusion::Expression > _5539){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5539->getShape(),_5538),1.0,_5539,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5540,    double _5541) { return mosek::fusion::p_Expr::sub(_5540,_5541); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5540,double _5541){
  return ::mosek::fusion::p_Expr::add_(_5540,1.0,::mosek::fusion::p_Expr::constTerm(_5540->getShape(),_5541),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _5542,    monty::rc_ptr< ::mosek::fusion::Expression > _5543) { return mosek::fusion::p_Expr::sub(_5542,_5543); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _5542,monty::rc_ptr< ::mosek::fusion::Expression > _5543){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5542),1.0,_5543,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _5544,    monty::rc_ptr< ::mosek::fusion::Expression > _5545) { return mosek::fusion::p_Expr::sub(_5544,_5545); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _5544,monty::rc_ptr< ::mosek::fusion::Expression > _5545){
  _checked_ptr_1<double> _ptr__5544(_5544 ? _5544->raw() : nullptr, _5544 ? _5544->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_5544),1.0,_5545,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5546,    std::shared_ptr< monty::ndarray< double,2 > > _5547) { return mosek::fusion::p_Expr::sub(_5546,_5547); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5546,std::shared_ptr< monty::ndarray< double,2 > > _5547){
  return ::mosek::fusion::p_Expr::add_(_5546,1.0,::mosek::fusion::p_Expr::constTerm(_5547),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5548,    std::shared_ptr< monty::ndarray< double,1 > > _5549) { return mosek::fusion::p_Expr::sub(_5548,_5549); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5548,std::shared_ptr< monty::ndarray< double,1 > > _5549){
  _checked_ptr_1<double> _ptr__5549(_5549 ? _5549->raw() : nullptr, _5549 ? _5549->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5548,1.0,::mosek::fusion::p_Expr::constTerm(_5549),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _5550,    monty::rc_ptr< ::mosek::fusion::Expression > _5551) { return mosek::fusion::p_Expr::sub(_5550,_5551); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _5550,monty::rc_ptr< ::mosek::fusion::Expression > _5551){
  return ::mosek::fusion::p_Expr::add_(_5550,1.0,_5551,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5552,    monty::rc_ptr< ::mosek::fusion::Expression > _5553) { return mosek::fusion::p_Expr::add(_5552,_5553); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5552,monty::rc_ptr< ::mosek::fusion::Expression > _5553){
  return ::mosek::fusion::p_Expr::add_(_5553,1.0,::mosek::fusion::p_Expr::constTerm(_5552),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5554,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5555) { return mosek::fusion::p_Expr::add(_5554,_5555); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5554,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5555){
  return ::mosek::fusion::p_Expr::add_(_5554,1.0,::mosek::fusion::p_Expr::constTerm(_5555),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5556,    monty::rc_ptr< ::mosek::fusion::Expression > _5557) { return mosek::fusion::p_Expr::add(_5556,_5557); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _5556,monty::rc_ptr< ::mosek::fusion::Expression > _5557){
  return ::mosek::fusion::p_Expr::add_(_5557,1.0,::mosek::fusion::p_Expr::constTerm(_5556),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5558,    monty::rc_ptr< ::mosek::fusion::Matrix > _5559) { return mosek::fusion::p_Expr::add(_5558,_5559); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5558,monty::rc_ptr< ::mosek::fusion::Matrix > _5559){
  return ::mosek::fusion::p_Expr::add_(_5558,1.0,::mosek::fusion::p_Expr::constTerm(_5559),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _5560,    monty::rc_ptr< ::mosek::fusion::Expression > _5561) { return mosek::fusion::p_Expr::add(_5560,_5561); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _5560,monty::rc_ptr< ::mosek::fusion::Expression > _5561){
  return ::mosek::fusion::p_Expr::add_(_5561,1.0,::mosek::fusion::p_Expr::constTerm(_5561->getShape(),_5560),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5562,    double _5563) { return mosek::fusion::p_Expr::add(_5562,_5563); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5562,double _5563){
  return ::mosek::fusion::p_Expr::add_(_5562,1.0,::mosek::fusion::p_Expr::constTerm(_5562->getShape(),_5563),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _5564,    monty::rc_ptr< ::mosek::fusion::Expression > _5565) { return mosek::fusion::p_Expr::add(_5564,_5565); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _5564,monty::rc_ptr< ::mosek::fusion::Expression > _5565){
  return ::mosek::fusion::p_Expr::add_(_5565,1.0,::mosek::fusion::p_Expr::constTerm(_5564),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _5566,    monty::rc_ptr< ::mosek::fusion::Expression > _5567) { return mosek::fusion::p_Expr::add(_5566,_5567); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _5566,monty::rc_ptr< ::mosek::fusion::Expression > _5567){
  _checked_ptr_1<double> _ptr__5566(_5566 ? _5566->raw() : nullptr, _5566 ? _5566->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5567,1.0,::mosek::fusion::p_Expr::constTerm(_5566),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5568,    std::shared_ptr< monty::ndarray< double,2 > > _5569) { return mosek::fusion::p_Expr::add(_5568,_5569); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5568,std::shared_ptr< monty::ndarray< double,2 > > _5569){
  return ::mosek::fusion::p_Expr::add_(_5568,1.0,::mosek::fusion::p_Expr::constTerm(_5569),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5570,    std::shared_ptr< monty::ndarray< double,1 > > _5571) { return mosek::fusion::p_Expr::add(_5570,_5571); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5570,std::shared_ptr< monty::ndarray< double,1 > > _5571){
  _checked_ptr_1<double> _ptr__5571(_5571 ? _5571->raw() : nullptr, _5571 ? _5571->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_5570,1.0,::mosek::fusion::p_Expr::constTerm(_5571),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _5572,    monty::rc_ptr< ::mosek::fusion::Expression > _5573) { return mosek::fusion::p_Expr::add(_5572,_5573); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _5572,monty::rc_ptr< ::mosek::fusion::Expression > _5573){
  return ::mosek::fusion::p_Expr::add_(_5572,1.0,_5573,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5574,monty::rc_ptr< ::mosek::fusion::WorkStack > _5575,monty::rc_ptr< ::mosek::fusion::WorkStack > _5576) { mosek::fusion::p_Expr::_get_impl(this)->eval(_5574,_5575,_5576); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5574,monty::rc_ptr< ::mosek::fusion::WorkStack > _5575,monty::rc_ptr< ::mosek::fusion::WorkStack > _5576){
  std::vector<int> _9482;
  for (int _5577 = (int)0, _9483 = (int)((ptrb)->size(0)); _5577 < _9483 ; ++_5577)
  {
    _9482.push_back((int)((*ptrb)(_5577)));
  }
  auto _9484 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9482.size()),_9482.begin(),_9482.end()));
  ::mosek::fusion::p_BaseExpression::storeexpr(_5574,shape,_9484,inst,subj,cof_v,bfix);
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5578,std::shared_ptr< monty::ndarray< long long,1 > > _5579,std::shared_ptr< monty::ndarray< double,1 > > _5580,std::shared_ptr< monty::ndarray< double,1 > > _5581,std::shared_ptr< monty::ndarray< int,1 > > _5582,std::shared_ptr< monty::ndarray< long long,1 > > _5583){
  _checked_ptr_1<long long> _ptr__5578(_5578 ? _5578->raw() : nullptr, _5578 ? _5578->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5579(_5579 ? _5579->raw() : nullptr, _5579 ? _5579->size(0) : 0);
  _checked_ptr_1<double> _ptr__5580(_5580 ? _5580->raw() : nullptr, _5580 ? _5580->size(0) : 0);
  _checked_ptr_1<double> _ptr__5581(_5581 ? _5581->raw() : nullptr, _5581 ? _5581->size(0) : 0);
  _checked_ptr_1<int> _ptr__5582(_5582 ? _5582->raw() : nullptr, _5582 ? _5582->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5583(_5583 ? _5583->raw() : nullptr, _5583 ? _5583->size(0) : 0);
  if ((NULL == _5582.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _5584 = ((int)((_5578)->size(0)) - (int)1);
  long long _5585 = _ptr__5578[((int)((_5578)->size(0)) - (int)1)];
  int _5586 = (int)((_5582)->size(0));
  long long _5587 = (long long)1;
  int _9485 = (int)0;
  int _9486 = _5586;
  for (int _5588 = _9485; _5588 < _9486; ++_5588)
  {
    {
      _5587 *= _ptr__5582[_5588];
    }
  }
  if (((int)((_5578)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_5585 != (int)((_5579)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_5585 != (int)((_5580)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _5581.get()) || (_5584 != (int)((_5581)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _5583.get()) && ((int)((_5583)->size(0)) < _5587)))
  {
    {
      if (((int)((_5583)->size(0)) != ((int)((_5578)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_5583)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5583[(int)0] < (int)0) || (_ptr__5583[(int)0] >= _5587)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _5589 = true;
          long long _5590 = _5587;
          int _9487 = (int)1;
          int _9488 = (int)((_5583)->size(0));
          for (int _5591 = _9487; _5591 < _9488; ++_5591)
          {
            {
              _5589 = (_5589 && ((_ptr__5583[_5591] >= (int)0) && ((_ptr__5583[_5591] < _5590) && (_ptr__5583[_5591] > _ptr__5583[(_5591 - (int)1)]))));
            }
          }
          if ((!_5589))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_5587 != ((long long)((_5578)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _5592 = false;
  bool _5593 = false;
  if ((_ptr__5578[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _5594 = true;
  int _9489 = (int)0;
  int _9490 = _5584;
  for (int _5595 = _9489; _5595 < _9490; ++_5595)
  {
    {
      _5594 = (_5594 && (_ptr__5578[_5595] <= _ptr__5578[safe_add( _5595,(int)1 )]));
    }
  }
  if ((!_5594))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5596){
  monty::rc_ptr< ::mosek::fusion::Model > _9491;
  bool _9492 = ((NULL == _5596.get()) || ((int)((_5596)->size(0)) == (int)0));
  if (_9492)
  {
    _9491 = nullptr;
  }
  else
  {
    _9491 = ((*_5596)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _9491;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _5597) { return __mosek_2fusion_2Expression__pick(_5597); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _5598) { return __mosek_2fusion_2Expression__pick(_5598); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _5599) { return __mosek_2fusion_2Expression__index(_5599); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _5600) { return __mosek_2fusion_2Expression__index(_5600); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _5601,std::shared_ptr< monty::ndarray< int,1 > > _5602) { return __mosek_2fusion_2Expression__slice(_5601,_5602); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _5603,int _5604) { return __mosek_2fusion_2Expression__slice(_5603,_5604); }
monty::rc_ptr< mosek::fusion::FlatExpr > mosek::fusion::Expression::eval() { return __mosek_2fusion_2Expression__eval(); }
mosek::fusion::FlatExpr::FlatExpr(mosek::fusion::p_FlatExpr *_impl) : _impl(_impl) { /*std::cout << "FlatExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::FlatExpr::~FlatExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_FlatExpr::p_FlatExpr  (::mosek::fusion::FlatExpr * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_inst() { return _impl->inst; }
void mosek::fusion::FlatExpr::set_inst(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->inst = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::FlatExpr::get_shape() { return _impl->shape; }
void mosek::fusion::FlatExpr::set_shape(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->shape = _val; }
long long mosek::fusion::FlatExpr::get_nnz() { return _impl->nnz; }
void mosek::fusion::FlatExpr::set_nnz(long long _val) { _impl->nnz = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_cof() { return _impl->cof; }
void mosek::fusion::FlatExpr::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_subj() { return _impl->subj; }
void mosek::fusion::FlatExpr::set_subj(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::FlatExpr::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::FlatExpr::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::FlatExpr::get_bfix() { return _impl->bfix; }
void mosek::fusion::FlatExpr::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5609){ return new mosek::fusion::FlatExpr(_5609); }mosek::fusion::FlatExpr::FlatExpr  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5609) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5609); }void mosek::fusion::p_FlatExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::FlatExpr > _5609){monty::rc_reserve __reserve_this(_pubthis);   {
    bfix = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5609)->bfix);
    ptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5609)->ptrb);
    subj = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5609)->subj);
    cof = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_FlatExpr::_get_impl(_5609)->cof);
    nnz = mosek::fusion::p_FlatExpr::_get_impl(_5609)->nnz;
    shape = mosek::fusion::p_FlatExpr::_get_impl(_5609)->shape;
    inst = mosek::fusion::p_FlatExpr::_get_impl(_5609)->inst;
  }
}mosek::fusion::FlatExpr::t mosek::fusion::p_FlatExpr::_new_FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5610,    std::shared_ptr< monty::ndarray< long long,1 > > _5611,    std::shared_ptr< monty::ndarray< long long,1 > > _5612,    std::shared_ptr< monty::ndarray< double,1 > > _5613,    std::shared_ptr< monty::ndarray< int,1 > > _5614,    std::shared_ptr< monty::ndarray< long long,1 > > _5615){ return new mosek::fusion::FlatExpr(_5610,_5611,_5612,_5613,_5614,_5615); }mosek::fusion::FlatExpr::FlatExpr  (std::shared_ptr< monty::ndarray< double,1 > > _5610,    std::shared_ptr< monty::ndarray< long long,1 > > _5611,    std::shared_ptr< monty::ndarray< long long,1 > > _5612,    std::shared_ptr< monty::ndarray< double,1 > > _5613,    std::shared_ptr< monty::ndarray< int,1 > > _5614,    std::shared_ptr< monty::ndarray< long long,1 > > _5615) :    FlatExpr(new mosek::fusion::p_FlatExpr(this)){ mosek::fusion::p_FlatExpr::_get_impl(this)->_initialize(_5610,_5611,_5612,_5613,_5614,_5615); }void mosek::fusion::p_FlatExpr::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5610,    std::shared_ptr< monty::ndarray< long long,1 > > _5611,    std::shared_ptr< monty::ndarray< long long,1 > > _5612,    std::shared_ptr< monty::ndarray< double,1 > > _5613,    std::shared_ptr< monty::ndarray< int,1 > > _5614,    std::shared_ptr< monty::ndarray< long long,1 > > _5615){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5610(_5610 ? _5610->raw() : nullptr, _5610 ? _5610->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5611(_5611 ? _5611->raw() : nullptr, _5611 ? _5611->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5612(_5612 ? _5612->raw() : nullptr, _5612 ? _5612->size(0) : 0);
    _checked_ptr_1<double> _ptr__5613(_5613 ? _5613->raw() : nullptr, _5613 ? _5613->size(0) : 0);
    _checked_ptr_1<int> _ptr__5614(_5614 ? _5614->raw() : nullptr, _5614 ? _5614->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5615(_5615 ? _5615->raw() : nullptr, _5615 ? _5615->size(0) : 0);
    if (((NULL != _5610.get()) && ((int)((_5610)->size(0)) != ((int)((_5611)->size(0)) - (int)1))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of bfix and ptrb"));
      }
    }
    {}
    if (((NULL == _5613.get()) || ((NULL == _5612.get()) || ((int)((_5612)->size(0)) != (int)((_5613)->size(0))))))
    {
      {
        throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of subj and cof"));
      }
    }
    {}
    if ((NULL != _5614.get()))
    {
      {
        if ((NULL != _5615.get()))
        {
          {
            if (((int)((_5615)->size(0)) != ((int)((_5611)->size(0)) - (int)1)))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching lengths of inst and ptrb"));
              }
            }
            {}
          }
        }
        else if((::mosek::fusion::p_Set::size(_5614) != ((long long)((_5611)->size(0)) - (int)1)))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching shape and ptrb"));
          }
        }
        {}
      }
    }
    {}
    bfix = _5610;
    ptrb = _5611;
    subj = _5612;
    cof = _5613;
    nnz = ((*ptrb)(((int)((ptrb)->size(0)) - (int)1)));
    shape = _5614;
    inst = _5615;
  }
}std::string mosek::fusion::FlatExpr :: toString() { return mosek::fusion::p_FlatExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_FlatExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5616 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5616->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("FlatExpr:"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"))->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| ptrb["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((ptrb)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(ptrb)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| subj["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((subj)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(subj)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| cof ["))->__mosek_2fusion_2Utils_2StringBuffer__a((int)((cof)->size(0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(cof)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| bfix["));
  if ((NULL != bfix.get()))
  {
    {
      _5616->__mosek_2fusion_2Utils_2StringBuffer__a((int)((bfix)->size(0)));
    }
  }
  {}
  _5616->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(bfix)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("| inst["));
  if ((NULL != inst.get()))
  {
    {
      _5616->__mosek_2fusion_2Utils_2StringBuffer__a((int)((inst)->size(0)));
    }
  }
  {}
  _5616->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] = "))->__mosek_2fusion_2Utils_2StringBuffer__a(inst)->__mosek_2fusion_2Utils_2StringBuffer__lf()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("+-----------------"));
  return _5616->toString();
}
int mosek::fusion::FlatExpr :: size() { return mosek::fusion::p_FlatExpr::_get_impl(this)->size(); }int mosek::fusion::p_FlatExpr::size(){
  return ((int)((ptrb)->size(0)) - (int)1);
}
void mosek::fusion::p_FlatExpr::destroy(){inst.reset();shape.reset();cof.reset();subj.reset();ptrb.reset();bfix.reset();}void mosek::fusion::FlatExpr::destroy() { mosek::fusion::p_FlatExpr::_get_impl(this)->destroy(); }mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _5617,    int _5618,    std::shared_ptr< monty::ndarray< int,1 > > _5619,    std::shared_ptr< monty::ndarray< int,1 > > _5620,    std::shared_ptr< monty::ndarray< double,1 > > _5621,    std::shared_ptr< monty::ndarray< int,1 > > _5622,    std::shared_ptr< monty::ndarray< int,1 > > _5623,    std::shared_ptr< monty::ndarray< double,1 > > _5624,    double _5625){ return new mosek::fusion::SymmetricMatrix(_5617,_5618,_5619,_5620,_5621,_5622,_5623,_5624,_5625); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _5617,    int _5618,    std::shared_ptr< monty::ndarray< int,1 > > _5619,    std::shared_ptr< monty::ndarray< int,1 > > _5620,    std::shared_ptr< monty::ndarray< double,1 > > _5621,    std::shared_ptr< monty::ndarray< int,1 > > _5622,    std::shared_ptr< monty::ndarray< int,1 > > _5623,    std::shared_ptr< monty::ndarray< double,1 > > _5624,    double _5625) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_5617,_5618,_5619,_5620,_5621,_5622,_5623,_5624,_5625); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _5617,    int _5618,    std::shared_ptr< monty::ndarray< int,1 > > _5619,    std::shared_ptr< monty::ndarray< int,1 > > _5620,    std::shared_ptr< monty::ndarray< double,1 > > _5621,    std::shared_ptr< monty::ndarray< int,1 > > _5622,    std::shared_ptr< monty::ndarray< int,1 > > _5623,    std::shared_ptr< monty::ndarray< double,1 > > _5624,    double _5625){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5619(_5619 ? _5619->raw() : nullptr, _5619 ? _5619->size(0) : 0);
    _checked_ptr_1<int> _ptr__5620(_5620 ? _5620->raw() : nullptr, _5620 ? _5620->size(0) : 0);
    _checked_ptr_1<double> _ptr__5621(_5621 ? _5621->raw() : nullptr, _5621 ? _5621->size(0) : 0);
    _checked_ptr_1<int> _ptr__5622(_5622 ? _5622->raw() : nullptr, _5622 ? _5622->size(0) : 0);
    _checked_ptr_1<int> _ptr__5623(_5623 ? _5623->raw() : nullptr, _5623 ? _5623->size(0) : 0);
    _checked_ptr_1<double> _ptr__5624(_5624 ? _5624->raw() : nullptr, _5624 ? _5624->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _5617;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _5618;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _5619;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _5620;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _5621;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _5622;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _5623;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _5624;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _5625;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _5626,    std::shared_ptr< monty::ndarray< int,1 > > _5627,    std::shared_ptr< monty::ndarray< double,1 > > _5628) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5626,_5627,_5628); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _5626,std::shared_ptr< monty::ndarray< int,1 > > _5627,std::shared_ptr< monty::ndarray< double,1 > > _5628){
  _checked_ptr_1<int> _ptr__5627(_5627 ? _5627->raw() : nullptr, _5627 ? _5627->size(0) : 0);
  _checked_ptr_1<double> _ptr__5628(_5628 ? _5628->raw() : nullptr, _5628 ? _5628->size(0) : 0);
  if (((int)((_5627)->size(0)) != (int)((_5628)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _9493 = (int)0;
  int _9494 = (int)((_5627)->size(0));
  for (int _5629 = _9493; _5629 < _9494; ++_5629)
  {
    {
      if (((_ptr__5627[_5629] < (int)0) || (_ptr__5627[_5629] >= _5626)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _9495;
  for (int _5631 = (int)0, _9496 = (int)((_5627)->size(0)); _5631 < _9496 ; ++_5631)
  {
    _9495.push_back(_ptr__5627[_5631]);
  }
  auto _9497 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9495.size()),_9495.begin(),_9495.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5630 = _9497;
  _checked_ptr_1<int> _ptr__5630(_5630 ? _5630->raw() : nullptr,_5630 ? _5630->size(0) : 0);
  std::vector<int> _9498;
  for (int _5633 = (int)0, _9499 = (int)((_5627)->size(0)); _5633 < _9499 ; ++_5633)
  {
    _9498.push_back((int)1);
  }
  auto _9500 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9498.size()),_9498.begin(),_9498.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5632 = _9500;
  _checked_ptr_1<int> _ptr__5632(_5632 ? _5632->raw() : nullptr,_5632 ? _5632->size(0) : 0);
  std::vector<double> _9501;
  for (int _5635 = (int)0, _9502 = (int)((_5628)->size(0)); _5635 < _9502 ; ++_5635)
  {
    _9501.push_back(_ptr__5628[_5635]);
  }
  auto _9503 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9501.size()),_9501.begin(),_9501.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5634 = _9503;
  _checked_ptr_1<double> _ptr__5634(_5634 ? _5634->raw() : nullptr,_5634 ? _5634->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5626,(int)1,_5630,_5632,_5634,_5630,_5632,_5634,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _5636) { return mosek::fusion::p_SymmetricMatrix::rankOne(_5636); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5636){
  _checked_ptr_1<double> _ptr__5636(_5636 ? _5636->raw() : nullptr, _5636 ? _5636->size(0) : 0);
  int _5637 = (int)((_5636)->size(0));
  std::vector<int> _9504;
  for (int _5639 = (int)0, _9505 = _5637; _5639 < _9505 ; ++_5639)
  {
    _9504.push_back(_5639);
  }
  auto _9506 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9504.size()),_9504.begin(),_9504.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5638 = _9506;
  _checked_ptr_1<int> _ptr__5638(_5638 ? _5638->raw() : nullptr,_5638 ? _5638->size(0) : 0);
  std::vector<int> _9507;
  for (int _5641 = (int)0, _9508 = _5637; _5641 < _9508 ; ++_5641)
  {
    _9507.push_back((int)1);
  }
  auto _9509 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9507.size()),_9507.begin(),_9507.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5640 = _9509;
  _checked_ptr_1<int> _ptr__5640(_5640 ? _5640->raw() : nullptr,_5640 ? _5640->size(0) : 0);
  std::vector<double> _9510;
  for (int _5643 = (int)0, _9511 = _5637; _5643 < _9511 ; ++_5643)
  {
    _9510.push_back(_ptr__5636[_5643]);
  }
  auto _9512 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9510.size()),_9510.begin(),_9510.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5642 = _9512;
  _checked_ptr_1<double> _ptr__5642(_5642 ? _5642->raw() : nullptr,_5642 ? _5642->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5637,(int)1,_5638,_5640,_5642,_5638,_5640,_5642,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5644) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_5644); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5644){
  _checked_ptr_1<double> _ptr__5644(_5644 ? _5644->raw() : nullptr, _5644 ? _5644->size(0) : 0);
  int _5645 = (int)((_5644)->size(0));
  std::vector<int> _9513;
  for (int _5647 = (int)0, _9514 = _5645; _5647 < _9514 ; ++_5647)
  {
    _9513.push_back(_5647);
  }
  auto _9515 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9513.size()),_9513.begin(),_9513.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5646 = _9515;
  _checked_ptr_1<int> _ptr__5646(_5646 ? _5646->raw() : nullptr,_5646 ? _5646->size(0) : 0);
  std::vector<int> _9516;
  for (int _5648 = (int)0, _9517 = _5645; _5648 < _9517 ; ++_5648)
  {
    _9516.push_back((_5645 - _5648));
  }
  auto _9518 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9516.size()),_9516.begin(),_9516.end()));
  std::vector<double> _9519;
  for (int _5649 = (int)0, _9520 = _5645; _5649 < _9520 ; ++_5649)
  {
    _9519.push_back(_ptr__5644[_5649]);
  }
  auto _9521 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9519.size()),_9519.begin(),_9519.end()));
  std::vector<double> _9522;
  for (int _5650 = (int)0, _9523 = _5645; _5650 < _9523 ; ++_5650)
  {
    _9522.push_back(1.0);
  }
  auto _9524 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9522.size()),_9522.begin(),_9522.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5645,_5645,_5646,_9518,_9521,_5646,_5646,_9524,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5651) { return mosek::fusion::p_SymmetricMatrix::diag(_5651); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5651){
  _checked_ptr_1<double> _ptr__5651(_5651 ? _5651->raw() : nullptr, _5651 ? _5651->size(0) : 0);
  int _5652 = (int)((_5651)->size(0));
  std::vector<int> _9525;
  for (int _5654 = (int)0, _9526 = _5652; _5654 < _9526 ; ++_5654)
  {
    _9525.push_back(_5654);
  }
  auto _9527 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9525.size()),_9525.begin(),_9525.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5653 = _9527;
  _checked_ptr_1<int> _ptr__5653(_5653 ? _5653->raw() : nullptr,_5653 ? _5653->size(0) : 0);
  std::vector<double> _9528;
  for (int _5655 = (int)0, _9529 = _5652; _5655 < _9529 ; ++_5655)
  {
    _9528.push_back(_ptr__5651[_5655]);
  }
  auto _9530 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9528.size()),_9528.begin(),_9528.end()));
  std::vector<double> _9531;
  for (int _5656 = (int)0, _9532 = _5652; _5656 < _9532 ; ++_5656)
  {
    _9531.push_back(1.0);
  }
  auto _9533 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9531.size()),_9531.begin(),_9531.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_5652,_5652,_5653,_5653,_9530,_5653,_5653,_9533,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5657) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_5657); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5657) { return __mosek_2fusion_2SymmetricMatrix__add(_5657); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5657){
  int _5658 = _pubthis->getdim();
  if ((_5657->getdim() != _5658))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _5659 = (int)((usubi)->size(0));
  int _5660 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->usubi)->size(0));
  int _5661 = safe_add( _5659,_5660 );
  int _5662 = (int)((vsubi)->size(0));
  int _5663 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->vsubi)->size(0));
  int _5664 = safe_add( _5662,_5663 );
  std::shared_ptr< monty::ndarray< double,1 > > _5665 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5664)));
  _checked_ptr_1<double> _ptr__5665(_5665 ? _5665->raw() : nullptr,_5665 ? _5665->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5666 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5664)));
  _checked_ptr_1<int> _ptr__5666(_5666 ? _5666->raw() : nullptr,_5666 ? _5666->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5667 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5664)));
  _checked_ptr_1<int> _ptr__5667(_5667 ? _5667->raw() : nullptr,_5667 ? _5667->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5668 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5661)));
  _checked_ptr_1<double> _ptr__5668(_5668 ? _5668->raw() : nullptr,_5668 ? _5668->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5669 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5661)));
  _checked_ptr_1<int> _ptr__5669(_5669 ? _5669->raw() : nullptr,_5669 ? _5669->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5670 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5661)));
  _checked_ptr_1<int> _ptr__5670(_5670 ? _5670->raw() : nullptr,_5670 ? _5670->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5670,(int)0,_5659);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->usubi,(int)0,_5670,_5659,_5660);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_5669,(int)0,_5659);
  int _9534 = (int)0;
  int _9535 = _5660;
  for (int _5671 = _9534; _5671 < _9535; ++_5671)
  {
    {
      _ptr__5669[safe_add( _5671,_5659 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->usubj)(_5671)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_5668,(int)0,_5659);
    }
  }
  else
  {
    {
      int _9536 = (int)0;
      int _9537 = _5659;
      for (int _5672 = _9536; _5672 < _9537; ++_5672)
      {
        {
          _ptr__5668[_5672] = (scale * ((*uval)(_5672)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->uval,(int)0,_5668,_5659,_5660);
    }
  }
  else
  {
    {
      int _9538 = (int)0;
      int _9539 = _5660;
      for (int _5673 = _9538; _5673 < _9539; ++_5673)
      {
        {
          _ptr__5668[safe_add( _5673,_5659 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->uval)(_5673)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_5670,(int)0,_5659);
  int _9540 = (int)0;
  int _9541 = _5663;
  for (int _5674 = _9540; _5674 < _9541; ++_5674)
  {
    {
      _ptr__5667[safe_add( _5674,_5662 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->vsubi)(_5674)),mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_5666,(int)0,_5662);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->vsubj,_5662,_5666,_5662,_5663);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_5665,(int)0,_5662);
    }
  }
  else
  {
    {
      int _9542 = (int)0;
      int _9543 = _5662;
      for (int _5675 = _9542; _5675 < _9543; ++_5675)
      {
        {
          _ptr__5665[_5675] = (scale * ((*vval)(_5675)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->vval,(int)0,_5665,_5662,_5663);
    }
  }
  else
  {
    {
      int _9544 = (int)0;
      int _9545 = _5663;
      for (int _5676 = _9544; _5676 < _9545; ++_5676)
      {
        {
          _ptr__5665[safe_add( _5676,_5662 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->vval)(_5676)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_5657)->d1 ),_5670,_5669,_5668,_5667,_5666,_5665,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5677) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_5677); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5677) { return __mosek_2fusion_2SymmetricMatrix__sub(_5677); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5677){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_5677->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _5678) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_5678); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _5678) { return __mosek_2fusion_2SymmetricMatrix__mul(_5678); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _5678){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _5678));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5679,    std::shared_ptr< monty::ndarray< int,2 > > _5680,    std::shared_ptr< monty::ndarray< double,1 > > _5681){ return new mosek::fusion::NDSparseArray(_5679,_5680,_5681); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5679,    std::shared_ptr< monty::ndarray< int,2 > > _5680,    std::shared_ptr< monty::ndarray< double,1 > > _5681) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5679,_5680,_5681); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5679,    std::shared_ptr< monty::ndarray< int,2 > > _5680,    std::shared_ptr< monty::ndarray< double,1 > > _5681){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5679(_5679 ? _5679->raw() : nullptr, _5679 ? _5679->size(0) : 0);
    _checked_ptr_1<double> _ptr__5681(_5681 ? _5681->raw() : nullptr, _5681 ? _5681->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _5682 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5680)->size(0)))));
    _checked_ptr_1<long long> _ptr__5682(_5682 ? _5682->raw() : nullptr,_5682 ? _5682->size(0) : 0);
    size = (long long)1;
    int _9546 = (int)0;
    int _9547 = (int)((_5679)->size(0));
    for (int _5683 = _9546; _5683 < _9547; ++_5683)
    {
      {
        size = safe_mul( size,_ptr__5679[_5683] );
      }
    }
    int _5684 = (int)((_5679)->size(0));
    if (((int)((_5680)->size(0)) != (int)((_5681)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_5680)->size(1)) != _5684))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    int _9548 = (int)0;
    int _9549 = (int)((_5680)->size(0));
    for (int _5685 = _9548; _5685 < _9549; ++_5685)
    {
      {
        int _9550 = (int)0;
        int _9551 = (int)((_5680)->size(1));
        for (int _5686 = _9550; _5686 < _9551; ++_5686)
        {
          {
            if (((((*_5680)(_5685,_5686)) < (int)0) || (((*_5680)(_5685,_5686)) >= _ptr__5679[_5686])))
            {
              {
                throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
              }
            }
            {}
          }
        }
      }
    }
    int _9552 = (int)0;
    int _9553 = (int)((_5680)->size(0));
    for (int _5687 = _9552; _5687 < _9553; ++_5687)
    {
      {
        long long _5688 = (long long)0;
        int _9554 = (int)0;
        int _9555 = (int)((_5680)->size(1));
        for (int _5689 = _9554; _5689 < _9555; ++_5689)
        {
          {
            _5688 = safe_add( safe_mul( _5688,_ptr__5679[((_5684 - _5689) - (int)1)] ),((*_5680)(_5687,_5689)) );
          }
        }
        _ptr__5682[_5687] = _5688;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5679);
    bool _5690 = true;
    int _9556 = (int)1;
    int _9557 = (int)((_5682)->size(0));
    for (int _5691 = _9556; _5691 < _9557; ++_5691)
    {
      {
        _5690 = (_5690 && (_ptr__5682[_5691] >= _ptr__5682[(_5691 - (int)1)]));
      }
    }
    if (_5690)
    {
      {
        int _5692 = (int)1;
        int _9558 = (int)1;
        int _9559 = (int)((_5682)->size(0));
        for (int _5693 = _9558; _5693 < _9559; ++_5693)
        {
          {
            if ((_ptr__5682[(_5693 - (int)1)] > _ptr__5682[_5693]))
            {
              {
                ++ _5692;
              }
            }
            {}
          }
        }
        if ((_5692 == (int)((_5682)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5682);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5681);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5692)));
            ((*inst)((int)0)) = _ptr__5682[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5692)));
            ((*cof)((int)0)) = _ptr__5681[(int)0];
            int _5694 = (int)0;
            int _9560 = (int)1;
            int _9561 = (int)((_5682)->size(0));
            for (int _5695 = _9560; _5695 < _9561; ++_5695)
            {
              {
                if ((_ptr__5682[_5695] > _ptr__5682[(_5695 - (int)1)]))
                {
                  {
                    ++ _5694;
                    ((*inst)(_5694)) = _ptr__5682[_5695];
                    ((*cof)(_5694)) = _ptr__5681[_5695];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5694)) = (((*cof)(_5694)) + _ptr__5681[_5695]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5696 = ::mosek::fusion::Utils::Tools::range((long long)((_5682)->size(0)));
        _checked_ptr_1<long long> _ptr__5696(_5696 ? _5696->raw() : nullptr,_5696 ? _5696->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5696,_5682,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5682)->size(0)));
        int _5697 = (int)1;
        int _9562 = (int)1;
        int _9563 = (int)((_5682)->size(0));
        for (int _5698 = _9562; _5698 < _9563; ++_5698)
        {
          {
            if ((_ptr__5682[_ptr__5696[(_5698 - (int)1)]] < _ptr__5682[_ptr__5696[_5698]]))
            {
              {
                ++ _5697;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5697)));
        ((*inst)((int)0)) = _ptr__5682[_ptr__5696[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5697)));
        ((*cof)((int)0)) = _ptr__5681[_ptr__5696[(int)0]];
        int _5699 = (int)0;
        int _9564 = (int)1;
        int _9565 = (int)((_5682)->size(0));
        for (int _5700 = _9564; _5700 < _9565; ++_5700)
        {
          {
            if ((_ptr__5682[_ptr__5696[_5700]] > _ptr__5682[_ptr__5696[(_5700 - (int)1)]]))
            {
              {
                ++ _5699;
                ((*inst)(_5699)) = _ptr__5682[_ptr__5696[_5700]];
                ((*cof)(_5699)) = _ptr__5681[_ptr__5696[_5700]];
              }
            }
            else
            {
              {
                ((*cof)(_5699)) = (((*cof)(_5699)) + _ptr__5681[_ptr__5696[_5700]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5701,    std::shared_ptr< monty::ndarray< long long,1 > > _5702,    std::shared_ptr< monty::ndarray< double,1 > > _5703){ return new mosek::fusion::NDSparseArray(_5701,_5702,_5703); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _5701,    std::shared_ptr< monty::ndarray< long long,1 > > _5702,    std::shared_ptr< monty::ndarray< double,1 > > _5703) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5701,_5702,_5703); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _5701,    std::shared_ptr< monty::ndarray< long long,1 > > _5702,    std::shared_ptr< monty::ndarray< double,1 > > _5703){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5701(_5701 ? _5701->raw() : nullptr, _5701 ? _5701->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5702(_5702 ? _5702->raw() : nullptr, _5702 ? _5702->size(0) : 0);
    _checked_ptr_1<double> _ptr__5703(_5703 ? _5703->raw() : nullptr, _5703 ? _5703->size(0) : 0);
    size = (long long)1;
    int _9566 = (int)0;
    int _9567 = (int)((_5701)->size(0));
    for (int _5704 = _9566; _5704 < _9567; ++_5704)
    {
      {
        size = safe_mul( size,_ptr__5701[_5704] );
      }
    }
    if (((int)((_5702)->size(0)) != (int)((_5703)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    int _9568 = (int)0;
    int _9569 = (int)((_5702)->size(0));
    for (int _5705 = _9568; _5705 < _9569; ++_5705)
    {
      {
        if (((_ptr__5702[_5705] < (int)0) || (_ptr__5702[_5705] >= size)))
        {
          {
            throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
          }
        }
        {}
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_5701);
    bool _5706 = true;
    int _9570 = (int)1;
    int _9571 = (int)((_5702)->size(0));
    for (int _5707 = _9570; _5707 < _9571; ++_5707)
    {
      {
        _5706 = (_5706 && (_ptr__5702[_5707] >= _ptr__5702[(_5707 - (int)1)]));
      }
    }
    if (_5706)
    {
      {
        int _5708 = (int)1;
        int _9572 = (int)1;
        int _9573 = (int)((_5702)->size(0));
        for (int _5709 = _9572; _5709 < _9573; ++_5709)
        {
          {
            if ((_ptr__5702[(_5709 - (int)1)] > _ptr__5702[_5709]))
            {
              {
                ++ _5708;
              }
            }
            {}
          }
        }
        if ((_5708 == (int)((_5702)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_5702);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_5703);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5708)));
            ((*inst)((int)0)) = _ptr__5702[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5708)));
            ((*cof)((int)0)) = _ptr__5703[(int)0];
            int _5710 = (int)0;
            int _9574 = (int)1;
            int _9575 = (int)((_5702)->size(0));
            for (int _5711 = _9574; _5711 < _9575; ++_5711)
            {
              {
                if ((_ptr__5702[_5711] > _ptr__5702[(_5711 - (int)1)]))
                {
                  {
                    ++ _5710;
                    ((*inst)(_5710)) = _ptr__5702[_5711];
                    ((*cof)(_5710)) = _ptr__5703[_5711];
                  }
                }
                else
                {
                  {
                    ((*cof)(_5710)) = (((*cof)(_5710)) + _ptr__5703[_5711]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _5712 = ::mosek::fusion::Utils::Tools::range((long long)((_5702)->size(0)));
        _checked_ptr_1<long long> _ptr__5712(_5712 ? _5712->raw() : nullptr,_5712 ? _5712->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_5712,_5702,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_5702)->size(0)));
        int _5713 = (int)1;
        int _9576 = (int)1;
        int _9577 = (int)((_5702)->size(0));
        for (int _5714 = _9576; _5714 < _9577; ++_5714)
        {
          {
            if ((_ptr__5702[_ptr__5712[(_5714 - (int)1)]] < _ptr__5702[_ptr__5712[_5714]]))
            {
              {
                ++ _5713;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5713)));
        ((*inst)((int)0)) = _ptr__5702[_ptr__5712[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5713)));
        ((*cof)((int)0)) = _ptr__5703[_ptr__5712[(int)0]];
        int _5715 = (int)0;
        int _9578 = (int)1;
        int _9579 = (int)((_5702)->size(0));
        for (int _5716 = _9578; _5716 < _9579; ++_5716)
        {
          {
            if ((_ptr__5702[_ptr__5712[_5716]] > ((*inst)(_ptr__5712[(_5716 - (int)1)]))))
            {
              {
                ++ _5715;
                ((*inst)(_5715)) = _ptr__5702[_ptr__5712[_5716]];
                ((*cof)(_5715)) = _ptr__5703[_ptr__5712[_5716]];
              }
            }
            else
            {
              {
                ((*cof)(_5715)) = (((*cof)(_5715)) + _ptr__5703[_ptr__5712[_5716]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5717){ return new mosek::fusion::NDSparseArray(_5717); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _5717) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_5717); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5717){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _5718 = _5717->numNonzeros();
    int _5719 = _5717->numColumns();
    int _5720 = _5717->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _5721 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5718)));
    _checked_ptr_1<double> _ptr__5721(_5721 ? _5721->raw() : nullptr,_5721 ? _5721->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5722 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5718)));
    _checked_ptr_1<int> _ptr__5722(_5722 ? _5722->raw() : nullptr,_5722 ? _5722->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _5723 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5718)));
    _checked_ptr_1<int> _ptr__5723(_5723 ? _5723->raw() : nullptr,_5723 ? _5723->size(0) : 0);
    _5717->getDataAsTriplets(_5723,_5722,_5721);
    size = safe_mul( (long long)_5717->numRows(),(long long)_5717->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5720),(int)(_5719)});
    std::vector<long long> _9580;
    for (long long _5724 = (long long)0, _9581 = _5718; _5724 < _9581 ; ++_5724)
    {
      _9580.push_back(safe_add( safe_mul( (long long)_ptr__5723[_5724],_5719 ),(long long)_ptr__5722[_5724] ));
    }
    auto _9582 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9580.size()),_9580.begin(),_9580.end()));
    inst = _9582;
    cof = _5721;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5725) { return mosek::fusion::p_NDSparseArray::make(_5725); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _5725){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5725);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5726,    std::shared_ptr< monty::ndarray< long long,1 > > _5727,    std::shared_ptr< monty::ndarray< double,1 > > _5728) { return mosek::fusion::p_NDSparseArray::make(_5726,_5727,_5728); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5726,std::shared_ptr< monty::ndarray< long long,1 > > _5727,std::shared_ptr< monty::ndarray< double,1 > > _5728){
  _checked_ptr_1<int> _ptr__5726(_5726 ? _5726->raw() : nullptr, _5726 ? _5726->size(0) : 0);
  _checked_ptr_1<long long> _ptr__5727(_5727 ? _5727->raw() : nullptr, _5727 ? _5727->size(0) : 0);
  _checked_ptr_1<double> _ptr__5728(_5728 ? _5728->raw() : nullptr, _5728 ? _5728->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5726,_5727,_5728);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _5729,    std::shared_ptr< monty::ndarray< int,2 > > _5730,    std::shared_ptr< monty::ndarray< double,1 > > _5731) { return mosek::fusion::p_NDSparseArray::make(_5729,_5730,_5731); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _5729,std::shared_ptr< monty::ndarray< int,2 > > _5730,std::shared_ptr< monty::ndarray< double,1 > > _5731){
  _checked_ptr_1<int> _ptr__5729(_5729 ? _5729->raw() : nullptr, _5729 ? _5729->size(0) : 0);
  _checked_ptr_1<double> _ptr__5731(_5731 ? _5731->raw() : nullptr, _5731 ? _5731->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_5729,_5730,_5731);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5732,    int _5733,    std::shared_ptr< monty::ndarray< double,1 > > _5734){ return new mosek::fusion::DenseMatrix(_5732,_5733,_5734); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5732,    int _5733,    std::shared_ptr< monty::ndarray< double,1 > > _5734) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5732,_5733,_5734); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5732,    int _5733,    std::shared_ptr< monty::ndarray< double,1 > > _5734){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5734(_5734 ? _5734->raw() : nullptr, _5734 ? _5734->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5732,_5733);
    nnz = (long long)safe_mul( _5732,_5733 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _5732,_5733 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_5734,(int)0,data,(int)0,safe_mul( _5732,_5733 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5735){ return new mosek::fusion::DenseMatrix(_5735); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _5735) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5735); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _5735){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_5735)->dimi,mosek::fusion::p_Matrix::_get_impl(_5735)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _9583 = _5735;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9583.get()))
    {
      ::mosek::fusion::DenseMatrix::t _5736 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9583.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_5736)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9583.get()))
    {
      ::mosek::fusion::SparseMatrix::t _5737 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9583.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_5737)->dimi,mosek::fusion::p_Matrix::_get_impl(_5737)->dimj ));
        long long _9584 = (long long)0;
        long long _9585 = mosek::fusion::p_SparseMatrix::_get_impl(_5737)->nnz;
        for (long long _5739 = _9584; _5739 < _9585; ++_5739)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5737)->subi)(_5739)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_5737)->subj)(_5739)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5737)->val)(_5739));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _5738 = _9583;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5740){ return new mosek::fusion::DenseMatrix(_5740); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _5740) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5740); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _5740){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_5740)->size(0)),(int)((_5740)->size(1)));
    std::vector<double> _9586;
    for (int _5741 = (int)0, _9587 = dimi; _5741 < _9587 ; ++_5741)
    {
      for (int _5742 = (int)0, _9588 = dimj; _5742 < _9588 ; ++_5742)
      {
        _9586.push_back(((*_5740)(_5741,_5742)));
      }
    }
    auto _9589 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9586.size()),_9586.begin(),_9586.end()));
    data = _9589;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _5743,    int _5744,    double _5745){ return new mosek::fusion::DenseMatrix(_5743,_5744,_5745); }mosek::fusion::DenseMatrix::DenseMatrix  (int _5743,    int _5744,    double _5745) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_5743,_5744,_5745); }void mosek::fusion::p_DenseMatrix::_initialize  (int _5743,    int _5744,    double _5745){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_5743,_5744);
    std::vector<double> _9590;
    for (int _5746 = (int)0, _9591 = _5743; _5746 < _9591 ; ++_5746)
    {
      for (int _5747 = (int)0, _9592 = _5744; _5747 < _9592 ; ++_5747)
      {
        _9590.push_back(_5745);
      }
    }
    auto _9593 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9590.size()),_9590.begin(),_9590.end()));
    data = _9593;
    nnz = (long long)safe_mul( _5743,_5744 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5748 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _5748->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _5748->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _5749 = (int)0;
  {
    int _5750 = (int)0;
    for(;(_5750 < dimi);++ _5750)
    {
      {
        if ((_5750 > (int)0))
        {
          {
            _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _5748->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5749)));
        ++ _5749;
        {
          int _5751 = (int)1;
          for(;(_5751 < dimj);++ _5751)
          {
            {
              _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _5748->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_5749)));
              ++ _5749;
            }
          }
        }
        _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _5748->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _5748->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _5752 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5752(_5752 ? _5752->raw() : nullptr,_5752 ? _5752->size(0) : 0);
  int _5753 = (int)0;
  int _5754 = dimi;
  int _9594 = (int)0;
  int _9595 = dimi;
  for (int _5755 = _9594; _5755 < _9595; ++_5755)
  {
    {
      int _5756 = _5755;
      int _9596 = (int)0;
      int _9597 = dimj;
      for (int _5757 = _9596; _5757 < _9597; ++_5757)
      {
        {
          _ptr__5752[_5756] = ((*data)(_5753));
          _5756 = safe_add( _5756,_5754 );
          ++ _5753;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_5752)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5758,std::shared_ptr< monty::ndarray< int,1 > > _5759,std::shared_ptr< monty::ndarray< double,1 > > _5760) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_5758,_5759,_5760); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5758,std::shared_ptr< monty::ndarray< int,1 > > _5759,std::shared_ptr< monty::ndarray< double,1 > > _5760){
  _checked_ptr_1<int> _ptr__5758(_5758 ? _5758->raw() : nullptr, _5758 ? _5758->size(0) : 0);
  _checked_ptr_1<int> _ptr__5759(_5759 ? _5759->raw() : nullptr, _5759 ? _5759->size(0) : 0);
  _checked_ptr_1<double> _ptr__5760(_5760 ? _5760->raw() : nullptr, _5760 ? _5760->size(0) : 0);
  if ((((int)((_5758)->size(0)) < nnz) || (((int)((_5759)->size(0)) < nnz) || ((int)((_5760)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_5760,(int)0,(int)((data)->size(0)));
  int _5761 = (int)0;
  int _9598 = (int)0;
  int _9599 = dimi;
  for (int _5762 = _9598; _5762 < _9599; ++_5762)
  {
    {
      int _9600 = (int)0;
      int _9601 = dimj;
      for (int _5763 = _9600; _5763 < _9601; ++_5763)
      {
        {
          _ptr__5758[_5761] = _5762;
          _ptr__5759[_5761] = _5763;
          ++ _5761;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _5764,int _5765) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_5764,_5765); }double mosek::fusion::p_DenseMatrix::get(int _5764,int _5765){
  return ((*data)(safe_add( safe_mul( _5764,dimj ),_5765 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5766,    int _5767,    std::shared_ptr< monty::ndarray< int,1 > > _5768,    std::shared_ptr< monty::ndarray< int,1 > > _5769,    std::shared_ptr< monty::ndarray< double,1 > > _5770,    long long _5771){ return new mosek::fusion::SparseMatrix(_5766,_5767,_5768,_5769,_5770,_5771); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5766,    int _5767,    std::shared_ptr< monty::ndarray< int,1 > > _5768,    std::shared_ptr< monty::ndarray< int,1 > > _5769,    std::shared_ptr< monty::ndarray< double,1 > > _5770,    long long _5771) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5766,_5767,_5768,_5769,_5770,_5771); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5766,    int _5767,    std::shared_ptr< monty::ndarray< int,1 > > _5768,    std::shared_ptr< monty::ndarray< int,1 > > _5769,    std::shared_ptr< monty::ndarray< double,1 > > _5770,    long long _5771){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5768(_5768 ? _5768->raw() : nullptr, _5768 ? _5768->size(0) : 0);
    _checked_ptr_1<int> _ptr__5769(_5769 ? _5769->raw() : nullptr, _5769 ? _5769->size(0) : 0);
    _checked_ptr_1<double> _ptr__5770(_5770 ? _5770->raw() : nullptr, _5770 ? _5770->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5766,_5767);
    if ((_5771 > (int)0))
    {
      {
        if ((((int)((_5768)->size(0)) < _5771) || (((int)((_5769)->size(0)) < _5771) || ((int)((_5770)->size(0)) < _5771))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        long long _9602 = (long long)0;
        long long _9603 = _5771;
        for (long long _5772 = _9602; _5772 < _9603; ++_5772)
        {
          {
            if (((_ptr__5768[_5772] < (int)0) || ((_ptr__5768[_5772] >= dimi) || ((_ptr__5769[_5772] < (int)0) || (_ptr__5769[_5772] >= dimj)))))
            {
              {
                throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
              }
            }
            {}
          }
        }
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5773 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _5774 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _5775 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_5768,_5769,_5770,_5773,_5774,_5775,_5771,dimi,dimj);
        subi = ((*_5773)((int)0));
        subj = ((*_5774)((int)0));
        val = ((*_5775)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _5776,    int _5777,    std::shared_ptr< monty::ndarray< int,1 > > _5778,    std::shared_ptr< monty::ndarray< int,1 > > _5779,    std::shared_ptr< monty::ndarray< double,1 > > _5780){ return new mosek::fusion::SparseMatrix(_5776,_5777,_5778,_5779,_5780); }mosek::fusion::SparseMatrix::SparseMatrix  (int _5776,    int _5777,    std::shared_ptr< monty::ndarray< int,1 > > _5778,    std::shared_ptr< monty::ndarray< int,1 > > _5779,    std::shared_ptr< monty::ndarray< double,1 > > _5780) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_5776,_5777,_5778,_5779,_5780); }void mosek::fusion::p_SparseMatrix::_initialize  (int _5776,    int _5777,    std::shared_ptr< monty::ndarray< int,1 > > _5778,    std::shared_ptr< monty::ndarray< int,1 > > _5779,    std::shared_ptr< monty::ndarray< double,1 > > _5780){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5778(_5778 ? _5778->raw() : nullptr, _5778 ? _5778->size(0) : 0);
    _checked_ptr_1<int> _ptr__5779(_5779 ? _5779->raw() : nullptr, _5779 ? _5779->size(0) : 0);
    _checked_ptr_1<double> _ptr__5780(_5780 ? _5780->raw() : nullptr, _5780 ? _5780->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_5776,_5777);
    int _5781 = (int)0;
    int _9604 = (int)0;
    int _9605 = (int)((_5780)->size(0));
    for (int _5782 = _9604; _5782 < _9605; ++_5782)
    {
      {
        if (((_ptr__5780[_5782] > (int)0) || (_ptr__5780[_5782] < (int)0)))
        {
          {
            ++ _5781;
          }
        }
        {}
      }
    }
    if (((_5781 > (int)0) && (_5781 < (int)((_5778)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5781)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5781)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5781)));
        nnz = _5781;
        int _5783 = (int)0;
        int _9606 = (int)0;
        int _9607 = (int)((_5780)->size(0));
        for (int _5784 = _9606; _5784 < _9607; ++_5784)
        {
          {
            if (((_ptr__5780[_5784] < (int)0) || (_ptr__5780[_5784] > (int)0)))
            {
              {
                ((*val)(_5783)) = _ptr__5780[_5784];
                ((*subj)(_5783)) = _ptr__5779[_5784];
                ((*subi)(_5783)) = _ptr__5778[_5784];
                ++ _5783;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _5778;
        subj = _5779;
        val = _5780;
        if ((NULL == _5778.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _5785 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__5785(_5785 ? _5785->raw() : nullptr,_5785 ? _5785->size(0) : 0);
  long long _5786 = (long long)0;
  int _9608 = (int)0;
  int _9609 = dimi;
  for (int _5787 = _9608; _5787 < _9609; ++_5787)
  {
    {
      _ptr__5785[_5787] = _5786;
      {
        for(;((_5786 < nnz) && (((*subi)(_5786)) == _5787));++ _5786)
        {
          {
          }
        }
      }
    }
  }
  _ptr__5785[dimi] = _5786;
  return _5785;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5788 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _5788->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _5788->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _9610 = (int)1;
      int _9611 = (int)((subi)->size(0));
      for (int _5789 = _9610; _5789 < _9611; ++_5789)
      {
        {
          _5788->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_5789)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_5789)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_5789)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _5788->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _5788->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _5790 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__5790(_5790 ? _5790->raw() : nullptr,_5790 ? _5790->size(0) : 0);
  int _9612 = (int)0;
  int _9613 = (int)((subi)->size(0));
  for (int _5791 = _9612; _5791 < _9613; ++_5791)
  {
    {
      _ptr__5790[safe_add( safe_mul( ((*subi)(_5791)),dimj ),((*subj)(_5791)) )] = ((*val)(_5791));
    }
  }
  return _5790;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5792,std::shared_ptr< monty::ndarray< int,1 > > _5793,std::shared_ptr< monty::ndarray< double,1 > > _5794) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_5792,_5793,_5794); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5792,std::shared_ptr< monty::ndarray< int,1 > > _5793,std::shared_ptr< monty::ndarray< double,1 > > _5794){
  _checked_ptr_1<int> _ptr__5792(_5792 ? _5792->raw() : nullptr, _5792 ? _5792->size(0) : 0);
  _checked_ptr_1<int> _ptr__5793(_5793 ? _5793->raw() : nullptr, _5793 ? _5793->size(0) : 0);
  _checked_ptr_1<double> _ptr__5794(_5794 ? _5794->raw() : nullptr, _5794 ? _5794->size(0) : 0);
  if ((((long long)((_5792)->size(0)) < nnz) || (((long long)((_5793)->size(0)) < nnz) || ((long long)((_5794)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_5792,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_5793,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_5794,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _5795,int _5796) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_5795,_5796); }double mosek::fusion::p_SparseMatrix::get(int _5795,int _5796){
  if (((_5795 < (int)0) || ((_5795 >= dimi) || ((_5796 < (int)0) || (_5796 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _5797 = (int)((subi)->size(0));
  int _5798 = (int)0;
  while ( ((_5797 - _5798) > (int)1) )
  {
    {
      int _5799 = (safe_add( _5798,_5797 ) / (int)2);
      if (((((*subi)(_5799)) < _5795) || ((((*subi)(_5799)) == _5795) && (((*subj)(_5799)) < _5796))))
      {
        {
          _5798 = _5799;
        }
      }
      else if(((((*subi)(_5799)) > _5795) || ((((*subi)(_5799)) == _5795) && (((*subj)(_5799)) > _5796))))
      {
        {
          _5797 = _5799;
        }
      }
      else
      {
        {
          return ((*val)(_5799));
        }
      }
    }
  }
  if (((((*subi)(_5798)) == _5795) && (((*subj)(_5798)) == _5796)))
  {
    {
      return ((*val)(_5798));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _5800,    int _5801){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_5800 < (int)0) || (_5801 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _5800;
    dimj = _5801;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _5802 = dimi;
  dimi = dimj;
  dimj = _5802;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5803,    monty::rc_ptr< ::mosek::fusion::Matrix > _5804) { return mosek::fusion::p_Matrix::diag(_5803,_5804); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5803,monty::rc_ptr< ::mosek::fusion::Matrix > _5804){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _9614;
  for (int _5805 = (int)0, _9615 = _5803; _5805 < _9615 ; ++_5805)
  {
    _9614.push_back(_5804);
  }
  auto _9616 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_9614.size()),_9614.begin(),_9614.end()));
  return ::mosek::fusion::p_Matrix::diag(_9616);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5806) { return mosek::fusion::p_Matrix::diag(_5806); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5806){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5807 = _5806;
  long long _5808 = (long long)0;
  int _5809 = (int)0;
  int _5810 = (int)0;
  int _9617 = (int)0;
  int _9618 = (int)((_5806)->size(0));
  for (int _5811 = _9617; _5811 < _9618; ++_5811)
  {
    {
      _5810 = safe_add( _5810,mosek::fusion::p_Matrix::_get_impl(((*_5806)(_5811)))->dimi );
      _5809 = safe_add( _5809,mosek::fusion::p_Matrix::_get_impl(((*_5806)(_5811)))->dimj );
      _5808 = safe_add( _5808,((*_5806)(_5811))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5812 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5808)));
  _checked_ptr_1<int> _ptr__5812(_5812 ? _5812->raw() : nullptr,_5812 ? _5812->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5813 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5808)));
  _checked_ptr_1<int> _ptr__5813(_5813 ? _5813->raw() : nullptr,_5813 ? _5813->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5814 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5808)));
  _checked_ptr_1<double> _ptr__5814(_5814 ? _5814->raw() : nullptr,_5814 ? _5814->size(0) : 0);
  {
    int _5815 = (int)0;
    int _5816 = (int)0;
    long long _5817 = (long long)0;
    int _9619 = (int)0;
    int _9620 = (int)((_5806)->size(0));
    for (int _5818 = _9619; _5818 < _9620; ++_5818)
    {
      {
        long long _5819 = ((*_5806)(_5818))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _5820 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5819)));
        _checked_ptr_1<double> _ptr__5820(_5820 ? _5820->raw() : nullptr,_5820 ? _5820->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5821 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5819)));
        _checked_ptr_1<int> _ptr__5821(_5821 ? _5821->raw() : nullptr,_5821 ? _5821->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _5822 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5819)));
        _checked_ptr_1<int> _ptr__5822(_5822 ? _5822->raw() : nullptr,_5822 ? _5822->size(0) : 0);
        ((*_5806)(_5818))->getDataAsTriplets(_5822,_5821,_5820);
        ::mosek::fusion::Utils::Tools::arraycopy(_5820,(long long)0,_5814,_5817,_5819);
        long long _9621 = (long long)0;
        long long _9622 = _5819;
        for (long long _5823 = _9621; _5823 < _9622; ++_5823)
        {
          {
            _ptr__5812[safe_add( _5817,_5823 )] = safe_add( _ptr__5822[_5823],_5816 );
            _ptr__5813[safe_add( _5817,_5823 )] = safe_add( _ptr__5822[_5823],_5815 );
          }
        }
        _5817 = safe_add( _5817,_5819 );
        _5816 = safe_add( _5816,mosek::fusion::p_Matrix::_get_impl(((*_5806)(_5818)))->dimi );
        _5815 = safe_add( _5815,mosek::fusion::p_Matrix::_get_impl(((*_5806)(_5818)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5810,_5809,_5812,_5813,_5814)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5824,    double _5825,    int _5826) { return mosek::fusion::p_Matrix::antidiag(_5824,_5825,_5826); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5824,double _5825,int _5826){
  if (((_5826 < _5824) && (_5826 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5825,(_5824 - _5826)),_5826);
    }
  }
  else if(((_5826 > (-_5824)) && (_5826 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5825,safe_add( _5824,_5826 )),_5826);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _5827,    double _5828) { return mosek::fusion::p_Matrix::antidiag(_5827,_5828); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _5827,double _5828){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_5828,_5827),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5829,    double _5830,    int _5831) { return mosek::fusion::p_Matrix::diag(_5829,_5830,_5831); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5829,double _5830,int _5831){
  if (((_5831 < _5829) && (_5831 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5830,(_5829 - _5831)),_5831);
    }
  }
  else if(((_5831 > (-_5829)) && (_5831 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5830,safe_add( _5829,_5831 )),_5831);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _5832,    double _5833) { return mosek::fusion::p_Matrix::diag(_5832,_5833); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _5832,double _5833){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_5833,_5832),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5834,    int _5835) { return mosek::fusion::p_Matrix::antidiag(_5834,_5835); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5834,int _5835){
  _checked_ptr_1<double> _ptr__5834(_5834 ? _5834->raw() : nullptr, _5834 ? _5834->size(0) : 0);
  int _9623;
  bool _9624 = (_5835 > (int)0);
  if (_9624)
  {
    _9623 = _5835;
  }
  else
  {
    _9623 = (-_5835);
  }
  int _5836 = _9623;
  int _5837 = safe_add( (int)((_5834)->size(0)),_5836 );
  int _5838 = (int)((_5834)->size(0));
  if ((_5835 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5839 = ::mosek::fusion::Utils::Tools::range(_5835,safe_add( _5838,_5835 ));
      _checked_ptr_1<int> _ptr__5839(_5839 ? _5839->raw() : nullptr,_5839 ? _5839->size(0) : 0);
      std::vector<int> _9625;
      for (int _5841 = (int)1, _9626 = safe_add( _5838,(int)1 ); _5841 < _9626 ; ++_5841)
      {
        _9625.push_back((safe_add( _5838,_5835 ) - _5841));
      }
      auto _9627 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9625.size()),_9625.begin(),_9625.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5840 = _9627;
      _checked_ptr_1<int> _ptr__5840(_5840 ? _5840->raw() : nullptr,_5840 ? _5840->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5837,_5837,_5839,_5840,_5834)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5842 = ::mosek::fusion::Utils::Tools::range((int)0,_5838);
      _checked_ptr_1<int> _ptr__5842(_5842 ? _5842->raw() : nullptr,_5842 ? _5842->size(0) : 0);
      std::vector<int> _9628;
      for (int _5844 = (int)1, _9629 = safe_add( _5838,(int)1 ); _5844 < _9629 ; ++_5844)
      {
        _9628.push_back((_5838 - _5844));
      }
      auto _9630 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9628.size()),_9628.begin(),_9628.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _5843 = _9630;
      _checked_ptr_1<int> _ptr__5843(_5843 ? _5843->raw() : nullptr,_5843 ? _5843->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5837,_5837,_5842,_5843,_5834)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _5845) { return mosek::fusion::p_Matrix::antidiag(_5845); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5845){
  _checked_ptr_1<double> _ptr__5845(_5845 ? _5845->raw() : nullptr, _5845 ? _5845->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_5845,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5846,    int _5847) { return mosek::fusion::p_Matrix::diag(_5846,_5847); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5846,int _5847){
  _checked_ptr_1<double> _ptr__5846(_5846 ? _5846->raw() : nullptr, _5846 ? _5846->size(0) : 0);
  int _9631;
  bool _9632 = (_5847 > (int)0);
  if (_9632)
  {
    _9631 = _5847;
  }
  else
  {
    _9631 = (-_5847);
  }
  int _5848 = _9631;
  int _5849 = safe_add( (int)((_5846)->size(0)),_5848 );
  int _5850 = (int)((_5846)->size(0));
  if ((_5847 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5851 = ::mosek::fusion::Utils::Tools::range((int)0,_5850);
      _checked_ptr_1<int> _ptr__5851(_5851 ? _5851->raw() : nullptr,_5851 ? _5851->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5852 = ::mosek::fusion::Utils::Tools::range(_5848,safe_add( _5850,_5848 ));
      _checked_ptr_1<int> _ptr__5852(_5852 ? _5852->raw() : nullptr,_5852 ? _5852->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5849,_5849,_5851,_5852,_5846)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5853 = ::mosek::fusion::Utils::Tools::range(_5848,safe_add( _5850,_5848 ));
      _checked_ptr_1<int> _ptr__5853(_5853 ? _5853->raw() : nullptr,_5853 ? _5853->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5854 = ::mosek::fusion::Utils::Tools::range((int)0,_5850);
      _checked_ptr_1<int> _ptr__5854(_5854 ? _5854->raw() : nullptr,_5854 ? _5854->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5849,_5849,_5853,_5854,_5846)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _5855) { return mosek::fusion::p_Matrix::diag(_5855); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _5855){
  _checked_ptr_1<double> _ptr__5855(_5855 ? _5855->raw() : nullptr, _5855 ? _5855->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_5855,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _5856,    int _5857) { return mosek::fusion::p_Matrix::ones(_5856,_5857); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _5856,int _5857){
  return ::mosek::fusion::p_Matrix::dense(_5856,_5857,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _5858) { return mosek::fusion::p_Matrix::eye(_5858); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _5858){
  std::vector<double> _9633;
  for (int _5859 = (int)0, _9634 = _5858; _5859 < _9634 ; ++_5859)
  {
    _9633.push_back(1.0);
  }
  auto _9635 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9633.size()),_9633.begin(),_9633.end()));
  return ::mosek::fusion::p_Matrix::diag(_9635);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5860) { return mosek::fusion::p_Matrix::dense(_5860); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5860){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5860)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5861,    int _5862,    double _5863) { return mosek::fusion::p_Matrix::dense(_5861,_5862,_5863); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5861,int _5862,double _5863){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5861,_5862,_5863)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _5864,    int _5865,    std::shared_ptr< monty::ndarray< double,1 > > _5866) { return mosek::fusion::p_Matrix::dense(_5864,_5865,_5866); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _5864,int _5865,std::shared_ptr< monty::ndarray< double,1 > > _5866){
  _checked_ptr_1<double> _ptr__5866(_5866 ? _5866->raw() : nullptr, _5866 ? _5866->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5864,_5865,_5866)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _5867) { return mosek::fusion::p_Matrix::dense(_5867); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _5867){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_5867)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _5868) { return mosek::fusion::p_Matrix::sparse(_5868); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5868){
  std::shared_ptr< monty::ndarray< int,1 > > _5869 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5868->numNonzeros())));
  _checked_ptr_1<int> _ptr__5869(_5869 ? _5869->raw() : nullptr,_5869 ? _5869->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5870 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5868->numNonzeros())));
  _checked_ptr_1<int> _ptr__5870(_5870 ? _5870->raw() : nullptr,_5870 ? _5870->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5871 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5868->numNonzeros())));
  _checked_ptr_1<double> _ptr__5871(_5871 ? _5871->raw() : nullptr,_5871 ? _5871->size(0) : 0);
  _5868->getDataAsTriplets(_5869,_5870,_5871);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5868->numRows(),_5868->numColumns(),_5869,_5870,_5871)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5872) { return mosek::fusion::p_Matrix::sparse(_5872); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5872){
  int _5873 = (int)((_5872)->size(0));
  int _5874 = (int)((((*_5872)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5875 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5873)));
  _checked_ptr_1<int> _ptr__5875(_5875 ? _5875->raw() : nullptr,_5875 ? _5875->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5876 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5874)));
  _checked_ptr_1<int> _ptr__5876(_5876 ? _5876->raw() : nullptr,_5876 ? _5876->size(0) : 0);
  long long _5877 = (long long)0;
  int _5878 = (int)0;
  {
    int _5879 = (int)0;
    for(;(_5879 < _5873);++ _5879)
    {
      {
        {
          int _5880 = (int)0;
          for(;(_5880 < _5874);++ _5880)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _5881 = ((*((*_5872)(_5879)))(_5880));
              if ((NULL != _5881.get()))
              {
                {
                  if ((_ptr__5876[_5880] == (int)0))
                  {
                    {
                      _ptr__5876[_5880] = mosek::fusion::p_Matrix::_get_impl(_5881)->dimj;
                    }
                  }
                  else if((_ptr__5876[_5880] != mosek::fusion::p_Matrix::_get_impl(_5881)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__5875[_5879] == (int)0))
                  {
                    {
                      _ptr__5875[_5879] = mosek::fusion::p_Matrix::_get_impl(_5881)->dimi;
                    }
                  }
                  else if((_ptr__5875[_5879] != mosek::fusion::p_Matrix::_get_impl(_5881)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _5877 = safe_add( _5877,_5881->numNonzeros() );
                }
              }
              {}
              ++ _5878;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5882 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_5877)));
  _checked_ptr_1<double> _ptr__5882(_5882 ? _5882->raw() : nullptr,_5882 ? _5882->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5883 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5877)));
  _checked_ptr_1<int> _ptr__5883(_5883 ? _5883->raw() : nullptr,_5883 ? _5883->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5884 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5877)));
  _checked_ptr_1<int> _ptr__5884(_5884 ? _5884->raw() : nullptr,_5884 ? _5884->size(0) : 0);
  int _5885 = (int)0;
  int _5886 = (int)0;
  {
    int _5887 = (int)0;
    for(;(_5887 < _5873);++ _5887)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _5888 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5874)));
        _checked_ptr_1<int> _ptr__5888(_5888 ? _5888->raw() : nullptr,_5888 ? _5888->size(0) : 0);
        {
          int _5889 = (int)0;
          for(;(_5889 < _ptr__5875[_5887]);++ _5889)
          {
            {
              int _5890 = (int)0;
              {
                int _5891 = (int)0;
                for(;(_5891 < _5874);++ _5891)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _5892 = ((*((*_5872)(_5887)))(_5891));
                    if ((NULL != _5892.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _9636 = _5892;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_9636.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _5893 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_9636.get()));
                          {
                            int _5896 = _ptr__5888[_5891];
                            {
                              int _5897 = (int)0;
                              for(;(_5897 < mosek::fusion::p_Matrix::_get_impl(_5893)->dimj);++ _5897)
                              {
                                {
                                  _ptr__5882[_5885] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_5893)->data)(_5896));
                                  _ptr__5883[_5885] = safe_add( _5886,_5889 );
                                  _ptr__5884[_5885] = safe_add( _5890,_5897 );
                                  ++ _5896;
                                  ++ _5885;
                                }
                              }
                            }
                            _ptr__5888[_5891] = _5896;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_9636.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _5894 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_9636.get()));
                          {
                            int _5898;
                            {
                              _5898 = _ptr__5888[_5891];
                              for(;((_5898 < mosek::fusion::p_SparseMatrix::_get_impl(_5894)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_5894)->subi)(_5898)) == _5889));++ _5898)
                              {
                                {
                                  _ptr__5882[_5885] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_5894)->val)(_5898));
                                  _ptr__5884[_5885] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_5894)->subj)(_5898)),_5890 );
                                  _ptr__5883[_5885] = safe_add( _5886,_5889 );
                                  ++ _5885;
                                }
                              }
                            }
                            _ptr__5888[_5891] = _5898;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _5895 = _9636;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _5890 = safe_add( _5890,_ptr__5876[_5891] );
                  }
                }
              }
            }
          }
        }
        _5886 = safe_add( _5886,_ptr__5875[_5887] );
      }
    }
  }
  int _5899 = (int)0;
  int _5900 = (int)0;
  {
    int _5901 = (int)0;
    for(;(_5901 < _5873);++ _5901)
    {
      {
        _5899 = safe_add( _5899,_ptr__5875[_5901] );
      }
    }
  }
  {
    int _5902 = (int)0;
    for(;(_5902 < _5874);++ _5902)
    {
      {
        _5900 = safe_add( _5900,_ptr__5876[_5902] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5899,_5900,_5883,_5884,_5882)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _5903) { return mosek::fusion::p_Matrix::sparse(_5903); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _5903){
  int _5904 = (int)((_5903)->size(0));
  int _5905 = (int)((_5903)->size(1));
  long long _5906 = (long long)safe_mul( _5904,_5905 );
  std::vector<int> _9637;
  for (int _5908 = (int)0, _9638 = _5904; _5908 < _9638 ; ++_5908)
  {
    for (int _5909 = (int)0, _9639 = _5905; _5909 < _9639 ; ++_5909)
    {
      _9637.push_back(_5908);
    }
  }
  auto _9640 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9637.size()),_9637.begin(),_9637.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5907 = _9640;
  _checked_ptr_1<int> _ptr__5907(_5907 ? _5907->raw() : nullptr,_5907 ? _5907->size(0) : 0);
  std::vector<int> _9641;
  for (int _5911 = (int)0, _9642 = _5904; _5911 < _9642 ; ++_5911)
  {
    for (int _5912 = (int)0, _9643 = _5905; _5912 < _9643 ; ++_5912)
    {
      _9641.push_back(_5912);
    }
  }
  auto _9644 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9641.size()),_9641.begin(),_9641.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _5910 = _9644;
  _checked_ptr_1<int> _ptr__5910(_5910 ? _5910->raw() : nullptr,_5910 ? _5910->size(0) : 0);
  std::vector<double> _9645;
  for (int _5914 = (int)0, _9646 = _5904; _5914 < _9646 ; ++_5914)
  {
    for (int _5915 = (int)0, _9647 = _5905; _5915 < _9647 ; ++_5915)
    {
      _9645.push_back(((*_5903)(_5914,_5915)));
    }
  }
  auto _9648 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9645.size()),_9645.begin(),_9645.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _5913 = _9648;
  _checked_ptr_1<double> _ptr__5913(_5913 ? _5913->raw() : nullptr,_5913 ? _5913->size(0) : 0);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5904,_5905,_5907,_5910,_5913)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5916,    int _5917) { return mosek::fusion::p_Matrix::sparse(_5916,_5917); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5916,int _5917){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5916,_5917,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5918,    int _5919,    std::shared_ptr< monty::ndarray< int,1 > > _5920,    std::shared_ptr< monty::ndarray< int,1 > > _5921,    double _5922) { return mosek::fusion::p_Matrix::sparse(_5918,_5919,_5920,_5921,_5922); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5918,int _5919,std::shared_ptr< monty::ndarray< int,1 > > _5920,std::shared_ptr< monty::ndarray< int,1 > > _5921,double _5922){
  _checked_ptr_1<int> _ptr__5920(_5920 ? _5920->raw() : nullptr, _5920 ? _5920->size(0) : 0);
  _checked_ptr_1<int> _ptr__5921(_5921 ? _5921->raw() : nullptr, _5921 ? _5921->size(0) : 0);
  int _5923 = (int)0;
  if ((NULL != _5920.get()))
  {
    {
      _5923 = (int)((_5920)->size(0));
    }
  }
  else if((NULL != _5921.get()))
  {
    {
      _5923 = (int)((_5921)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_5918,_5919,_5920,_5921,::mosek::fusion::Utils::Tools::makevector(_5922,_5923));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5924,    std::shared_ptr< monty::ndarray< int,1 > > _5925,    double _5926) { return mosek::fusion::p_Matrix::sparse(_5924,_5925,_5926); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5924,std::shared_ptr< monty::ndarray< int,1 > > _5925,double _5926){
  _checked_ptr_1<int> _ptr__5924(_5924 ? _5924->raw() : nullptr, _5924 ? _5924->size(0) : 0);
  _checked_ptr_1<int> _ptr__5925(_5925 ? _5925->raw() : nullptr, _5925 ? _5925->size(0) : 0);
  int _5927 = (int)0;
  int _5928 = (int)0;
  int _5929 = (int)((_5924)->size(0));
  if ((_5929 > (int)((_5925)->size(0))))
  {
    {
      _5929 = (int)((_5925)->size(0));
    }
  }
  {}
  int _9649 = (int)0;
  int _9650 = _5929;
  for (int _5930 = _9649; _5930 < _9650; ++_5930)
  {
    {
      if ((_5928 < _ptr__5924[_5930]))
      {
        {
          _5928 = _ptr__5924[_5930];
        }
      }
      {}
      if ((_5927 < _ptr__5925[_5930]))
      {
        {
          _5927 = _ptr__5925[_5930];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5928,(int)1 ),safe_add( _5927,(int)1 ),_5924,_5925,_5926);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _5931,    std::shared_ptr< monty::ndarray< int,1 > > _5932,    std::shared_ptr< monty::ndarray< double,1 > > _5933) { return mosek::fusion::p_Matrix::sparse(_5931,_5932,_5933); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _5931,std::shared_ptr< monty::ndarray< int,1 > > _5932,std::shared_ptr< monty::ndarray< double,1 > > _5933){
  _checked_ptr_1<int> _ptr__5931(_5931 ? _5931->raw() : nullptr, _5931 ? _5931->size(0) : 0);
  _checked_ptr_1<int> _ptr__5932(_5932 ? _5932->raw() : nullptr, _5932 ? _5932->size(0) : 0);
  _checked_ptr_1<double> _ptr__5933(_5933 ? _5933->raw() : nullptr, _5933 ? _5933->size(0) : 0);
  int _5934 = (int)0;
  int _5935 = (int)0;
  int _5936 = (int)((_5931)->size(0));
  if ((_5936 > (int)((_5932)->size(0))))
  {
    {
      _5936 = (int)((_5932)->size(0));
    }
  }
  {}
  if ((_5936 > (int)((_5933)->size(0))))
  {
    {
      _5936 = (int)((_5933)->size(0));
    }
  }
  {}
  int _9651 = (int)0;
  int _9652 = _5936;
  for (int _5937 = _9651; _5937 < _9652; ++_5937)
  {
    {
      if ((_5935 < _ptr__5931[_5937]))
      {
        {
          _5935 = _ptr__5931[_5937];
        }
      }
      {}
      if ((_5934 < _ptr__5932[_5937]))
      {
        {
          _5934 = _ptr__5932[_5937];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _5935,(int)1 ),safe_add( _5934,(int)1 ),_5931,_5932,_5933);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _5938,    int _5939,    std::shared_ptr< monty::ndarray< int,1 > > _5940,    std::shared_ptr< monty::ndarray< int,1 > > _5941,    std::shared_ptr< monty::ndarray< double,1 > > _5942) { return mosek::fusion::p_Matrix::sparse(_5938,_5939,_5940,_5941,_5942); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _5938,int _5939,std::shared_ptr< monty::ndarray< int,1 > > _5940,std::shared_ptr< monty::ndarray< int,1 > > _5941,std::shared_ptr< monty::ndarray< double,1 > > _5942){
  _checked_ptr_1<int> _ptr__5940(_5940 ? _5940->raw() : nullptr, _5940 ? _5940->size(0) : 0);
  _checked_ptr_1<int> _ptr__5941(_5941 ? _5941->raw() : nullptr, _5941 ? _5941->size(0) : 0);
  _checked_ptr_1<double> _ptr__5942(_5942 ? _5942->raw() : nullptr, _5942 ? _5942->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _9653;
  bool _9654 = (NULL != _5942.get());
  if (_9654)
  {
    _9653 = _5942;
  }
  else
  {
    _9653 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _5943 = _9653;
  _checked_ptr_1<double> _ptr__5943(_5943 ? _5943->raw() : nullptr,_5943 ? _5943->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9655;
  bool _9656 = (NULL != _5941.get());
  if (_9656)
  {
    _9655 = _5941;
  }
  else
  {
    _9655 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5944 = _9655;
  _checked_ptr_1<int> _ptr__5944(_5944 ? _5944->raw() : nullptr,_5944 ? _5944->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _9657;
  bool _9658 = (NULL != _5940.get());
  if (_9658)
  {
    _9657 = _5940;
  }
  else
  {
    _9657 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _5945 = _9657;
  _checked_ptr_1<int> _ptr__5945(_5945 ? _5945->raw() : nullptr,_5945 ? _5945->size(0) : 0);
  long long _5946 = (long long)((_5945)->size(0));
  if ((((long long)((_5944)->size(0)) != _5946) || ((long long)((_5943)->size(0)) != _5946)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_5938,_5939,_5945,_5944,_5943,_5946)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _5952) : RuntimeException(_5952)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _5953) : RuntimeException(_5953)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _5954) : RuntimeException(_5954.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _5955) : RuntimeException(_5955)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _5956) : mosek::fusion::FusionRuntimeException(_5956)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _5957) : mosek::fusion::FusionException(_5957)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _5958) : mosek::fusion::FusionRuntimeException(_5958)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _5959) : mosek::fusion::FusionRuntimeException(_5959)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _5960) : mosek::fusion::FusionRuntimeException(_5960)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _5961) : mosek::fusion::FusionRuntimeException(_5961)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _5962) : mosek::fusion::FusionRuntimeException(_5962)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _5963) : mosek::fusion::FusionRuntimeException(_5963)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _5964) : mosek::fusion::FusionRuntimeException(_5964)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _5965) : mosek::fusion::FusionRuntimeException(_5965)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _5966) : mosek::fusion::FusionRuntimeException(_5966)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _5967) : mosek::fusion::FusionRuntimeException(_5967)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _5968) : mosek::fusion::FusionRuntimeException(_5968)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _5969) : mosek::fusion::FusionRuntimeException(_5969)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _5970) : mosek::fusion::FusionRuntimeException(_5970)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _5971) : mosek::fusion::FusionRuntimeException(_5971)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _5972) : mosek::fusion::FusionRuntimeException(_5972)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _5973) : RuntimeException(_5973)  {
    msg = _5973;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _5974) : Exception(_5974)  {
    msg = _5974;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _5975){ return new mosek::fusion::LinkedBlocks(_5975); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _5975) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5975); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _5975){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_5975);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5976){ return new mosek::fusion::LinkedBlocks(_5976); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5976) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_5976); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5976){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5976)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_5976)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5976)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_5976)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _5977) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_5977); }void mosek::fusion::p_LinkedBlocks::free(int _5977){
  int _5978 = ((*bfirst)(_5977));
  ints->free(_5977,((*bsize)(_5977)));
  ((*bsize)(_5977)) = (-(int)1);
  ((*bfirst)(_5977)) = (-(int)1);
  blocks->free(_5978,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _5979) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_5979); }int mosek::fusion::p_LinkedBlocks::alloc(int _5979){
  int _9659;
  bool _9660 = (_5979 > (int)0);
  if (_9660)
  {
    _9659 = ints->alloc(_5979);
  }
  else
  {
    _9659 = (-(int)1);
  }
  int _5980 = _9659;
  int _5981 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _5982 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5982(_5982 ? _5982->raw() : nullptr,_5982 ? _5982->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5983 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__5983(_5983 ? _5983->raw() : nullptr,_5983 ? _5983->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_5982,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_5983,(int)0,(int)((bfirst)->size(0)));
      bsize = _5982;
      bfirst = _5983;
    }
  }
  {}
  ((*bfirst)(_5981)) = _5980;
  ((*bsize)(_5981)) = _5979;
  return _5981;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _5984) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_5984); }int mosek::fusion::p_LinkedBlocks::maxidx(int _5984){
  return ints->maxidx(((*bfirst)(_5984)),((*bsize)(_5984)));
}
void mosek::fusion::LinkedBlocks :: get(int _5985,std::shared_ptr< monty::ndarray< int,1 > > _5986,int _5987) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_5985,_5986,_5987); }void mosek::fusion::p_LinkedBlocks::get(int _5985,std::shared_ptr< monty::ndarray< int,1 > > _5986,int _5987){
  _checked_ptr_1<int> _ptr__5986(_5986 ? _5986->raw() : nullptr, _5986 ? _5986->size(0) : 0);
  ints->get(((*bfirst)(_5985)),((*bsize)(_5985)),_5986,_5987);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _5988) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_5988); }int mosek::fusion::p_LinkedBlocks::blocksize(int _5988){
  return ((*bsize)(_5988));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _5989){ return new mosek::fusion::LinkedInts(_5989); }mosek::fusion::LinkedInts::LinkedInts  (int _5989) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5989); }void mosek::fusion::p_LinkedInts::_initialize  (int _5989){monty::rc_reserve __reserve_this(_pubthis);   {
    int _9661;
    bool _9662 = (_5989 > (int)0);
    if (_9662)
    {
      _9661 = _5989;
    }
    else
    {
      _9661 = (int)128;
    }
    int _5990 = _9661;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5990)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_5990)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_5990 - (int)1);
    int _9663 = (int)1;
    int _9664 = _5990;
    for (int _5991 = _9663; _5991 < _9664; ++_5991)
    {
      {
        ((*prev)(_5991)) = (_5991 - (int)1);
        ((*next)((_5991 - (int)1))) = _5991;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_5990 - (int)1))) = (-(int)1);
    nfree = _5990;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5992){ return new mosek::fusion::LinkedInts(_5992); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5992) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_5992); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _5992){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5992)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_5992)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_5992)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_5992)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_5992)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_5992)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _5993,int _5994) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_5993,_5994); }void mosek::fusion::p_LinkedInts::free(int _5993,int _5994){
  int _5995 = _5993;
  int _5996 = _5995;
  int _9665 = (int)0;
  int _9666 = (_5994 - (int)1);
  for (int _5997 = _9665; _5997 < _9666; ++_5997)
  {
    {
      _5996 = ((*next)(_5996));
    }
  }
  int _5998 = ((*prev)(_5995));
  int _5999 = ((*next)(_5996));
  if ((_5998 >= (int)0))
  {
    {
      ((*next)(_5998)) = _5999;
    }
  }
  {}
  if ((_5999 >= (int)0))
  {
    {
      ((*prev)(_5999)) = _5998;
    }
  }
  {}
  ((*prev)(_5995)) = (-(int)1);
  ((*next)(_5996)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _5996;
    }
  }
  {}
  first_free = _5995;
  nfree += _5994;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _6000) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6000); }int mosek::fusion::p_LinkedInts::alloc(int _6000){
  return allocblock(_6000);
}
void mosek::fusion::LinkedInts :: alloc(int _6001,std::shared_ptr< monty::ndarray< int,1 > > _6002,int _6003) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_6001,_6002,_6003); }void mosek::fusion::p_LinkedInts::alloc(int _6001,std::shared_ptr< monty::ndarray< int,1 > > _6002,int _6003){
  _checked_ptr_1<int> _ptr__6002(_6002 ? _6002->raw() : nullptr, _6002 ? _6002->size(0) : 0);
  int _6004 = allocblock(_6001);
  int _9667 = (int)0;
  int _9668 = _6001;
  for (int _6005 = _9667; _6005 < _9668; ++_6005)
  {
    {
      _ptr__6002[safe_add( _6005,_6003 )] = _6004;
      _6004 = ((*next)(_6004));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _6006,int _6007,std::shared_ptr< monty::ndarray< int,1 > > _6008,int _6009) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_6006,_6007,_6008,_6009); }void mosek::fusion::p_LinkedInts::get(int _6006,int _6007,std::shared_ptr< monty::ndarray< int,1 > > _6008,int _6009){
  _checked_ptr_1<int> _ptr__6008(_6008 ? _6008->raw() : nullptr, _6008 ? _6008->size(0) : 0);
  int _6010 = _6006;
  int _9669 = (int)0;
  int _9670 = _6007;
  for (int _6011 = _9669; _6011 < _9670; ++_6011)
  {
    {
      _ptr__6008[safe_add( _6011,_6009 )] = _6010;
      _6010 = ((*next)(_6010));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _6012,int _6013) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_6012,_6013); }int mosek::fusion::p_LinkedInts::maxidx(int _6012,int _6013){
  int _6014 = _6012;
  int _6015 = _6012;
  int _9671 = (int)1;
  int _9672 = _6013;
  for (int _6016 = _9671; _6016 < _9672; ++_6016)
  {
    {
      _6015 = ((*next)(_6015));
      if ((_6014 < _6015))
      {
        {
          _6014 = _6015;
        }
      }
      {}
    }
  }
  return _6014;
}
int mosek::fusion::p_LinkedInts::allocblock(int _6017){
  int _6018 = (int)((next)->size(0));
  if ((nfree < _6017))
  {
    {
      int _6019 = (_6017 - nfree);
      if ((_6019 < _6018))
      {
        {
          _6019 = _6018;
        }
      }
      {}
      recap(safe_add( _6019,_6018 ));
    }
  }
  {}
  int _6020 = first_free;
  int _6021 = _6020;
  int _9673 = (int)0;
  int _9674 = (_6017 - (int)1);
  for (int _6022 = _9673; _6022 < _9674; ++_6022)
  {
    {
      _6021 = ((*next)(_6021));
    }
  }
  first_free = ((*next)(_6021));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_6021)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _6021;
    }
  }
  {}
  first_used = _6020;
  nfree -= _6017;
  return _6020;
}
void mosek::fusion::p_LinkedInts::recap(int _6023){
  int _6024 = (int)((next)->size(0));
  if ((_6023 > _6024))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_6023);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_6023);
      int _9675 = _6024;
      int _9676 = (_6023 - (int)1);
      for (int _6025 = _9675; _6025 < _9676; ++_6025)
      {
        {
          ((*next)(_6025)) = safe_add( _6025,(int)1 );
          ((*prev)(safe_add( _6025,(int)1 ))) = _6025;
        }
      }
      ((*next)((_6023 - (int)1))) = (-(int)1);
      ((*prev)(_6024)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _6024;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _6024;
        }
      }
      last_free = (_6023 - (int)1);
      nfree += (_6023 - _6024);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _6026 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _6027 = first_used;
  while ( (_6027 >= (int)0) )
  {
    {
      ((*_6026)(_6027)) = true;
      _6027 = ((*next)(_6027));
      if (((_6027 >= (int)0) && ((*_6026)(_6027))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _6027 = first_free;
  int _6028 = (int)0;
  while ( (_6027 >= (int)0) )
  {
    {
      ++ _6028;
      ((*_6026)(_6027)) = true;
      _6027 = ((*next)(_6027));
      if (((_6027 >= (int)0) && ((*_6026)(_6027))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6028 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _9677 = (int)0;
  int _9678 = (int)((_6026)->size(0));
  for (int _6029 = _9677; _6029 < _9678; ++_6029)
  {
    {
      if ((!((*_6026)(_6027))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _9679 = (int)0;
  int _9680 = (int)((_6026)->size(0));
  for (int _6030 = _9679; _6030 < _9680; ++_6030)
  {
    {
      ((*_6026)(_6030)) = false;
    }
  }
  _6027 = last_free;
  int _6031 = (int)0;
  while ( (_6027 >= (int)0) )
  {
    {
      ++ _6031;
      ((*_6026)(_6027)) = true;
      _6027 = ((*prev)(_6027));
      if (((_6027 >= (int)0) && ((*_6026)(_6027))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_6031 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6032,    const std::string & _6033,    double _6034) { mosek::fusion::p_Parameters::setParameter(_6032,_6033,_6034); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6032,const std::string & _6033,double _6034){
  if (false)
  {
    {
    }
  }
  else if((_6033 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6033 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6033 == std::string ("numThreads")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6035 = _6034;
          if (((int)0 <= _6035))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6035);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6033 == std::string ("mtSpincount")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6036 = _6034;
          if ((((int)0 <= _6036) && (_6036 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6036);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6033 == std::string ("biMaxIterations")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6037 = _6034;
          if (((int)0 <= _6037))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6037);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6038 = _6034;
          if (((int)0 <= _6038))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6038);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6039 = _6034;
          if (((int)0 <= _6039))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6039);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logResponse")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6040 = _6034;
          if (((int)0 <= _6040))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6040);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6033 == std::string ("logBi")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6041 = _6034;
          if (((int)0 <= _6041))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6041);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logBiFreq")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6042 = _6034;
          if (((int)0 <= _6042))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6042);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6033 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6033 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6033 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6033 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6033 == std::string ("logIntpnt")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6043 = _6034;
          if (((int)0 <= _6043))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6043);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6044 = _6034;
          if (((int)0 <= _6044))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6044);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6045 = _6034;
          if (((int)0 <= _6045))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6045);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  else if((_6033 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6033 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6033 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6033 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6046 = _6034;
          if (((-(int)1) <= _6046))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6046);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6033 == std::string ("presolveLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6047 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6047);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logPresolve")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6048 = _6034;
          if (((int)0 <= _6048))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6048);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6033 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6049 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6049);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6050 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6050);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6051 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6051);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simPrimalCrash")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6052 = _6034;
          if (((int)0 <= _6052))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6052);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logSim")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6053 = _6034;
          if (((int)0 <= _6053))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6053);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logSimMinor")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6054 = _6034;
          if (((int)0 <= _6054))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6054);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logSimFreq")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6055 = _6034;
          if (((int)0 <= _6055))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6055);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6056 = _6034;
          if ((((int)0 <= _6056) && (_6056 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6056);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6033 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6057 = _6034;
          if ((((int)0 <= _6057) && (_6057 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6057);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6033 == std::string ("simMaxIterations")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6058 = _6034;
          if (((int)0 <= _6058))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6058);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6033 == std::string ("simRefactorFreq")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6059 = _6034;
          if (((int)0 <= _6059))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6059);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simSeed")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6060 = _6034;
          if ((((int)0 <= _6060) && (_6060 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6060);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6033 == std::string ("logMio")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6061 = _6034;
          if (((int)0 <= _6061))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6061);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logMioFreq")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6062 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6062);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6063 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6063);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6064 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6064);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6065 = _6034;
          if (((int)0 <= _6065))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6065);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6066 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6066);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6033 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6067 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6067);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioProbingLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6068 = _6034;
          if ((((-(int)1) <= _6068) && (_6068 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6068);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6069 = _6034;
          if ((((-(int)1) <= _6069) && (_6069 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6069);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6070 = _6034;
          if ((((-(int)1) <= _6070) && (_6070 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6070);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6033 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6033 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6033 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6033 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6033 == std::string ("mioSeed")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6071 = _6034;
          if (((int)0 <= _6071))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6071);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6033 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6033 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6072 = _6034;
          if (((int)40 <= _6072))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6072);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6073 = _6034;
          if (((int)0 <= _6073))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6073);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6033 == std::string ("logInfeasAna")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6074 = _6034;
          if (((int)0 <= _6074))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6074);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6033 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6033 == std::string ("licensePauseTime")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6075 = _6034;
          if ((((int)0 <= _6075) && (_6075 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6075);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6033 == std::string ("log")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6076 = _6034;
          if (((int)0 <= _6076))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6076);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logExpand")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6077 = _6034;
          if (((int)0 <= _6077))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6077);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logFile")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6078 = _6034;
          if (((int)0 <= _6078))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6078);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("logOrder")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6079 = _6034;
          if (((int)0 <= _6079))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6079);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6033 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6033 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6080 = _6034;
          if ((((int)0 <= _6080) && (_6080 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6080);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6081 = _6034;
          if ((((int)0 <= _6081) && (_6081 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6081);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6082 = _6034;
          if (((int)0 <= _6082))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6082);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6033 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6033 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6033 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6033 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6033 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6033 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6033 == std::string ("simDualCrash")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6083 = _6034;
          if (((int)0 <= _6083))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6083);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6033 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6084 = _6034;
          if ((((-(int)1) <= _6084) && (_6084 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6084);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6033 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6033 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6033 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6033 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6033 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6085 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6085);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6086 = _6034;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6086);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6033 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6033 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6033 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6033 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6087 = _6034;
          if (((-(int)1) <= _6087))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6087);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioFeaspumpLevel")))
  {
    {
      if (((_6034 - (int)_6034) == 0.0))
      {
        {
          double _6088 = _6034;
          if ((((-(int)1) <= _6088) && (_6088 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6088);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("optimizerMaxTime")))
  {
    {
      double _6089 = _6034;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6089);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("lowerObjCut")))
  {
    {
      double _6090 = _6034;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6090);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("upperObjCut")))
  {
    {
      double _6091 = _6034;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6091);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6092 = _6034;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6092);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6093 = _6034;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6093);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolRelGap")))
  {
    {
      double _6094 = _6034;
      if ((1.000000e-14 <= _6094))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6094);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolStepSize")))
  {
    {
      double _6095 = _6034;
      if (((0.000000e+00 <= _6095) && (_6095 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6095);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6096 = _6034;
      if (((1.000000e-06 <= _6096) && (_6096 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6096);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolRelStep")))
  {
    {
      double _6097 = _6034;
      if (((1.000000e-04 <= _6097) && (_6097 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6097);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolPath")))
  {
    {
      double _6098 = _6034;
      if (((0.000000e+00 <= _6098) && (_6098 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6098);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolPfeas")))
  {
    {
      double _6099 = _6034;
      if (((0.000000e+00 <= _6099) && (_6099 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6099);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolDfeas")))
  {
    {
      double _6100 = _6034;
      if (((0.000000e+00 <= _6100) && (_6100 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6100);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolMuRed")))
  {
    {
      double _6101 = _6034;
      if (((0.000000e+00 <= _6101) && (_6101 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6101);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolInfeas")))
  {
    {
      double _6102 = _6034;
      if (((0.000000e+00 <= _6102) && (_6102 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6102);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6103 = _6034;
      if (((0.000000e+00 <= _6103) && (_6103 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6103);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6104 = _6034;
      if (((0.000000e+00 <= _6104) && (_6104 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6104);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6105 = _6034;
      if (((0.000000e+00 <= _6105) && (_6105 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6105);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6106 = _6034;
      if (((0.000000e+00 <= _6106) && (_6106 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6106);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6107 = _6034;
      if ((1.000000e+00 <= _6107))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6107);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6108 = _6034;
      if (((0.000000e+00 <= _6108) && (_6108 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6108);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolPsafe")))
  {
    {
      double _6109 = _6034;
      if ((1.000000e-04 <= _6109))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6109);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("intpntTolDsafe")))
  {
    {
      double _6110 = _6034;
      if ((1.000000e-04 <= _6110))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6110);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioMaxTime")))
  {
    {
      double _6111 = _6034;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6111);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioRelGapConst")))
  {
    {
      double _6112 = _6034;
      if ((1.000000e-15 <= _6112))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6112);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioTolRelGap")))
  {
    {
      double _6113 = _6034;
      if ((0.000000e+00 <= _6113))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6113);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioTolAbsGap")))
  {
    {
      double _6114 = _6034;
      if ((0.000000e+00 <= _6114))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6114);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6115 = _6034;
      if ((1.000000e-09 <= _6115))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6115);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("basisTolX")))
  {
    {
      double _6116 = _6034;
      if ((1.000000e-09 <= _6116))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6116);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("basisTolS")))
  {
    {
      double _6117 = _6034;
      if ((1.000000e-09 <= _6117))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6117);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("basisRelTolS")))
  {
    {
      double _6118 = _6034;
      if ((0.000000e+00 <= _6118))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6118);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveTolX")))
  {
    {
      double _6119 = _6034;
      if ((0.000000e+00 <= _6119))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6119);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveTolS")))
  {
    {
      double _6120 = _6034;
      if ((0.000000e+00 <= _6120))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6120);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveTolAij")))
  {
    {
      double _6121 = _6034;
      if ((1.000000e-15 <= _6121))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6121);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6122 = _6034;
      if ((0.000000e+00 <= _6122))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6122);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6123 = _6034;
      if ((0.000000e+00 <= _6123))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6123);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6124 = _6034;
      if ((1.000000e-12 <= _6124))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6124);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioTolFeas")))
  {
    {
      double _6125 = _6034;
      if (((1.000000e-09 <= _6125) && (_6125 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6125);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("anaSolInfeasTol")))
  {
    {
      double _6126 = _6034;
      if ((0.000000e+00 <= _6126))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6126);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6033 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6127 = _6034;
      if (((0.000000e+00 <= _6127) && (_6127 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6032.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6127);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6033 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6033 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6033 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6033 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6033 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6033 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6128,    const std::string & _6129,    int _6130) { mosek::fusion::p_Parameters::setParameter(_6128,_6129,_6130); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6128,const std::string & _6129,int _6130){
  if (false)
  {
    {
    }
  }
  else if((_6129 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_6129 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_6129 == std::string ("numThreads")))
  {
    {
      int _6131 = _6130;
      if (((int)0 <= _6131))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6131);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_6129 == std::string ("mtSpincount")))
  {
    {
      int _6132 = _6130;
      if ((((int)0 <= _6132) && (_6132 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6132);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_6129 == std::string ("biMaxIterations")))
  {
    {
      int _6133 = _6130;
      if (((int)0 <= _6133))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6133);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _6134 = _6130;
      if (((int)0 <= _6134))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6134);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logCutSecondOpt")))
  {
    {
      int _6135 = _6130;
      if (((int)0 <= _6135))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6135);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logResponse")))
  {
    {
      int _6136 = _6130;
      if (((int)0 <= _6136))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6136);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_6129 == std::string ("logBi")))
  {
    {
      int _6137 = _6130;
      if (((int)0 <= _6137))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6137);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logBiFreq")))
  {
    {
      int _6138 = _6130;
      if (((int)0 <= _6138))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6138);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_6129 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_6129 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_6129 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_6129 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_6129 == std::string ("logIntpnt")))
  {
    {
      int _6139 = _6130;
      if (((int)0 <= _6139))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6139);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntMaxIterations")))
  {
    {
      int _6140 = _6130;
      if (((int)0 <= _6140))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6140);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntOffColTrh")))
  {
    {
      int _6141 = _6130;
      if (((int)0 <= _6141))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6141);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  else if((_6129 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_6129 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_6129 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_6129 == std::string ("intpntMaxNumCor")))
  {
    {
      int _6142 = _6130;
      if (((-(int)1) <= _6142))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6142);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_6129 == std::string ("presolveLevel")))
  {
    {
      int _6143 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6143);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logPresolve")))
  {
    {
      int _6144 = _6130;
      if (((int)0 <= _6144))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6144);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_6129 == std::string ("presolveMaxNumPass")))
  {
    {
      int _6145 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6145);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _6146 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6146);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _6147 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6147);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simPrimalCrash")))
  {
    {
      int _6148 = _6130;
      if (((int)0 <= _6148))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6148);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logSim")))
  {
    {
      int _6149 = _6130;
      if (((int)0 <= _6149))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6149);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logSimMinor")))
  {
    {
      int _6150 = _6130;
      if (((int)0 <= _6150))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6150);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logSimFreq")))
  {
    {
      int _6151 = _6130;
      if (((int)0 <= _6151))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6151);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _6152 = _6130;
      if ((((int)0 <= _6152) && (_6152 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6152);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_6129 == std::string ("simDualRestrictSelection")))
  {
    {
      int _6153 = _6130;
      if ((((int)0 <= _6153) && (_6153 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6153);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_6129 == std::string ("simMaxIterations")))
  {
    {
      int _6154 = _6130;
      if (((int)0 <= _6154))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6154);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_6129 == std::string ("simRefactorFreq")))
  {
    {
      int _6155 = _6130;
      if (((int)0 <= _6155))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6155);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simSeed")))
  {
    {
      int _6156 = _6130;
      if ((((int)0 <= _6156) && (_6156 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6156);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_6129 == std::string ("logMio")))
  {
    {
      int _6157 = _6130;
      if (((int)0 <= _6157))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6157);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logMioFreq")))
  {
    {
      int _6158 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6158);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _6159 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6159);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioMaxNumBranches")))
  {
    {
      int _6160 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6160);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      int _6161 = _6130;
      if (((int)0 <= _6161))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6161);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _6162 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6162);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_6129 == std::string ("mioHeuristicLevel")))
  {
    {
      int _6163 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6163);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioProbingLevel")))
  {
    {
      int _6164 = _6130;
      if ((((-(int)1) <= _6164) && (_6164 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6164);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _6165 = _6130;
      if ((((-(int)1) <= _6165) && (_6165 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6165);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _6166 = _6130;
      if ((((-(int)1) <= _6166) && (_6166 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6166);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_6129 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_6129 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_6129 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_6129 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_6129 == std::string ("mioSeed")))
  {
    {
      int _6167 = _6130;
      if (((int)0 <= _6167))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6167);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_6129 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_6129 == std::string ("writeLpLineWidth")))
  {
    {
      int _6168 = _6130;
      if (((int)40 <= _6168))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6168);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _6169 = _6130;
      if (((int)0 <= _6169))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6169);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_6129 == std::string ("logInfeasAna")))
  {
    {
      int _6170 = _6130;
      if (((int)0 <= _6170))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6170);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_6129 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_6129 == std::string ("licensePauseTime")))
  {
    {
      int _6171 = _6130;
      if ((((int)0 <= _6171) && (_6171 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6171);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_6129 == std::string ("log")))
  {
    {
      int _6172 = _6130;
      if (((int)0 <= _6172))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6172);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logExpand")))
  {
    {
      int _6173 = _6130;
      if (((int)0 <= _6173))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6173);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logFile")))
  {
    {
      int _6174 = _6130;
      if (((int)0 <= _6174))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6174);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("logOrder")))
  {
    {
      int _6175 = _6130;
      if (((int)0 <= _6175))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6175);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_6129 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_6129 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _6176 = _6130;
      if ((((int)0 <= _6176) && (_6176 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6176);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _6177 = _6130;
      if ((((int)0 <= _6177) && (_6177 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6177);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _6178 = _6130;
      if (((int)0 <= _6178))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6178);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_6129 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_6129 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_6129 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_6129 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_6129 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_6129 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_6129 == std::string ("simDualCrash")))
  {
    {
      int _6179 = _6130;
      if (((int)0 <= _6179))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6179);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_6129 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _6180 = _6130;
      if ((((-(int)1) <= _6180) && (_6180 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6180);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_6129 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_6129 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_6129 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_6129 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_6129 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _6181 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _6182 = _6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_6129 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_6129 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_6129 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_6129 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _6183 = _6130;
      if (((-(int)1) <= _6183))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6183);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioFeaspumpLevel")))
  {
    {
      int _6184 = _6130;
      if ((((-(int)1) <= _6184) && (_6184 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6184);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("optimizerMaxTime")))
  {
    {
      double _6185 = (double)_6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6185);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("lowerObjCut")))
  {
    {
      double _6186 = (double)_6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6186);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("upperObjCut")))
  {
    {
      double _6187 = (double)_6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6187);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _6188 = (double)_6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6188);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _6189 = (double)_6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6189);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolRelGap")))
  {
    {
      double _6190 = (double)_6130;
      if ((1.000000e-14 <= _6190))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6190);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolStepSize")))
  {
    {
      double _6191 = (double)_6130;
      if (((0.000000e+00 <= _6191) && (_6191 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6191);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simLuTolRelPiv")))
  {
    {
      double _6192 = (double)_6130;
      if (((1.000000e-06 <= _6192) && (_6192 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6192);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolRelStep")))
  {
    {
      double _6193 = (double)_6130;
      if (((1.000000e-04 <= _6193) && (_6193 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6193);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolPath")))
  {
    {
      double _6194 = (double)_6130;
      if (((0.000000e+00 <= _6194) && (_6194 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6194);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolPfeas")))
  {
    {
      double _6195 = (double)_6130;
      if (((0.000000e+00 <= _6195) && (_6195 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6195);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolDfeas")))
  {
    {
      double _6196 = (double)_6130;
      if (((0.000000e+00 <= _6196) && (_6196 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6196);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolMuRed")))
  {
    {
      double _6197 = (double)_6130;
      if (((0.000000e+00 <= _6197) && (_6197 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6197);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolInfeas")))
  {
    {
      double _6198 = (double)_6130;
      if (((0.000000e+00 <= _6198) && (_6198 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6198);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _6199 = (double)_6130;
      if (((0.000000e+00 <= _6199) && (_6199 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6199);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _6200 = (double)_6130;
      if (((0.000000e+00 <= _6200) && (_6200 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6200);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _6201 = (double)_6130;
      if (((0.000000e+00 <= _6201) && (_6201 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6201);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _6202 = (double)_6130;
      if (((0.000000e+00 <= _6202) && (_6202 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6202);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _6203 = (double)_6130;
      if ((1.000000e+00 <= _6203))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6203);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _6204 = (double)_6130;
      if (((0.000000e+00 <= _6204) && (_6204 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6204);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolPsafe")))
  {
    {
      double _6205 = (double)_6130;
      if ((1.000000e-04 <= _6205))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6205);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("intpntTolDsafe")))
  {
    {
      double _6206 = (double)_6130;
      if ((1.000000e-04 <= _6206))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6206);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioMaxTime")))
  {
    {
      double _6207 = (double)_6130;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6207);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioRelGapConst")))
  {
    {
      double _6208 = (double)_6130;
      if ((1.000000e-15 <= _6208))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6208);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioTolRelGap")))
  {
    {
      double _6209 = (double)_6130;
      if ((0.000000e+00 <= _6209))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6209);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioTolAbsGap")))
  {
    {
      double _6210 = (double)_6130;
      if ((0.000000e+00 <= _6210))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6210);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _6211 = (double)_6130;
      if ((1.000000e-09 <= _6211))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6211);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("basisTolX")))
  {
    {
      double _6212 = (double)_6130;
      if ((1.000000e-09 <= _6212))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6212);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("basisTolS")))
  {
    {
      double _6213 = (double)_6130;
      if ((1.000000e-09 <= _6213))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6213);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("basisRelTolS")))
  {
    {
      double _6214 = (double)_6130;
      if ((0.000000e+00 <= _6214))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6214);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveTolX")))
  {
    {
      double _6215 = (double)_6130;
      if ((0.000000e+00 <= _6215))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6215);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveTolS")))
  {
    {
      double _6216 = (double)_6130;
      if ((0.000000e+00 <= _6216))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6216);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveTolAij")))
  {
    {
      double _6217 = (double)_6130;
      if ((1.000000e-15 <= _6217))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6217);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _6218 = (double)_6130;
      if ((0.000000e+00 <= _6218))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6218);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("presolveTolRelLindep")))
  {
    {
      double _6219 = (double)_6130;
      if ((0.000000e+00 <= _6219))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6219);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _6220 = (double)_6130;
      if ((1.000000e-12 <= _6220))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6220);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioTolFeas")))
  {
    {
      double _6221 = (double)_6130;
      if (((1.000000e-09 <= _6221) && (_6221 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6221);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("anaSolInfeasTol")))
  {
    {
      double _6222 = (double)_6130;
      if ((0.000000e+00 <= _6222))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6222);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6129 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _6223 = (double)_6130;
      if (((0.000000e+00 <= _6223) && (_6223 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_6128.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6223);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_6129 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_6129 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_6129 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_6129 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_6129 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_6129 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _6224,    const std::string & _6225,    const std::string & _6226) { mosek::fusion::p_Parameters::setParameter(_6224,_6225,_6226); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6224,const std::string & _6225,const std::string & _6226){
  if (false)
  {
    {
    }
  }
  {}
  if ((_6225 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _6227 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6227 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_6227);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("removeUnusedSolutions")))
  {
    {
      int _6228 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6228 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_6228);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _6230 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6230))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_6230);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6229)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntMultiThread")))
  {
    {
      int _6231 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6231 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_6231);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _6233 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6233) && (_6233 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_6233);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6232)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("optimizer")))
  {
    {
      int _6234 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6226);
      if ((_6234 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_6234);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _6236 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6236))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_6236);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6235)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _6238 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6238))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_6238);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6237)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _6240 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6240))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_6240);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6239)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _6242 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6242))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_6242);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6241)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logLocalInfo")))
  {
    {
      int _6243 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6243 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_LOCAL_INFO"),_6243);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _6245 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6245))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_6245);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6244)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _6247 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6247))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_6247);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6246)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("biCleanOptimizer")))
  {
    {
      int _6248 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6226);
      if ((_6248 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_6248);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntStartingPoint")))
  {
    {
      int _6249 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_6226);
      if ((_6249 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_6249);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntDiffStep")))
  {
    {
      int _6250 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6250 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_6250);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntScaling")))
  {
    {
      int _6251 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6226);
      if ((_6251 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_6251);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntSolveForm")))
  {
    {
      int _6252 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6226);
      if ((_6252 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_6252);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _6254 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6254))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_6254);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6253)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _6256 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6256))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_6256);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6255)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _6258 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6258))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_6258);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6257)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntOrderMethod")))
  {
    {
      int _6259 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_6226);
      if ((_6259 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_6259);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntBasis")))
  {
    {
      int _6260 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_6226);
      if ((_6260 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_6260);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _6261 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6261 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_6261);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("biIgnoreNumError")))
  {
    {
      int _6262 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6262 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_6262);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _6264 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((-(int)1) <= _6264))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_6264);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6263)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveUse")))
  {
    {
      int _6265 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_6226);
      if ((_6265 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_6265);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _6267 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_6267);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6266)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _6269 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6269))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_6269);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6268)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveLindepUse")))
  {
    {
      int _6270 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6270 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_6270);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _6272 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_6272);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6271)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _6274 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_6274);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6273)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _6276 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_6276);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6275)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _6278 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6278))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_6278);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6277)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _6280 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6280))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_6280);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6279)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _6282 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6282))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_6282);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6281)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _6284 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6284))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_6284);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6283)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _6286 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6286) && (_6286 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_6286);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6285)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simPrimalSelection")))
  {
    {
      int _6287 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6226);
      if ((_6287 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_6287);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _6289 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6289) && (_6289 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_6289);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6288)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simDualSelection")))
  {
    {
      int _6290 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_6226);
      if ((_6290 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_6290);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _6292 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6292))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_6292);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6291)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simHotstartLu")))
  {
    {
      int _6293 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6293 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_6293);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _6295 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6295))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_6295);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6294)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _6297 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6297) && (_6297 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_6297);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6296)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioMode")))
  {
    {
      int _6298 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_6226);
      if ((_6298 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_6298);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _6300 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6300))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_6300);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6299)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _6302 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_6302);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6301)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _6304 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_6304);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6303)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _6306 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_6306);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6305)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      try
      {
        {
          int _6308 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6308))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_6308);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6307)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _6310 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_6310);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6309)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioNodeSelection")))
  {
    {
      int _6311 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_6226);
      if ((_6311 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_6311);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _6313 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_6313);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6312)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _6315 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((-(int)1) <= _6315) && (_6315 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_6315);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6314)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _6317 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((-(int)1) <= _6317) && (_6317 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_6317);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6316)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _6319 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((-(int)1) <= _6319) && (_6319 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_6319);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6318)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioBranchDir")))
  {
    {
      int _6320 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_6226);
      if ((_6320 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_6320);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioRootOptimizer")))
  {
    {
      int _6321 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6226);
      if ((_6321 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_6321);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioNodeOptimizer")))
  {
    {
      int _6322 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_6226);
      if ((_6322 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_6322);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _6323 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6323 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_6323);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _6324 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6324 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_6324);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _6326 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6326))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_6326);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6325)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _6327 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6327 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_6327);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("writeLpQuotedNames")))
  {
    {
      int _6328 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6328 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_6328);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _6330 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)40 <= _6330))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_6330);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6329)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _6332 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6332))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_6332);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6331)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("writeLpFullObj")))
  {
    {
      int _6333 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6333 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_6333);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _6335 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6335))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_6335);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6334)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("licenseWait")))
  {
    {
      int _6336 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6336 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_6336);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _6337 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6337 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_6337);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _6339 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6339) && (_6339 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_6339);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6338)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("licenseDebug")))
  {
    {
      int _6340 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6340 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_6340);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("log")))
  {
    {
      try
      {
        {
          int _6342 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6342))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_6342);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6341)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _6344 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6344))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_6344);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6343)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _6346 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6346))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_6346);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6345)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _6348 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6348))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_6348);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6347)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simScaling")))
  {
    {
      int _6349 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_6226);
      if ((_6349 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_6349);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simScalingMethod")))
  {
    {
      int _6350 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_6226);
      if ((_6350 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_6350);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6352 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6352) && (_6352 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_6352);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6351)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _6354 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((int)0 <= _6354) && (_6354 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_6354);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6353)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _6356 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6356))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_6356);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6355)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simHotstart")))
  {
    {
      int _6357 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_6226);
      if ((_6357 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_6357);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simBasisFactorUse")))
  {
    {
      int _6358 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6358 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_6358);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simDegen")))
  {
    {
      int _6359 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_6226);
      if ((_6359 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_6359);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simReformulation")))
  {
    {
      int _6360 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_6226);
      if ((_6360 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_6360);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simExploitDupvec")))
  {
    {
      int _6361 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_6226);
      if ((_6361 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_6361);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simSaveLu")))
  {
    {
      int _6362 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6362 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_6362);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simNonSingular")))
  {
    {
      int _6363 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6363 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_6363);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _6365 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((int)0 <= _6365))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_6365);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6364)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("infeasPreferPrimal")))
  {
    {
      int _6366 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6366 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_6366);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _6368 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((-(int)1) <= _6368) && (_6368 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_6368);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6367)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioCutCmir")))
  {
    {
      int _6369 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6369 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_6369);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioCutClique")))
  {
    {
      int _6370 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6370 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_6370);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioCutImpliedBound")))
  {
    {
      int _6371 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6371 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_6371);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _6372 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6372 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_6372);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioCutGmi")))
  {
    {
      int _6373 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6373 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_6373);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _6375 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_6375);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6374)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _6377 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_6377);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6376)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("cacheLicense")))
  {
    {
      int _6378 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6378 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_6378);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intpntRegularizationUse")))
  {
    {
      int _6379 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6379 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_6379);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simSolveForm")))
  {
    {
      int _6380 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_6226);
      if ((_6380 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_6380);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("simSwitchOptimizer")))
  {
    {
      int _6381 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_6226);
      if ((_6381 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_6381);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _6383 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if (((-(int)1) <= _6383))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_6383);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6382)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioFeaspumpLevel")))
  {
    {
      try
      {
        {
          int _6385 = ::mosek::fusion::Utils::Tools::toInt(_6226);
          if ((((-(int)1) <= _6385) && (_6385 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_6385);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6384)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _6387 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_6387);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6386)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _6389 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_6389);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6388)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _6391 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_6391);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6390)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6393 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_6393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _6395 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_6395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _6397 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-14 <= _6397))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_6397);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6396)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _6399 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6399) && (_6399 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_6399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _6401 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((1.000000e-06 <= _6401) && (_6401 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_6401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _6403 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((1.000000e-04 <= _6403) && (_6403 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_6403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _6405 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6405) && (_6405 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_6405);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6404)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _6407 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6407) && (_6407 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_6407);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6406)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _6409 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6409) && (_6409 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_6409);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6408)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _6411 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6411) && (_6411 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_6411);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6410)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _6413 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6413) && (_6413 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_6413);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6412)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _6415 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6415) && (_6415 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_6415);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6414)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _6417 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6417) && (_6417 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_6417);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6416)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _6419 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6419) && (_6419 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_6419);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6418)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _6421 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6421) && (_6421 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_6421);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6420)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _6423 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e+00 <= _6423))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_6423);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6422)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _6425 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6425) && (_6425 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_6425);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6424)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _6427 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-04 <= _6427))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_6427);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6426)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _6429 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-04 <= _6429))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_6429);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6428)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _6431 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_6431);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6430)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _6433 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-15 <= _6433))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_6433);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6432)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _6435 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6435))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_6435);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6434)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _6437 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6437))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_6437);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6436)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _6439 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-09 <= _6439))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_6439);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6438)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _6441 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-09 <= _6441))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_6441);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6440)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _6443 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-09 <= _6443))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_6443);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6442)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _6445 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6445))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_6445);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6444)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _6447 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6447))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_6447);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6446)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _6449 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6449))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_6449);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6448)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _6451 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-15 <= _6451))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_6451);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6450)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _6453 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6453))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_6453);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6452)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _6455 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6455))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_6455);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6454)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _6457 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((1.000000e-12 <= _6457))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_6457);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6456)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _6459 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((1.000000e-09 <= _6459) && (_6459 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_6459);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6458)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("anaSolInfeasTol")))
  {
    {
      try
      {
        {
          double _6461 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if ((0.000000e+00 <= _6461))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_ANA_SOL_INFEAS_TOL"),_6461);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6460)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (anaSolInfeasTol)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _6463 = ::mosek::fusion::Utils::Tools::toDouble(_6226);
          if (((0.000000e+00 <= _6463) && (_6463 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_6463);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _6462)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_6225 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_6226);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_6226);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_6226);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_6226);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_6226);
      return;
    }
  }
  {}
  if ((_6225 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_6224.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_6226);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _6464){
  if ((_6464 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6464 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _6465){
  if ((_6465 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_6465 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _6466){
  if ((_6466 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6466 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6466 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6466 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _6467){
  if ((_6467 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6467 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6467 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6467 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _6468){
  if ((_6468 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6468 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6468 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6468 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6468 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6468 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6468 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _6469){
  if ((_6469 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6469 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6469 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6469 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6469 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6469 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6469 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6469 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6469 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6469 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6469 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6469 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6469 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6469 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6469 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6469 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6469 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6469 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6469 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6469 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6469 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6469 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6469 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6469 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _6470){
  if ((_6470 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6470 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6470 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _6471){
  if ((_6471 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6471 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6471 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _6472){
  if ((_6472 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6472 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6472 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6472 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6472 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6472 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6472 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6472 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6472 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6472 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _6473){
  if ((_6473 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6473 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6473 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6473 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6473 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6473 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6473 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6473 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _6474){
  if ((_6474 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6474 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6474 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6474 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6474 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6474 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _6475){
  if ((_6475 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _6476){
  if ((_6476 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6476 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _6477){
  if ((_6477 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6477 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6477 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6477 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _6478){
  if ((_6478 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6478 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6478 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6478 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6478 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _6479){
  if ((_6479 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6479 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6479 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6479 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6479 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6479 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6479 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6479 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6479 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_6479 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_6479 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_6479 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_6479 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_6479 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_6479 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_6479 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_6479 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_6479 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_6479 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_6479 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_6479 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_6479 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_6479 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_6479 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_6479 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_6479 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_6479 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_6479 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_6479 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_6479 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_6479 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_6479 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_6479 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_6479 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_6479 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_6479 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_6479 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_6479 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_6479 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_6479 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_6479 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_6479 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_6479 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_6479 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_6479 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_6479 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_6479 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_6479 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_6479 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_6479 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_6479 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_6479 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_6479 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_6479 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_6479 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_6479 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_6479 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_6479 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_6479 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_6479 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_6479 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_6479 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_6479 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_6479 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_6479 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_6479 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_6479 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_6479 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_6479 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_6479 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_6479 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_6479 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_6479 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_6479 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_6479 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_6479 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_6479 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_6479 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_6479 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_6479 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_6479 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_6479 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_6479 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_6479 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_6479 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_6479 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_6479 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_6479 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_6479 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_6479 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_6479 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_6479 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_6479 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_6479 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_6479 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_6479 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_6479 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_6479 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_6479 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_6479 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_6479 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_6479 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_6479 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_6479 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_6479 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_6479 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_6479 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_6479 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_6479 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_6479 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_6479 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_6479 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_6479 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_6479 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_6479 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_6479 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_6479 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_6479 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_6479 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_6479 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_6479 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_6479 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_6479 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_6479 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_6479 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_6479 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_6479 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_6479 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_6479 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_6479 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_6479 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_6479 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_6479 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_6479 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_6479 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_6479 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_6479 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_6479 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_6479 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_6479 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_6479 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_6479 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_6479 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_6479 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_6479 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_6479 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_6479 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_6479 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_6479 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_6479 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_6479 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_6479 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_6479 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_6479 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_6479 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_6479 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_6479 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_6479 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_6479 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_6479 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_6479 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_6479 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_6479 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_6479 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_6479 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_6479 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_6479 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_6479 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_6479 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_6479 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_6479 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_6479 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_6479 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_6479 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_6479 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_6479 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_6479 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_6479 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_6479 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_6479 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_6479 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_6479 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_6479 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_6479 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_6479 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_6479 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_6479 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_6479 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_6479 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_6479 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_6479 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_6479 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_6479 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_6479 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_6479 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_6479 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_6479 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_6479 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_6479 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_6479 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_6479 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_6479 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_6479 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_6479 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_6479 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_6479 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_6479 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_6479 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_6479 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_6479 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_6479 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_6479 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_6479 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_6479 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_6479 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_6479 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_6479 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_6479 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_6479 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_6479 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_6479 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_6479 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_6479 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_6479 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_6479 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_6479 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_6479 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_6479 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_6479 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_6479 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_6479 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_6479 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_6479 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_6479 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_6479 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_6479 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_6479 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_6479 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_6479 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_6479 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_6479 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_6479 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_6479 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_6479 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_6479 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_6479 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_6479 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_6479 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_6479 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_6479 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_6479 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_6479 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_6479 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_6479 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_6479 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_6479 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_6479 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_6479 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_6479 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_6479 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_6479 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_6479 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_6479 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_6479 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_6479 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_6479 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_6479 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_6479 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_6479 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_6479 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_6479 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_6479 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_6479 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_6479 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_6479 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_6479 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_6479 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_6479 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_6479 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_6479 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_6479 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_6479 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_6479 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_6479 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_6479 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_6479 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_6479 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_6479 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_6479 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_6479 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_6479 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_6479 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_6479 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_6479 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_6479 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_6479 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_6479 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_6479 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_6479 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_6479 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_6479 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_6479 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_6479 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_6479 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_6479 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_6479 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_6479 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_6479 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_6479 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_6479 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_6479 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_6479 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_6479 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_6479 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_6479 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_6479 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_6479 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_6479 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_6479 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_6479 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_6479 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_6479 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_6479 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_6479 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_6479 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _6480){
  if ((_6480 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6480 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _6481){
  if ((_6481 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6481 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6481 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6481 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6481 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6481 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6481 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6481 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6481 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _6482){
  if ((_6482 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6482 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6482 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6482 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6482 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _6483){
  if ((_6483 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6483 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6483 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _6484){
  if ((_6484 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6484 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6484 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6484 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _6485){
  if ((_6485 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6485 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6485 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _6486){
  if ((_6486 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6486 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6486 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6486 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6486 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6486 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _6487){
  if ((_6487 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6487 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6487 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6487 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6487 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6487 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6487 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _6488){
  if ((_6488 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6488 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _6489){
  if ((_6489 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6489 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _6490){
  if ((_6490 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6490 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6490 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6490 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _6491){
  if ((_6491 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6491 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6491 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6491 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _6492){
  if ((_6492 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6492 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _6493){
  if ((_6493 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6493 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6493 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6493 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _6494){
  if ((_6494 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6494 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6494 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6494 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6494 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6494 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6494 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6494 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _6495){
  if ((_6495 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6495 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_6495 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6495 == std::string ("intpntPurify")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6495 == std::string ("numThreads")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6495 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6495 == std::string ("timingLevel")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_6495 == std::string ("mtSpincount")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6495 == std::string ("maxNumWarnings")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6495 == std::string ("optimizer")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6495 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6495 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6495 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6495 == std::string ("logAnaPro")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6495 == std::string ("logResponse")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6495 == std::string ("logLocalInfo")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6495 == std::string ("logBi")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6495 == std::string ("logBiFreq")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6495 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6495 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6495 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6495 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6495 == std::string ("intpntScaling")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6495 == std::string ("intpntSolveForm")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6495 == std::string ("logIntpnt")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6495 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6495 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6495 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6495 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6495 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6495 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6495 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6495 == std::string ("presolveUse")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_6495 == std::string ("presolveLevel")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6495 == std::string ("logPresolve")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6495 == std::string ("presolveLindepUse")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_6495 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_6495 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6495 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6495 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_6495 == std::string ("simStabilityPriority")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_6495 == std::string ("simPrimalCrash")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_6495 == std::string ("logSim")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6495 == std::string ("logSimMinor")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6495 == std::string ("logSimFreq")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6495 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_6495 == std::string ("simPrimalSelection")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_6495 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_6495 == std::string ("simDualSelection")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_6495 == std::string ("simMaxIterations")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_6495 == std::string ("simHotstartLu")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_6495 == std::string ("simRefactorFreq")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_6495 == std::string ("simSeed")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_6495 == std::string ("mioMode")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6495 == std::string ("logMio")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6495 == std::string ("logMioFreq")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6495 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6495 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6495 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6495 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6495 == std::string ("mioNodeSelection")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6495 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6495 == std::string ("mioProbingLevel")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6495 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6495 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6495 == std::string ("mioBranchDir")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6495 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6495 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6495 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6495 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6495 == std::string ("mioSeed")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6495 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6495 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_6495 == std::string ("readMpsFormat")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_6495 == std::string ("writeMpsFormat")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_6495 == std::string ("readMpsWidth")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_6495 == std::string ("readDebug")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_6495 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_6495 == std::string ("writeDataParam")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_6495 == std::string ("writeFreeCon")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_6495 == std::string ("writeGenericNames")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_6495 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_6495 == std::string ("writeCompression")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_6495 == std::string ("writeMpsInt")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_6495 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_6495 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_6495 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_6495 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_6495 == std::string ("writeLpFullObj")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_6495 == std::string ("writePrecision")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_6495 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)174;
    }
  }
  {}
  if ((_6495 == std::string ("writeSolHead")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_6495 == std::string ("writeSolConstraints")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_6495 == std::string ("writeSolVariables")))
  {
    {
      return (int)175;
    }
  }
  {}
  if ((_6495 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_6495 == std::string ("writeBasHead")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_6495 == std::string ("writeBasConstraints")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_6495 == std::string ("writeBasVariables")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_6495 == std::string ("writeIntHead")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_6495 == std::string ("writeIntConstraints")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_6495 == std::string ("writeIntVariables")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_6495 == std::string ("solReadNameWidth")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_6495 == std::string ("solReadWidth")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_6495 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6495 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6495 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6495 == std::string ("logInfeasAna")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6495 == std::string ("licenseWait")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6495 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6495 == std::string ("licensePauseTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6495 == std::string ("licenseDebug")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6495 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_6495 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_6495 == std::string ("log")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6495 == std::string ("logExpand")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6495 == std::string ("logFile")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6495 == std::string ("logOrder")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6495 == std::string ("logSensitivity")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6495 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6495 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_6495 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)176;
    }
  }
  {}
  if ((_6495 == std::string ("paramReadCaseName")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6495 == std::string ("paramReadIgnError")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6495 == std::string ("solutionCallback")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_6495 == std::string ("simScaling")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_6495 == std::string ("simScalingMethod")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_6495 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_6495 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_6495 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_6495 == std::string ("simHotstart")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_6495 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_6495 == std::string ("simDegen")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_6495 == std::string ("simReformulation")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_6495 == std::string ("simExploitDupvec")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_6495 == std::string ("simSaveLu")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_6495 == std::string ("simNonSingular")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_6495 == std::string ("simDualCrash")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_6495 == std::string ("logStorage")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6495 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6495 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteHints")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteParameters")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteProblem")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteHeader")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6495 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6495 == std::string ("ptfWriteTransform")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_6495 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_6495 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6495 == std::string ("mioCutCmir")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6495 == std::string ("mioCutClique")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6495 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6495 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6495 == std::string ("mioCutGmi")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6495 == std::string ("sensitivityType")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_6495 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_6495 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_6495 == std::string ("sensitivityAll")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_6495 == std::string ("logFeasRepair")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6495 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6495 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6495 == std::string ("simSolveForm")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_6495 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_6495 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_6495 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6495 == std::string ("logCheckConvexity")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6495 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6495 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_6495 == std::string ("writeXmlMode")))
  {
    {
      return (int)177;
    }
  }
  {}
  if ((_6495 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6495 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6495 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6495 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6495 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6495 == std::string ("mioFeaspumpLevel")))
  {
    {
      return (int)67;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _6496){
  if ((_6496 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6496 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6496 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _6497){
  if ((_6497 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6497 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6497 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6497 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6497 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6497 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6497 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6497 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6497 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6497 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6497 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6497 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6497 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6497 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6497 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6497 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6497 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6497 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6497 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6497 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6497 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6497 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6497 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6497 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6497 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6497 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6497 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6497 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6497 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6497 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6497 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6497 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6497 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6497 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6497 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6497 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6497 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6497 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6497 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6497 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6497 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6497 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6497 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6497 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6497 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _6498){
  if ((_6498 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6498 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6498 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6498 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6498 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6498 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6498 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6498 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6498 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6498 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6498 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6498 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6498 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6498 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6498 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6498 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6498 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6498 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6498 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6498 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6498 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6498 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6498 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6498 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6498 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6498 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6498 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6498 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6498 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6498 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6498 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6498 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6498 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6498 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6498 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6498 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6498 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6498 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6498 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6498 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _6499){
  if ((_6499 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6499 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6499 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _6500){
  if ((_6500 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6500 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6500 == std::string ("optimizeResponse")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6500 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6500 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6500 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6500 == std::string ("mioNodeDepth")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumbin")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumcont")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumcon")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumcone")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumrqcones")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumdexpcones")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumppowcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumdpowcones")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumconevar")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumdexpcones")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumppowcones")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumdpowcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6500 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6500 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6500 == std::string ("mioConstructSolution")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6500 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumRelax")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumBranch")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6500 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6500 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6500 == std::string ("mioUserObjCut")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6500 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6500 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6500 == std::string ("rdProtype")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6500 == std::string ("rdNumcon")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6500 == std::string ("rdNumvar")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6500 == std::string ("rdNumbarvar")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6500 == std::string ("rdNumintvar")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6500 == std::string ("rdNumq")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6500 == std::string ("simDualDegIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6500 == std::string ("simDualInfIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6500 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6500 == std::string ("simPrimalIter")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6500 == std::string ("simDualIter")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6500 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6500 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6500 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6500 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6500 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6500 == std::string ("simDualHotstart")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6500 == std::string ("solItrProsta")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_6500 == std::string ("solItrSolsta")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_6500 == std::string ("solBasProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_6500 == std::string ("solBasSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_6500 == std::string ("solItgProsta")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_6500 == std::string ("solItgSolsta")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_6500 == std::string ("simNumcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6500 == std::string ("simNumvar")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6500 == std::string ("optNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6500 == std::string ("optNumvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6500 == std::string ("stoNumARealloc")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_6500 == std::string ("rdNumcone")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6500 == std::string ("simSolveDual")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_6500 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6500 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)72;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _6501){
  if ((_6501 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6501 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6501 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6501 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6501 == std::string ("presolveStackSize")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6501 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6501 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _6502){
  if ((_6502 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6502 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6502 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6502 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6502 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6502 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6502 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6502 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6502 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6502 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6502 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6502 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6502 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _6503){
  if ((_6503 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6503 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6503 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6503 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6503 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6503 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6503 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6503 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6503 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6503 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6503 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6503 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6503 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6503 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6503 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6503 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6503 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6503 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6503 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6503 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6503 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6503 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6503 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6503 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6503 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6503 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6503 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6503 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6503 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6503 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6503 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6503 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6503 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6503 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6503 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6503 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6503 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6503 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6503 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6503 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6503 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6503 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6503 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6503 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _6504){
  if ((_6504 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6504 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _6505){
  if ((_6505 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6505 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6505 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6505 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6505 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6505 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6505 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6505 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6505 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6505 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6505 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6505 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6505 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6505 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6505 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6505 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6505 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6505 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6505 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6505 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6505 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6505 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6505 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6505 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6505 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6505 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6505 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6505 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6505 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6505 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6505 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6505 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6505 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6505 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6505 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6505 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6505 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6505 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6505 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6505 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6505 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6505 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_6505 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6505 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6505 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6505 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6505 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6505 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6505 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6505 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6505 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6505 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6505 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6505 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6505 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6505 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6505 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6505 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6505 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6505 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6505 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6505 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6505 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6505 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6505 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6505 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6505 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6505 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6505 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6505 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6505 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6505 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6505 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6505 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _6506){
  if ((_6506 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6506 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6506 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6506 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6506 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6506 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6506 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6506 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6506 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _6507){
  if ((_6507 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _6508){
  if ((_6508 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6508 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6508 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6508 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6508 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _6509){
  if ((_6509 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6509 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6509 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _6510){
  if ((_6510 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6510 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6510 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6510 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6510 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6510 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6510 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _6511){
  if ((_6511 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6511 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6511 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6511 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _6512){
  if ((_6512 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6512 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6512 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _6513){
  if ((_6513 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_6513 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_6513 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_6513 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_6513 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_6513 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_6513 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_6513 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_6513 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_6513 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_6513 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_6513 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_6513 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_6513 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6513 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_6513 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_6513 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_6513 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_6513 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_6513 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6513 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_6513 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_6513 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_6513 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_6513 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_6513 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_6513 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6513 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_6513 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_6513 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_6513 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_6513 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_6513 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_6513 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_6513 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_6513 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_6513 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_6513 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_6513 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_6513 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_6513 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_6513 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_6513 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_6513 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_6513 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_6513 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_6513 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_6513 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_6513 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_6513 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_6513 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_6513 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_6513 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_6513 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_6513 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_6513 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_6513 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_6513 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_6513 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_6513 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_6513 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_6513 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_6513 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_6513 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_6513 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_6513 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_6513 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6513 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_6513 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_6513 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_6513 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_6513 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_6513 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_6513 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_6513 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_6513 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_6513 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_6513 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_6513 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_6513 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_6513 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_6513 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_6513 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_6513 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_6513 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_6513 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_6513 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_6513 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_6513 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_6513 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_6513 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_6513 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_6513 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _6514){
  if ((_6514 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6514 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6514 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6514 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6514 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _6515){
  if ((_6515 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6515 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6515 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6515 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _6516){
  if ((_6516 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6516 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6516 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _6517){
  if ((_6517 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6517 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6517 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _6518){
  if ((_6518 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6518 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6518 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6518 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _6519){
  if ((_6519 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6519 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _6520){
  if ((_6520 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6520 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _6521){
  if ((_6521 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6521 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6521 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6521 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6521 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _6522){
  if ((_6522 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6522 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _6523){
  if ((_6523 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6523 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6523 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6523 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6523 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _6524){
  if ((_6524 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6524 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_6524 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_6524 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_6524 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _6525){
  if ((_6525 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_6525 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }