#ifndef __FUSION_P_H__
#define __FUSION_P_H__
#include "monty.h"
#include "mosektask_p.h"
#include "list"
#include "vector"
#include "unordered_map"
#include "fusion.h"
namespace mosek
{
namespace fusion
{
// mosek.fusion.BaseModel from file 'src/fusion/cxx/BaseModel_p.h'
// namespace mosek::fusion
struct p_BaseModel
{
  p_BaseModel(BaseModel * _pubthis);

  void _initialize( monty::rc_ptr<BaseModel> m);
  void _initialize( const std::string & name,
                    const std::string & licpath);

  virtual ~p_BaseModel() { /* std::cout << "~p_BaseModel()" << std::endl;*/  }

  static p_BaseModel * _get_impl(Model * _inst) { return _inst->_impl; }

  //----------------------

  bool synched;
  std::string taskname;

  monty::rc_ptr<SolutionStruct> sol_itr;
  monty::rc_ptr<SolutionStruct> sol_itg;
  monty::rc_ptr<SolutionStruct> sol_bas;

  //---------------------

  std::unique_ptr<Task> task;

  //---------------------
  void task_setLogHandler (const msghandler_t & handler);
  void task_setDataCallbackHandler (const datacbhandler_t & handler);
  void task_setCallbackHandler (const cbhandler_t & handler);

  int task_append_barvar(int size, int num);

  void task_var_name   (int index, const std::string & name);
  void task_con_name   (int index, const std::string & name);
  void task_cone_name  (int index, const std::string & name);
  void task_barvar_name(int index, const std::string & name);
  void task_objectivename(         const std::string & name);

  void task_format_var_names(const std::shared_ptr<monty::ndarray<int,1>> subj, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_con_names(const std::shared_ptr<monty::ndarray<int,1>> subi, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_cone_names(const std::shared_ptr<monty::ndarray<int,1>> subk, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);

  void task_break_solve();

  //--------------------------

  int task_numvar();
  int task_numcon();
  int task_numcone();
  int task_numbarvar();

  //--------------------------

  void task_put_param(const std::string & name, const std::string & value);
  void task_put_param(const std::string & name, int    value);
  void task_put_param(const std::string & name, double value);
  
  double    task_get_dinf (const std::string & name);
  int       task_get_iinf (const std::string & name);
  long long task_get_liinf(const std::string & name);
  
  //--------------------------

  void task_con_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_con_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );

  void task_var_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_var_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );
  
  void task_var_putintlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);
  void task_var_putcontlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs); 
 
  //--------------------------

  void task_putbararowlist(const std::shared_ptr<monty::ndarray<int,1>>       subi,
                           const std::shared_ptr<monty::ndarray<long long,1>> ptr,
                           const std::shared_ptr<monty::ndarray<int,1>>       subj,
                           const std::shared_ptr<monty::ndarray<long long,1>> matidx);

  void task_putbaraijlist(const std::shared_ptr<monty::ndarray<int,1>> subi,
                          const std::shared_ptr<monty::ndarray<int,1>> subj,
                          std::shared_ptr<monty::ndarray<long long,1>> matidx);
  
  void task_putbarc(const std::shared_ptr<monty::ndarray<int,1>> subj,
                    const std::shared_ptr<monty::ndarray<int,1>> subl,
                    const std::shared_ptr<monty::ndarray<int,1>> subk,
                    const std::shared_ptr<monty::ndarray<double,1>> val);
  
  std::shared_ptr<monty::ndarray<long long,1>> task_appendsymmatlist (const std::shared_ptr<monty::ndarray<int,1>>       & dim, 
                                                                      const std::shared_ptr<monty::ndarray<long long,1>> & nz, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subk, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subl, 
                                                                      const std::shared_ptr<monty::ndarray<double,1>>    & val);
  int  task_barvar_dim(int j);
  void task_putbaraij (int i, int j, int k);
  void task_putbaraij (int i, int j, const std::shared_ptr<monty::ndarray<int,1>> & k);
  void task_putbarcj  (int j, int k);
  void task_putbarcj  (int j,        const std::shared_ptr<monty::ndarray<int,1>> & k);
  int  task_barvardim (int index);

  int task_append_var(int num);
  int task_append_con(int num);

  void task_append_zerocones (int numcone);
  void task_clear_cones   ( const std::shared_ptr<monty::ndarray<int,1>> & idxs );
  void task_put_zerocones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_quadcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_rquadcones( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_pexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_ppowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );
  void task_put_dexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_dpowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );

  void task_putarowlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & idxs, 
    const std::shared_ptr<monty::ndarray<long long,1>> & ptrb, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof);
  void task_putaijlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & subi, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof, 
    long long                           num);

  void task_setnumvar(int num);
  void task_cleanup(int oldnum, int oldnumcon, int oldnumcone, int oldnumbarvar);
  void task_solve();

  void task_putobjective( 
    bool                             maximize,
    const std::shared_ptr<monty::ndarray<int,1>>    & subj    ,
    const std::shared_ptr<monty::ndarray<double,1>> & cof     ,
    double                           cfix    );

  void task_putclist(   
    const std::shared_ptr<monty::ndarray<int,1>>    & subj,
    const std::shared_ptr<monty::ndarray<double,1>> & cof);


  void task_putobjectivename(const std::string & name);

  void task_write(const std::string & filename);
  void task_dump (const std::string & filename);

  MSKtask_t task_get();
  MSKtask_t __mosek_2fusion_2BaseModel__task_get();
  
  void dispose();

  void task_putxx_slice(SolutionType which, int first, int last, std::shared_ptr<monty::ndarray<double,1>> & xx);

  static void env_syeig (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);
  static void env_potrf (int n, std::shared_ptr<monty::ndarray<double,1>> & a);                        
  static void env_syevd (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);

  static void env_putlicensecode(std::shared_ptr<monty::ndarray<int,1>> code);
  static void env_putlicensepath(const std::string &licfile);
  static void env_putlicensewait(int wait);

  static std::string env_getversion();

  void convertSolutionStatus(MSKsoltypee soltype, p_SolutionStruct * sol, MSKsolstae status, MSKprostae prosta);


};

// End of file 'src/fusion/cxx/BaseModel_p.h'
struct p_Model : public ::mosek::fusion::p_BaseModel
{
Model * _pubthis;
static mosek::fusion::p_Model* _get_impl(mosek::fusion::Model * _inst){ return static_cast< mosek::fusion::p_Model* >(mosek::fusion::p_BaseModel::_get_impl(_inst)); }
static mosek::fusion::p_Model * _get_impl(mosek::fusion::Model::t _inst) { return _get_impl(_inst.get()); }
p_Model(Model * _pubthis);
virtual ~p_Model() { /* std::cout << "~p_Model" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::WorkStack > xs{};monty::rc_ptr< ::mosek::fusion::WorkStack > ws{};monty::rc_ptr< ::mosek::fusion::WorkStack > rs{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > con_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > cons{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_type{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_ub{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_lb{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_efix{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_idx{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_slackidx{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconmap{};std::shared_ptr< monty::ndarray< bool,1 > > initsol_xx_flag{};std::shared_ptr< monty::ndarray< double,1 > > initsol_xx{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > var_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > barvars{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_ptr{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_num{};int natbarvarmap_nblock{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_dim{};std::shared_ptr< monty::ndarray< long long,1 > > natbarvar_ptr{};int natbarvar_numbarvarelm{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_j{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_i{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_type{};std::shared_ptr< monty::ndarray< int,1 > > natconemap_dim{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconemap{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > vars{};int bfixidx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natvarmap{};mosek::fusion::SolutionType solutionptr{};mosek::fusion::AccSolutionStatus acceptable_sol{};std::string model_name{};virtual void destroy();
static Model::t _new_Model(monty::rc_ptr< ::mosek::fusion::Model > _464);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _464);
static Model::t _new_Model(const std::string &  _469);
void _initialize(const std::string &  _469);
static Model::t _new_Model();
void _initialize();
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _472,std::shared_ptr< monty::ndarray< int,1 > > _473,std::shared_ptr< monty::ndarray< int,1 > > _474) ;
virtual void connames(std::shared_ptr< monty::ndarray< int,1 > > _475,const std::string &  _476,std::shared_ptr< monty::ndarray< int,1 > > _477,std::shared_ptr< monty::ndarray< long long,1 > > _478) ;
virtual void varnames(std::shared_ptr< monty::ndarray< int,1 > > _479,const std::string &  _480,std::shared_ptr< monty::ndarray< int,1 > > _481,std::shared_ptr< monty::ndarray< long long,1 > > _482) ;
virtual void varname(int _483,const std::string &  _484) ;
virtual void natbarvarmap_get(int _485,std::shared_ptr< monty::ndarray< int,1 > > _486) ;
virtual void natbarvar_get(int _490,std::shared_ptr< monty::ndarray< long long,1 > > _491) ;
virtual int natbarvarmap_alloc(int _498,int _499) ;
virtual int natvarmap_alloc(int _517) ;
virtual int natconmap_alloc(int _527) ;
virtual int natconemap_alloc(int _537) ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _540) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _546) ;
static  void putlicensewait(bool _552);
static  void putlicensepath(const std::string &  _553);
static  void putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _554);
virtual /* override */ void dispose() ;
virtual void nativeVarToStr(int _557,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _558) ;
virtual MSKtask_t __mosek_2fusion_2Model__getTask() ;
virtual void getConstraintValues(bool _559,std::shared_ptr< monty::ndarray< int,1 > > _560,std::shared_ptr< monty::ndarray< double,1 > > _561,int _562) ;
virtual void getVariableDuals(bool _570,std::shared_ptr< monty::ndarray< long long,1 > > _571,std::shared_ptr< monty::ndarray< double,1 > > _572,int _573) ;
virtual void getVariableValues(bool _579,std::shared_ptr< monty::ndarray< long long,1 > > _580,std::shared_ptr< monty::ndarray< double,1 > > _581,int _582) ;
virtual void setVariableValues(bool _588,std::shared_ptr< monty::ndarray< long long,1 > > _589,std::shared_ptr< monty::ndarray< double,1 > > _590) ;
virtual void flushNames() ;
virtual void writeTask(const std::string &  _600) ;
virtual long long getSolverLIntInfo(const std::string &  _601) ;
virtual int getSolverIntInfo(const std::string &  _602) ;
virtual double getSolverDoubleInfo(const std::string &  _603) ;
virtual void setCallbackHandler(mosek::cbhandler_t  _604) ;
virtual void setDataCallbackHandler(mosek::datacbhandler_t  _605) ;
virtual void setLogHandler(mosek::msghandler_t  _606) ;
virtual void setSolverParam(const std::string &  _607,double _608) ;
virtual void setSolverParam(const std::string &  _609,int _610) ;
virtual void setSolverParam(const std::string &  _611,const std::string &  _612) ;
virtual void breakSolver() ;
virtual void solve() ;
virtual void flushSolutions() ;
virtual void flush_initsol(mosek::fusion::SolutionType _613) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus() ;
virtual mosek::fusion::ProblemStatus getProblemStatus() ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus() ;
virtual double dualObjValue() ;
virtual double primalObjValue() ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _620,bool _621,bool _622) ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _627,bool _628) ;
virtual void setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _629,std::shared_ptr< monty::ndarray< double,1 > > _630) ;
virtual void ensure_initsol_xx() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_bars(mosek::fusion::SolutionType _637) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_barx(mosek::fusion::SolutionType _638) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_y(mosek::fusion::SolutionType _639) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xc(mosek::fusion::SolutionType _640) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_snx(mosek::fusion::SolutionType _641) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_suc(mosek::fusion::SolutionType _642) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slc(mosek::fusion::SolutionType _643) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_sux(mosek::fusion::SolutionType _644) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slx(mosek::fusion::SolutionType _645) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_yx(mosek::fusion::SolutionType _646) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xx(mosek::fusion::SolutionType _647) ;
virtual void selectedSolution(mosek::fusion::SolutionType _648) ;
virtual mosek::fusion::AccSolutionStatus getAcceptedSolutionStatus() ;
virtual void acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _649) ;
virtual mosek::fusion::ProblemStatus getProblemStatus(mosek::fusion::SolutionType _650) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus(mosek::fusion::SolutionType _652) ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus(mosek::fusion::SolutionType _653) ;
virtual mosek::fusion::SolutionStatus getSolutionStatus(mosek::fusion::SolutionType _654,bool _655) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _658,monty::rc_ptr< ::mosek::fusion::Expression > _659) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _692,monty::rc_ptr< ::mosek::fusion::Expression > _693,std::shared_ptr< monty::ndarray< int,1 > > _694,bool _695) ;
virtual void updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _725,monty::rc_ptr< ::mosek::fusion::Variable > _726) ;
virtual void objective_(const std::string &  _760,mosek::fusion::ObjectiveSense _761,monty::rc_ptr< ::mosek::fusion::Expression > _762) ;
virtual void objective(double _791) ;
virtual void objective(mosek::fusion::ObjectiveSense _792,double _793) ;
virtual void objective(mosek::fusion::ObjectiveSense _794,monty::rc_ptr< ::mosek::fusion::Expression > _795) ;
virtual void objective(const std::string &  _796,double _797) ;
virtual void objective(const std::string &  _798,mosek::fusion::ObjectiveSense _799,double _800) ;
virtual void objective(const std::string &  _801,mosek::fusion::ObjectiveSense _802,monty::rc_ptr< ::mosek::fusion::Expression > _803) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _804,monty::rc_ptr< ::mosek::fusion::ConeDomain > _805) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _806,monty::rc_ptr< ::mosek::fusion::Expression > _807,monty::rc_ptr< ::mosek::fusion::ConeDomain > _808) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _809,monty::rc_ptr< ::mosek::fusion::RangeDomain > _810) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _811,monty::rc_ptr< ::mosek::fusion::Expression > _812,monty::rc_ptr< ::mosek::fusion::RangeDomain > _813) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _814,monty::rc_ptr< ::mosek::fusion::LinearDomain > _815) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _816,monty::rc_ptr< ::mosek::fusion::Expression > _817,monty::rc_ptr< ::mosek::fusion::LinearDomain > _818) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _819,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _820) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _821,monty::rc_ptr< ::mosek::fusion::Expression > _822,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _823) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _824,monty::rc_ptr< ::mosek::fusion::PSDDomain > _825) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _826,monty::rc_ptr< ::mosek::fusion::Expression > _827,monty::rc_ptr< ::mosek::fusion::PSDDomain > _828) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _829) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _830,int _831,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _832) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _833,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _834) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _835,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _836) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _837,int _838,int _839,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _840) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _841,int _842,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _843) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _844,std::shared_ptr< monty::ndarray< int,1 > > _845,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _846) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _847) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _848,int _849,monty::rc_ptr< ::mosek::fusion::PSDDomain > _850) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _851,monty::rc_ptr< ::mosek::fusion::PSDDomain > _852) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _853,monty::rc_ptr< ::mosek::fusion::PSDDomain > _854) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _855,int _856,int _857,monty::rc_ptr< ::mosek::fusion::PSDDomain > _858) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _859,int _860,monty::rc_ptr< ::mosek::fusion::PSDDomain > _861) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _862,std::shared_ptr< monty::ndarray< int,1 > > _863,monty::rc_ptr< ::mosek::fusion::PSDDomain > _864) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _865) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _866) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _867) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _868,monty::rc_ptr< ::mosek::fusion::ConeDomain > _869) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _870,monty::rc_ptr< ::mosek::fusion::RangeDomain > _871) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _872,monty::rc_ptr< ::mosek::fusion::LinearDomain > _873) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _874) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _875,monty::rc_ptr< ::mosek::fusion::ConeDomain > _876) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _877,monty::rc_ptr< ::mosek::fusion::RangeDomain > _878) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _879,monty::rc_ptr< ::mosek::fusion::LinearDomain > _880) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _881) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _882,monty::rc_ptr< ::mosek::fusion::ConeDomain > _883) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _884,monty::rc_ptr< ::mosek::fusion::RangeDomain > _885) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _886,monty::rc_ptr< ::mosek::fusion::LinearDomain > _887) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _888,std::shared_ptr< monty::ndarray< int,1 > > _889,monty::rc_ptr< ::mosek::fusion::ConeDomain > _890) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _891,std::shared_ptr< monty::ndarray< int,1 > > _892,monty::rc_ptr< ::mosek::fusion::RangeDomain > _893) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _894,std::shared_ptr< monty::ndarray< int,1 > > _895,monty::rc_ptr< ::mosek::fusion::LinearDomain > _896) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _897,std::shared_ptr< monty::ndarray< int,1 > > _898) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _899,int _900,monty::rc_ptr< ::mosek::fusion::ConeDomain > _901) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _902,int _903,monty::rc_ptr< ::mosek::fusion::RangeDomain > _904) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _905,int _906,monty::rc_ptr< ::mosek::fusion::LinearDomain > _907) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _908,int _909) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _910) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__ranged_variable(const std::string &  _911,std::shared_ptr< monty::ndarray< int,1 > > _912,monty::rc_ptr< ::mosek::fusion::RangeDomain > _913) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _934,std::shared_ptr< monty::ndarray< int,1 > > _935,monty::rc_ptr< ::mosek::fusion::ConeDomain > _936) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _964,std::shared_ptr< monty::ndarray< int,1 > > _965,monty::rc_ptr< ::mosek::fusion::LinearDomain > _966) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _1006,std::shared_ptr< monty::ndarray< int,1 > > _1007,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1008) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricVariable > __mosek_2fusion_2Model__variable_(const std::string &  _1030,std::shared_ptr< monty::ndarray< int,1 > > _1031,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1032) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1047,monty::rc_ptr< ::mosek::fusion::Expression > _1048,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1049) ;
virtual void update_bfix(std::shared_ptr< monty::ndarray< int,1 > > _1089,std::shared_ptr< monty::ndarray< double,1 > > _1090) ;
virtual void putarows(std::shared_ptr< monty::ndarray< int,1 > > _1092,monty::rc_ptr< ::mosek::fusion::WorkStack > _1093,int _1094,int _1095,int _1096,int _1097,int _1098) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1135,monty::rc_ptr< ::mosek::fusion::Expression > _1136,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1137) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1203,monty::rc_ptr< ::mosek::fusion::Expression > _1204,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1205) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1256,monty::rc_ptr< ::mosek::fusion::Expression > _1257,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1258) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1308,monty::rc_ptr< ::mosek::fusion::Expression > _1309,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1310) ;
static  std::string getVersion();
virtual bool hasConstraint(const std::string &  _1357) ;
virtual bool hasVariable(const std::string &  _1358) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(int _1359) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(const std::string &  _1360) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(int _1361) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(const std::string &  _1362) ;
virtual std::string getName() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Model__clone() ;
}; // struct Model;

// mosek.fusion.Debug from file 'src/fusion/cxx/Debug_p.h'
// namespace mosek::fusion
struct p_Debug
{
  Debug * _pubthis;

  p_Debug(Debug * _pubthis) : _pubthis(_pubthis) {}

  static Debug::t o ()                 { return monty::rc_ptr<Debug>(new Debug()); }
  Debug::t p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (      int val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (long long val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (   double val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (     bool val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t lf()                        { std::cout << std::endl; return Debug::t(_pubthis); }

  static p_Debug * _get_impl(Debug * _inst) { return _inst->ptr; }

  template<typename T>
  Debug::t p(const std::shared_ptr<monty::ndarray<T,1>> & val)
  {
    if (val->size() > 0)
    {
      std::cout << (*val)[0];
      for (int i = 1; i < val->size(); ++i)
        std::cout << "," << (*val)[i];
    }
    return Debug::t(_pubthis);
  }

  Debug::t __mosek_2fusion_2Debug__p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }

  template<class C>
  Debug::t __mosek_2fusion_2Debug__p (C val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t __mosek_2fusion_2Debug__lf()      { std::cout << std::endl; return Debug::t(_pubthis); }
  
};
// End of file 'src/fusion/cxx/Debug_p.h'
struct p_Sort
{
Sort * _pubthis;
static mosek::fusion::p_Sort* _get_impl(mosek::fusion::Sort * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Sort * _get_impl(mosek::fusion::Sort::t _inst) { return _get_impl(_inst.get()); }
p_Sort(Sort * _pubthis);
virtual ~p_Sort() { /* std::cout << "~p_Sort" << std::endl;*/ };
virtual void destroy();
static  void argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _151,std::shared_ptr< monty::ndarray< long long,1 > > _152,int _153,int _154,int _155,std::shared_ptr< monty::ndarray< long long,1 > > _156);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _164,std::shared_ptr< monty::ndarray< long long,1 > > _165);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _166,std::shared_ptr< monty::ndarray< int,1 > > _167);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _168,std::shared_ptr< monty::ndarray< long long,1 > > _169,std::shared_ptr< monty::ndarray< long long,1 > > _170);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _171,std::shared_ptr< monty::ndarray< int,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,long long _176,long long _177);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179,long long _180,long long _181);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _182,std::shared_ptr< monty::ndarray< long long,1 > > _183,std::shared_ptr< monty::ndarray< long long,1 > > _184,long long _185,long long _186);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _187,std::shared_ptr< monty::ndarray< int,1 > > _188,std::shared_ptr< monty::ndarray< int,1 > > _189,long long _190,long long _191);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _192,std::shared_ptr< monty::ndarray< long long,1 > > _193,long long _194,long long _195,bool _196);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _199,std::shared_ptr< monty::ndarray< int,1 > > _200,long long _201,long long _202,bool _203);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _206,std::shared_ptr< monty::ndarray< long long,1 > > _207,std::shared_ptr< monty::ndarray< long long,1 > > _208,long long _209,long long _210,bool _211);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _214,std::shared_ptr< monty::ndarray< int,1 > > _215,std::shared_ptr< monty::ndarray< int,1 > > _216,long long _217,long long _218,bool _219);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _222,std::shared_ptr< monty::ndarray< long long,1 > > _223,long long _224,long long _225,long long _226,long long _227);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< int,1 > > _229,long long _230,long long _231,int _232,int _233);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< long long,1 > > _235,std::shared_ptr< monty::ndarray< long long,1 > > _236,long long _237,long long _238,std::shared_ptr< monty::ndarray< long long,1 > > _239);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _242,std::shared_ptr< monty::ndarray< int,1 > > _243,std::shared_ptr< monty::ndarray< int,1 > > _244,long long _245,long long _246,std::shared_ptr< monty::ndarray< int,1 > > _247);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _250,std::shared_ptr< monty::ndarray< long long,1 > > _251,long long _252,long long _253,bool _254);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< int,1 > > _257,long long _258,long long _259,bool _260);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< long long,1 > > _263,std::shared_ptr< monty::ndarray< long long,1 > > _264,long long _265,long long _266,bool _267);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< int,1 > > _270,std::shared_ptr< monty::ndarray< int,1 > > _271,long long _272,long long _273,bool _274);
}; // struct Sort;

struct p_IndexCounter
{
IndexCounter * _pubthis;
static mosek::fusion::p_IndexCounter* _get_impl(mosek::fusion::IndexCounter * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_IndexCounter * _get_impl(mosek::fusion::IndexCounter::t _inst) { return _get_impl(_inst.get()); }
p_IndexCounter(IndexCounter * _pubthis);
virtual ~p_IndexCounter() { /* std::cout << "~p_IndexCounter" << std::endl;*/ };
long long start{};std::shared_ptr< monty::ndarray< int,1 > > dims{};std::shared_ptr< monty::ndarray< long long,1 > > strides{};std::shared_ptr< monty::ndarray< long long,1 > > st{};std::shared_ptr< monty::ndarray< int,1 > > ii{};int n{};virtual void destroy();
static IndexCounter::t _new_IndexCounter(std::shared_ptr< monty::ndarray< int,1 > > _276);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _276);
static IndexCounter::t _new_IndexCounter(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
void _initialize(long long _278,std::shared_ptr< monty::ndarray< int,1 > > _279,std::shared_ptr< monty::ndarray< int,1 > > _280);
static IndexCounter::t _new_IndexCounter(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
void _initialize(long long _283,std::shared_ptr< monty::ndarray< int,1 > > _284,std::shared_ptr< monty::ndarray< long long,1 > > _285);
virtual bool atEnd() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getIndex() ;
virtual long long next() ;
virtual long long get() ;
virtual void inc() ;
virtual void reset() ;
}; // struct IndexCounter;

struct p_CommonTools
{
CommonTools * _pubthis;
static mosek::fusion::p_CommonTools* _get_impl(mosek::fusion::CommonTools * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_CommonTools * _get_impl(mosek::fusion::CommonTools::t _inst) { return _get_impl(_inst.get()); }
p_CommonTools(CommonTools * _pubthis);
virtual ~p_CommonTools() { /* std::cout << "~p_CommonTools" << std::endl;*/ };
virtual void destroy();
static  std::shared_ptr< monty::ndarray< long long,1 > > resize(std::shared_ptr< monty::ndarray< long long,1 > > _291,int _292);
static  std::shared_ptr< monty::ndarray< int,1 > > resize(std::shared_ptr< monty::ndarray< int,1 > > _294,int _295);
static  std::shared_ptr< monty::ndarray< double,1 > > resize(std::shared_ptr< monty::ndarray< double,1 > > _297,int _298);
static  int binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301);
static  int binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _305,long long _306);
static  int binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _308,long long _309);
static  int binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _313,long long _314);
static  void ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _318,std::shared_ptr< monty::ndarray< int,1 > > _319,std::shared_ptr< monty::ndarray< int,1 > > _320);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _322,std::shared_ptr< monty::ndarray< int,1 > > _323,std::shared_ptr< monty::ndarray< double,1 > > _324,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _325,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _326,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _327,long long _328,int _329,int _330);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _343,std::shared_ptr< monty::ndarray< int,1 > > _344,std::shared_ptr< monty::ndarray< double,1 > > _345,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _346,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _347,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _348,long long _349,int _350,int _351);
static  void tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _364,std::shared_ptr< monty::ndarray< int,1 > > _365,std::shared_ptr< monty::ndarray< double,1 > > _366,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _367,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _368,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _369,long long _370,int _371,int _372);
static  void argMSort(std::shared_ptr< monty::ndarray< int,1 > > _398,std::shared_ptr< monty::ndarray< int,1 > > _399);
static  void mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405,std::shared_ptr< monty::ndarray< int,1 > > _406,int _407,int _408,int _409);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _415,std::shared_ptr< monty::ndarray< long long,1 > > _416,std::shared_ptr< monty::ndarray< long long,1 > > _417,long long _418,long long _419);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _420,std::shared_ptr< monty::ndarray< int,1 > > _421,std::shared_ptr< monty::ndarray< int,1 > > _422,long long _423,long long _424);
}; // struct CommonTools;

struct p_SolutionStruct
{
SolutionStruct * _pubthis;
static mosek::fusion::p_SolutionStruct* _get_impl(mosek::fusion::SolutionStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SolutionStruct * _get_impl(mosek::fusion::SolutionStruct::t _inst) { return _get_impl(_inst.get()); }
p_SolutionStruct(SolutionStruct * _pubthis);
virtual ~p_SolutionStruct() { /* std::cout << "~p_SolutionStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > yx{};std::shared_ptr< monty::ndarray< double,1 > > snx{};std::shared_ptr< monty::ndarray< double,1 > > sux{};std::shared_ptr< monty::ndarray< double,1 > > slx{};std::shared_ptr< monty::ndarray< double,1 > > bars{};std::shared_ptr< monty::ndarray< double,1 > > barx{};std::shared_ptr< monty::ndarray< double,1 > > y{};std::shared_ptr< monty::ndarray< double,1 > > suc{};std::shared_ptr< monty::ndarray< double,1 > > slc{};std::shared_ptr< monty::ndarray< double,1 > > xx{};std::shared_ptr< monty::ndarray< double,1 > > xc{};double dobj{};double pobj{};mosek::fusion::ProblemStatus probstatus{};mosek::fusion::SolutionStatus dstatus{};mosek::fusion::SolutionStatus pstatus{};int sol_numbarvar{};int sol_numcone{};int sol_numvar{};int sol_numcon{};virtual void destroy();
static SolutionStruct::t _new_SolutionStruct(int _425,int _426,int _427,int _428);
void _initialize(int _425,int _426,int _427,int _428);
static SolutionStruct::t _new_SolutionStruct(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
void _initialize(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _429);
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2SolutionStruct__clone() ;
virtual void resize(int _430,int _431,int _432,int _433) ;
virtual bool isDualAcceptable(mosek::fusion::AccSolutionStatus _453) ;
virtual bool isPrimalAcceptable(mosek::fusion::AccSolutionStatus _454) ;
virtual bool isAcceptable(mosek::fusion::SolutionStatus _455,mosek::fusion::AccSolutionStatus _456) ;
}; // struct SolutionStruct;

struct p_ConNZStruct
{
ConNZStruct * _pubthis;
static mosek::fusion::p_ConNZStruct* _get_impl(mosek::fusion::ConNZStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConNZStruct * _get_impl(mosek::fusion::ConNZStruct::t _inst) { return _get_impl(_inst.get()); }
p_ConNZStruct(ConNZStruct * _pubthis);
virtual ~p_ConNZStruct() { /* std::cout << "~p_ConNZStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};virtual void destroy();
static ConNZStruct::t _new_ConNZStruct(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _457,std::shared_ptr< monty::ndarray< int,1 > > _458,std::shared_ptr< monty::ndarray< double,1 > > _459,std::shared_ptr< monty::ndarray< double,1 > > _460,std::shared_ptr< monty::ndarray< int,1 > > _461,std::shared_ptr< monty::ndarray< int,1 > > _462,std::shared_ptr< monty::ndarray< int,1 > > _463);
}; // struct ConNZStruct;

struct p_BaseVariable : public /*implements*/ virtual ::mosek::fusion::Variable
{
BaseVariable * _pubthis;
static mosek::fusion::p_BaseVariable* _get_impl(mosek::fusion::BaseVariable * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseVariable * _get_impl(mosek::fusion::BaseVariable::t _inst) { return _get_impl(_inst.get()); }
p_BaseVariable(BaseVariable * _pubthis);
virtual ~p_BaseVariable() { /* std::cout << "~p_BaseVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};monty::rc_ptr< ::mosek::fusion::Model > model{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1601,monty::rc_ptr< ::mosek::fusion::Model > _1602);
void _initialize(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1601,monty::rc_ptr< ::mosek::fusion::Model > _1602);
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::Model > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< long long,1 > > _1605,std::shared_ptr< monty::ndarray< long long,1 > > _1606);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1603,std::shared_ptr< monty::ndarray< int,1 > > _1604,std::shared_ptr< monty::ndarray< long long,1 > > _1605,std::shared_ptr< monty::ndarray< long long,1 > > _1606);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseVariable__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseVariable__eval(); }
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1609,monty::rc_ptr< ::mosek::fusion::WorkStack > _1610,monty::rc_ptr< ::mosek::fusion::WorkStack > _1611) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1631) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _1631) { return __mosek_2fusion_2BaseVariable__reshape(_1631); }
virtual void setLevel(std::shared_ptr< monty::ndarray< double,1 > > _1635) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2BaseVariable__getModel() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
virtual int getND() ;
virtual int getDim(int _1638) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual long long getSize() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void makeContinuous() ;
virtual void makeInteger() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1659,int _1660,int _1661) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1659,int _1660,int _1661) { return __mosek_2fusion_2BaseVariable__index(_1659,_1660,_1661); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1662,int _1663) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1662,int _1663) { return __mosek_2fusion_2BaseVariable__index(_1662,_1663); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1664) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1664) { return __mosek_2fusion_2BaseVariable__index(_1664); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1667) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1667) { return __mosek_2fusion_2BaseVariable__index(_1667); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1668,std::shared_ptr< monty::ndarray< int,1 > > _1669,std::shared_ptr< monty::ndarray< int,1 > > _1670) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1668,std::shared_ptr< monty::ndarray< int,1 > > _1669,std::shared_ptr< monty::ndarray< int,1 > > _1670) { return __mosek_2fusion_2BaseVariable__pick(_1668,_1669,_1670); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1673,std::shared_ptr< monty::ndarray< int,1 > > _1674) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1673,std::shared_ptr< monty::ndarray< int,1 > > _1674) { return __mosek_2fusion_2BaseVariable__pick(_1673,_1674); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1677) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1677) { return __mosek_2fusion_2BaseVariable__pick(_1677); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return __mosek_2fusion_2BaseVariable__pick(_1698); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag(int _1708) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag(int _1708) { return __mosek_2fusion_2BaseVariable__antidiag(_1708); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag(int _1709) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag(int _1709) { return __mosek_2fusion_2BaseVariable__diag(_1709); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _1710,std::shared_ptr< monty::ndarray< int,1 > > _1711,int _1712) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1733,std::shared_ptr< monty::ndarray< int,1 > > _1734) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1733,std::shared_ptr< monty::ndarray< int,1 > > _1734) { return __mosek_2fusion_2BaseVariable__slice(_1733,_1734); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1768,int _1769) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1768,int _1769) { return __mosek_2fusion_2BaseVariable__slice(_1768,_1769); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseVariable__asExpr() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
virtual int inst(int _1778,std::shared_ptr< monty::ndarray< long long,1 > > _1779,int _1780,std::shared_ptr< monty::ndarray< long long,1 > > _1781) ;
virtual int numInst() ;
virtual void inst(int _1784,std::shared_ptr< monty::ndarray< long long,1 > > _1785) ;
virtual void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1792,bool _1793) ;
virtual void dual_lu(int _1798,std::shared_ptr< monty::ndarray< double,1 > > _1799,bool _1800) ;
virtual void values(int _1803,std::shared_ptr< monty::ndarray< double,1 > > _1804,bool _1805) ;
virtual void make_continuous() ;
virtual void make_integer() ;
}; // struct BaseVariable;

struct p_SliceVariable : public ::mosek::fusion::p_BaseVariable
{
SliceVariable * _pubthis;
static mosek::fusion::p_SliceVariable* _get_impl(mosek::fusion::SliceVariable * _inst){ return static_cast< mosek::fusion::p_SliceVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_SliceVariable * _get_impl(mosek::fusion::SliceVariable::t _inst) { return _get_impl(_inst.get()); }
p_SliceVariable(SliceVariable * _pubthis);
virtual ~p_SliceVariable() { /* std::cout << "~p_SliceVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};virtual void destroy();
static SliceVariable::t _new_SliceVariable(monty::rc_ptr< ::mosek::fusion::Model > _1364,std::shared_ptr< monty::ndarray< int,1 > > _1365,std::shared_ptr< monty::ndarray< long long,1 > > _1366,std::shared_ptr< monty::ndarray< long long,1 > > _1367);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1364,std::shared_ptr< monty::ndarray< int,1 > > _1365,std::shared_ptr< monty::ndarray< long long,1 > > _1366,std::shared_ptr< monty::ndarray< long long,1 > > _1367);
}; // struct SliceVariable;

struct p_ModelVariable : public ::mosek::fusion::p_BaseVariable
{
ModelVariable * _pubthis;
static mosek::fusion::p_ModelVariable* _get_impl(mosek::fusion::ModelVariable * _inst){ return static_cast< mosek::fusion::p_ModelVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_ModelVariable * _get_impl(mosek::fusion::ModelVariable::t _inst) { return _get_impl(_inst.get()); }
p_ModelVariable(ModelVariable * _pubthis);
virtual ~p_ModelVariable() { /* std::cout << "~p_ModelVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};long long varid{};std::string name{};virtual void destroy();
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1564,monty::rc_ptr< ::mosek::fusion::Model > _1565);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1564,monty::rc_ptr< ::mosek::fusion::Model > _1565);
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::Model > _1566,const std::string &  _1567,std::shared_ptr< monty::ndarray< int,1 > > _1568,long long _1569,std::shared_ptr< monty::ndarray< long long,1 > > _1570,std::shared_ptr< monty::ndarray< long long,1 > > _1571);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1566,const std::string &  _1567,std::shared_ptr< monty::ndarray< int,1 > > _1568,long long _1569,std::shared_ptr< monty::ndarray< long long,1 > > _1570,std::shared_ptr< monty::ndarray< long long,1 > > _1571);
virtual void flushNames() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void elementName(long long _1572,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1573) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1574) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelVariable;

struct p_SymRangedVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymRangedVariable * _pubthis;
static mosek::fusion::p_SymRangedVariable* _get_impl(mosek::fusion::SymRangedVariable * _inst){ return static_cast< mosek::fusion::p_SymRangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymRangedVariable * _get_impl(mosek::fusion::SymRangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymRangedVariable(SymRangedVariable * _pubthis);
virtual ~p_SymRangedVariable() { /* std::cout << "~p_SymRangedVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1368,monty::rc_ptr< ::mosek::fusion::Model > _1369);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1368,monty::rc_ptr< ::mosek::fusion::Model > _1369);
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1370,const std::string &  _1371,long long _1372,int _1373,std::shared_ptr< monty::ndarray< long long,1 > > _1374,std::shared_ptr< monty::ndarray< int,1 > > _1375);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1370,const std::string &  _1371,long long _1372,int _1373,std::shared_ptr< monty::ndarray< long long,1 > > _1374,std::shared_ptr< monty::ndarray< int,1 > > _1375);
virtual void dual_u(int _1376,std::shared_ptr< monty::ndarray< double,1 > > _1377) ;
virtual void dual_l(int _1378,std::shared_ptr< monty::ndarray< double,1 > > _1379) ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1383) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1383) { return __mosek_2fusion_2SymRangedVariable__clone(_1383); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1384,std::shared_ptr< monty::ndarray< long long,1 > > _1385,std::shared_ptr< monty::ndarray< int,1 > > _1386);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1402,std::shared_ptr< monty::ndarray< long long,1 > > _1403);
}; // struct SymRangedVariable;

struct p_RangedVariable : public ::mosek::fusion::p_ModelVariable
{
RangedVariable * _pubthis;
static mosek::fusion::p_RangedVariable* _get_impl(mosek::fusion::RangedVariable * _inst){ return static_cast< mosek::fusion::p_RangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_RangedVariable * _get_impl(mosek::fusion::RangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_RangedVariable(RangedVariable * _pubthis);
virtual ~p_RangedVariable() { /* std::cout << "~p_RangedVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};virtual void destroy();
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1414,monty::rc_ptr< ::mosek::fusion::Model > _1415);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1414,monty::rc_ptr< ::mosek::fusion::Model > _1415);
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1416,const std::string &  _1417,long long _1418,std::shared_ptr< monty::ndarray< int,1 > > _1419,std::shared_ptr< monty::ndarray< long long,1 > > _1420,std::shared_ptr< monty::ndarray< int,1 > > _1421);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1416,const std::string &  _1417,long long _1418,std::shared_ptr< monty::ndarray< int,1 > > _1419,std::shared_ptr< monty::ndarray< long long,1 > > _1420,std::shared_ptr< monty::ndarray< int,1 > > _1421);
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2RangedVariable__elementDesc(long long _1422,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1423) ;
virtual /* override */ void flushNames() ;
virtual void dual_u(int _1427,std::shared_ptr< monty::ndarray< double,1 > > _1428) ;
virtual void dual_l(int _1429,std::shared_ptr< monty::ndarray< double,1 > > _1430) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1431) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1431) { return __mosek_2fusion_2RangedVariable__clone(_1431); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1432);
}; // struct RangedVariable;

struct p_LinearPSDVariable : public ::mosek::fusion::p_ModelVariable
{
LinearPSDVariable * _pubthis;
static mosek::fusion::p_LinearPSDVariable* _get_impl(mosek::fusion::LinearPSDVariable * _inst){ return static_cast< mosek::fusion::p_LinearPSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDVariable * _get_impl(mosek::fusion::LinearPSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDVariable(LinearPSDVariable * _pubthis);
virtual ~p_LinearPSDVariable() { /* std::cout << "~p_LinearPSDVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};int varid{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int conedim{};virtual void destroy();
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1434,monty::rc_ptr< ::mosek::fusion::Model > _1435);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1434,monty::rc_ptr< ::mosek::fusion::Model > _1435);
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1436,const std::string &  _1437,int _1438,std::shared_ptr< monty::ndarray< int,1 > > _1439,int _1440,std::shared_ptr< monty::ndarray< long long,1 > > _1441);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1436,const std::string &  _1437,int _1438,std::shared_ptr< monty::ndarray< int,1 > > _1439,int _1440,std::shared_ptr< monty::ndarray< long long,1 > > _1441);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1444) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1445) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1446) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1446) { return __mosek_2fusion_2LinearPSDVariable__clone(_1446); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1447);
}; // struct LinearPSDVariable;

struct p_PSDVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
PSDVariable * _pubthis;
static mosek::fusion::p_PSDVariable* _get_impl(mosek::fusion::PSDVariable * _inst){ return static_cast< mosek::fusion::p_PSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_PSDVariable * _get_impl(mosek::fusion::PSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_PSDVariable(PSDVariable * _pubthis);
virtual ~p_PSDVariable() { /* std::cout << "~p_PSDVariable" << std::endl;*/ };
int conedim2{};int conedim1{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int varid{};virtual void destroy();
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1449,monty::rc_ptr< ::mosek::fusion::Model > _1450);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1449,monty::rc_ptr< ::mosek::fusion::Model > _1450);
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1451,const std::string &  _1452,int _1453,std::shared_ptr< monty::ndarray< int,1 > > _1454,int _1455,int _1456,std::shared_ptr< monty::ndarray< long long,1 > > _1457);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1451,const std::string &  _1452,int _1453,std::shared_ptr< monty::ndarray< int,1 > > _1454,int _1455,int _1456,std::shared_ptr< monty::ndarray< long long,1 > > _1457);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2PSDVariable__elementDesc(long long _1460,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1461) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1462) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1462) { return __mosek_2fusion_2PSDVariable__clone(_1462); }
static  std::shared_ptr< monty::ndarray< long long,1 > > fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1463,int _1464,int _1465,std::shared_ptr< monty::ndarray< long long,1 > > _1466);
}; // struct PSDVariable;

struct p_SymLinearVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymLinearVariable * _pubthis;
static mosek::fusion::p_SymLinearVariable* _get_impl(mosek::fusion::SymLinearVariable * _inst){ return static_cast< mosek::fusion::p_SymLinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymLinearVariable * _get_impl(mosek::fusion::SymLinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymLinearVariable(SymLinearVariable * _pubthis);
virtual ~p_SymLinearVariable() { /* std::cout << "~p_SymLinearVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1491,monty::rc_ptr< ::mosek::fusion::Model > _1492);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1491,monty::rc_ptr< ::mosek::fusion::Model > _1492);
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1493,const std::string &  _1494,long long _1495,int _1496,std::shared_ptr< monty::ndarray< long long,1 > > _1497,std::shared_ptr< monty::ndarray< int,1 > > _1498);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1493,const std::string &  _1494,long long _1495,int _1496,std::shared_ptr< monty::ndarray< long long,1 > > _1497,std::shared_ptr< monty::ndarray< int,1 > > _1498);
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1502) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1502) { return __mosek_2fusion_2SymLinearVariable__clone(_1502); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1503,std::shared_ptr< monty::ndarray< long long,1 > > _1504,std::shared_ptr< monty::ndarray< int,1 > > _1505);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1521,std::shared_ptr< monty::ndarray< long long,1 > > _1522);
}; // struct SymLinearVariable;

struct p_LinearVariable : public ::mosek::fusion::p_ModelVariable
{
LinearVariable * _pubthis;
static mosek::fusion::p_LinearVariable* _get_impl(mosek::fusion::LinearVariable * _inst){ return static_cast< mosek::fusion::p_LinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearVariable * _get_impl(mosek::fusion::LinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearVariable(LinearVariable * _pubthis);
virtual ~p_LinearVariable() { /* std::cout << "~p_LinearVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1533,monty::rc_ptr< ::mosek::fusion::Model > _1534);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1533,monty::rc_ptr< ::mosek::fusion::Model > _1534);
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1535,const std::string &  _1536,long long _1537,std::shared_ptr< monty::ndarray< int,1 > > _1538,std::shared_ptr< monty::ndarray< long long,1 > > _1539,std::shared_ptr< monty::ndarray< int,1 > > _1540);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1535,const std::string &  _1536,long long _1537,std::shared_ptr< monty::ndarray< int,1 > > _1538,std::shared_ptr< monty::ndarray< long long,1 > > _1539,std::shared_ptr< monty::ndarray< int,1 > > _1540);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1546) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1546) { return __mosek_2fusion_2LinearVariable__clone(_1546); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1547);
}; // struct LinearVariable;

struct p_ConicVariable : public ::mosek::fusion::p_ModelVariable
{
ConicVariable * _pubthis;
static mosek::fusion::p_ConicVariable* _get_impl(mosek::fusion::ConicVariable * _inst){ return static_cast< mosek::fusion::p_ConicVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_ConicVariable * _get_impl(mosek::fusion::ConicVariable::t _inst) { return _get_impl(_inst.get()); }
p_ConicVariable(ConicVariable * _pubthis);
virtual ~p_ConicVariable() { /* std::cout << "~p_ConicVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};int varid{};virtual void destroy();
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1549,monty::rc_ptr< ::mosek::fusion::Model > _1550);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1549,monty::rc_ptr< ::mosek::fusion::Model > _1550);
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::Model > _1551,const std::string &  _1552,int _1553,std::shared_ptr< monty::ndarray< int,1 > > _1554,std::shared_ptr< monty::ndarray< int,1 > > _1555);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1551,const std::string &  _1552,int _1553,std::shared_ptr< monty::ndarray< int,1 > > _1554,std::shared_ptr< monty::ndarray< int,1 > > _1555);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1561) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1561) { return __mosek_2fusion_2ConicVariable__clone(_1561); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1562);
}; // struct ConicVariable;

struct p_NilVariable : public ::mosek::fusion::p_BaseVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
NilVariable * _pubthis;
static mosek::fusion::p_NilVariable* _get_impl(mosek::fusion::NilVariable * _inst){ return static_cast< mosek::fusion::p_NilVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_NilVariable * _get_impl(mosek::fusion::NilVariable::t _inst) { return _get_impl(_inst.get()); }
p_NilVariable(NilVariable * _pubthis);
virtual ~p_NilVariable() { /* std::cout << "~p_NilVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static NilVariable::t _new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > > _1575);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _1575);
static NilVariable::t _new_NilVariable();
void _initialize();
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2NilVariable__elementDesc(long long _1577,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1578) ;
virtual void elementName(long long _1579,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1580) ;
virtual /* override */ int numInst() ;
virtual int inst(int _1581,std::shared_ptr< monty::ndarray< long long,1 > > _1582,std::shared_ptr< monty::ndarray< long long,1 > > _1583) ;
virtual /* override */ void inst(int _1584,std::shared_ptr< monty::ndarray< long long,1 > > _1585) ;
virtual /* override */ void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1586,bool _1587) ;
virtual /* override */ void values(int _1588,std::shared_ptr< monty::ndarray< double,1 > > _1589,bool _1590) ;
virtual /* override */ void make_continuous() ;
virtual /* override */ void make_integer() ;
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591) { return __mosek_2fusion_2NilVariable__index(_1591); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1591) { return __mosek_2fusion_2NilVariable__index(_1591); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(int _1593) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1593) { return __mosek_2fusion_2NilVariable__index(_1593); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1593) { return __mosek_2fusion_2NilVariable__index(_1593); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) { return __mosek_2fusion_2NilVariable__slice(_1595,_1596); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1595,std::shared_ptr< monty::ndarray< int,1 > > _1596) { return __mosek_2fusion_2NilVariable__slice(_1595,_1596); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(int _1599,int _1600) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1599,int _1600) { return __mosek_2fusion_2NilVariable__slice(_1599,_1600); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1599,int _1600) { return __mosek_2fusion_2NilVariable__slice(_1599,_1600); }
}; // struct NilVariable;

struct p_Var
{
Var * _pubthis;
static mosek::fusion::p_Var* _get_impl(mosek::fusion::Var * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Var * _get_impl(mosek::fusion::Var::t _inst) { return _get_impl(_inst.get()); }
p_Var(Var * _pubthis);
virtual ~p_Var() { /* std::cout << "~p_Var" << std::endl;*/ };
virtual void destroy();
static  monty::rc_ptr< ::mosek::fusion::Variable > empty(std::shared_ptr< monty::ndarray< int,1 > > _1841);
static  monty::rc_ptr< ::mosek::fusion::Variable > compress(monty::rc_ptr< ::mosek::fusion::Variable > _1843);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1851,int _1852);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1853,int _1854,int _1855);
static  monty::rc_ptr< ::mosek::fusion::Variable > flatten(monty::rc_ptr< ::mosek::fusion::Variable > _1856);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _1857,std::shared_ptr< monty::ndarray< int,1 > > _1858);
static  monty::rc_ptr< ::mosek::fusion::Variable > index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _1859,std::shared_ptr< monty::ndarray< int,1 > > _1860);
static  monty::rc_ptr< ::mosek::fusion::Variable > hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1889,int _1890);
static  monty::rc_ptr< ::mosek::fusion::Variable > vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1891,int _1892);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1893,int _1894);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _1895,int _1896,int _1897);
static  monty::rc_ptr< ::mosek::fusion::Variable > drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _1898,int _1899,int _1900);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _1964);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1966,monty::rc_ptr< ::mosek::fusion::Variable > _1967,monty::rc_ptr< ::mosek::fusion::Variable > _1968);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _1969,monty::rc_ptr< ::mosek::fusion::Variable > _1970);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1971);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1972,monty::rc_ptr< ::mosek::fusion::Variable > _1973,monty::rc_ptr< ::mosek::fusion::Variable > _1974);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _1975,monty::rc_ptr< ::mosek::fusion::Variable > _1976);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1977);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _1978,monty::rc_ptr< ::mosek::fusion::Variable > _1979,monty::rc_ptr< ::mosek::fusion::Variable > _1980,int _1981);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _1982,monty::rc_ptr< ::mosek::fusion::Variable > _1983,int _1984);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1985,int _1986);
static  monty::rc_ptr< ::mosek::fusion::Variable > promote(monty::rc_ptr< ::mosek::fusion::Variable > _1989,int _1990);
static  monty::rc_ptr< ::mosek::fusion::Variable > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _1995,int _1996);
}; // struct Var;

struct p_ConstraintCache
{
ConstraintCache * _pubthis;
static mosek::fusion::p_ConstraintCache* _get_impl(mosek::fusion::ConstraintCache * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConstraintCache * _get_impl(mosek::fusion::ConstraintCache::t _inst) { return _get_impl(_inst.get()); }
p_ConstraintCache(ConstraintCache * _pubthis);
virtual ~p_ConstraintCache() { /* std::cout << "~p_ConstraintCache" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmatidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};long long nbarnz{};long long nunordered{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subi{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subj{};std::shared_ptr< monty::ndarray< double,1 > > buffer_cof{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subi{};std::shared_ptr< monty::ndarray< int,1 > > subj{};long long nnz{};int nrows{};virtual void destroy();
static ConstraintCache::t _new_ConstraintCache(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2119);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2119);
static ConstraintCache::t _new_ConstraintCache(std::shared_ptr< monty::ndarray< long long,1 > > _2120,std::shared_ptr< monty::ndarray< double,1 > > _2121,std::shared_ptr< monty::ndarray< int,1 > > _2122,std::shared_ptr< monty::ndarray< double,1 > > _2123,std::shared_ptr< monty::ndarray< int,1 > > _2124,std::shared_ptr< monty::ndarray< int,1 > > _2125,std::shared_ptr< monty::ndarray< int,1 > > _2126);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _2120,std::shared_ptr< monty::ndarray< double,1 > > _2121,std::shared_ptr< monty::ndarray< int,1 > > _2122,std::shared_ptr< monty::ndarray< double,1 > > _2123,std::shared_ptr< monty::ndarray< int,1 > > _2124,std::shared_ptr< monty::ndarray< int,1 > > _2125,std::shared_ptr< monty::ndarray< int,1 > > _2126);
virtual void unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2129) ;
virtual long long order_barentries() ;
virtual void add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2139,std::shared_ptr< monty::ndarray< int,1 > > _2140,std::shared_ptr< monty::ndarray< int,1 > > _2141) ;
virtual void unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2147,std::shared_ptr< monty::ndarray< int,1 > > _2148,std::shared_ptr< monty::ndarray< double,1 > > _2149,std::shared_ptr< monty::ndarray< double,1 > > _2150) ;
virtual void add(std::shared_ptr< monty::ndarray< long long,1 > > _2159,std::shared_ptr< monty::ndarray< int,1 > > _2160,std::shared_ptr< monty::ndarray< double,1 > > _2161,std::shared_ptr< monty::ndarray< double,1 > > _2162) ;
virtual long long flush(std::shared_ptr< monty::ndarray< int,1 > > _2163,std::shared_ptr< monty::ndarray< int,1 > > _2164,std::shared_ptr< monty::ndarray< double,1 > > _2165,std::shared_ptr< monty::ndarray< double,1 > > _2166) ;
virtual long long numUnsorted() ;
virtual monty::rc_ptr< ::mosek::fusion::ConstraintCache > __mosek_2fusion_2ConstraintCache__clone() ;
}; // struct ConstraintCache;

struct p_Constraint
{
Constraint * _pubthis;
static mosek::fusion::p_Constraint* _get_impl(mosek::fusion::Constraint * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Constraint * _get_impl(mosek::fusion::Constraint::t _inst) { return _get_impl(_inst.get()); }
p_Constraint(Constraint * _pubthis);
virtual ~p_Constraint() { /* std::cout << "~p_Constraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::Model > model{};virtual void destroy();
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Constraint > _2240,monty::rc_ptr< ::mosek::fusion::Model > _2241);
void _initialize(monty::rc_ptr< ::mosek::fusion::Constraint > _2240,monty::rc_ptr< ::mosek::fusion::Model > _2241);
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Model > _2242,std::shared_ptr< monty::ndarray< int,1 > > _2243,std::shared_ptr< monty::ndarray< int,1 > > _2244);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2242,std::shared_ptr< monty::ndarray< int,1 > > _2243,std::shared_ptr< monty::ndarray< int,1 > > _2244);
virtual /* override */ std::string toString() ;
virtual void toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2245,long long _2246,std::shared_ptr< monty::ndarray< std::string,1 > > _2247) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void values(bool _2250,int _2251,std::shared_ptr< monty::ndarray< double,1 > > _2252) ;
virtual void update(std::shared_ptr< monty::ndarray< double,1 > > _2253) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2254) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2258,monty::rc_ptr< ::mosek::fusion::Variable > _2259,bool _2260) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2279,monty::rc_ptr< ::mosek::fusion::Variable > _2280) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__get_model() ;
virtual int get_nd() ;
virtual long long size() ;
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2283,int _2284);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2285,monty::rc_ptr< ::mosek::fusion::Constraint > _2286,monty::rc_ptr< ::mosek::fusion::Constraint > _2287,int _2288);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2289,monty::rc_ptr< ::mosek::fusion::Constraint > _2290,int _2291);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2292);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2293);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2294,monty::rc_ptr< ::mosek::fusion::Constraint > _2295,monty::rc_ptr< ::mosek::fusion::Constraint > _2296);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2297,monty::rc_ptr< ::mosek::fusion::Constraint > _2298,monty::rc_ptr< ::mosek::fusion::Constraint > _2299);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2300,monty::rc_ptr< ::mosek::fusion::Constraint > _2301);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2302,monty::rc_ptr< ::mosek::fusion::Constraint > _2303);
static  monty::rc_ptr< ::mosek::fusion::Constraint > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2304,int _2305);
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2356) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(int _2363) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2364,std::shared_ptr< monty::ndarray< int,1 > > _2365) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(int _2384,int _2385) ;
virtual int getND() ;
virtual int getSize() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__getModel() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct Constraint;

struct p_SliceConstraint : public ::mosek::fusion::p_Constraint
{
SliceConstraint * _pubthis;
static mosek::fusion::p_SliceConstraint* _get_impl(mosek::fusion::SliceConstraint * _inst){ return static_cast< mosek::fusion::p_SliceConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_SliceConstraint * _get_impl(mosek::fusion::SliceConstraint::t _inst) { return _get_impl(_inst.get()); }
p_SliceConstraint(SliceConstraint * _pubthis);
virtual ~p_SliceConstraint() { /* std::cout << "~p_SliceConstraint" << std::endl;*/ };
virtual void destroy();
static SliceConstraint::t _new_SliceConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2189,std::shared_ptr< monty::ndarray< int,1 > > _2190,std::shared_ptr< monty::ndarray< int,1 > > _2191);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2189,std::shared_ptr< monty::ndarray< int,1 > > _2190,std::shared_ptr< monty::ndarray< int,1 > > _2191);
virtual /* override */ std::string toString() ;
}; // struct SliceConstraint;

struct p_ModelConstraint : public ::mosek::fusion::p_Constraint
{
ModelConstraint * _pubthis;
static mosek::fusion::p_ModelConstraint* _get_impl(mosek::fusion::ModelConstraint * _inst){ return static_cast< mosek::fusion::p_ModelConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_ModelConstraint * _get_impl(mosek::fusion::ModelConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ModelConstraint(ModelConstraint * _pubthis);
virtual ~p_ModelConstraint() { /* std::cout << "~p_ModelConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2229,monty::rc_ptr< ::mosek::fusion::Model > _2230);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2229,monty::rc_ptr< ::mosek::fusion::Model > _2230);
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2231,const std::string &  _2232,std::shared_ptr< monty::ndarray< int,1 > > _2233,std::shared_ptr< monty::ndarray< int,1 > > _2234);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2231,const std::string &  _2232,std::shared_ptr< monty::ndarray< int,1 > > _2233,std::shared_ptr< monty::ndarray< int,1 > > _2234);
virtual /* override */ std::string toString() ;
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2239) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelConstraint;

struct p_LinearPSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearPSDConstraint * _pubthis;
static mosek::fusion::p_LinearPSDConstraint* _get_impl(mosek::fusion::LinearPSDConstraint * _inst){ return static_cast< mosek::fusion::p_LinearPSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDConstraint * _get_impl(mosek::fusion::LinearPSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDConstraint(LinearPSDConstraint * _pubthis);
virtual ~p_LinearPSDConstraint() { /* std::cout << "~p_LinearPSDConstraint" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};int conid{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};virtual void destroy();
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2065,monty::rc_ptr< ::mosek::fusion::Model > _2066);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2065,monty::rc_ptr< ::mosek::fusion::Model > _2066);
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2067,const std::string &  _2068,int _2069,std::shared_ptr< monty::ndarray< int,1 > > _2070,int _2071,std::shared_ptr< monty::ndarray< int,1 > > _2072,std::shared_ptr< monty::ndarray< long long,1 > > _2073);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2067,const std::string &  _2068,int _2069,std::shared_ptr< monty::ndarray< int,1 > > _2070,int _2071,std::shared_ptr< monty::ndarray< int,1 > > _2072,std::shared_ptr< monty::ndarray< long long,1 > > _2073);
virtual void domainToString(long long _2074,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2075) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2079) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2079) { return __mosek_2fusion_2LinearPSDConstraint__clone(_2079); }
}; // struct LinearPSDConstraint;

struct p_PSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
PSDConstraint * _pubthis;
static mosek::fusion::p_PSDConstraint* _get_impl(mosek::fusion::PSDConstraint * _inst){ return static_cast< mosek::fusion::p_PSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_PSDConstraint * _get_impl(mosek::fusion::PSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_PSDConstraint(PSDConstraint * _pubthis);
virtual ~p_PSDConstraint() { /* std::cout << "~p_PSDConstraint" << std::endl;*/ };
bool names_flushed{};int conedim1{};int conedim0{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};int conid{};virtual void destroy();
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2080,monty::rc_ptr< ::mosek::fusion::Model > _2081);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2080,monty::rc_ptr< ::mosek::fusion::Model > _2081);
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2082,const std::string &  _2083,int _2084,std::shared_ptr< monty::ndarray< int,1 > > _2085,int _2086,int _2087,std::shared_ptr< monty::ndarray< long long,1 > > _2088,std::shared_ptr< monty::ndarray< int,1 > > _2089);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2082,const std::string &  _2083,int _2084,std::shared_ptr< monty::ndarray< int,1 > > _2085,int _2086,int _2087,std::shared_ptr< monty::ndarray< long long,1 > > _2088,std::shared_ptr< monty::ndarray< int,1 > > _2089);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2090) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2090) { return __mosek_2fusion_2PSDConstraint__clone(_2090); }
static  std::shared_ptr< monty::ndarray< int,1 > > computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2091,int _2092,int _2093,std::shared_ptr< monty::ndarray< int,1 > > _2094);
}; // struct PSDConstraint;

struct p_RangedConstraint : public ::mosek::fusion::p_ModelConstraint
{
RangedConstraint * _pubthis;
static mosek::fusion::p_RangedConstraint* _get_impl(mosek::fusion::RangedConstraint * _inst){ return static_cast< mosek::fusion::p_RangedConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_RangedConstraint * _get_impl(mosek::fusion::RangedConstraint::t _inst) { return _get_impl(_inst.get()); }
p_RangedConstraint(RangedConstraint * _pubthis);
virtual ~p_RangedConstraint() { /* std::cout << "~p_RangedConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2193,monty::rc_ptr< ::mosek::fusion::Model > _2194);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2193,monty::rc_ptr< ::mosek::fusion::Model > _2194);
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2195,const std::string &  _2196,std::shared_ptr< monty::ndarray< int,1 > > _2197,std::shared_ptr< monty::ndarray< int,1 > > _2198);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2195,const std::string &  _2196,std::shared_ptr< monty::ndarray< int,1 > > _2197,std::shared_ptr< monty::ndarray< int,1 > > _2198);
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2199) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2199) { return __mosek_2fusion_2RangedConstraint__clone(_2199); }
}; // struct RangedConstraint;

struct p_ConicConstraint : public ::mosek::fusion::p_ModelConstraint
{
ConicConstraint * _pubthis;
static mosek::fusion::p_ConicConstraint* _get_impl(mosek::fusion::ConicConstraint * _inst){ return static_cast< mosek::fusion::p_ConicConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_ConicConstraint * _get_impl(mosek::fusion::ConicConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ConicConstraint(ConicConstraint * _pubthis);
virtual ~p_ConicConstraint() { /* std::cout << "~p_ConicConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeslack{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::ConeDomain > dom{};int conid{};virtual void destroy();
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2200,monty::rc_ptr< ::mosek::fusion::Model > _2201);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2200,monty::rc_ptr< ::mosek::fusion::Model > _2201);
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2202,const std::string &  _2203,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2204,std::shared_ptr< monty::ndarray< int,1 > > _2205,int _2206,std::shared_ptr< monty::ndarray< int,1 > > _2207,std::shared_ptr< monty::ndarray< int,1 > > _2208);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2202,const std::string &  _2203,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2204,std::shared_ptr< monty::ndarray< int,1 > > _2205,int _2206,std::shared_ptr< monty::ndarray< int,1 > > _2207,std::shared_ptr< monty::ndarray< int,1 > > _2208);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2215,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2216) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2217) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2217) { return __mosek_2fusion_2ConicConstraint__clone(_2217); }
}; // struct ConicConstraint;

struct p_LinearConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearConstraint * _pubthis;
static mosek::fusion::p_LinearConstraint* _get_impl(mosek::fusion::LinearConstraint * _inst){ return static_cast< mosek::fusion::p_LinearConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearConstraint * _get_impl(mosek::fusion::LinearConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearConstraint(LinearConstraint * _pubthis);
virtual ~p_LinearConstraint() { /* std::cout << "~p_LinearConstraint" << std::endl;*/ };
std::string name{};int conid{};virtual void destroy();
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2218,monty::rc_ptr< ::mosek::fusion::Model > _2219);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2218,monty::rc_ptr< ::mosek::fusion::Model > _2219);
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2220,const std::string &  _2221,int _2222,std::shared_ptr< monty::ndarray< int,1 > > _2223,std::shared_ptr< monty::ndarray< int,1 > > _2224);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2220,const std::string &  _2221,int _2222,std::shared_ptr< monty::ndarray< int,1 > > _2223,std::shared_ptr< monty::ndarray< int,1 > > _2224);
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2226,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2227) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2228) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2228) { return __mosek_2fusion_2LinearConstraint__clone(_2228); }
}; // struct LinearConstraint;

struct p_Set
{
Set * _pubthis;
static mosek::fusion::p_Set* _get_impl(mosek::fusion::Set * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Set * _get_impl(mosek::fusion::Set::t _inst) { return _get_impl(_inst.get()); }
p_Set(Set * _pubthis);
virtual ~p_Set() { /* std::cout << "~p_Set" << std::endl;*/ };
virtual void destroy();
static  long long size(std::shared_ptr< monty::ndarray< int,1 > > _2390);
static  bool match(std::shared_ptr< monty::ndarray< int,1 > > _2393,std::shared_ptr< monty::ndarray< int,1 > > _2394);
static  long long linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2396,std::shared_ptr< monty::ndarray< int,1 > > _2397);
static  std::shared_ptr< monty::ndarray< int,1 > > idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2400,long long _2401);
static  void idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2403,long long _2404,std::shared_ptr< monty::ndarray< int,1 > > _2405);
static  std::string indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2409,long long _2410);
static  std::string keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2417);
static  void indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2420,long long _2421,std::shared_ptr< monty::ndarray< int,1 > > _2422);
static  std::shared_ptr< monty::ndarray< long long,1 > > strides(std::shared_ptr< monty::ndarray< int,1 > > _2426);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2430,std::shared_ptr< monty::ndarray< int,1 > > _2431);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2435);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2437,int _2438,int _2439);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2440,int _2441);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2442);
static  std::shared_ptr< monty::ndarray< int,1 > > scalar();
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< std::string,1 > > _2443);
}; // struct Set;

struct p_ConeDomain
{
ConeDomain * _pubthis;
static mosek::fusion::p_ConeDomain* _get_impl(mosek::fusion::ConeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConeDomain * _get_impl(mosek::fusion::ConeDomain::t _inst) { return _get_impl(_inst.get()); }
p_ConeDomain(ConeDomain * _pubthis);
virtual ~p_ConeDomain() { /* std::cout << "~p_ConeDomain" << std::endl;*/ };
double alpha{};std::shared_ptr< monty::ndarray< int,1 > > shape{};bool int_flag{};bool axisset{};int axisidx{};mosek::fusion::QConeKey key{};virtual void destroy();
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2444,double _2445,std::shared_ptr< monty::ndarray< int,1 > > _2446);
void _initialize(mosek::fusion::QConeKey _2444,double _2445,std::shared_ptr< monty::ndarray< int,1 > > _2446);
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2447,std::shared_ptr< monty::ndarray< int,1 > > _2448);
void _initialize(mosek::fusion::QConeKey _2447,std::shared_ptr< monty::ndarray< int,1 > > _2448);
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2449) ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__integral() ;
virtual bool axisIsSet() ;
virtual int getAxis() ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__axis(int _2450) ;
}; // struct ConeDomain;

struct p_LinPSDDomain
{
LinPSDDomain * _pubthis;
static mosek::fusion::p_LinPSDDomain* _get_impl(mosek::fusion::LinPSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinPSDDomain * _get_impl(mosek::fusion::LinPSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinPSDDomain(LinPSDDomain * _pubthis);
virtual ~p_LinPSDDomain() { /* std::cout << "~p_LinPSDDomain" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2451,int _2452);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2451,int _2452);
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2453);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2453);
static LinPSDDomain::t _new_LinPSDDomain();
void _initialize();
}; // struct LinPSDDomain;

struct p_PSDDomain
{
PSDDomain * _pubthis;
static mosek::fusion::p_PSDDomain* _get_impl(mosek::fusion::PSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_PSDDomain * _get_impl(mosek::fusion::PSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_PSDDomain(PSDDomain * _pubthis);
virtual ~p_PSDDomain() { /* std::cout << "~p_PSDDomain" << std::endl;*/ };
bool axisIsSet{};int conedim2{};int conedim1{};mosek::fusion::PSDKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2454,std::shared_ptr< monty::ndarray< int,1 > > _2455,int _2456,int _2457);
void _initialize(mosek::fusion::PSDKey _2454,std::shared_ptr< monty::ndarray< int,1 > > _2455,int _2456,int _2457);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2459,std::shared_ptr< monty::ndarray< int,1 > > _2460);
void _initialize(mosek::fusion::PSDKey _2459,std::shared_ptr< monty::ndarray< int,1 > > _2460);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2461);
void _initialize(mosek::fusion::PSDKey _2461);
virtual monty::rc_ptr< ::mosek::fusion::PSDDomain > __mosek_2fusion_2PSDDomain__axis(int _2462,int _2463) ;
}; // struct PSDDomain;

struct p_RangeDomain
{
RangeDomain * _pubthis;
static mosek::fusion::p_RangeDomain* _get_impl(mosek::fusion::RangeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_RangeDomain * _get_impl(mosek::fusion::RangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_RangeDomain(RangeDomain * _pubthis);
virtual ~p_RangeDomain() { /* std::cout << "~p_RangeDomain" << std::endl;*/ };
bool cardinal_flag{};bool scalable{};std::shared_ptr< monty::ndarray< double,1 > > ub{};std::shared_ptr< monty::ndarray< double,1 > > lb{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool empty{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangeDomain::t _new_RangeDomain(bool _2465,std::shared_ptr< monty::ndarray< double,1 > > _2466,std::shared_ptr< monty::ndarray< double,1 > > _2467,std::shared_ptr< monty::ndarray< int,1 > > _2468);
void _initialize(bool _2465,std::shared_ptr< monty::ndarray< double,1 > > _2466,std::shared_ptr< monty::ndarray< double,1 > > _2467,std::shared_ptr< monty::ndarray< int,1 > > _2468);
static RangeDomain::t _new_RangeDomain(bool _2469,std::shared_ptr< monty::ndarray< double,1 > > _2470,std::shared_ptr< monty::ndarray< double,1 > > _2471,std::shared_ptr< monty::ndarray< int,1 > > _2472,std::shared_ptr< monty::ndarray< int,2 > > _2473);
void _initialize(bool _2469,std::shared_ptr< monty::ndarray< double,1 > > _2470,std::shared_ptr< monty::ndarray< double,1 > > _2471,std::shared_ptr< monty::ndarray< int,1 > > _2472,std::shared_ptr< monty::ndarray< int,2 > > _2473);
static RangeDomain::t _new_RangeDomain(bool _2474,std::shared_ptr< monty::ndarray< double,1 > > _2475,std::shared_ptr< monty::ndarray< double,1 > > _2476,std::shared_ptr< monty::ndarray< int,1 > > _2477,std::shared_ptr< monty::ndarray< int,2 > > _2478,int _2479);
void _initialize(bool _2474,std::shared_ptr< monty::ndarray< double,1 > > _2475,std::shared_ptr< monty::ndarray< double,1 > > _2476,std::shared_ptr< monty::ndarray< int,1 > > _2477,std::shared_ptr< monty::ndarray< int,2 > > _2478,int _2479);
static RangeDomain::t _new_RangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2480);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2480);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > __mosek_2fusion_2RangeDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2481) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2484) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2486) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2487) ;
}; // struct RangeDomain;

struct p_SymmetricRangeDomain : public ::mosek::fusion::p_RangeDomain
{
SymmetricRangeDomain * _pubthis;
static mosek::fusion::p_SymmetricRangeDomain* _get_impl(mosek::fusion::SymmetricRangeDomain * _inst){ return static_cast< mosek::fusion::p_SymmetricRangeDomain* >(mosek::fusion::p_RangeDomain::_get_impl(_inst)); }
static mosek::fusion::p_SymmetricRangeDomain * _get_impl(mosek::fusion::SymmetricRangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricRangeDomain(SymmetricRangeDomain * _pubthis);
virtual ~p_SymmetricRangeDomain() { /* std::cout << "~p_SymmetricRangeDomain" << std::endl;*/ };
int dim{};virtual void destroy();
static SymmetricRangeDomain::t _new_SymmetricRangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2464);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2464);
}; // struct SymmetricRangeDomain;

struct p_SymmetricLinearDomain
{
SymmetricLinearDomain * _pubthis;
static mosek::fusion::p_SymmetricLinearDomain* _get_impl(mosek::fusion::SymmetricLinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricLinearDomain * _get_impl(mosek::fusion::SymmetricLinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricLinearDomain(SymmetricLinearDomain * _pubthis);
virtual ~p_SymmetricLinearDomain() { /* std::cout << "~p_SymmetricLinearDomain" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::LinearDomain > dom{};int dim{};virtual void destroy();
static SymmetricLinearDomain::t _new_SymmetricLinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2489);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2489);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2490) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2493) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__integral() ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2495) ;
}; // struct SymmetricLinearDomain;

struct p_LinearDomain
{
LinearDomain * _pubthis;
static mosek::fusion::p_LinearDomain* _get_impl(mosek::fusion::LinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinearDomain * _get_impl(mosek::fusion::LinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinearDomain(LinearDomain * _pubthis);
virtual ~p_LinearDomain() { /* std::cout << "~p_LinearDomain" << std::endl;*/ };
bool empty{};bool scalable{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< double,1 > > bnd{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2497,bool _2498,std::shared_ptr< monty::ndarray< double,1 > > _2499,std::shared_ptr< monty::ndarray< int,1 > > _2500);
void _initialize(mosek::fusion::RelationKey _2497,bool _2498,std::shared_ptr< monty::ndarray< double,1 > > _2499,std::shared_ptr< monty::ndarray< int,1 > > _2500);
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2501,bool _2502,std::shared_ptr< monty::ndarray< double,1 > > _2503,std::shared_ptr< monty::ndarray< int,1 > > _2504,std::shared_ptr< monty::ndarray< int,2 > > _2505,int _2506);
void _initialize(mosek::fusion::RelationKey _2501,bool _2502,std::shared_ptr< monty::ndarray< double,1 > > _2503,std::shared_ptr< monty::ndarray< int,1 > > _2504,std::shared_ptr< monty::ndarray< int,2 > > _2505,int _2506);
static LinearDomain::t _new_LinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2507);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2507);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2LinearDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2508) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2511) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2513) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2514) ;
}; // struct LinearDomain;

struct p_Domain
{
Domain * _pubthis;
static mosek::fusion::p_Domain* _get_impl(mosek::fusion::Domain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Domain * _get_impl(mosek::fusion::Domain::t _inst) { return _get_impl(_inst.get()); }
p_Domain(Domain * _pubthis);
virtual ~p_Domain() { /* std::cout << "~p_Domain" << std::endl;*/ };
virtual void destroy();
static  long long dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2516);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > mkLinearDomain(mosek::fusion::RelationKey _2519,monty::rc_ptr< ::mosek::fusion::Matrix > _2520);
static  long long prod(std::shared_ptr< monty::ndarray< int,1 > > _2526);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(bool _2529,std::shared_ptr< monty::ndarray< double,1 > > _2530,std::shared_ptr< monty::ndarray< double,1 > > _2531,std::shared_ptr< monty::ndarray< int,2 > > _2532,std::shared_ptr< monty::ndarray< int,1 > > _2533);
static  monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2535);
static  monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2536);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2537,std::shared_ptr< monty::ndarray< int,2 > > _2538);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2539,std::shared_ptr< monty::ndarray< int,1 > > _2540);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2541,std::shared_ptr< monty::ndarray< int,2 > > _2542);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2543,std::shared_ptr< monty::ndarray< int,1 > > _2544);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2545);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2546);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2547);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _2548,int _2549);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2550,std::shared_ptr< monty::ndarray< int,1 > > _2551);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2553,int _2554);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _2555);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2556,std::shared_ptr< monty::ndarray< int,1 > > _2557);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2559,int _2560);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _2561);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2562);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(int _2564);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _2565);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(int _2567);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _2568);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2570,int _2571);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _2572);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(std::shared_ptr< monty::ndarray< int,1 > > _2573);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2575,int _2576);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _2577);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone();
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2578,int _2579);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _2580);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2581,int _2582);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _2583);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2584,int _2585);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _2586);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(std::shared_ptr< monty::ndarray< int,1 > > _2587);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2588,int _2589);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _2590);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2591,std::shared_ptr< monty::ndarray< double,1 > > _2592,std::shared_ptr< monty::ndarray< int,1 > > _2593);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2594,double _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2598,std::shared_ptr< monty::ndarray< double,1 > > _2599,std::shared_ptr< monty::ndarray< int,1 > > _2600);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2602,double _2603,std::shared_ptr< monty::ndarray< int,1 > > _2604);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2605,std::shared_ptr< monty::ndarray< double,1 > > _2606);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _2607,double _2608);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2610,std::shared_ptr< monty::ndarray< double,1 > > _2611);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _2613,double _2614);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2615);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2616,std::shared_ptr< monty::ndarray< int,1 > > _2617);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _2618);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _2621);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2622,std::shared_ptr< monty::ndarray< int,1 > > _2623);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2625,int _2626,int _2627);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2629,int _2630);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _2632);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _2633);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2634,std::shared_ptr< monty::ndarray< int,1 > > _2635);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,2 > > _2636);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _2639);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2640,std::shared_ptr< monty::ndarray< int,1 > > _2641);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2642,int _2643,int _2644);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2645,int _2646);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _2647);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _2648);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2649,std::shared_ptr< monty::ndarray< int,1 > > _2650);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _2651);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _2654);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2655,std::shared_ptr< monty::ndarray< int,1 > > _2656);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2657,int _2658,int _2659);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2660,int _2661);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _2662);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(std::shared_ptr< monty::ndarray< int,1 > > _2663);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2665,int _2666);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _2667);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded();
}; // struct Domain;

struct p_BaseExpression : public /*implements*/ virtual ::mosek::fusion::Expression
{
BaseExpression * _pubthis;
static mosek::fusion::p_BaseExpression* _get_impl(mosek::fusion::BaseExpression * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseExpression * _get_impl(mosek::fusion::BaseExpression::t _inst) { return _get_impl(_inst.get()); }
p_BaseExpression(BaseExpression * _pubthis);
virtual ~p_BaseExpression() { /* std::cout << "~p_BaseExpression" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseExpression::t _new_BaseExpression(std::shared_ptr< monty::ndarray< int,1 > > _4820);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4820);
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expression__eval() { return __mosek_2fusion_2BaseExpression__eval(); }
static  void storeexpr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4836,std::shared_ptr< monty::ndarray< int,1 > > _4837,std::shared_ptr< monty::ndarray< int,1 > > _4838,std::shared_ptr< monty::ndarray< long long,1 > > _4839,std::shared_ptr< monty::ndarray< long long,1 > > _4840,std::shared_ptr< monty::ndarray< double,1 > > _4841,std::shared_ptr< monty::ndarray< double,1 > > _4842);
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4853,monty::rc_ptr< ::mosek::fusion::WorkStack > _4854,monty::rc_ptr< ::mosek::fusion::WorkStack > _4855) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4856) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4856) { return __mosek_2fusion_2BaseExpression__pick(_4856); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4857) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4857) { return __mosek_2fusion_2BaseExpression__pick(_4857); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _4860) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4860) { return __mosek_2fusion_2BaseExpression__index(_4860); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(int _4863) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(int _4863) { return __mosek_2fusion_2BaseExpression__index(_4863); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4865,std::shared_ptr< monty::ndarray< int,1 > > _4866) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4865,std::shared_ptr< monty::ndarray< int,1 > > _4866) { return __mosek_2fusion_2BaseExpression__slice(_4865,_4866); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(int _4867,int _4868) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(int _4867,int _4868) { return __mosek_2fusion_2BaseExpression__slice(_4867,_4868); }
virtual long long getSize() ;
virtual int getND() ;
virtual int getDim(int _4869) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct BaseExpression;

struct p_ExprConst : public ::mosek::fusion::p_BaseExpression
{
ExprConst * _pubthis;
static mosek::fusion::p_ExprConst* _get_impl(mosek::fusion::ExprConst * _inst){ return static_cast< mosek::fusion::p_ExprConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprConst * _get_impl(mosek::fusion::ExprConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprConst(ExprConst * _pubthis);
virtual ~p_ExprConst() { /* std::cout << "~p_ExprConst" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2668,std::shared_ptr< monty::ndarray< long long,1 > > _2669,std::shared_ptr< monty::ndarray< double,1 > > _2670);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2668,std::shared_ptr< monty::ndarray< long long,1 > > _2669,std::shared_ptr< monty::ndarray< double,1 > > _2670);
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _2671,std::shared_ptr< monty::ndarray< long long,1 > > _2672,double _2673);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2671,std::shared_ptr< monty::ndarray< long long,1 > > _2672,double _2673);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2676,monty::rc_ptr< ::mosek::fusion::WorkStack > _2677,monty::rc_ptr< ::mosek::fusion::WorkStack > _2678) ;
static  void validate(std::shared_ptr< monty::ndarray< int,1 > > _2692,std::shared_ptr< monty::ndarray< double,1 > > _2693,std::shared_ptr< monty::ndarray< long long,1 > > _2694);
virtual /* override */ std::string toString() ;
}; // struct ExprConst;

struct p_ExprPick : public ::mosek::fusion::p_BaseExpression
{
ExprPick * _pubthis;
static mosek::fusion::p_ExprPick* _get_impl(mosek::fusion::ExprPick * _inst){ return static_cast< mosek::fusion::p_ExprPick* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPick * _get_impl(mosek::fusion::ExprPick::t _inst) { return _get_impl(_inst.get()); }
p_ExprPick(ExprPick * _pubthis);
virtual ~p_ExprPick() { /* std::cout << "~p_ExprPick" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > idxs{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2697,std::shared_ptr< monty::ndarray< int,2 > > _2698);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2697,std::shared_ptr< monty::ndarray< int,2 > > _2698);
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _2709,std::shared_ptr< monty::ndarray< long long,1 > > _2710);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2709,std::shared_ptr< monty::ndarray< long long,1 > > _2710);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2714,monty::rc_ptr< ::mosek::fusion::WorkStack > _2715,monty::rc_ptr< ::mosek::fusion::WorkStack > _2716) ;
virtual /* override */ std::string toString() ;
}; // struct ExprPick;

struct p_ExprSlice : public ::mosek::fusion::p_BaseExpression
{
ExprSlice * _pubthis;
static mosek::fusion::p_ExprSlice* _get_impl(mosek::fusion::ExprSlice * _inst){ return static_cast< mosek::fusion::p_ExprSlice* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSlice * _get_impl(mosek::fusion::ExprSlice::t _inst) { return _get_impl(_inst.get()); }
p_ExprSlice(ExprSlice * _pubthis);
virtual ~p_ExprSlice() { /* std::cout << "~p_ExprSlice" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > last{};std::shared_ptr< monty::ndarray< int,1 > > first{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSlice::t _new_ExprSlice(monty::rc_ptr< ::mosek::fusion::Expression > _2768,std::shared_ptr< monty::ndarray< int,1 > > _2769,std::shared_ptr< monty::ndarray< int,1 > > _2770);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2768,std::shared_ptr< monty::ndarray< int,1 > > _2769,std::shared_ptr< monty::ndarray< int,1 > > _2770);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2771,monty::rc_ptr< ::mosek::fusion::WorkStack > _2772,monty::rc_ptr< ::mosek::fusion::WorkStack > _2773) ;
static  std::shared_ptr< monty::ndarray< int,1 > > makeShape(std::shared_ptr< monty::ndarray< int,1 > > _2827,std::shared_ptr< monty::ndarray< int,1 > > _2828,std::shared_ptr< monty::ndarray< int,1 > > _2829);
virtual /* override */ std::string toString() ;
}; // struct ExprSlice;

struct p_ExprPermuteDims : public ::mosek::fusion::p_BaseExpression
{
ExprPermuteDims * _pubthis;
static mosek::fusion::p_ExprPermuteDims* _get_impl(mosek::fusion::ExprPermuteDims * _inst){ return static_cast< mosek::fusion::p_ExprPermuteDims* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPermuteDims * _get_impl(mosek::fusion::ExprPermuteDims::t _inst) { return _get_impl(_inst.get()); }
p_ExprPermuteDims(ExprPermuteDims * _pubthis);
virtual ~p_ExprPermuteDims() { /* std::cout << "~p_ExprPermuteDims" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > dperm{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2834,monty::rc_ptr< ::mosek::fusion::Expression > _2835);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2834,monty::rc_ptr< ::mosek::fusion::Expression > _2835);
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _2841,monty::rc_ptr< ::mosek::fusion::Expression > _2842,int _2843);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2841,monty::rc_ptr< ::mosek::fusion::Expression > _2842,int _2843);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2844,monty::rc_ptr< ::mosek::fusion::WorkStack > _2845,monty::rc_ptr< ::mosek::fusion::WorkStack > _2846) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(std::shared_ptr< monty::ndarray< int,1 > > _2898,std::shared_ptr< monty::ndarray< int,1 > > _2899);
}; // struct ExprPermuteDims;

struct p_ExprTranspose : public ::mosek::fusion::p_BaseExpression
{
ExprTranspose * _pubthis;
static mosek::fusion::p_ExprTranspose* _get_impl(mosek::fusion::ExprTranspose * _inst){ return static_cast< mosek::fusion::p_ExprTranspose* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprTranspose * _get_impl(mosek::fusion::ExprTranspose::t _inst) { return _get_impl(_inst.get()); }
p_ExprTranspose(ExprTranspose * _pubthis);
virtual ~p_ExprTranspose() { /* std::cout << "~p_ExprTranspose" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprTranspose::t _new_ExprTranspose(monty::rc_ptr< ::mosek::fusion::Expression > _2901);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _2901);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2902,monty::rc_ptr< ::mosek::fusion::WorkStack > _2903,monty::rc_ptr< ::mosek::fusion::WorkStack > _2904) ;
virtual /* override */ std::string toString() ;
static  std::shared_ptr< monty::ndarray< int,1 > > transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _2948);
}; // struct ExprTranspose;

struct p_ExprStack : public ::mosek::fusion::p_BaseExpression
{
ExprStack * _pubthis;
static mosek::fusion::p_ExprStack* _get_impl(mosek::fusion::ExprStack * _inst){ return static_cast< mosek::fusion::p_ExprStack* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprStack * _get_impl(mosek::fusion::ExprStack::t _inst) { return _get_impl(_inst.get()); }
p_ExprStack(ExprStack * _pubthis);
virtual ~p_ExprStack() { /* std::cout << "~p_ExprStack" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > exprs{};virtual void destroy();
static ExprStack::t _new_ExprStack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2949,int _2950);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _2949,int _2950);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _2952,monty::rc_ptr< ::mosek::fusion::WorkStack > _2953,monty::rc_ptr< ::mosek::fusion::WorkStack > _2954) ;
static  std::shared_ptr< monty::ndarray< int,1 > > getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _3102,int _3103);
virtual /* override */ std::string toString() ;
}; // struct ExprStack;

struct p_ExprInner : public ::mosek::fusion::p_BaseExpression
{
ExprInner * _pubthis;
static mosek::fusion::p_ExprInner* _get_impl(mosek::fusion::ExprInner * _inst){ return static_cast< mosek::fusion::p_ExprInner* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprInner * _get_impl(mosek::fusion::ExprInner::t _inst) { return _get_impl(_inst.get()); }
p_ExprInner(ExprInner * _pubthis);
virtual ~p_ExprInner() { /* std::cout << "~p_ExprInner" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > vcof{};std::shared_ptr< monty::ndarray< long long,1 > > vsub{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3117,std::shared_ptr< monty::ndarray< long long,1 > > _3118,std::shared_ptr< monty::ndarray< double,1 > > _3119);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3117,std::shared_ptr< monty::ndarray< long long,1 > > _3118,std::shared_ptr< monty::ndarray< double,1 > > _3119);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3123,std::shared_ptr< monty::ndarray< double,1 > > _3124);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3123,std::shared_ptr< monty::ndarray< double,1 > > _3124);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _3126,std::shared_ptr< monty::ndarray< int,2 > > _3127,std::shared_ptr< monty::ndarray< double,1 > > _3128);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3126,std::shared_ptr< monty::ndarray< int,2 > > _3127,std::shared_ptr< monty::ndarray< double,1 > > _3128);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3129,monty::rc_ptr< ::mosek::fusion::WorkStack > _3130,monty::rc_ptr< ::mosek::fusion::WorkStack > _3131) ;
static  std::shared_ptr< monty::ndarray< long long,1 > > range(int _3167);
static  std::shared_ptr< monty::ndarray< long long,1 > > convert(std::shared_ptr< monty::ndarray< int,1 > > _3169,std::shared_ptr< monty::ndarray< int,2 > > _3170);
virtual /* override */ std::string toString() ;
}; // struct ExprInner;

struct p_ExprMulDiagRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagRight * _pubthis;
static mosek::fusion::p_ExprMulDiagRight* _get_impl(mosek::fusion::ExprMulDiagRight * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagRight * _get_impl(mosek::fusion::ExprMulDiagRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagRight(ExprMulDiagRight * _pubthis);
virtual ~p_ExprMulDiagRight() { /* std::cout << "~p_ExprMulDiagRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3177,int _3178,std::shared_ptr< monty::ndarray< int,1 > > _3179,std::shared_ptr< monty::ndarray< int,1 > > _3180,std::shared_ptr< monty::ndarray< double,1 > > _3181,monty::rc_ptr< ::mosek::fusion::Expression > _3182,int _3183);
void _initialize(int _3177,int _3178,std::shared_ptr< monty::ndarray< int,1 > > _3179,std::shared_ptr< monty::ndarray< int,1 > > _3180,std::shared_ptr< monty::ndarray< double,1 > > _3181,monty::rc_ptr< ::mosek::fusion::Expression > _3182,int _3183);
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _3184,int _3185,std::shared_ptr< monty::ndarray< int,1 > > _3186,std::shared_ptr< monty::ndarray< int,1 > > _3187,std::shared_ptr< monty::ndarray< double,1 > > _3188,monty::rc_ptr< ::mosek::fusion::Expression > _3189);
void _initialize(int _3184,int _3185,std::shared_ptr< monty::ndarray< int,1 > > _3186,std::shared_ptr< monty::ndarray< int,1 > > _3187,std::shared_ptr< monty::ndarray< double,1 > > _3188,monty::rc_ptr< ::mosek::fusion::Expression > _3189);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3190,monty::rc_ptr< ::mosek::fusion::WorkStack > _3191,monty::rc_ptr< ::mosek::fusion::WorkStack > _3192) ;
static  int validate(int _3284,int _3285,std::shared_ptr< monty::ndarray< int,1 > > _3286,std::shared_ptr< monty::ndarray< int,1 > > _3287,std::shared_ptr< monty::ndarray< double,1 > > _3288,monty::rc_ptr< ::mosek::fusion::Expression > _3289);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagRight;

struct p_ExprMulDiagLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagLeft * _pubthis;
static mosek::fusion::p_ExprMulDiagLeft* _get_impl(mosek::fusion::ExprMulDiagLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagLeft * _get_impl(mosek::fusion::ExprMulDiagLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagLeft(ExprMulDiagLeft * _pubthis);
virtual ~p_ExprMulDiagLeft() { /* std::cout << "~p_ExprMulDiagLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3297,int _3298,std::shared_ptr< monty::ndarray< int,1 > > _3299,std::shared_ptr< monty::ndarray< int,1 > > _3300,std::shared_ptr< monty::ndarray< double,1 > > _3301,monty::rc_ptr< ::mosek::fusion::Expression > _3302,int _3303);
void _initialize(int _3297,int _3298,std::shared_ptr< monty::ndarray< int,1 > > _3299,std::shared_ptr< monty::ndarray< int,1 > > _3300,std::shared_ptr< monty::ndarray< double,1 > > _3301,monty::rc_ptr< ::mosek::fusion::Expression > _3302,int _3303);
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _3304,int _3305,std::shared_ptr< monty::ndarray< int,1 > > _3306,std::shared_ptr< monty::ndarray< int,1 > > _3307,std::shared_ptr< monty::ndarray< double,1 > > _3308,monty::rc_ptr< ::mosek::fusion::Expression > _3309);
void _initialize(int _3304,int _3305,std::shared_ptr< monty::ndarray< int,1 > > _3306,std::shared_ptr< monty::ndarray< int,1 > > _3307,std::shared_ptr< monty::ndarray< double,1 > > _3308,monty::rc_ptr< ::mosek::fusion::Expression > _3309);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3310,monty::rc_ptr< ::mosek::fusion::WorkStack > _3311,monty::rc_ptr< ::mosek::fusion::WorkStack > _3312) ;
static  int validate(int _3397,int _3398,std::shared_ptr< monty::ndarray< int,1 > > _3399,std::shared_ptr< monty::ndarray< int,1 > > _3400,std::shared_ptr< monty::ndarray< double,1 > > _3401,monty::rc_ptr< ::mosek::fusion::Expression > _3402);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagLeft;

struct p_ExprMulElement : public ::mosek::fusion::p_BaseExpression
{
ExprMulElement * _pubthis;
static mosek::fusion::p_ExprMulElement* _get_impl(mosek::fusion::ExprMulElement * _inst){ return static_cast< mosek::fusion::p_ExprMulElement* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulElement * _get_impl(mosek::fusion::ExprMulElement::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulElement(ExprMulElement * _pubthis);
virtual ~p_ExprMulElement() { /* std::cout << "~p_ExprMulElement" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< long long,1 > > msp{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};virtual void destroy();
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3410,std::shared_ptr< monty::ndarray< long long,1 > > _3411,monty::rc_ptr< ::mosek::fusion::Expression > _3412);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3410,std::shared_ptr< monty::ndarray< long long,1 > > _3411,monty::rc_ptr< ::mosek::fusion::Expression > _3412);
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _3417,std::shared_ptr< monty::ndarray< long long,1 > > _3418,monty::rc_ptr< ::mosek::fusion::Expression > _3419,int _3420);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _3417,std::shared_ptr< monty::ndarray< long long,1 > > _3418,monty::rc_ptr< ::mosek::fusion::Expression > _3419,int _3420);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3421,monty::rc_ptr< ::mosek::fusion::WorkStack > _3422,monty::rc_ptr< ::mosek::fusion::WorkStack > _3423) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulElement;

struct p_ExprMulScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarConst * _pubthis;
static mosek::fusion::p_ExprMulScalarConst* _get_impl(mosek::fusion::ExprMulScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarConst * _get_impl(mosek::fusion::ExprMulScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarConst(ExprMulScalarConst * _pubthis);
virtual ~p_ExprMulScalarConst() { /* std::cout << "~p_ExprMulScalarConst" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};double c{};virtual void destroy();
static ExprMulScalarConst::t _new_ExprMulScalarConst(double _3470,monty::rc_ptr< ::mosek::fusion::Expression > _3471);
void _initialize(double _3470,monty::rc_ptr< ::mosek::fusion::Expression > _3471);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3472,monty::rc_ptr< ::mosek::fusion::WorkStack > _3473,monty::rc_ptr< ::mosek::fusion::WorkStack > _3474) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarConst;

struct p_ExprScalarMul : public ::mosek::fusion::p_BaseExpression
{
ExprScalarMul * _pubthis;
static mosek::fusion::p_ExprScalarMul* _get_impl(mosek::fusion::ExprScalarMul * _inst){ return static_cast< mosek::fusion::p_ExprScalarMul* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprScalarMul * _get_impl(mosek::fusion::ExprScalarMul::t _inst) { return _get_impl(_inst.get()); }
p_ExprScalarMul(ExprScalarMul * _pubthis);
virtual ~p_ExprScalarMul() { /* std::cout << "~p_ExprScalarMul" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprScalarMul::t _new_ExprScalarMul(int _3482,int _3483,std::shared_ptr< monty::ndarray< int,1 > > _3484,std::shared_ptr< monty::ndarray< int,1 > > _3485,std::shared_ptr< monty::ndarray< double,1 > > _3486,monty::rc_ptr< ::mosek::fusion::Expression > _3487,int _3488);
void _initialize(int _3482,int _3483,std::shared_ptr< monty::ndarray< int,1 > > _3484,std::shared_ptr< monty::ndarray< int,1 > > _3485,std::shared_ptr< monty::ndarray< double,1 > > _3486,monty::rc_ptr< ::mosek::fusion::Expression > _3487,int _3488);
static ExprScalarMul::t _new_ExprScalarMul(int _3489,int _3490,std::shared_ptr< monty::ndarray< int,1 > > _3491,std::shared_ptr< monty::ndarray< int,1 > > _3492,std::shared_ptr< monty::ndarray< double,1 > > _3493,monty::rc_ptr< ::mosek::fusion::Expression > _3494);
void _initialize(int _3489,int _3490,std::shared_ptr< monty::ndarray< int,1 > > _3491,std::shared_ptr< monty::ndarray< int,1 > > _3492,std::shared_ptr< monty::ndarray< double,1 > > _3493,monty::rc_ptr< ::mosek::fusion::Expression > _3494);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3495,monty::rc_ptr< ::mosek::fusion::WorkStack > _3496,monty::rc_ptr< ::mosek::fusion::WorkStack > _3497) ;
static  int validate(int _3522,int _3523,std::shared_ptr< monty::ndarray< int,1 > > _3524,std::shared_ptr< monty::ndarray< int,1 > > _3525,std::shared_ptr< monty::ndarray< double,1 > > _3526,monty::rc_ptr< ::mosek::fusion::Expression > _3527);
virtual /* override */ std::string toString() ;
}; // struct ExprScalarMul;

struct p_ExprMulRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulRight * _pubthis;
static mosek::fusion::p_ExprMulRight* _get_impl(mosek::fusion::ExprMulRight * _inst){ return static_cast< mosek::fusion::p_ExprMulRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulRight * _get_impl(mosek::fusion::ExprMulRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulRight(ExprMulRight * _pubthis);
virtual ~p_ExprMulRight() { /* std::cout << "~p_ExprMulRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulRight::t _new_ExprMulRight(int _3533,int _3534,std::shared_ptr< monty::ndarray< int,1 > > _3535,std::shared_ptr< monty::ndarray< int,1 > > _3536,std::shared_ptr< monty::ndarray< double,1 > > _3537,monty::rc_ptr< ::mosek::fusion::Expression > _3538,int _3539);
void _initialize(int _3533,int _3534,std::shared_ptr< monty::ndarray< int,1 > > _3535,std::shared_ptr< monty::ndarray< int,1 > > _3536,std::shared_ptr< monty::ndarray< double,1 > > _3537,monty::rc_ptr< ::mosek::fusion::Expression > _3538,int _3539);
static ExprMulRight::t _new_ExprMulRight(int _3540,int _3541,std::shared_ptr< monty::ndarray< int,1 > > _3542,std::shared_ptr< monty::ndarray< int,1 > > _3543,std::shared_ptr< monty::ndarray< double,1 > > _3544,monty::rc_ptr< ::mosek::fusion::Expression > _3545);
void _initialize(int _3540,int _3541,std::shared_ptr< monty::ndarray< int,1 > > _3542,std::shared_ptr< monty::ndarray< int,1 > > _3543,std::shared_ptr< monty::ndarray< double,1 > > _3544,monty::rc_ptr< ::mosek::fusion::Expression > _3545);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3546,monty::rc_ptr< ::mosek::fusion::WorkStack > _3547,monty::rc_ptr< ::mosek::fusion::WorkStack > _3548) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3698,std::shared_ptr< monty::ndarray< int,1 > > _3699);
static  int validate(int _3700,int _3701,std::shared_ptr< monty::ndarray< int,1 > > _3702,std::shared_ptr< monty::ndarray< int,1 > > _3703,std::shared_ptr< monty::ndarray< double,1 > > _3704,monty::rc_ptr< ::mosek::fusion::Expression > _3705);
virtual /* override */ std::string toString() ;
}; // struct ExprMulRight;

struct p_ExprMulLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulLeft * _pubthis;
static mosek::fusion::p_ExprMulLeft* _get_impl(mosek::fusion::ExprMulLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulLeft * _get_impl(mosek::fusion::ExprMulLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulLeft(ExprMulLeft * _pubthis);
virtual ~p_ExprMulLeft() { /* std::cout << "~p_ExprMulLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulLeft::t _new_ExprMulLeft(int _3713,int _3714,std::shared_ptr< monty::ndarray< int,1 > > _3715,std::shared_ptr< monty::ndarray< int,1 > > _3716,std::shared_ptr< monty::ndarray< double,1 > > _3717,monty::rc_ptr< ::mosek::fusion::Expression > _3718,int _3719);
void _initialize(int _3713,int _3714,std::shared_ptr< monty::ndarray< int,1 > > _3715,std::shared_ptr< monty::ndarray< int,1 > > _3716,std::shared_ptr< monty::ndarray< double,1 > > _3717,monty::rc_ptr< ::mosek::fusion::Expression > _3718,int _3719);
static ExprMulLeft::t _new_ExprMulLeft(int _3720,int _3721,std::shared_ptr< monty::ndarray< int,1 > > _3722,std::shared_ptr< monty::ndarray< int,1 > > _3723,std::shared_ptr< monty::ndarray< double,1 > > _3724,monty::rc_ptr< ::mosek::fusion::Expression > _3725);
void _initialize(int _3720,int _3721,std::shared_ptr< monty::ndarray< int,1 > > _3722,std::shared_ptr< monty::ndarray< int,1 > > _3723,std::shared_ptr< monty::ndarray< double,1 > > _3724,monty::rc_ptr< ::mosek::fusion::Expression > _3725);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3726,monty::rc_ptr< ::mosek::fusion::WorkStack > _3727,monty::rc_ptr< ::mosek::fusion::WorkStack > _3728) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _3826,int _3827,std::shared_ptr< monty::ndarray< int,1 > > _3828);
static  int validate(int _3829,int _3830,std::shared_ptr< monty::ndarray< int,1 > > _3831,std::shared_ptr< monty::ndarray< int,1 > > _3832,std::shared_ptr< monty::ndarray< double,1 > > _3833,monty::rc_ptr< ::mosek::fusion::Expression > _3834);
virtual /* override */ std::string toString() ;
}; // struct ExprMulLeft;

struct p_ExprMulVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulVar * _pubthis;
static mosek::fusion::p_ExprMulVar* _get_impl(mosek::fusion::ExprMulVar * _inst){ return static_cast< mosek::fusion::p_ExprMulVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVar * _get_impl(mosek::fusion::ExprMulVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVar(ExprMulVar * _pubthis);
virtual ~p_ExprMulVar() { /* std::cout << "~p_ExprMulVar" << std::endl;*/ };
bool left{};monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulVar::t _new_ExprMulVar(bool _3841,int _3842,int _3843,std::shared_ptr< monty::ndarray< int,1 > > _3844,std::shared_ptr< monty::ndarray< int,1 > > _3845,std::shared_ptr< monty::ndarray< double,1 > > _3846,monty::rc_ptr< ::mosek::fusion::Variable > _3847);
void _initialize(bool _3841,int _3842,int _3843,std::shared_ptr< monty::ndarray< int,1 > > _3844,std::shared_ptr< monty::ndarray< int,1 > > _3845,std::shared_ptr< monty::ndarray< double,1 > > _3846,monty::rc_ptr< ::mosek::fusion::Variable > _3847);
static ExprMulVar::t _new_ExprMulVar(bool _3850,int _3851,int _3852,std::shared_ptr< monty::ndarray< int,1 > > _3853,std::shared_ptr< monty::ndarray< int,1 > > _3854,std::shared_ptr< monty::ndarray< double,1 > > _3855,monty::rc_ptr< ::mosek::fusion::Variable > _3856,int _3857);
void _initialize(bool _3850,int _3851,int _3852,std::shared_ptr< monty::ndarray< int,1 > > _3853,std::shared_ptr< monty::ndarray< int,1 > > _3854,std::shared_ptr< monty::ndarray< double,1 > > _3855,monty::rc_ptr< ::mosek::fusion::Variable > _3856,int _3857);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3858,monty::rc_ptr< ::mosek::fusion::WorkStack > _3859,monty::rc_ptr< ::mosek::fusion::WorkStack > _3860) ;
virtual void eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _3861,monty::rc_ptr< ::mosek::fusion::WorkStack > _3862,monty::rc_ptr< ::mosek::fusion::WorkStack > _3863) ;
virtual void eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _3969,monty::rc_ptr< ::mosek::fusion::WorkStack > _3970,monty::rc_ptr< ::mosek::fusion::WorkStack > _3971) ;
virtual void validate(int _4037,int _4038,std::shared_ptr< monty::ndarray< int,1 > > _4039,std::shared_ptr< monty::ndarray< int,1 > > _4040,std::shared_ptr< monty::ndarray< double,1 > > _4041) ;
static  std::shared_ptr< monty::ndarray< int,1 > > resshape(int _4045,int _4046,std::shared_ptr< monty::ndarray< int,1 > > _4047,bool _4048);
virtual /* override */ std::string toString() ;
}; // struct ExprMulVar;

struct p_ExprMulScalarVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarVar * _pubthis;
static mosek::fusion::p_ExprMulScalarVar* _get_impl(mosek::fusion::ExprMulScalarVar * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarVar * _get_impl(mosek::fusion::ExprMulScalarVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarVar(ExprMulScalarVar * _pubthis);
virtual ~p_ExprMulScalarVar() { /* std::cout << "~p_ExprMulScalarVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4049,int _4050,std::shared_ptr< monty::ndarray< int,1 > > _4051,std::shared_ptr< monty::ndarray< int,1 > > _4052,std::shared_ptr< monty::ndarray< double,1 > > _4053,monty::rc_ptr< ::mosek::fusion::Variable > _4054);
void _initialize(int _4049,int _4050,std::shared_ptr< monty::ndarray< int,1 > > _4051,std::shared_ptr< monty::ndarray< int,1 > > _4052,std::shared_ptr< monty::ndarray< double,1 > > _4053,monty::rc_ptr< ::mosek::fusion::Variable > _4054);
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _4057,int _4058,std::shared_ptr< monty::ndarray< int,1 > > _4059,std::shared_ptr< monty::ndarray< int,1 > > _4060,std::shared_ptr< monty::ndarray< double,1 > > _4061,monty::rc_ptr< ::mosek::fusion::Variable > _4062,int _4063);
void _initialize(int _4057,int _4058,std::shared_ptr< monty::ndarray< int,1 > > _4059,std::shared_ptr< monty::ndarray< int,1 > > _4060,std::shared_ptr< monty::ndarray< double,1 > > _4061,monty::rc_ptr< ::mosek::fusion::Variable > _4062,int _4063);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4064,monty::rc_ptr< ::mosek::fusion::WorkStack > _4065,monty::rc_ptr< ::mosek::fusion::WorkStack > _4066) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarVar;

struct p_ExprMulVarScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulVarScalarConst * _pubthis;
static mosek::fusion::p_ExprMulVarScalarConst* _get_impl(mosek::fusion::ExprMulVarScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulVarScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVarScalarConst * _get_impl(mosek::fusion::ExprMulVarScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVarScalarConst(ExprMulVarScalarConst * _pubthis);
virtual ~p_ExprMulVarScalarConst() { /* std::cout << "~p_ExprMulVarScalarConst" << std::endl;*/ };
double c{};monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprMulVarScalarConst::t _new_ExprMulVarScalarConst(monty::rc_ptr< ::mosek::fusion::Variable > _4085,double _4086);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4085,double _4086);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4087,monty::rc_ptr< ::mosek::fusion::WorkStack > _4088,monty::rc_ptr< ::mosek::fusion::WorkStack > _4089) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulVarScalarConst;

struct p_ExprAdd : public ::mosek::fusion::p_BaseExpression
{
ExprAdd * _pubthis;
static mosek::fusion::p_ExprAdd* _get_impl(mosek::fusion::ExprAdd * _inst){ return static_cast< mosek::fusion::p_ExprAdd* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprAdd * _get_impl(mosek::fusion::ExprAdd::t _inst) { return _get_impl(_inst.get()); }
p_ExprAdd(ExprAdd * _pubthis);
virtual ~p_ExprAdd() { /* std::cout << "~p_ExprAdd" << std::endl;*/ };
double m2{};double m1{};monty::rc_ptr< ::mosek::fusion::Expression > e2{};monty::rc_ptr< ::mosek::fusion::Expression > e1{};virtual void destroy();
static ExprAdd::t _new_ExprAdd(monty::rc_ptr< ::mosek::fusion::Expression > _4107,monty::rc_ptr< ::mosek::fusion::Expression > _4108,double _4109,double _4110);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4107,monty::rc_ptr< ::mosek::fusion::Expression > _4108,double _4109,double _4110);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4112,monty::rc_ptr< ::mosek::fusion::WorkStack > _4113,monty::rc_ptr< ::mosek::fusion::WorkStack > _4114) ;
virtual /* override */ std::string toString() ;
}; // struct ExprAdd;

struct p_ExprWSum : public ::mosek::fusion::p_BaseExpression
{
ExprWSum * _pubthis;
static mosek::fusion::p_ExprWSum* _get_impl(mosek::fusion::ExprWSum * _inst){ return static_cast< mosek::fusion::p_ExprWSum* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprWSum * _get_impl(mosek::fusion::ExprWSum::t _inst) { return _get_impl(_inst.get()); }
p_ExprWSum(ExprWSum * _pubthis);
virtual ~p_ExprWSum() { /* std::cout << "~p_ExprWSum" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > w{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > es{};virtual void destroy();
static ExprWSum::t _new_ExprWSum(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4224,std::shared_ptr< monty::ndarray< double,1 > > _4225);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4224,std::shared_ptr< monty::ndarray< double,1 > > _4225);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4232,monty::rc_ptr< ::mosek::fusion::WorkStack > _4233,monty::rc_ptr< ::mosek::fusion::WorkStack > _4234) ;
virtual /* override */ std::string toString() ;
}; // struct ExprWSum;

struct p_ExprSumReduce : public ::mosek::fusion::p_BaseExpression
{
ExprSumReduce * _pubthis;
static mosek::fusion::p_ExprSumReduce* _get_impl(mosek::fusion::ExprSumReduce * _inst){ return static_cast< mosek::fusion::p_ExprSumReduce* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSumReduce * _get_impl(mosek::fusion::ExprSumReduce::t _inst) { return _get_impl(_inst.get()); }
p_ExprSumReduce(ExprSumReduce * _pubthis);
virtual ~p_ExprSumReduce() { /* std::cout << "~p_ExprSumReduce" << std::endl;*/ };
int dim{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSumReduce::t _new_ExprSumReduce(int _4301,monty::rc_ptr< ::mosek::fusion::Expression > _4302);
void _initialize(int _4301,monty::rc_ptr< ::mosek::fusion::Expression > _4302);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4304,monty::rc_ptr< ::mosek::fusion::WorkStack > _4305,monty::rc_ptr< ::mosek::fusion::WorkStack > _4306) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeShape(int _4410,std::shared_ptr< monty::ndarray< int,1 > > _4411);
virtual /* override */ std::string toString() ;
}; // struct ExprSumReduce;

struct p_ExprDenseTril : public ::mosek::fusion::p_BaseExpression
{
ExprDenseTril * _pubthis;
static mosek::fusion::p_ExprDenseTril* _get_impl(mosek::fusion::ExprDenseTril * _inst){ return static_cast< mosek::fusion::p_ExprDenseTril* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDenseTril * _get_impl(mosek::fusion::ExprDenseTril::t _inst) { return _get_impl(_inst.get()); }
p_ExprDenseTril(ExprDenseTril * _pubthis);
virtual ~p_ExprDenseTril() { /* std::cout << "~p_ExprDenseTril" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDenseTril::t _new_ExprDenseTril(int _4415,int _4416,monty::rc_ptr< ::mosek::fusion::Expression > _4417,int _4418);
void _initialize(int _4415,int _4416,monty::rc_ptr< ::mosek::fusion::Expression > _4417,int _4418);
static ExprDenseTril::t _new_ExprDenseTril(int _4419,int _4420,monty::rc_ptr< ::mosek::fusion::Expression > _4421);
void _initialize(int _4419,int _4420,monty::rc_ptr< ::mosek::fusion::Expression > _4421);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4423,monty::rc_ptr< ::mosek::fusion::WorkStack > _4424,monty::rc_ptr< ::mosek::fusion::WorkStack > _4425) ;
}; // struct ExprDenseTril;

struct p_ExprDense : public ::mosek::fusion::p_BaseExpression
{
ExprDense * _pubthis;
static mosek::fusion::p_ExprDense* _get_impl(mosek::fusion::ExprDense * _inst){ return static_cast< mosek::fusion::p_ExprDense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDense * _get_impl(mosek::fusion::ExprDense::t _inst) { return _get_impl(_inst.get()); }
p_ExprDense(ExprDense * _pubthis);
virtual ~p_ExprDense() { /* std::cout << "~p_ExprDense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDense::t _new_ExprDense(monty::rc_ptr< ::mosek::fusion::Expression > _4498);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4498);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDense;

struct p_ExprSymmetrize : public ::mosek::fusion::p_BaseExpression
{
ExprSymmetrize * _pubthis;
static mosek::fusion::p_ExprSymmetrize* _get_impl(mosek::fusion::ExprSymmetrize * _inst){ return static_cast< mosek::fusion::p_ExprSymmetrize* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSymmetrize * _get_impl(mosek::fusion::ExprSymmetrize::t _inst) { return _get_impl(_inst.get()); }
p_ExprSymmetrize(ExprSymmetrize * _pubthis);
virtual ~p_ExprSymmetrize() { /* std::cout << "~p_ExprSymmetrize" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSymmetrize::t _new_ExprSymmetrize(int _4524,int _4525,monty::rc_ptr< ::mosek::fusion::Expression > _4526,int _4527);
void _initialize(int _4524,int _4525,monty::rc_ptr< ::mosek::fusion::Expression > _4526,int _4527);
static ExprSymmetrize::t _new_ExprSymmetrize(int _4528,int _4529,monty::rc_ptr< ::mosek::fusion::Expression > _4530);
void _initialize(int _4528,int _4529,monty::rc_ptr< ::mosek::fusion::Expression > _4530);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4532,monty::rc_ptr< ::mosek::fusion::WorkStack > _4533,monty::rc_ptr< ::mosek::fusion::WorkStack > _4534) ;
}; // struct ExprSymmetrize;

struct p_ExprCompress : public ::mosek::fusion::p_BaseExpression
{
ExprCompress * _pubthis;
static mosek::fusion::p_ExprCompress* _get_impl(mosek::fusion::ExprCompress * _inst){ return static_cast< mosek::fusion::p_ExprCompress* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCompress * _get_impl(mosek::fusion::ExprCompress::t _inst) { return _get_impl(_inst.get()); }
p_ExprCompress(ExprCompress * _pubthis);
virtual ~p_ExprCompress() { /* std::cout << "~p_ExprCompress" << std::endl;*/ };
double eps{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4633);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4633);
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4634,double _4635);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4634,double _4635);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4636,monty::rc_ptr< ::mosek::fusion::WorkStack > _4637,monty::rc_ptr< ::mosek::fusion::WorkStack > _4638) ;
static  void arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4704,monty::rc_ptr< ::mosek::fusion::WorkStack > _4705,int _4706,int _4707,int _4708,int _4709,int _4710);
static  void merge_sort(int _4746,int _4747,int _4748,int _4749,int _4750,int _4751,std::shared_ptr< monty::ndarray< int,1 > > _4752,std::shared_ptr< monty::ndarray< long long,1 > > _4753);
virtual /* override */ std::string toString() ;
}; // struct ExprCompress;

struct p_ExprCondense : public ::mosek::fusion::p_BaseExpression
{
ExprCondense * _pubthis;
static mosek::fusion::p_ExprCondense* _get_impl(mosek::fusion::ExprCondense * _inst){ return static_cast< mosek::fusion::p_ExprCondense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCondense * _get_impl(mosek::fusion::ExprCondense::t _inst) { return _get_impl(_inst.get()); }
p_ExprCondense(ExprCondense * _pubthis);
virtual ~p_ExprCondense() { /* std::cout << "~p_ExprCondense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCondense::t _new_ExprCondense(monty::rc_ptr< ::mosek::fusion::Expression > _4776);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4776);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4777,monty::rc_ptr< ::mosek::fusion::WorkStack > _4778,monty::rc_ptr< ::mosek::fusion::WorkStack > _4779) ;
}; // struct ExprCondense;

struct p_ExprFromVar : public ::mosek::fusion::p_BaseExpression
{
ExprFromVar * _pubthis;
static mosek::fusion::p_ExprFromVar* _get_impl(mosek::fusion::ExprFromVar * _inst){ return static_cast< mosek::fusion::p_ExprFromVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprFromVar * _get_impl(mosek::fusion::ExprFromVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprFromVar(ExprFromVar * _pubthis);
virtual ~p_ExprFromVar() { /* std::cout << "~p_ExprFromVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprFromVar::t _new_ExprFromVar(monty::rc_ptr< ::mosek::fusion::Variable > _4786);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _4786);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4787,monty::rc_ptr< ::mosek::fusion::WorkStack > _4788,monty::rc_ptr< ::mosek::fusion::WorkStack > _4789) ;
virtual /* override */ std::string toString() ;
}; // struct ExprFromVar;

struct p_ExprReshape : public ::mosek::fusion::p_BaseExpression
{
ExprReshape * _pubthis;
static mosek::fusion::p_ExprReshape* _get_impl(mosek::fusion::ExprReshape * _inst){ return static_cast< mosek::fusion::p_ExprReshape* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprReshape * _get_impl(mosek::fusion::ExprReshape::t _inst) { return _get_impl(_inst.get()); }
p_ExprReshape(ExprReshape * _pubthis);
virtual ~p_ExprReshape() { /* std::cout << "~p_ExprReshape" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};virtual void destroy();
static ExprReshape::t _new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > > _4807,monty::rc_ptr< ::mosek::fusion::Expression > _4808);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4807,monty::rc_ptr< ::mosek::fusion::Expression > _4808);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4810,monty::rc_ptr< ::mosek::fusion::WorkStack > _4811,monty::rc_ptr< ::mosek::fusion::WorkStack > _4812) ;
virtual /* override */ std::string toString() ;
}; // struct ExprReshape;

struct p_Expr : public ::mosek::fusion::p_BaseExpression
{
Expr * _pubthis;
static mosek::fusion::p_Expr* _get_impl(mosek::fusion::Expr * _inst){ return static_cast< mosek::fusion::p_Expr* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_Expr * _get_impl(mosek::fusion::Expr::t _inst) { return _get_impl(_inst.get()); }
p_Expr(Expr * _pubthis);
virtual ~p_Expr() { /* std::cout << "~p_Expr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< double,1 > > cof_v{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4947,std::shared_ptr< monty::ndarray< long long,1 > > _4948,std::shared_ptr< monty::ndarray< double,1 > > _4949,std::shared_ptr< monty::ndarray< double,1 > > _4950,std::shared_ptr< monty::ndarray< int,1 > > _4951,std::shared_ptr< monty::ndarray< long long,1 > > _4952);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4947,std::shared_ptr< monty::ndarray< long long,1 > > _4948,std::shared_ptr< monty::ndarray< double,1 > > _4949,std::shared_ptr< monty::ndarray< double,1 > > _4950,std::shared_ptr< monty::ndarray< int,1 > > _4951,std::shared_ptr< monty::ndarray< long long,1 > > _4952);
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _4963,std::shared_ptr< monty::ndarray< long long,1 > > _4964,std::shared_ptr< monty::ndarray< double,1 > > _4965,std::shared_ptr< monty::ndarray< double,1 > > _4966,std::shared_ptr< monty::ndarray< int,1 > > _4967,std::shared_ptr< monty::ndarray< long long,1 > > _4968,int _4969);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _4963,std::shared_ptr< monty::ndarray< long long,1 > > _4964,std::shared_ptr< monty::ndarray< double,1 > > _4965,std::shared_ptr< monty::ndarray< double,1 > > _4966,std::shared_ptr< monty::ndarray< int,1 > > _4967,std::shared_ptr< monty::ndarray< long long,1 > > _4968,int _4969);
static Expr::t _new_Expr(monty::rc_ptr< ::mosek::fusion::Expression > _4970);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4970);
virtual long long prod(std::shared_ptr< monty::ndarray< int,1 > > _4995) ;
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _4998);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5001,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5002);
static  monty::rc_ptr< ::mosek::fusion::Expression > condense(monty::rc_ptr< ::mosek::fusion::Expression > _5006);
static  monty::rc_ptr< ::mosek::fusion::Expression > flatten(monty::rc_ptr< ::mosek::fusion::Expression > _5007);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5008,int _5009,int _5010);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5011,int _5012);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _5013,std::shared_ptr< monty::ndarray< int,1 > > _5014);
virtual long long size() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2Expr__eval() ;
virtual monty::rc_ptr< ::mosek::fusion::FlatExpr > __mosek_2fusion_2BaseExpression__eval() { return __mosek_2fusion_2Expr__eval(); }
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(std::shared_ptr< monty::ndarray< int,1 > > _5017);
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(int _5018);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones();
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _5019,std::shared_ptr< monty::ndarray< int,2 > > _5020);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _5021);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(int _5022);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5023);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _5024);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(double _5033);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5034,std::shared_ptr< monty::ndarray< int,2 > > _5035,double _5036);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5044,std::shared_ptr< monty::ndarray< int,2 > > _5045,std::shared_ptr< monty::ndarray< double,1 > > _5046);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _5054,double _5055);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(int _5056,double _5057);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,2 > > _5059);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,1 > > _5062);
virtual long long numNonzeros() ;
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5063,int _5064);
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _5065);
static  monty::rc_ptr< ::mosek::fusion::Expression > neg(monty::rc_ptr< ::mosek::fusion::Expression > _5066);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(bool _5067,monty::rc_ptr< ::mosek::fusion::Matrix > _5068,monty::rc_ptr< ::mosek::fusion::Expression > _5069);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5076,monty::rc_ptr< ::mosek::fusion::Matrix > _5077);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5078,monty::rc_ptr< ::mosek::fusion::Variable > _5079);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5080,monty::rc_ptr< ::mosek::fusion::Matrix > _5081);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _5082,monty::rc_ptr< ::mosek::fusion::Expression > _5083);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _5084,std::shared_ptr< monty::ndarray< double,2 > > _5085);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _5092,std::shared_ptr< monty::ndarray< double,2 > > _5093);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5100,monty::rc_ptr< ::mosek::fusion::Variable > _5101);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _5108,monty::rc_ptr< ::mosek::fusion::Expression > _5109);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _5116,monty::rc_ptr< ::mosek::fusion::Expression > _5117);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _5126,monty::rc_ptr< ::mosek::fusion::Expression > _5127);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5129,monty::rc_ptr< ::mosek::fusion::Expression > _5130);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5133,double _5134);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(double _5135,monty::rc_ptr< ::mosek::fusion::Expression > _5136);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5137,std::shared_ptr< monty::ndarray< double,1 > > _5138);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,1 > > _5139,monty::rc_ptr< ::mosek::fusion::Expression > _5140);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5141,std::shared_ptr< monty::ndarray< double,2 > > _5142);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,2 > > _5143,monty::rc_ptr< ::mosek::fusion::Expression > _5144);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _5145,monty::rc_ptr< ::mosek::fusion::Matrix > _5146);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5147,monty::rc_ptr< ::mosek::fusion::Expression > _5148);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5149,std::shared_ptr< monty::ndarray< double,1 > > _5150,monty::rc_ptr< ::mosek::fusion::Expression > _5151);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5166,std::shared_ptr< monty::ndarray< double,2 > > _5167,monty::rc_ptr< ::mosek::fusion::Expression > _5168);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5183,monty::rc_ptr< ::mosek::fusion::Matrix > _5184,monty::rc_ptr< ::mosek::fusion::Expression > _5185);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Variable > _5194,monty::rc_ptr< ::mosek::fusion::Matrix > _5195);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _5201,monty::rc_ptr< ::mosek::fusion::Variable > _5202);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _5208,int _5209,int _5210,std::shared_ptr< monty::ndarray< int,1 > > _5211,std::shared_ptr< monty::ndarray< int,1 > > _5212,std::shared_ptr< monty::ndarray< double,1 > > _5213,monty::rc_ptr< ::mosek::fusion::Variable > _5214);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5216,monty::rc_ptr< ::mosek::fusion::Matrix > _5217);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5225,std::shared_ptr< monty::ndarray< double,2 > > _5226);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5230,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5231);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _5232,std::shared_ptr< monty::ndarray< double,1 > > _5233);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Matrix > _5238,monty::rc_ptr< ::mosek::fusion::Expression > _5239);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5240,monty::rc_ptr< ::mosek::fusion::Expression > _5241);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,2 > > _5242,monty::rc_ptr< ::mosek::fusion::Expression > _5243);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,1 > > _5244,monty::rc_ptr< ::mosek::fusion::Expression > _5245);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5246,monty::rc_ptr< ::mosek::fusion::Expression > _5247);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Expression > _5251,std::shared_ptr< monty::ndarray< double,1 > > _5252);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Matrix > _5255,monty::rc_ptr< ::mosek::fusion::Variable > _5256);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5263,monty::rc_ptr< ::mosek::fusion::Matrix > _5264);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _5271,monty::rc_ptr< ::mosek::fusion::Variable > _5272);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _5274,std::shared_ptr< monty::ndarray< double,1 > > _5275);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(int _5277,std::shared_ptr< monty::ndarray< long long,1 > > _5278,std::shared_ptr< monty::ndarray< long long,1 > > _5279,std::shared_ptr< monty::ndarray< double,1 > > _5280,std::shared_ptr< monty::ndarray< double,1 > > _5281,std::shared_ptr< monty::ndarray< long long,1 > > _5282,std::shared_ptr< monty::ndarray< double,1 > > _5283,std::shared_ptr< monty::ndarray< int,1 > > _5284,int _5285,bool _5286);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(monty::rc_ptr< ::mosek::fusion::Variable > _5316,int _5317,std::shared_ptr< monty::ndarray< double,1 > > _5318,std::shared_ptr< monty::ndarray< int,1 > > _5319,int _5320,bool _5321);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _5338);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5344,double _5345,double _5346);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5347,double _5348,monty::rc_ptr< ::mosek::fusion::Expression > _5349);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5350,monty::rc_ptr< ::mosek::fusion::Expression > _5351,double _5352);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5353,monty::rc_ptr< ::mosek::fusion::Expression > _5354,monty::rc_ptr< ::mosek::fusion::Expression > _5355);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5356,double _5357,double _5358);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5359,double _5360,monty::rc_ptr< ::mosek::fusion::Expression > _5361);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5362,monty::rc_ptr< ::mosek::fusion::Expression > _5363,double _5364);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5365,monty::rc_ptr< ::mosek::fusion::Expression > _5366,monty::rc_ptr< ::mosek::fusion::Expression > _5367);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _5368,monty::rc_ptr< ::mosek::fusion::Expression > _5369);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5370,double _5371);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _5372,monty::rc_ptr< ::mosek::fusion::Expression > _5373);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5374);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5376,monty::rc_ptr< ::mosek::fusion::Expression > _5377,monty::rc_ptr< ::mosek::fusion::Expression > _5378);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5379,monty::rc_ptr< ::mosek::fusion::Expression > _5380,double _5381);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5382,double _5383,monty::rc_ptr< ::mosek::fusion::Expression > _5384);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5385,double _5386,double _5387);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5388,monty::rc_ptr< ::mosek::fusion::Expression > _5389,monty::rc_ptr< ::mosek::fusion::Expression > _5390);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5391,monty::rc_ptr< ::mosek::fusion::Expression > _5392,double _5393);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5394,double _5395,monty::rc_ptr< ::mosek::fusion::Expression > _5396);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _5397,monty::rc_ptr< ::mosek::fusion::Expression > _5398);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5399,double _5400);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _5401,monty::rc_ptr< ::mosek::fusion::Expression > _5402);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5403);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5405,monty::rc_ptr< ::mosek::fusion::Expression > _5406,monty::rc_ptr< ::mosek::fusion::Expression > _5407,monty::rc_ptr< ::mosek::fusion::Expression > _5408);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5409,monty::rc_ptr< ::mosek::fusion::Expression > _5410,monty::rc_ptr< ::mosek::fusion::Expression > _5411,double _5412);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5413,monty::rc_ptr< ::mosek::fusion::Expression > _5414,double _5415,monty::rc_ptr< ::mosek::fusion::Expression > _5416);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5417,monty::rc_ptr< ::mosek::fusion::Expression > _5418,double _5419,double _5420);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5421,double _5422,monty::rc_ptr< ::mosek::fusion::Expression > _5423,monty::rc_ptr< ::mosek::fusion::Expression > _5424);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5425,double _5426,monty::rc_ptr< ::mosek::fusion::Expression > _5427,double _5428);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5429,double _5430,double _5431,monty::rc_ptr< ::mosek::fusion::Expression > _5432);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5433,double _5434,monty::rc_ptr< ::mosek::fusion::Expression > _5435);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5436,monty::rc_ptr< ::mosek::fusion::Expression > _5437,double _5438);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5439,monty::rc_ptr< ::mosek::fusion::Expression > _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _5442,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5443);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5444,int _5445);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5446,int _5447);
static  monty::rc_ptr< ::mosek::fusion::Expression > repeat(monty::rc_ptr< ::mosek::fusion::Expression > _5460,int _5461,int _5462);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _5464);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5466);
static  monty::rc_ptr< ::mosek::fusion::Expression > add_(monty::rc_ptr< ::mosek::fusion::Expression > _5499,double _5500,monty::rc_ptr< ::mosek::fusion::Expression > _5501,double _5502);
static  monty::rc_ptr< ::mosek::fusion::Expression > transpose(monty::rc_ptr< ::mosek::fusion::Expression > _5513);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _5514,monty::rc_ptr< ::mosek::fusion::Expression > _5515);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5516,monty::rc_ptr< ::mosek::fusion::Expression > _5517);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,2 > > _5518,monty::rc_ptr< ::mosek::fusion::Expression > _5519);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,1 > > _5520,monty::rc_ptr< ::mosek::fusion::Expression > _5521);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5522,monty::rc_ptr< ::mosek::fusion::Matrix > _5523);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5524,std::shared_ptr< monty::ndarray< double,2 > > _5525);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5526,std::shared_ptr< monty::ndarray< double,1 > > _5527);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _5528,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5529);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5530,monty::rc_ptr< ::mosek::fusion::Expression > _5531);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5532,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5533);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Matrix > _5534,monty::rc_ptr< ::mosek::fusion::Expression > _5535);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5536,monty::rc_ptr< ::mosek::fusion::Matrix > _5537);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(double _5538,monty::rc_ptr< ::mosek::fusion::Expression > _5539);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5540,double _5541);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,2 > > _5542,monty::rc_ptr< ::mosek::fusion::Expression > _5543);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,1 > > _5544,monty::rc_ptr< ::mosek::fusion::Expression > _5545);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5546,std::shared_ptr< monty::ndarray< double,2 > > _5547);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5548,std::shared_ptr< monty::ndarray< double,1 > > _5549);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _5550,monty::rc_ptr< ::mosek::fusion::Expression > _5551);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5552,monty::rc_ptr< ::mosek::fusion::Expression > _5553);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5554,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _5555);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Matrix > _5556,monty::rc_ptr< ::mosek::fusion::Expression > _5557);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5558,monty::rc_ptr< ::mosek::fusion::Matrix > _5559);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(double _5560,monty::rc_ptr< ::mosek::fusion::Expression > _5561);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5562,double _5563);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,2 > > _5564,monty::rc_ptr< ::mosek::fusion::Expression > _5565);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,1 > > _5566,monty::rc_ptr< ::mosek::fusion::Expression > _5567);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5568,std::shared_ptr< monty::ndarray< double,2 > > _5569);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5570,std::shared_ptr< monty::ndarray< double,1 > > _5571);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _5572,monty::rc_ptr< ::mosek::fusion::Expression > _5573);
virtual /* override */ int getND() ;
virtual /* override */ std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5574,monty::rc_ptr< ::mosek::fusion::WorkStack > _5575,monty::rc_ptr< ::mosek::fusion::WorkStack > _5576) ;
static  void validateData(std::shared_ptr< monty::ndarray< long long,1 > > _5578,std::shared_ptr< monty::ndarray< long long,1 > > _5579,std::shared_ptr< monty::ndarray< double,1 > > _5580,std::shared_ptr< monty::ndarray< double,1 > > _5581,std::shared_ptr< monty::ndarray< int,1 > > _5582,std::shared_ptr< monty::ndarray< long long,1 > > _5583);
static  monty::rc_ptr< ::mosek::fusion::Model > extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _5596);
}; // struct Expr;

struct p_WorkStack
{
WorkStack * _pubthis;
static mosek::fusion::p_WorkStack* _get_impl(mosek::fusion::WorkStack * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_WorkStack * _get_impl(mosek::fusion::WorkStack::t _inst) { return _get_impl(_inst.get()); }
p_WorkStack(WorkStack * _pubthis);
virtual ~p_WorkStack() { /* std::cout << "~p_WorkStack" << std::endl;*/ };
int cof_base{};int bfix_base{};int nidxs_base{};int sp_base{};int shape_base{};int ptr_base{};bool hassp{};int nelem{};int nnz{};int nd{};int pf64{};int pi64{};int pi32{};std::shared_ptr< monty::ndarray< double,1 > > f64{};std::shared_ptr< monty::ndarray< long long,1 > > i64{};std::shared_ptr< monty::ndarray< int,1 > > i32{};virtual void destroy();
static WorkStack::t _new_WorkStack();
void _initialize();
virtual bool peek_hassp() ;
virtual int peek_nnz() ;
virtual int peek_nelem() ;
virtual int peek_dim(int _4870) ;
virtual int peek_nd() ;
virtual void alloc_expr(int _4871,int _4872,int _4873,bool _4874) ;
virtual void move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _4875) ;
virtual void peek_expr() ;
virtual void pop_expr() ;
virtual void ensure_sparsity() ;
virtual void clear() ;
virtual int allocf64(int _4890) ;
virtual int alloci64(int _4893) ;
virtual int alloci32(int _4896) ;
virtual void pushf64(double _4899) ;
virtual void pushi64(long long _4900) ;
virtual void pushi32(int _4901) ;
virtual void ensuref64(int _4902) ;
virtual void ensurei64(int _4905) ;
virtual void ensurei32(int _4908) ;
virtual int popf64(int _4911) ;
virtual int popi64(int _4912) ;
virtual int popi32(int _4913) ;
virtual void popf64(int _4914,std::shared_ptr< monty::ndarray< double,1 > > _4915,int _4916) ;
virtual void popi64(int _4917,std::shared_ptr< monty::ndarray< long long,1 > > _4918,int _4919) ;
virtual void popi32(int _4920,std::shared_ptr< monty::ndarray< int,1 > > _4921,int _4922) ;
virtual double popf64() ;
virtual long long popi64() ;
virtual int popi32() ;
virtual double peekf64() ;
virtual long long peeki64() ;
virtual int peeki32() ;
virtual double peekf64(int _4923) ;
virtual long long peeki64(int _4924) ;
virtual int peeki32(int _4925) ;
}; // struct WorkStack;

struct p_SymmetricExpr
{
SymmetricExpr * _pubthis;
static mosek::fusion::p_SymmetricExpr* _get_impl(mosek::fusion::SymmetricExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricExpr * _get_impl(mosek::fusion::SymmetricExpr::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricExpr(SymmetricExpr * _pubthis);
virtual ~p_SymmetricExpr() { /* std::cout << "~p_SymmetricExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > xs{};monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > b{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > Ms{};int n{};virtual void destroy();
static SymmetricExpr::t _new_SymmetricExpr(int _4926,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4927,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4928,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4929);
void _initialize(int _4926,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _4927,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _4928,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4929);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4930,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _4931);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4932,double _4933);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4935,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _4936);
virtual /* override */ std::string toString() ;
}; // struct SymmetricExpr;

struct p_FlatExpr
{
FlatExpr * _pubthis;
static mosek::fusion::p_FlatExpr* _get_impl(mosek::fusion::FlatExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_FlatExpr * _get_impl(mosek::fusion::FlatExpr::t _inst) { return _get_impl(_inst.get()); }
p_FlatExpr(FlatExpr * _pubthis);
virtual ~p_FlatExpr() { /* std::cout << "~p_FlatExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > shape{};long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static FlatExpr::t _new_FlatExpr(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5609);
void _initialize(monty::rc_ptr< ::mosek::fusion::FlatExpr > _5609);
static FlatExpr::t _new_FlatExpr(std::shared_ptr< monty::ndarray< double,1 > > _5610,std::shared_ptr< monty::ndarray< long long,1 > > _5611,std::shared_ptr< monty::ndarray< long long,1 > > _5612,std::shared_ptr< monty::ndarray< double,1 > > _5613,std::shared_ptr< monty::ndarray< int,1 > > _5614,std::shared_ptr< monty::ndarray< long long,1 > > _5615);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _5610,std::shared_ptr< monty::ndarray< long long,1 > > _5611,std::shared_ptr< monty::ndarray< long long,1 > > _5612,std::shared_ptr< monty::ndarray< double,1 > > _5613,std::shared_ptr< monty::ndarray< int,1 > > _5614,std::shared_ptr< monty::ndarray< long long,1 > > _5615);
virtual /* override */ std::string toString() ;
virtual int size() ;
}; // struct FlatExpr;

struct p_SymmetricMatrix
{
SymmetricMatrix * _pubthis;
static mosek::fusion::p_SymmetricMatrix* _get_impl(mosek::fusion::SymmetricMatrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricMatrix * _get_impl(mosek::fusion::SymmetricMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricMatrix(SymmetricMatrix * _pubthis);
virtual ~p_SymmetricMatrix() { /* std::cout << "~p_SymmetricMatrix" << std::endl;*/ };
int nnz{};double scale{};std::shared_ptr< monty::ndarray< double,1 > > vval{};std::shared_ptr< monty::ndarray< int,1 > > vsubj{};std::shared_ptr< monty::ndarray< int,1 > > vsubi{};std::shared_ptr< monty::ndarray< double,1 > > uval{};std::shared_ptr< monty::ndarray< int,1 > > usubj{};std::shared_ptr< monty::ndarray< int,1 > > usubi{};int d1{};int d0{};virtual void destroy();
static SymmetricMatrix::t _new_SymmetricMatrix(int _5617,int _5618,std::shared_ptr< monty::ndarray< int,1 > > _5619,std::shared_ptr< monty::ndarray< int,1 > > _5620,std::shared_ptr< monty::ndarray< double,1 > > _5621,std::shared_ptr< monty::ndarray< int,1 > > _5622,std::shared_ptr< monty::ndarray< int,1 > > _5623,std::shared_ptr< monty::ndarray< double,1 > > _5624,double _5625);
void _initialize(int _5617,int _5618,std::shared_ptr< monty::ndarray< int,1 > > _5619,std::shared_ptr< monty::ndarray< int,1 > > _5620,std::shared_ptr< monty::ndarray< double,1 > > _5621,std::shared_ptr< monty::ndarray< int,1 > > _5622,std::shared_ptr< monty::ndarray< int,1 > > _5623,std::shared_ptr< monty::ndarray< double,1 > > _5624,double _5625);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(int _5626,std::shared_ptr< monty::ndarray< int,1 > > _5627,std::shared_ptr< monty::ndarray< double,1 > > _5628);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(std::shared_ptr< monty::ndarray< double,1 > > _5636);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _5644);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5651);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5657) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _5677) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__mul(double _5678) ;
virtual int getdim() ;
}; // struct SymmetricMatrix;

struct p_NDSparseArray
{
NDSparseArray * _pubthis;
static mosek::fusion::p_NDSparseArray* _get_impl(mosek::fusion::NDSparseArray * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_NDSparseArray * _get_impl(mosek::fusion::NDSparseArray::t _inst) { return _get_impl(_inst.get()); }
p_NDSparseArray(NDSparseArray * _pubthis);
virtual ~p_NDSparseArray() { /* std::cout << "~p_NDSparseArray" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > dims{};long long size{};virtual void destroy();
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5679,std::shared_ptr< monty::ndarray< int,2 > > _5680,std::shared_ptr< monty::ndarray< double,1 > > _5681);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5679,std::shared_ptr< monty::ndarray< int,2 > > _5680,std::shared_ptr< monty::ndarray< double,1 > > _5681);
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _5701,std::shared_ptr< monty::ndarray< long long,1 > > _5702,std::shared_ptr< monty::ndarray< double,1 > > _5703);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _5701,std::shared_ptr< monty::ndarray< long long,1 > > _5702,std::shared_ptr< monty::ndarray< double,1 > > _5703);
static NDSparseArray::t _new_NDSparseArray(monty::rc_ptr< ::mosek::fusion::Matrix > _5717);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5717);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(monty::rc_ptr< ::mosek::fusion::Matrix > _5725);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5726,std::shared_ptr< monty::ndarray< long long,1 > > _5727,std::shared_ptr< monty::ndarray< double,1 > > _5728);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _5729,std::shared_ptr< monty::ndarray< int,2 > > _5730,std::shared_ptr< monty::ndarray< double,1 > > _5731);
}; // struct NDSparseArray;

struct p_Matrix
{
Matrix * _pubthis;
static mosek::fusion::p_Matrix* _get_impl(mosek::fusion::Matrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Matrix * _get_impl(mosek::fusion::Matrix::t _inst) { return _get_impl(_inst.get()); }
p_Matrix(Matrix * _pubthis);
virtual ~p_Matrix() { /* std::cout << "~p_Matrix" << std::endl;*/ };
int dimj{};int dimi{};virtual void destroy();
static Matrix::t _new_Matrix(int _5800,int _5801);
void _initialize(int _5800,int _5801);
virtual /* override */ std::string toString() ;
virtual void switchDims() ;
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5803,monty::rc_ptr< ::mosek::fusion::Matrix > _5804);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _5806);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5824,double _5825,int _5826);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _5827,double _5828);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5829,double _5830,int _5831);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _5832,double _5833);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5834,int _5835);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _5845);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5846,int _5847);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _5855);
static  monty::rc_ptr< ::mosek::fusion::Matrix > ones(int _5856,int _5857);
static  monty::rc_ptr< ::mosek::fusion::Matrix > eye(int _5858);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(monty::rc_ptr< ::mosek::fusion::Matrix > _5860);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5861,int _5862,double _5863);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _5864,int _5865,std::shared_ptr< monty::ndarray< double,1 > > _5866);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(std::shared_ptr< monty::ndarray< double,2 > > _5867);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _5868);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _5872);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< double,2 > > _5903);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5916,int _5917);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5918,int _5919,std::shared_ptr< monty::ndarray< int,1 > > _5920,std::shared_ptr< monty::ndarray< int,1 > > _5921,double _5922);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5924,std::shared_ptr< monty::ndarray< int,1 > > _5925,double _5926);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _5931,std::shared_ptr< monty::ndarray< int,1 > > _5932,std::shared_ptr< monty::ndarray< double,1 > > _5933);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _5938,int _5939,std::shared_ptr< monty::ndarray< int,1 > > _5940,std::shared_ptr< monty::ndarray< int,1 > > _5941,std::shared_ptr< monty::ndarray< double,1 > > _5942);
virtual double get(int _5947,int _5948) { throw monty::AbstractClassError("Call to abstract method"); }
virtual bool isSparse() { throw monty::AbstractClassError("Call to abstract method"); }
virtual std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5949,std::shared_ptr< monty::ndarray< int,1 > > _5950,std::shared_ptr< monty::ndarray< double,1 > > _5951) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { throw monty::AbstractClassError("Call to abstract method"); }
virtual long long numNonzeros() { throw monty::AbstractClassError("Call to abstract method"); }
virtual int numColumns() ;
virtual int numRows() ;
}; // struct Matrix;

struct p_DenseMatrix : public ::mosek::fusion::p_Matrix
{
DenseMatrix * _pubthis;
static mosek::fusion::p_DenseMatrix* _get_impl(mosek::fusion::DenseMatrix * _inst){ return static_cast< mosek::fusion::p_DenseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_DenseMatrix * _get_impl(mosek::fusion::DenseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_DenseMatrix(DenseMatrix * _pubthis);
virtual ~p_DenseMatrix() { /* std::cout << "~p_DenseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > data{};virtual void destroy();
static DenseMatrix::t _new_DenseMatrix(int _5732,int _5733,std::shared_ptr< monty::ndarray< double,1 > > _5734);
void _initialize(int _5732,int _5733,std::shared_ptr< monty::ndarray< double,1 > > _5734);
static DenseMatrix::t _new_DenseMatrix(monty::rc_ptr< ::mosek::fusion::Matrix > _5735);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _5735);
static DenseMatrix::t _new_DenseMatrix(std::shared_ptr< monty::ndarray< double,2 > > _5740);
void _initialize(std::shared_ptr< monty::ndarray< double,2 > > _5740);
static DenseMatrix::t _new_DenseMatrix(int _5743,int _5744,double _5745);
void _initialize(int _5743,int _5744,double _5745);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2DenseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5758,std::shared_ptr< monty::ndarray< int,1 > > _5759,std::shared_ptr< monty::ndarray< double,1 > > _5760) ;
virtual /* override */ double get(int _5764,int _5765) ;
virtual /* override */ long long numNonzeros() ;
}; // struct DenseMatrix;

struct p_SparseMatrix : public ::mosek::fusion::p_Matrix
{
SparseMatrix * _pubthis;
static mosek::fusion::p_SparseMatrix* _get_impl(mosek::fusion::SparseMatrix * _inst){ return static_cast< mosek::fusion::p_SparseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_SparseMatrix * _get_impl(mosek::fusion::SparseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SparseMatrix(SparseMatrix * _pubthis);
virtual ~p_SparseMatrix() { /* std::cout << "~p_SparseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > val{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< int,1 > > subi{};virtual void destroy();
static SparseMatrix::t _new_SparseMatrix(int _5766,int _5767,std::shared_ptr< monty::ndarray< int,1 > > _5768,std::shared_ptr< monty::ndarray< int,1 > > _5769,std::shared_ptr< monty::ndarray< double,1 > > _5770,long long _5771);
void _initialize(int _5766,int _5767,std::shared_ptr< monty::ndarray< int,1 > > _5768,std::shared_ptr< monty::ndarray< int,1 > > _5769,std::shared_ptr< monty::ndarray< double,1 > > _5770,long long _5771);
static SparseMatrix::t _new_SparseMatrix(int _5776,int _5777,std::shared_ptr< monty::ndarray< int,1 > > _5778,std::shared_ptr< monty::ndarray< int,1 > > _5779,std::shared_ptr< monty::ndarray< double,1 > > _5780);
void _initialize(int _5776,int _5777,std::shared_ptr< monty::ndarray< int,1 > > _5778,std::shared_ptr< monty::ndarray< int,1 > > _5779,std::shared_ptr< monty::ndarray< double,1 > > _5780);
virtual std::shared_ptr< monty::ndarray< long long,1 > > formPtrb() ;
virtual /* override */ std::string toString() ;
virtual /* override */ long long numNonzeros() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2SparseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _5792,std::shared_ptr< monty::ndarray< int,1 > > _5793,std::shared_ptr< monty::ndarray< double,1 > > _5794) ;
virtual /* override */ double get(int _5795,int _5796) ;
}; // struct SparseMatrix;

struct p_LinkedBlocks
{
LinkedBlocks * _pubthis;
static mosek::fusion::p_LinkedBlocks* _get_impl(mosek::fusion::LinkedBlocks * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedBlocks * _get_impl(mosek::fusion::LinkedBlocks::t _inst) { return _get_impl(_inst.get()); }
p_LinkedBlocks(LinkedBlocks * _pubthis);
virtual ~p_LinkedBlocks() { /* std::cout << "~p_LinkedBlocks" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > bfirst{};std::shared_ptr< monty::ndarray< int,1 > > bsize{};monty::rc_ptr< ::mosek::fusion::LinkedInts > blocks{};monty::rc_ptr< ::mosek::fusion::LinkedInts > ints{};virtual void destroy();
static LinkedBlocks::t _new_LinkedBlocks();
void _initialize();
static LinkedBlocks::t _new_LinkedBlocks(int _5975);
void _initialize(int _5975);
static LinkedBlocks::t _new_LinkedBlocks(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5976);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _5976);
virtual void free(int _5977) ;
virtual int alloc(int _5979) ;
virtual int maxidx(int _5984) ;
virtual void get(int _5985,std::shared_ptr< monty::ndarray< int,1 > > _5986,int _5987) ;
virtual int numblocks() ;
virtual int blocksize(int _5988) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedBlocks;

struct p_LinkedInts
{
LinkedInts * _pubthis;
static mosek::fusion::p_LinkedInts* _get_impl(mosek::fusion::LinkedInts * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedInts * _get_impl(mosek::fusion::LinkedInts::t _inst) { return _get_impl(_inst.get()); }
p_LinkedInts(LinkedInts * _pubthis);
virtual ~p_LinkedInts() { /* std::cout << "~p_LinkedInts" << std::endl;*/ };
int nfree{};int last_free{};int first_free{};int first_used{};std::shared_ptr< monty::ndarray< int,1 > > prev{};std::shared_ptr< monty::ndarray< int,1 > > next{};virtual void destroy();
static LinkedInts::t _new_LinkedInts(int _5989);
void _initialize(int _5989);
static LinkedInts::t _new_LinkedInts();
void _initialize();
static LinkedInts::t _new_LinkedInts(monty::rc_ptr< ::mosek::fusion::LinkedInts > _5992);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedInts > _5992);
virtual void free(int _5993,int _5994) ;
virtual int alloc() ;
virtual int alloc(int _6000) ;
virtual void alloc(int _6001,std::shared_ptr< monty::ndarray< int,1 > > _6002,int _6003) ;
virtual void get(int _6006,int _6007,std::shared_ptr< monty::ndarray< int,1 > > _6008,int _6009) ;
virtual int maxidx(int _6012,int _6013) ;
virtual int allocblock(int _6017) ;
virtual void recap(int _6023) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedInts;

struct p_Parameters
{
Parameters * _pubthis;
static mosek::fusion::p_Parameters* _get_impl(mosek::fusion::Parameters * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Parameters * _get_impl(mosek::fusion::Parameters::t _inst) { return _get_impl(_inst.get()); }
p_Parameters(Parameters * _pubthis);
virtual ~p_Parameters() { /* std::cout << "~p_Parameters" << std::endl;*/ };
virtual void destroy();
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6032,const std::string &  _6033,double _6034);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6128,const std::string &  _6129,int _6130);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _6224,const std::string &  _6225,const std::string &  _6226);
static  int string_to_variabletype_value(const std::string &  _6464);
static  int string_to_value_value(const std::string &  _6465);
static  int string_to_streamtype_value(const std::string &  _6466);
static  int string_to_startpointtype_value(const std::string &  _6467);
static  int string_to_stakey_value(const std::string &  _6468);
static  int string_to_sparam_value(const std::string &  _6469);
static  int string_to_solveform_value(const std::string &  _6470);
static  int string_to_soltype_value(const std::string &  _6471);
static  int string_to_solsta_value(const std::string &  _6472);
static  int string_to_solitem_value(const std::string &  _6473);
static  int string_to_simseltype_value(const std::string &  _6474);
static  int string_to_sensitivitytype_value(const std::string &  _6475);
static  int string_to_scalingmethod_value(const std::string &  _6476);
static  int string_to_scalingtype_value(const std::string &  _6477);
static  int string_to_rescodetype_value(const std::string &  _6478);
static  int string_to_rescode_value(const std::string &  _6479);
static  int string_to_xmlwriteroutputtype_value(const std::string &  _6480);
static  int string_to_prosta_value(const std::string &  _6481);
static  int string_to_problemtype_value(const std::string &  _6482);
static  int string_to_problemitem_value(const std::string &  _6483);
static  int string_to_parametertype_value(const std::string &  _6484);
static  int string_to_presolvemode_value(const std::string &  _6485);
static  int string_to_orderingtype_value(const std::string &  _6486);
static  int string_to_optimizertype_value(const std::string &  _6487);
static  int string_to_onoffkey_value(const std::string &  _6488);
static  int string_to_objsense_value(const std::string &  _6489);
static  int string_to_mpsformat_value(const std::string &  _6490);
static  int string_to_mionodeseltype_value(const std::string &  _6491);
static  int string_to_miomode_value(const std::string &  _6492);
static  int string_to_miocontsoltype_value(const std::string &  _6493);
static  int string_to_branchdir_value(const std::string &  _6494);
static  int string_to_iparam_value(const std::string &  _6495);
static  int string_to_iomode_value(const std::string &  _6496);
static  int string_to_internal_iinf_value(const std::string &  _6497);
static  int string_to_internal_dinf_value(const std::string &  _6498);
static  int string_to_inftype_value(const std::string &  _6499);
static  int string_to_iinfitem_value(const std::string &  _6500);
static  int string_to_internal_liinf_value(const std::string &  _6501);
static  int string_to_liinfitem_value(const std::string &  _6502);
static  int string_to_dparam_value(const std::string &  _6503);
static  int string_to_feature_value(const std::string &  _6504);
static  int string_to_dinfitem_value(const std::string &  _6505);
static  int string_to_dataformat_value(const std::string &  _6506);
static  int string_to_symmattype_value(const std::string &  _6507);
static  int string_to_scopr_value(const std::string &  _6508);
static  int string_to_nametype_value(const std::string &  _6509);
static  int string_to_conetype_value(const std::string &  _6510);
static  int string_to_compresstype_value(const std::string &  _6511);
static  int string_to_checkconvexitytype_value(const std::string &  _6512);
static  int string_to_callbackcode_value(const std::string &  _6513);
static  int string_to_purify_value(const std::string &  _6514);
static  int string_to_intpnthotstart_value(const std::string &  _6515);
static  int string_to_simhotstart_value(const std::string &  _6516);
static  int string_to_simdupvec_value(const std::string &  _6517);
static  int string_to_simreform_value(const std::string &  _6518);
static  int string_to_uplo_value(const std::string &  _6519);
static  int string_to_transpose_value(const std::string &  _6520);
static  int string_to_simdegen_value(const std::string &  _6521);
static  int string_to_mark_value(const std::string &  _6522);
static  int string_to_boundkey_value(const std::string &  _6523);
static  int string_to_basindtype_value(const std::string &  _6524);
static  int string_to_language_value(const std::string &  _6525);
}; // struct Parameters;

}
}
namespace mosek
{
namespace fusion
{
namespace Utils
{
// mosek.fusion.Utils.IntMap from file 'src/fusion/cxx/IntMap_p.h'
struct p_IntMap 
{
  IntMap * _pubself;

  static p_IntMap * _get_impl(IntMap * _inst) { return _inst->_impl.get(); }

  p_IntMap(IntMap * _pubself) : _pubself(_pubself) {}

  static IntMap::t _new_IntMap() { return new IntMap(); }

  ::std::unordered_map<long long,int> m;

  bool hasItem (long long key) { return m.find(key) != m.end(); }
  int  getItem (long long key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (long long key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<long long,1>> keys()
  { 
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<long long,1>>(new monty::ndarray<long long,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;    
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  IntMap::t clone();
  IntMap::t __mosek_2fusion_2Utils_2IntMap__clone();
};



struct p_StringIntMap
{
  StringIntMap * _pubself;

  static p_StringIntMap * _get_impl(StringIntMap * _inst) { return _inst->_impl.get(); }

  p_StringIntMap(StringIntMap * _pubself) : _pubself(_pubself) {}

  static StringIntMap::t _new_StringIntMap() { return new StringIntMap(); }

  ::std::unordered_map<std::string,int> m;

  bool hasItem (const std::string & key) { return m.find(key) != m.end(); }
  int  getItem (const std::string & key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (const std::string & key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<std::string,1>> keys()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<std::string,1>>(new monty::ndarray<std::string,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  StringIntMap::t clone();
  StringIntMap::t __mosek_2fusion_2Utils_2StringIntMap__clone();
};
// End of file 'src/fusion/cxx/IntMap_p.h'
// mosek.fusion.Utils.StringBuffer from file 'src/fusion/cxx/StringBuffer_p.h'
// namespace mosek::fusion::Utils
struct p_StringBuffer
{
  StringBuffer * _pubthis; 
  std::stringstream ss;

  p_StringBuffer(StringBuffer * _pubthis) : _pubthis(_pubthis) {}

  static p_StringBuffer * _get_impl(StringBuffer::t ptr) { return ptr->_impl.get(); }
  static p_StringBuffer * _get_impl(StringBuffer * ptr) { return ptr->_impl.get(); }

  static StringBuffer::t _new_StringBuffer() { return new StringBuffer(); }

  StringBuffer::t clear ();
  
  StringBuffer::t a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t a (const monty::ndarray<int,1> & val);
  StringBuffer::t a (const monty::ndarray<long long,1> & val);
  StringBuffer::t a (const monty::ndarray<double,1> & val);
  

  StringBuffer::t a (const int & val);
  StringBuffer::t a (const long long & val);
  StringBuffer::t a (const double & val);
  StringBuffer::t a (const bool & val);
  StringBuffer::t a (const std::string & val);

  StringBuffer::t lf ();
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__clear ();

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<int,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<long long,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<double,1> & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const int & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const long long & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const double & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const bool & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const std::string & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__lf ();

  std::string toString () const;
};
// End of file 'src/fusion/cxx/StringBuffer_p.h'
}
}
}
#endif
